﻿/*
 * mTools - © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous
 * la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou 
 * implicites.
 * Consultez la Licence pour les autorisations et les restrictions 
 * linguistiques spécifiques relevant de la Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Xml;
using System.Configuration;

namespace MetaNull.Configuration
{
	/// <summary>
	/// Helper functions for accessing XML Configuration files
	/// </summary>
	public class ConfigurationHelper
	{
		/// <summary>
		/// Helper method for retrieving string values from xmlnode.
		/// </summary>
		/// <param name="_node"></param>
		/// <param name="_attribute"></param>
		/// <param name="_val"></param>
		/// <returns></returns>
		public static XmlNode GetStringValue(XmlNode _node, string _attribute, ref string _val)
		{
			XmlNode a = _node.Attributes.RemoveNamedItem(_attribute);
			if (a == null)
			{
				throw new ConfigurationErrorsException("Attribute required: " + _attribute);
			}
			else
			{
				_val = a.Value;
			} 
			return a;
		}
		/// <summary>
		/// Helper method for retrieving bool values from xmlnode.
		/// </summary>
		/// <param name="_node"></param>
		/// <param name="_attribute"></param>
		/// <param name="_val"></param>
		/// <returns></returns>
		public static XmlNode GetBoolValue(XmlNode _node, string _attribute, ref bool _val)
		{
			XmlNode a = _node.Attributes.RemoveNamedItem(_attribute);
			if (a == null)
			{
				throw new ConfigurationErrorsException("Attribute required: " + _attribute);
			}
			else
			{
				_val = Boolean.Parse(a.Value);
			}
			return a;
		}
		/// <summary>
		/// Helper method for retrieving int values from xmlnode.
		/// </summary>
		/// <param name="_node"></param>
		/// <param name="_attribute"></param>
		/// <param name="_val"></param>
		/// <returns></returns>
		public static XmlNode GetIntValue(XmlNode _node, string _attribute, ref int _val)
		{
			XmlNode a = _node.Attributes.RemoveNamedItem(_attribute);
			if (a == null)
			{
				throw new ConfigurationErrorsException("Attribute required: " + _attribute);
			}
			else
			{
				_val = int.Parse(a.Value);
			}
			return a;
		}
		/// <summary>
		/// Helper method for retrieving double values from xmlnode.
		/// </summary>
		/// <param name="_node"></param>
		/// <param name="_attribute"></param>
		/// <param name="_val"></param>
		/// <returns></returns>
		public static XmlNode GetDoubleValue(XmlNode _node, string _attribute, ref double _val)
		{
			XmlNode a = _node.Attributes.RemoveNamedItem(_attribute);
			if (a == null)
			{
				throw new ConfigurationErrorsException("Attribute required: " + _attribute);
			}
			else
			{
				_val = double.Parse(a.Value);
			}
			return a;
		}
		/// <summary>
		/// Helper method for retrieving enum values from XmlNode.
		/// </summary>
		/// <param name="_node"></param>
		/// <param name="_attribute"></param>
		/// <param name="_enumType"></param>
		/// <param name="_val"></param>
		/// <returns></returns>
		public static XmlNode GetEnumValue(XmlNode _node, string _attribute, Type _enumType, ref int _val)
		{
			XmlNode a = _node.Attributes.RemoveNamedItem(_attribute);
			if (a == null)
			{
				throw new ConfigurationErrorsException("Attribute required: " + _attribute);
			}
			if (Enum.IsDefined(_enumType, a.Value))
			{
				_val = (int)Enum.Parse(_enumType, a.Value);
			}
			else
			{
				throw new ConfigurationErrorsException("Invalid Level: '" + a.Value + "'", a);
			}
			return a;
		}
	}
}
