﻿/*
 * mTools - © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous
 * la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou 
 * implicites.
 * Consultez la Licence pour les autorisations et les restrictions 
 * linguistiques spécifiques relevant de la Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace MetaNull.Threading
{
	/// <summary>
	/// Base class for thread parameters. Contains an unique &amp; auto-incremented
	/// instance counter (usefull to identify thread instances from within the 
	/// thread
	/// </summary>
	public class ThreadParameter
	{
		private static int GlobalInstanceNumber = 0;
		private int LocalInstanceNumber;
		/// <summary>
		/// Unique instance number of the current object
		/// </summary>
		public int InstanceNumber
		{
			get
			{
				return LocalInstanceNumber;
			}
		}

		/// <summary>
		/// Constructor
		/// </summary>
		public ThreadParameter()
		{
			lock (UniqueLock.Lock)
			{
				LocalInstanceNumber = GlobalInstanceNumber++;
			}
		}

		private sealed class UniqueLock
		{
			/// <summary>
			/// Accessor to the unique instance of the Lock object
			/// </summary>
			public static object Lock
			{
				get
				{
					return Singleton.TheOnlyLockInstance;
				}
			}
			private object TheOnlyLockInstance;

			private static readonly UniqueLock Singleton = new UniqueLock();

			private UniqueLock()
			{
				TheOnlyLockInstance = new object();
			}
		}
	}
}
