/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */

#include "udf.h"


size_t GetLastErrorMessage( char * pszDest, size_t cbDest ) { 
	LPVOID lpMsgBuf = 0;
	DWORD dw = GetLastError(); 

	DWORD cb = FormatMessage(
		FORMAT_MESSAGE_ALLOCATE_BUFFER | 
		FORMAT_MESSAGE_FROM_SYSTEM |
		FORMAT_MESSAGE_IGNORE_INSERTS,
		NULL,
		dw,
		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
		(LPTSTR) &lpMsgBuf,
		0, NULL );

	if( 0 != cbDest ) {
		memset( pszDest,0, cbDest );
	}
	if( cbDest <= cb ) {
		return cb;
	}
	strncpy( pszDest, (const char *)lpMsgBuf, cbDest );
	LocalFree(lpMsgBuf);

	return 0;
}

size_t GetLastWSAErrorMessage( char * pszDest, size_t cbDest ) { 
	LPVOID lpMsgBuf = 0;
	DWORD dw = WSAGetLastError(); 

	DWORD cb = FormatMessage(
		FORMAT_MESSAGE_ALLOCATE_BUFFER | 
		FORMAT_MESSAGE_FROM_SYSTEM |
		FORMAT_MESSAGE_IGNORE_INSERTS,
		NULL,
		dw,
		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
		(LPTSTR) &lpMsgBuf,
		0, NULL );

	if( 0 != cbDest ) {
		memset( pszDest,0, cbDest );
	}
	if( cbDest <= cb ) {
		return cb;
	}
	strncpy( pszDest, (const char *)lpMsgBuf, cbDest );
	LocalFree(lpMsgBuf);

	return 0;
}

int format_init_error( char * pszDest, char * pszFormat, ... ) {
	va_list argp;
	va_start( argp, pszFormat );
	return _vsnprintf( pszDest, MYSQL_ERRMSG_SIZE, pszFormat, argp );
}

int log_write( const char * message, ... ) {
	va_list va;
	FILE * fp = 0;
	
	fp = fopen( LOG_FILE, "a" );
	if( 0 == fp ) {
		return errno;
	}
	
	va_start( va, message );
	vfprintf( fp, message, va );
	fprintf( fp, "\n" );
	va_end( va );
	fclose( fp );

	return 0;
}

char * udf_report_error( char * pszDest, size_t cbDest, unsigned long * length, char * error, const char * msg, ... ) {
	va_list va;
	va_start( va, msg );
	vsnprintf( pszDest, cbDest, msg, va );
	va_end( va );
	log_write( pszDest );
	*length = strlen( pszDest );
	*error = 1;
	return pszDest;
}
char * udf_report_win_error( char * pszDest, size_t cbDest, unsigned long * length, char * error, const char * msg, ... ) {
	va_list va;
	size_t offset = 0;

	va_start( va, msg );
	vsnprintf( pszDest, cbDest, msg, va );
	va_end( va );

	offset = strlen( pszDest );
	if( offset < cbDest - 2 ) {
		pszDest[offset] = '\n';
		pszDest[offset + 1] = 0;

		GetLastErrorMessage( pszDest + (offset + 1), cbDest - (offset + 1));
	}

	log_write( pszDest );
	*length = strlen( pszDest );
	*error = 1;
	return pszDest;
}
char * udf_report_clr_error( char * pszDest, size_t cbDest, unsigned long * length, char * error, const char * msg, ...  ) {
	va_list va;
	size_t offset = 0;

	va_start( va, msg );
	vsnprintf( pszDest, cbDest, msg, va );
	va_end( va );

	offset = strlen( pszDest );
	if( offset < cbDest - 2 ) {
		pszDest[offset] = '\n';
		pszDest[offset + 1] = 0;

		strerror_s( pszDest + (offset + 1), cbDest - (offset + 1), errno );	// NOT THREAD SAFE
	}
	log_write( pszDest );
	*length = strlen( pszDest );
	*error = 1;
	return pszDest;
}