/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */


// Libcurl requires additional libraries (see below), and requires CURL_STATICLIB to be defined on Windows
//#define CURL_STATICLIB 
#include <curl/curl.h>
//#pragma comment( lib, "libcurl.lib" )
//#pragma comment( lib, "ws2_32.lib" )
//#pragma comment( lib, "winmm.lib" )
//#pragma comment( lib, "wldap32.lib" )

#include "udf.h"
#include "udf_http.h"
#include "win32.h"

//			LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_COPYPOSTFIELDS,	args->args[1] ))) {		break; }
//			LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_POSTFIELDSIZE,	args->lengths[1] ))) {	break; }

#define ARG_URL					0
#define ARG_POST_FIELDS			1
#define ARG_HTTP_PROXY			2
#define ARG_HTTP_PROXY_PORT		3
#define ARG_HTTP_PROXY_USERPWD	4

#define ARGS_MIN				2
#define ARGS_WITHPROXY			4
#define ARGS_WITHPROXYAUTH		5
#define ARGS_MAX				ARGS_WITHPROXYAUTH
#define ARGS_INVALID			3

#define HTTPPOST_SYNTAX			"httpPost( string URL, string POST_FIELDS, string POST_FIELDS[, string HTTP_PROXY, int HTTP_PROXY_PORT[, string HTTP_PROXY_USERPWD]] )"

/**
 * httpPost( string URL, string POST_FIELDS, string POST_FIELDS[, string HTTP_PROXY, int HTTP_PROXY_PORT[, string HTTP_PROXY_USERPWD]] )
 */
my_bool httpPost_init(UDF_INIT *initid, UDF_ARGS *args, char *message){
	int stError = MYSQL_ERRMSG_SIZE;
	char szError[MYSQL_ERRMSG_SIZE];
	char * url = 0, * postfields = 0, * proxyHost = 0, * proxyUserPwd = 0, * certificate = 0;
	long proxyPort = 0, postfieldsize = 0;
	CURL * pCurl = 0;
	CURLcode curlError = CURLE_OK;
	char * pszCurlError = 0;
	void * pCurlDataPtr = 0;
	struct sizedBuffer * psbBuffer = 0;
	unsigned char fError = 0;
	unsigned long cbAlloc = 0;
	int LAST_LINE = 0;
	
	memset( (void *) szError, 0, MYSQL_ERRMSG_SIZE );
	
	// Check arguments
	if( args->arg_count < ARGS_MIN || args->arg_count > ARGS_MAX || args->arg_count == ARGS_INVALID ) {	
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Wrong arguments count for " HTTPPOST_SYNTAX "." );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[ARG_URL] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Invalid argument type for " HTTPPOST_SYNTAX ": string expected for argument %d (URL)", ARG_URL + 1 );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[ARG_POST_FIELDS] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Invalid argument type for " HTTPPOST_SYNTAX ": string expected for argument %d (POST_FIELDS)", ARG_POST_FIELDS + 1 );
		return RC_INIT_ERROR;
	}
	if( args->arg_count >= ARGS_WITHPROXY && STRING_RESULT != args->arg_type[ARG_HTTP_PROXY] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Invalid argument type for " HTTPPOST_SYNTAX ": string expected for argument %d (PROXY HOST)", ARG_HTTP_PROXY + 1 );
		return RC_INIT_ERROR;
	}
	if( args->arg_count >= ARGS_WITHPROXY && INT_RESULT != args->arg_type[ARG_HTTP_PROXY_PORT] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Invalid argument type for " HTTPPOST_SYNTAX ": int expected for argument %d (PROXY PORT)", ARG_HTTP_PROXY_PORT + 1 );
		return RC_INIT_ERROR;
	}
	if( args->arg_count >= ARGS_WITHPROXYAUTH && STRING_RESULT != args->arg_type[ARG_HTTP_PROXY_USERPWD] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Invalid argument type for " HTTPPOST_SYNTAX ": string expected for argument %d (PROXY USER:PASSWORD)", ARG_HTTP_PROXY_USERPWD + 1 );
		return RC_INIT_ERROR;
	}

	// As MySQL string arguments might not be null terminated, they must be copied into 
	// standard C strings:
	// 1. Allocating
	do {
		cbAlloc = args->lengths[ARG_URL] + 1;
		url = (char *)malloc( cbAlloc );
		if( 0 == url ) {				fError = 1;	break;	}

		cbAlloc = args->lengths[ARG_POST_FIELDS] + 1;
		postfields = (char *)malloc( cbAlloc );
		if( 0 == url ) {				fError = 1;	break;	}
		
		cbAlloc = strlen( CERTIFICATE_PATH ) + 1;
		certificate = (char *)malloc( cbAlloc );
		if( 0 == certificate ) {		fError = 1; break; }

		if( args->arg_count >= ARGS_WITHPROXY ) {
			cbAlloc = args->lengths[ARG_HTTP_PROXY] + 1;
			proxyHost = (char *)malloc( cbAlloc );
			if( 0 == proxyHost ) {		fError = 1; break; }
		}
		if( args->arg_count >= ARGS_WITHPROXYAUTH ) {
			cbAlloc = args->lengths[ARG_HTTP_PROXY_USERPWD] + 1;
			proxyUserPwd = (char *)malloc( cbAlloc );
			if( 0 == proxyUserPwd ) {	fError = 1;	break; }
		}

		cbAlloc = sizeof( struct sizedBuffer );
		psbBuffer = (void *) malloc( cbAlloc );
		if( 0 == psbBuffer ) {			fError = 1;	break; }
	} while( 0 );	// Only once, to enable breaking
	if( fError ) {
		strerror_s( szError, stError, errno );
		if( 0 != url ) {			free( url );				url = 0;	}
		if( 0 != postfields ) {		free( postfields );			postfields = 0;	}
		if( 0 != certificate ) {	free( certificate );		certificate = 0;	}
		if( 0 != proxyHost ) {		free( proxyHost );			proxyHost = 0;	}
		if( 0 != proxyUserPwd ) {	free( proxyUserPwd );		proxyUserPwd = 0;	}
		if( 0 != psbBuffer ) {		free( psbBuffer );			psbBuffer = 0;	}
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Not enough memory to allocate %ud bytes. %s", cbAlloc, szError );
		return RC_INIT_ERROR;
	}
	// 2. Setting values
	psbBuffer->pData = 0;
	psbBuffer->cbData = 0;
	psbBuffer->cbLength = 0;
	strncpy_s( url, args->lengths[ARG_URL] + 1, args->args[ARG_URL], _TRUNCATE );
	strncpy_s( postfields, args->lengths[ARG_POST_FIELDS] + 1, args->args[ARG_POST_FIELDS], _TRUNCATE );
	postfieldsize = args->lengths[ARG_POST_FIELDS];
	strncpy_s( certificate, strlen( CERTIFICATE_PATH ) + 1, CERTIFICATE_PATH, _TRUNCATE );
	if( args->arg_count >= ARGS_WITHPROXY ) {
		strncpy_s( proxyHost, args->lengths[ARG_HTTP_PROXY] + 1, args->args[ARG_HTTP_PROXY], _TRUNCATE );
		proxyPort = (long)*(long long *)args->args[ARG_HTTP_PROXY_PORT];
	}
	if( args->arg_count >= ARGS_WITHPROXYAUTH ) {
		strncpy_s( proxyUserPwd, args->lengths[ARG_HTTP_PROXY_USERPWD] + 1, args->args[ARG_HTTP_PROXY_USERPWD], _TRUNCATE );
	}

	// Performs the REQUEST (can't be done in the "main" httpPost function as we need to send back the size of the output
	pCurl = curl_easy_init();
	if( 0 == pCurl ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:Init: Error initializing cURL library" );
		return RC_INIT_ERROR;
	}
	do {
		// URL
		if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_URL,				url ))) {	break; }

		// OPTIONS
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_POST,				1 ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_POSTFIELDS,		(void *)postfields ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_POSTFIELDSIZE,	(void *)postfieldsize ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_HEADER,			0 ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_AUTOREFERER,		1 ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_FOLLOWLOCATION,	1 ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_MAXREDIRS,		3 ))) {		break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_WRITEFUNCTION,	(void *)curlReceiveCallback ))) {	break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_WRITEDATA,		(void *)psbBuffer  ))) {			break; }

		// SSL
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_CAINFO,			certificate  ))) {	break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_SSL_VERIFYHOST,	0  ))) {			break; }
		LAST_LINE = __LINE__;	if( CURLE_OK != (curlError = curl_easy_setopt( pCurl, CURLOPT_SSL_VERIFYPEER,	0  ))) {			break; }

		// If a proxy is set
		if( args->arg_count >= ARGS_WITHPROXY ) {
			LAST_LINE = __LINE__;	if( CURLE_OK != ( curlError = curl_easy_setopt( pCurl, CURLOPT_PROXY,		proxyHost ))) {			break; }
			LAST_LINE = __LINE__;	if( CURLE_OK != ( curlError = curl_easy_setopt( pCurl, CURLOPT_PROXYPORT,	proxyPort ))) {			break; }
			LAST_LINE = __LINE__;	if( CURLE_OK != ( curlError = curl_easy_setopt( pCurl, CURLOPT_PROXYTYPE,	CURLPROXY_HTTP ))) {	break; }

			// If authentication is provided for the proxy
			if( args->arg_count >= ARGS_WITHPROXYAUTH ) {
				LAST_LINE = __LINE__;	if( CURLE_OK != ( curlError = curl_easy_setopt( pCurl, CURLOPT_PROXYUSERPWD, proxyUserPwd ))) {	break; }
			}
		} 
		// If no proxy is set
		else {
			LAST_LINE = __LINE__;	if( CURLE_OK != ( curlError = curl_easy_setopt( pCurl, CURLOPT_PROXY, "" ))) {		break;	}
		}

		// Performs the HTTP request
		if( CURLE_OK != (curlError = curl_easy_perform( pCurl ))) {		
			break;	
		}
	} while( 0 );	// Only once, just to enable breaking in case of error

	// Set the error message if any (before freeing libcurl)
	if( CURLE_OK != curlError ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "%d, httpPost:Init: cURL error: %s", LAST_LINE, curl_easy_strerror( curlError ) );
	}
	if( 0 != url ) {			free( url );				url = 0;	}
	if( 0 != postfields ) {		free( postfields );			postfields = 0;	}
	if( 0 != certificate ) {	free( certificate );		certificate = 0;	}
	if( 0 != proxyHost ) {		free( proxyHost );			proxyHost = 0;	}
	if( 0 != proxyUserPwd ) {	free( proxyUserPwd );		proxyUserPwd = 0;	}
	if( 0 != pszCurlError ) {	curl_free( pszCurlError );	pszCurlError = 0;	}
	if( 0 != pCurl ) {			curl_easy_cleanup( pCurl );	pCurl = 0;	}
	if( CURLE_OK != curlError ) {
		if( CURLE_WRITE_ERROR == curlError ) {
			strerror_s( szError, stError, errno );
			_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "httpPost:init: Not enough memory to retreive the document: %s", szError );	// ATTENTION, NOT THREAD SAFE (because of errno)
			return RC_INIT_ERROR;
		}
		if( 0 != psbBuffer ) {
			if( 0 != psbBuffer->pData ) {
				free( psbBuffer->pData );
				psbBuffer->pData = 0;
				psbBuffer->cbData = 0;
			}
			free( psbBuffer );
			psbBuffer = 0;
		}
		return RC_INIT_ERROR;
	}

	// Allocate memory for output/Tell MySQL about max size of the result
	initid->max_length = psbBuffer->cbLength;
	initid->ptr = (void *)psbBuffer;

	// Set information about the return type
	initid->maybe_null = 0;

	// Return
	return RC_INIT_SUCCESS;
}
void httpPost_deinit(UDF_INIT *initid){
	struct sizedBuffer * psbBuffer = (struct sizedBuffer*)initid->ptr;
	// Free allocated memory
	if( 0 != initid->ptr && 0 != psbBuffer->pData ) {
		free( (void *)psbBuffer->pData );
	}
}

char * httpPost(UDF_INIT *initid, UDF_ARGS *args, char *result, unsigned long *length, char *null_value, char *error ) {
	struct sizedBuffer * psbBuffer = (struct sizedBuffer*)initid->ptr;
	*null_value = 0;
	*error = 0;
	*length = psbBuffer->cbLength;
	return (char *)psbBuffer->pData;
}