/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */

// Winsock2 MUST be included before Windows.h
#include <winsock2.h>
#include <windows.h>
//#pragma comment( lib, "ws2_32.lib" )

#include "udf.h"
#include "udf_mDownloader.h"
#include "win32.h"

#define ARGS_MIN		3
#define ARGS_MAX_ARGUMENTS	10
#define ARGS_MAX		ARGS_ARGUMENT_0 + ARGS_MAX_ARGUMENTS

#define ARG_SERVER		0
#define ARG_PORT		1
#define ARG_COMMAND		2
#define ARG_ARGUMENT_0	3

#define MUDFSERVICE_MAX_OUTPUT	(4*1024)

/**
 * mDownloader( string SERVER, int PORT, int COMMAND[, string[] COMMAND_ARGUMENTS] )
 */
my_bool mDownloader_init(UDF_INIT *initid, UDF_ARGS *args, char *message){
	int buffer_size = 0;
	int stError = MYSQL_ERRMSG_SIZE;
	char szError[MYSQL_ERRMSG_SIZE];
	int i = 0;

	memset( (void *) szError, 0, MYSQL_ERRMSG_SIZE );

	// Check arguments
	if( args->arg_count < ARGS_MIN ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "mDownloader:Init: Wrong arguments count for mDownloader(string SERVER, int PORT, int COMMAND[, string[] COMMAND_ARGUMENTS])." );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[ARG_SERVER] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "mDownloader:Init: Wrong argument type for mDownloader(string SERVER, int PORT, int COMMAND[, string[] COMMAND_ARGUMENTS])", szError );
		return RC_INIT_ERROR;
	}
	if( INT_RESULT != args->arg_type[ARG_PORT] ) {
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "mDownloader:Init: Wrong argument type for mDownloader(string SERVER, int PORT, int COMMAND[, string[] COMMAND_ARGUMENTS])", szError );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[ARG_COMMAND] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "mDownloader:Init: Wrong argument type for mDownloader(string SERVER, int PORT, int COMMAND[, string[] COMMAND_ARGUMENTS])", szError );
		return RC_INIT_ERROR;
	}
	// Request all other arguments to be converted into strings
	for( i = ARG_ARGUMENT_0; i < (int)args->arg_count; i ++ ) {
		args->arg_type[i] = STRING_RESULT;
	}

	// Initializes Winsock
	{	WORD wVersion = MAKEWORD(2,2);
		WSADATA wsaData = {0};
		int err = 0;

		err = WSAStartup( wVersion, &wsaData );
		if( 0 != err ) {
			strerror_s( szError, stError, errno );
			_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "mDownloader:init: Could not load WinSock 2.2 library", szError );
			return RC_INIT_ERROR;
		}
	}

	// Allocate memory for output
	initid->ptr = (char *)malloc(MUDFSERVICE_MAX_OUTPUT + 1);
	if( 0 == initid->ptr ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "mDownloader:init: Not enough memory to allocate %ud bytes: %s", MUDFSERVICE_MAX_OUTPUT, szError );	// ATTENTION, NOT THREAD SAFE (because of errno)
		return RC_INIT_ERROR;
	}
	memset( initid->ptr, 0, (size_t)MUDFSERVICE_MAX_OUTPUT + 1 );

	// Set information about the return type
	initid->max_length = (size_t)MUDFSERVICE_MAX_OUTPUT;
	initid->maybe_null = 1;

	// Return
	return RC_INIT_SUCCESS;
}
void mDownloader_deinit(UDF_INIT *initid){
	// Free allocated memory
	if( 0 != initid->ptr ) {
		free( (void *)initid->ptr );
	}
	// Release WinSock Lib
	WSACleanup();
}

/**
 * mDownloader( string SERVER, int PORT, int COMMAND[, string[] COMMAND_ARGUMENTS] )
 */
char * mDownloader(UDF_INIT *initid, UDF_ARGS *args, char *result, unsigned long *length, char *null_value, char *error){
	
	SOCKET hSocket = INVALID_SOCKET;
	
	char * pszHostName = args->args[ARG_SERVER];
	size_t cbHostName = (size_t)args->lengths[ARG_SERVER];
	
	char pszHostIP[46] = {0};	// IPV6 notation: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx (39 characters) or xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:ddd.ddd.ddd.ddd (45 characters)
	char * pszTmpHostIp = 0;
	
	unsigned short usPort = (short)*((long long *)args->args[ARG_PORT]);
	
	char * pszCommand = args->args[ARG_COMMAND];
	size_t cbCommand = (size_t)args->lengths[ARG_COMMAND];

	char * pszArguments[ARGS_MAX_ARGUMENTS];
	size_t cbArguments[ARGS_MAX_ARGUMENTS];
	size_t cbArgumentsCount = 0;

	char * pszSvcCommandLine = 0;
	size_t cbSvcCommandLine = 0;
	
	DWORD dwBytesRead = MUDFSERVICE_MAX_OUTPUT;
	
	struct sockaddr_in hostAddr = {0};
	struct hostent * ptmpHost = 0, host = {0};
	
	int sockRc = 0;
	char wsaerror[MYSQL_ERRMSG_SIZE];

	int i;
	DWORD dwTotal = 0;
	
	cbArgumentsCount = 0;
	for( i = ARG_ARGUMENT_0; i < (int)args->arg_count; i ++ ) {
		pszArguments[ i - ARG_ARGUMENT_0 ] = args->args[ i ];
		cbArguments[ i - ARG_ARGUMENT_0 ] = args->lengths[ i ];
		cbArgumentsCount ++;
	}

	memset( wsaerror, 0, MYSQL_ERRMSG_SIZE );
	sockRc = SOCKET_ERROR;
	hSocket = INVALID_SOCKET;

	// Sends the request
	do {
		// creates the socket
		hSocket = socket( AF_INET, SOCK_STREAM, IPPROTO_TCP );
		if( INVALID_SOCKET == hSocket ) {	break;	}

		ptmpHost = gethostbyname( pszHostName );
		if( 0 == ptmpHost ) {
			ptmpHost = gethostbyaddr( pszHostName, strlen( pszHostName ), AF_INET );
		}
		if( 0 == ptmpHost ) {	
			sockRc = SOCKET_ERROR;	
			break;		
		}
		memcpy( (void *)&host, (void *)ptmpHost, sizeof( host ));
		pszTmpHostIp = inet_ntoa( *(struct in_addr *)*host.h_addr_list );
		if( 0 == pszTmpHostIp ) {
			sockRc = SOCKET_ERROR;
			break;
		}
		strncpy_s( pszHostIP, 46, pszTmpHostIp, _TRUNCATE );
		
		hostAddr.sin_family = AF_INET;
		hostAddr.sin_addr.s_addr = inet_addr( pszHostIP );
		hostAddr.sin_port = htons( usPort );

		// prepares the packet
		pszSvcCommandLine = mString( pszCommand, cbCommand );
		if( 0 == pszSvcCommandLine ) {sockRc = (-2);	break;}
		for( i = 0; i < (int)cbArgumentsCount; i++ ) {
			char * pTmp = 0;
			if( FALSE == mConcatenateInPlace( &pszSvcCommandLine, "\n", &cbSvcCommandLine )) {sockRc = (-2);break;}
			pTmp = mString( pszArguments[i], cbArguments[i] );
			if( FALSE == mConcatenateInPlace( &pszSvcCommandLine, pTmp, &cbSvcCommandLine )) {sockRc = (-2);break;}
			mHeapFree( pTmp );
		}

		// sends the packet
		if( SOCKET_ERROR == (sockRc = connect( hSocket, (SOCKADDR*) &hostAddr, sizeof(hostAddr) )))	{	break;	}
		if( SOCKET_ERROR == (sockRc = send( hSocket, pszSvcCommandLine, (int)cbSvcCommandLine, 0 ))) { break; }
		if( SOCKET_ERROR == (sockRc = shutdown( hSocket, SD_SEND ))) { break;}

		mHeapFree( pszSvcCommandLine );		pszSvcCommandLine = 0;
	} while( 0 );	// Only once, to enable breaking

	// Process errors
	if( INVALID_SOCKET == hSocket || SOCKET_ERROR == sockRc || (-2) == sockRc ) {
		if( -2 == sockRc ) {
			GetLastErrorMessage( wsaerror, MYSQL_ERRMSG_SIZE );
		} else {
			GetLastWSAErrorMessage( wsaerror, MYSQL_ERRMSG_SIZE );
		}
		*error = 1;
		if( INVALID_SOCKET != hSocket ) {
			if( 0 != pszSvcCommandLine ) {
				mHeapFree( pszSvcCommandLine );
				pszSvcCommandLine = 0;
			}
			closesocket( hSocket );
			hSocket = INVALID_SOCKET;
		}
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "mDownloader: WinSock Error: %s", wsaerror );
	}

	// Receives answer if any
	dwTotal = 0;
	do {
		sockRc = recv( hSocket, initid->ptr + dwTotal, (int)(dwBytesRead - dwTotal), 0 );
		if( 0 == sockRc ) {
			// Connection closed
			break;
		}
		if( sockRc < 0 ) {
			GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
			*error = 1;
			closesocket( hSocket );
			return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "mDownloader: Error sending data to server" );
		}
		dwTotal += (DWORD)sockRc; 
	} while( sockRc > 0 && dwTotal <= dwBytesRead );
	*length = (unsigned long)dwTotal;
	if( 0 == dwTotal ) {
		*null_value = 1;
	} else {
		*null_value = 0;
	}
		
	closesocket( hSocket );	hSocket = INVALID_SOCKET;
	
	return initid->ptr;
	
}
