/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */

// Winsock2 MUST be included before Windows.h
#include <winsock2.h>
#include <windows.h>
//#pragma comment( lib, "ws2_32.lib" )

#include "udf.h"
//#include "udf_sockets.h"
#include "win32.h"


/**
 * tcpSend( string SERVER, int PORT, string MESSAGE, int BYTES_TO_READ_BACK )
 * if BYTES_TO_READ_BACK = 0 then no answer is expected
 */
my_bool tcpSend_init(UDF_INIT *initid, UDF_ARGS *args, char *message){
	int buffer_size = 0;
	int stError = MYSQL_ERRMSG_SIZE;
	char szError[MYSQL_ERRMSG_SIZE];
	memset( (void *) szError, 0, MYSQL_ERRMSG_SIZE );


	// Check arguments
	if( 4 != args->arg_count ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:Init: Wrong arguments count for tcpSend(string server, int port, string message, int bytesToReadBack): three arguments expected.", szError );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[0] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:Init: Wrong argument type for tcpSend(string server, int port, string message, int bytesToReadBack): string expected for argument 1", szError );
		return RC_INIT_ERROR;
	}
	if( INT_RESULT != args->arg_type[1] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:Init: Wrong argument type for tcpSend(string server, int port, string message, int bytesToReadBack): int expected for argument 2", szError );
		return RC_INIT_ERROR;
	}
	if( STRING_RESULT != args->arg_type[2] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:Init: Wrong argument type for tcpSend(string server, int port, string message, int bytesToReadBack): string expected for argument 3", szError );
		return RC_INIT_ERROR;
	}
	if( INT_RESULT != args->arg_type[3] ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:Init: Wrong argument type for tcpSend(string server, int port, string message, int bytesToReadBack): int expected for argument 4", szError );
		return RC_INIT_ERROR;
	}

	// Initializes Winsock
	{	WORD wVersion = MAKEWORD(2,2);
		WSADATA wsaData = {0};
		int err = 0;

		err = WSAStartup( wVersion, &wsaData );
		if( 0 != err ) {
			strerror_s( szError, stError, errno );
			_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:init: Could not load WinSock 2.2 library", szError );
			return RC_INIT_ERROR;
		}
	}

	// Allocate memory for output
	buffer_size = (int)*((long long*) args->args[3] );
	initid->ptr = (char *)malloc((size_t)buffer_size + 1);
	if( 0 == initid->ptr ) {
		strerror_s( szError, stError, errno );
		_snprintf_s( message, MYSQL_ERRMSG_SIZE, _TRUNCATE, "tcpSend:init: alloc(%d b): %s", buffer_size, szError );	// ATTENTION, NOT THREAD SAFE (because of errno)
		return RC_INIT_ERROR;
	}
	memset( initid->ptr, 0, (size_t)buffer_size + 1 );

	// Set information about the return type
	initid->max_length = (size_t)buffer_size;
	initid->maybe_null = 1;

	// Return
	return RC_INIT_SUCCESS;
}
void tcpSend_deinit(UDF_INIT *initid){
	// Free allocated memory
	if( 0 != initid->ptr ) {
		free( (void *)initid->ptr );
	}

	WSACleanup();
}
char * tcpSend(UDF_INIT *initid, UDF_ARGS *args, char *result, unsigned long *length, char *null_value, char *error){
	SOCKET hSocket = INVALID_SOCKET;
	char * pszHostName = args->args[0];
	size_t cbHostName = (size_t)args->lengths[0];
	char pszHostIP[46] = {0};	// IPV6 notation: xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:xxxx (39 characters) or xxxx:xxxx:xxxx:xxxx:xxxx:xxxx:ddd.ddd.ddd.ddd (45 characters)
	char * pszTmpHostIp = 0;
	unsigned short usPort = (short)*((long long *)args->args[1]);
	char * pszMessage = args->args[2];
	size_t cbMessage = (size_t)args->lengths[2];
	DWORD dwBytesRead = (DWORD)*((long long *)args->args[3]);
	BOOL fRc = 0;
	struct sockaddr_in hostAddr = {0};
	struct hostent * ptmpHost = 0, host = {0};
	int iRc = 0;

	hSocket = socket( AF_INET, SOCK_STREAM, IPPROTO_TCP );
	if( INVALID_SOCKET == hSocket ) {
		GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
		*error = 1;
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Error creating the TCP/IP socket" );
	}

	ptmpHost = gethostbyname( pszHostName );
	if( 0 == ptmpHost ) {
		ptmpHost = gethostbyaddr( pszHostName, strlen( pszHostName ), AF_INET );
	}
	if( 0 == ptmpHost ) {
		GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
		*error = 1;
		closesocket( hSocket );
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Invalid Hostname" );
	}
	memcpy( (void *)&host, (void *)ptmpHost, sizeof( host ));
	pszTmpHostIp = inet_ntoa( *(struct in_addr *)*host.h_addr_list );
	if( 0 == pszTmpHostIp ) {
		*error = 1;
		closesocket( hSocket );
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Invalid address" );
	}
	strncpy( pszHostIP, pszTmpHostIp, 46 );
	
	hostAddr.sin_family = AF_INET;
	hostAddr.sin_addr.s_addr = inet_addr( pszHostIP );
	hostAddr.sin_port = htons( usPort );

	if( SOCKET_ERROR == connect( hSocket, (SOCKADDR*) &hostAddr, sizeof(hostAddr) )) {
		GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
		*error = 1;
		closesocket( hSocket );
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Error connecting to server" );
	}

	iRc = send( hSocket, pszMessage, (int)cbMessage, 0 );
	if( SOCKET_ERROR == iRc ) {
		GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
		*error = 1;
		closesocket( hSocket );
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Error sending data to server" );
	}

	iRc = shutdown( hSocket, SD_SEND );
	if( SOCKET_ERROR == iRc ) {
		GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
		*error = 1;
		closesocket( hSocket );
		return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Error sending data to server" );
	}

	if( 0 != dwBytesRead ) {
		DWORD dwTotal = 0;
		do {
			iRc = recv( hSocket, initid->ptr + dwTotal, (int)(dwBytesRead - dwTotal), 0 );
			if( 0 == iRc ) {
				// Connection closed
				break;
			}
			if( iRc < 0 ) {
				GetLastWSAErrorMessage( result, MYSQL_ERRMSG_SIZE );
				*error = 1;
				closesocket( hSocket );
				return udf_report_win_error( result, MYSQL_ERRMSG_SIZE, length, error, "tcpSend: Error sending data to server" );
			}
			dwTotal += (DWORD)iRc; 
		} while( iRc > 0 && dwTotal <= dwBytesRead );
		*length = (unsigned long)dwTotal;
		if( 0 == dwTotal ) {
			*null_value = 1;
		} else {
			*null_value = 0;
		}
	} else {
		*length = 0;
		*null_value = 1;
	}
		
	closesocket( hSocket );	hSocket = INVALID_SOCKET;
	
	return initid->ptr;
	
}
