/*
* mUDFDownloader - Copyright 2010 the European Commission
* 
* Licensed under the EUPL (the Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
* http://ec.europa.eu/idabc/eupl.html
* 
* Unless required by applicable law or agreed to in
  writing, software distributed under the Licence is
  distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
  express or implied.
* See the Licence for the specific language governing
  permissions and limitations under the Licence.
*
* The software binaries include MySQL-C binaries (compiled from the un-modified
  MySQL-C source). 
* MySQL-C is copyrighted by Oracle Corp. and licensed under the Gnu GPL v 2.
*
*/
/*
 * Author: Pascal Havelange (Pascal.HAVELANGE@ec.europa.eu)
 */

#include "win32.h"

LPVOID mHeapAlloc( SIZE_T cbBytes ) {
	HANDLE hHeap = 0;
	LPVOID lpBuffer = 0;

	hHeap = GetProcessHeap();
	if( NULL == hHeap ) {
		return (LPVOID)0;
	}
	lpBuffer = HeapAlloc( hHeap, HEAP_ZERO_MEMORY, cbBytes );
	if( NULL == lpBuffer ) {
		return (LPVOID)0;
	}
	return lpBuffer;
}

BOOL mHeapReAlloc( LPVOID * lpBuffer, SIZE_T cbBytes ) {
	HANDLE hHeap = 0;
	LPVOID lpTmp = 0;

	hHeap = GetProcessHeap();
	if( NULL == hHeap ) {
		return FALSE;
	}
	lpTmp = HeapReAlloc( hHeap, HEAP_ZERO_MEMORY, lpBuffer, cbBytes );
	if( NULL == lpTmp ) {
		return FALSE;
	}
	*lpBuffer = lpTmp;
	return TRUE;
}

BOOL mHeapFree( LPVOID lpBuffer ) {
	HANDLE hHeap = 0;

	hHeap = GetProcessHeap();
	if( NULL == hHeap ) {
		return FALSE;
	}
	return HeapFree( hHeap, 0, lpBuffer );
}

SIZE_T mHeapSize( LPVOID lpBuffer ) {
	HANDLE hHeap = 0;

	hHeap = GetProcessHeap();
	if( NULL == hHeap ) {
		return FALSE;
	}
	return HeapSize( hHeap, 0, lpBuffer );
}


LPTSTR mDirname( LPCTSTR pszPath, LPDWORD pcbPath ) {
	LPTSTR lpFilePart = 0;
	LPTSTR lpFullPath = 0;
	lpFullPath = mRealPath( pszPath, pcbPath, &lpFilePart );
	if( 0 == lpFullPath ) {
		return (LPTSTR)0;
	}
	if( 0 == lpFilePart ) {
		return lpFullPath;
	}
	* pcbPath = lpFilePart - lpFullPath;
	*lpFilePart = (TCHAR)0;
	return lpFullPath;
}

LPTSTR mFilename( LPCTSTR pszPath, LPDWORD pcbPath ) {
	LPTSTR lpFilePart = 0;
	LPTSTR lpFullPath = 0;
	LPTSTR lpFilename = 0;
	DWORD cbPathname = 0;
	lpFullPath = mRealPath( pszPath, pcbPath, &lpFilePart );
	if( 0 == lpFullPath ) {
		return (LPTSTR)0;
	}
	if( 0 == lpFilePart ) {
		return lpFullPath;
	}
	cbPathname = lpFilePart - lpFullPath;
	*pcbPath -= cbPathname;
	lpFilename = mHeapAlloc( (*pcbPath) + 1 );
	if( 0 == lpFilename ) {
		mHeapFree( lpFullPath );
		return (LPTSTR)0;
	}
	CopyMemory( lpFilename, lpFilePart, *pcbPath );
	mHeapFree( lpFullPath );
	return lpFilename;
}

LPTSTR mRealPath( LPCTSTR pszPath, LPDWORD pcbPath, LPTSTR * lpFilePart ) {
	DWORD dwRc = 0;
	LPTSTR pszBuffer = 0;
	DWORD cbBuffer = 0;
	
	// Get the size of the path and allocate memory
	dwRc = GetFullPathName( pszPath, cbBuffer, pszBuffer, 0 );
	if( 0 == dwRc ) {
		return (LPTSTR)0;
	}
	cbBuffer = dwRc;
	pszBuffer = (LPTSTR)mHeapAlloc( cbBuffer );
	if( 0 == pszBuffer ) {
		return (LPTSTR)0;
	}

	// Get the fully qualified name
	dwRc = GetFullPathName( pszPath, cbBuffer, pszBuffer, lpFilePart );
	if( 0 == dwRc ) {
		mHeapFree( (LPVOID)pszBuffer );
		return (LPTSTR)0;
	}
	if( 0 != pcbPath ) {
		*pcbPath = cbBuffer;
	}
	return pszBuffer;
}

LPTSTR mSystemDirectory( LPDWORD pcbPath ) {
	DWORD dwRc = 0;
	LPTSTR pszBuffer = 0;
	DWORD cbBuffer = 0;
	
	// Get the size of the path and allocate memory
	dwRc = GetSystemDirectory( pszBuffer, cbBuffer );
	if( 0 == dwRc ) {
		return (LPTSTR)0;
	}
	cbBuffer = dwRc;
	pszBuffer = (LPTSTR)mHeapAlloc( cbBuffer );
	if( 0 == pszBuffer ) {
		return (LPTSTR)0;
	}

	// Get the fully qualified name
	dwRc = GetSystemDirectory( pszBuffer, cbBuffer );
	if( 0 == dwRc ) {
		mHeapFree( (LPVOID)pszBuffer );
		return (LPTSTR)0;
	}
	if( 0 != pcbPath ) {
		*pcbPath = cbBuffer;
	}
	return pszBuffer;
}

LPTSTR mWindowsDirectory( LPDWORD pcbPath ) {
	DWORD dwRc = 0;
	LPTSTR pszBuffer = 0;
	DWORD cbBuffer = 0;
	
	// Get the size of the path and allocate memory
	dwRc = GetWindowsDirectory( pszBuffer, cbBuffer );
	if( 0 == dwRc ) {
		return (LPTSTR)0;
	}
	cbBuffer = dwRc;
	pszBuffer = (LPTSTR)mHeapAlloc( cbBuffer );
	if( 0 == pszBuffer ) {
		return (LPTSTR)0;
	}

	// Get the fully qualified name
	dwRc = GetWindowsDirectory( pszBuffer, cbBuffer );
	if( 0 == dwRc ) {
		mHeapFree( (LPVOID)pszBuffer );
		return (LPTSTR)0;
	}
	if( 0 != pcbPath ) {
		*pcbPath = cbBuffer;
	}
	return pszBuffer;
}

LPTSTR mCurrentDirectory( LPDWORD pcbPath ) {
	DWORD dwRc = 0;
	LPTSTR pszBuffer = 0;
	DWORD cbBuffer = 0;
	LPTSTR pszFqBuffer = 0;
	DWORD cbFqBuffer = 0;
	
	// Get the size of the path and allocate memory
	dwRc = GetCurrentDirectory( cbBuffer, pszBuffer );
	if( 0 == dwRc ) {
		return (LPTSTR)0;
	}
	cbBuffer = dwRc;
	pszBuffer = (LPTSTR)mHeapAlloc( cbBuffer );
	if( 0 == pszBuffer ) {
		return (LPTSTR)0;
	}

	// Get the path name
	dwRc = GetCurrentDirectory( cbBuffer, pszBuffer );
	if( 0 == dwRc ) {
		mHeapFree( (LPVOID)pszBuffer );
		return (LPTSTR)0;
	}
	if( 0 != pcbPath ) {
		*pcbPath = cbBuffer;
	}

	// Get the fully qualified name
	pszFqBuffer = mRealPath( pszBuffer, &cbFqBuffer, 0 );
	mHeapFree( (LPVOID)pszBuffer );
	if( 0 == pszFqBuffer ) {
		return (LPTSTR)0;
	}
	*pcbPath = cbFqBuffer;
	return pszFqBuffer;
}

LPTSTR mGetLastErrorMessage( LPDWORD pcbBuffer ) { 
	LPVOID lpMsgBuf = 0;
	LPTSTR pszBuffer = 0;
	DWORD dwError = 0;

	dwError = GetLastError(); 
	*pcbBuffer = FormatMessage(
		FORMAT_MESSAGE_ALLOCATE_BUFFER | 
		FORMAT_MESSAGE_FROM_SYSTEM |
		FORMAT_MESSAGE_IGNORE_INSERTS,
		NULL,
		dwError,
		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
		(LPTSTR) &lpMsgBuf,
		0, NULL );

	if( (DWORD)0 == *pcbBuffer ) {
		return (LPTSTR)0;
	}
	pszBuffer = mHeapAlloc( ((SIZE_T)(*pcbBuffer)) + 1 );
	if( (LPVOID)0 == pszBuffer ) {
		return (LPTSTR)0;
	}
	CopyMemory( (PVOID)pszBuffer, (const VOID *)lpMsgBuf, *pcbBuffer );
	LocalFree(lpMsgBuf);	lpMsgBuf = 0;
	pszBuffer[*pcbBuffer] = 0;

	return pszBuffer;
}

LPTSTR mFormatMessage( LPCTSTR pszFormat, LPDWORD pcbBuffer, ... ) {
	LPVOID lpMsgBuf = 0;
	LPTSTR pszBuffer = 0;
	DWORD dwError = 0;
	va_list va;

	va_start( va, pcbBuffer );

	*pcbBuffer = FormatMessage(
		FORMAT_MESSAGE_ALLOCATE_BUFFER | 
		FORMAT_MESSAGE_FROM_STRING,
		pszFormat,
		0, 0,
		(LPTSTR) &lpMsgBuf, 0, 
		&va
	);
	if( (DWORD)0 == *pcbBuffer ) {
		return (LPTSTR)0;
	}
	pszBuffer = mHeapAlloc( ((SIZE_T)(*pcbBuffer)) + 1 );
	if( (LPVOID)0 == pszBuffer ) {
		return (LPTSTR)0;
	}
	CopyMemory( (PVOID)pszBuffer, (const VOID *)lpMsgBuf, *pcbBuffer );
	LocalFree(lpMsgBuf);	lpMsgBuf = 0;
	pszBuffer[*pcbBuffer] = 0;

	va_end( va );
	return pszBuffer;
}

LPTSTR mConcatenate( LPCTSTR pszStr1, LPCTSTR pszStr2, LPDWORD pcbResult ) {
	return mFormatMessage( "%1%2%0", pcbResult, pszStr1, pszStr2 );
}

BOOL mConcatenateInPlace( LPTSTR * pszStr1, LPCTSTR pszStr2, LPDWORD pcbResult ) {
	LPTSTR pszTemp1 = 0;
	LPTSTR pszTemp2 = 0;
	
	pszTemp1 = mConcatenate( *pszStr1, pszStr2, pcbResult );
	if( 0 == pszTemp1 ) {
		return FALSE;
	}
	pszTemp2 = *pszStr1;
	*pszStr1 = pszTemp1;
	mHeapFree( pszTemp2 );
	return TRUE;
}

LPTSTR mString( LPCTSTR pszStr, DWORD cbStr ) {
	LPTSTR pszTemp = mHeapAlloc( cbStr + 1 );
	if( 0 == pszTemp ) {
		return 0;
	}
	strncpy_s( pszTemp, cbStr + 1, pszStr, _TRUNCATE );
	pszTemp[cbStr] = 0;	// not needed as soon as mHeapAlloc zeroes allocated memory
	return pszTemp;
}