﻿/*
 * mAggregatorStatus - © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.IO;
using System.Reflection;
using System.Xml;
using System.Xml.Xsl;
using System.Xml.XPath;

using System.Xml.Linq;

using System.Resources;
using System.Globalization;

namespace mAggregatorService
{
	
		/// <summary>
		/// Class meant to hold compiled stylesheets, each as a singleton (only one instance of the object)
		/// </summary>
		/// <remarks>
		/// .NET's XslCompiledTransform() creates and loads one Assembly for each XSL sheet loaded... 
		/// so better to load it only once to avoid memory overflow
		/// After processing, you should delete the temporary assemblies using the
		/// XslCompiledTransform.TemporaryFiles list
		/// </remarks>
		public sealed class CompiledXslFiles
		{
			#region StyleSheet Objects
			// Add one object for each stylesheet to load
			private XslCompiledTransform _RSSParser;

			#endregion

			#region Accessors
			// Add one Getter for each Parser
			public static XslCompiledTransform RSSParser
			{
				get
				{
					return _instance._RSSParser;
				}
			}
			#endregion

			#region Singleton Code
			static readonly CompiledXslFiles _instance = new CompiledXslFiles();

			private CompiledXslFiles()
			{
				
#if DEBUG
				bool fDebug = true;
#else
				bool fDebug = false;
#endif

				// Load every XML document in the objects
				XmlDocument xsl = mXslTools.LoadXmlResource("rss_simplify.xsl");
				_RSSParser = new XslCompiledTransform(fDebug);
				_RSSParser.Load(xsl);
			}
			#endregion

		}

}
