CREATE DATABASE  IF NOT EXISTS `mDownloader` /*!40100 DEFAULT CHARACTER SET utf8 */;
USE `mDownloader`;

CREATE USER 'Downloader'@'localhost' IDENTIFIED BY 'D0wnl04der';
GRANT SELECT, INSERT, UPDATE, DELETE ON `mDownloader`.* TO 'Downloader'@'localhost';

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

DROP TABLE IF EXISTS `ajax_call_urls`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ajax_call_urls` (
  `call_id` int(10) unsigned NOT NULL COMMENT 'Id of the Ajax Call',
  `url_id` smallint(5) unsigned NOT NULL COMMENT 'Id of the URL in the current multi-call',
  `url` varchar(1024) NOT NULL COMMENT 'URL to fetch',
  `post_fields` longtext COMMENT 'the full data to post in an HTTP POST operation. You must make sure that the data is formatted the way you want the server to receive it',
  `http_code` smallint(5) unsigned default NULL COMMENT 'HTTP return code once the URL has been retrieved',
  `call_content` longblob COMMENT 'Data returned by the URL',
  `call_content_length` int(10) unsigned default NULL COMMENT 'Length of the data',
  `call_content_type` varchar(255) default 'application/binary',
  `call_header` text COMMENT 'HTTP Header of the document at the given URL',
  `call_error` text COMMENT 'Error data or NULL',
  `duration` float default NULL COMMENT 'Duration in seconds of the download',
  `last_update` datetime default NULL COMMENT 'Date/time at which the URL process was ended',
  `method` enum('get','post') NOT NULL default 'get' COMMENT 'Only GET is implemented at the moment',
  `use_proxy` enum('yes','no') NOT NULL default 'no' COMMENT 'If set to yes, uses the HTTP Proxy',
  PRIMARY KEY  (`call_id`,`url_id`),
  KEY `idx_content_type` (`call_content_type`),
  KEY `idx_content_length` (`call_content_length`),
  KEY `idx_durations` (`duration`),
  KEY `idx_method` (`method`),
  CONSTRAINT `fk_ajax_call_urls_ajax_calls` FOREIGN KEY (`call_id`) REFERENCES `ajax_calls` (`call_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

DROP TABLE IF EXISTS `ajax_calls`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `ajax_calls` (
  `call_id` int(10) unsigned NOT NULL auto_increment COMMENT 'Id of the Ajax Call',
  `call_time` datetime default NULL COMMENT 'Date/time at which the call was issued',
  `user_id` varchar(16) default NULL COMMENT 'The user which is requesting the URL',
  PRIMARY KEY  (`call_id`),
  KEY `FK_ajax_calls_users` (`user_id`),
  CONSTRAINT `FK_ajax_calls_users` FOREIGN KEY (`user_id`) REFERENCES `known_users` (`user_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=559 DEFAULT CHARSET=utf8;
/*!40101 SET character_set_client = @saved_cs_client */;

DELIMITER ;;
/*!50003 SET SESSION SQL_MODE="STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION" */;;
/*!50003 CREATE  TRIGGER `trg_oninsert_ajax_call` BEFORE INSERT ON `ajax_calls` FOR EACH ROW begin

	if new.`call_time` is null then

		set new.`call_time` = now();

	end if;

end */;;
DELIMITER ;

/*!50003 DROP FUNCTION IF EXISTS `split` */;
/*!50003 SET @saved_sql_mode       = @@sql_mode */ ;
/*!50003 SET sql_mode              = 'STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION' */ ;
DELIMITER ;;
/*!50003 CREATE FUNCTION `split`(str text, delim varchar(255), pos int) RETURNS text CHARSET utf8
BEGIN
    return replace(substring(substring_index(str, delim, pos), length(substring_index(str, delim, pos - 1)) + 1), delim, '');
END */;;
DELIMITER ;
/*!50003 SET sql_mode              = @saved_sql_mode */ ;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;
