﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using System.Data.Common;
using MySql.Data.MySqlClient;

namespace mDownloaderService
{
	[Serializable()]
	public class SavedCallResult
	{
		/// <summary>
		/// CallId as set in the database
		/// </summary>
		public long callId = 0;

		/// <summary>
		/// Saved documents
		/// </summary>
		public SavedDocument[] urls;

		public SavedCallResult()
		{
			callId = 0;
			urls = null;
		}
		public SavedCallResult(long callId)
		{
			this.callId = callId;
			this.urls = new SavedDocument[0];
		}

		public SavedCallResult(long callId, SavedDocument[] urls)
		{
			this.callId = callId;
			this.urls = new SavedDocument[0];
		}
	}

	[Serializable()]
	public class SavedDocument
	{
		/// <summary>
		/// CallId as set in the database
		/// </summary>
		public long callId = 0;

		/// <summary>
		/// UrlId as set in the database
		/// </summary>
		public long urlId = 0;

		/// <summary>
		/// Document download request
		/// </summary>
		public DownloadRequest request;

		/// <summary>
		/// Downloaded document
		/// </summary>
		public DownloadResponse response;

		public SavedDocument()
		{
			callId = urlId = 0;
			request = new DownloadRequest();
			response = new DownloadResponse();
		}

	}

	[Serializable()]
	public class DownloadResponse
	{
		public string Content;
		public string ContentType;
		public long ContentLength;
		public Encoding CharacterSet;
		public long Length;
		public string[] Headers;
		public string Error;
		public double Duration;
		public DateTime LastUpdate;

		public bool IsFailed {
			get {
				return null != Error;
			}
		}
		public bool IsComplete {
			get {
				return null != Error || null != Content;
			}
		}

		public DownloadResponse()
		{
			Length = 0;
		}

		public DownloadResponse(DbDataReader reader)
		{
			if( !reader.HasRows ){
				return;
			}

			List<string> columnNames = new List<string>();
			for( int i = 0; i < reader.FieldCount; i ++ ) {
				columnNames.Add(reader.GetName(i));
			}
			int idx = 0;
			if (-1 != (idx = columnNames.IndexOf("call_content_type")))
			{
				if( !reader.IsDBNull(idx)) {
					string[] parts = reader.GetString(idx).Split(new char[] {';'});
					ContentType = parts[0].Trim();
					if( parts.Length > 1) {
						foreach( string subpart in parts.Where((sp, index) => index != 0 )) {
							string[] more = subpart.Trim().Split(new char[] { '=' }, 1);
							if( more.Length == 2 && "charset" == more[0].Trim().ToLower() ) {
								CharacterSet = Encoding.GetEncoding( more[1] );
								break;
							}
						}
					}
				}
			}
			if( -1 != (idx = columnNames.IndexOf( "call_content_length" ))) {
				if( !reader.IsDBNull(idx)) {
					ContentLength = reader.GetInt64(idx);
				}
			}
			if( -1 != (idx = columnNames.IndexOf( "call_content" ))) {
				if( !reader.IsDBNull(idx)) {
					Content = reader.GetString(idx);
				}
			}
			if( -1 != (idx = columnNames.IndexOf( "call_header" ))) {
				if( !reader.IsDBNull(idx)) {
					Headers = reader.GetString(idx).Split(new char[] { '\n' });
				}
			}
			if( -1 != (idx = columnNames.IndexOf( "call_error" ))) {
				if( !reader.IsDBNull(idx)) {
					Error = reader.GetString(idx);
				}
			}
			if( -1 != (idx = columnNames.IndexOf( "duration" ))) {
				if( !reader.IsDBNull(idx)) {
					Duration = reader.GetDouble(idx);
				}
			}
			if( -1 != (idx = columnNames.IndexOf( "last_update" ))) {
				if( !reader.IsDBNull(idx)) {
					LastUpdate = reader.GetDateTime(idx);
				}
			}
		}
	}

	[Serializable()]
	public class SaveRequest
	{
		/// <summary>
		/// Request
		/// </summary>
		public ClientRequest request;
		/// <summary>
		/// Response
		/// </summary>
		public mWebDocument response;

		/// <summary>
		/// Build a SaveRequest
		/// </summary>
		/// <param name="request"></param>
		public SaveRequest(ClientRequest request, mWebDocument response)
		{
			this.request = request;
			this.response = response;
		}

		public SaveRequest()
		{
			response = null;
			request = null;
		}
	}

	[Serializable()]
	public class ClientRequest
	{
		/// <summary>
		/// CallId as set in the database
		/// </summary>
		public long callId = 0;
		/// <summary>
		/// UrlId as set in the database
		/// </summary>
		public long urlId = 0;
		/// <summary>
		/// Document downlaod request
		/// </summary>
		public DownloadRequest request;

		public ClientRequest()
		{
			callId = urlId = 0;
			request = null;
		}
		/// <summary>
		/// Build a ClientRequest
		/// </summary>
		/// <param name="request"></param>
		public ClientRequest(DownloadRequest request)
		{
			this.request = request;
		}

		/// <summary>
		/// Build a request
		/// </summary>
		/// <param name="callId"></param>
		/// <param name="urlId"></param>
		/// <param name="request"></param>
		public ClientRequest(long callId, long urlId, DownloadRequest request)
			: this(request)
		{
			this.callId = callId;
			this.urlId = urlId;
		}
	}

	public class DownloadRequest
	{
		/// <summary>
		/// HTTP Method
		/// </summary>
		public enum HttpMethod { get, post };

		/// <summary>
		/// URL of the resource
		/// </summary>
		public string url = null;

		/// <summary>
		/// HTTP Method to use
		/// </summary>
		public HttpMethod method = HttpMethod.get;

		/// <summary>
		/// Data for POST operations
		/// </summary>
		public byte[] data = new byte[0];

		/// <summary>
		/// Enable/disable HTTP proxy for this request
		/// </summary>
		public bool throughProxy = false;

		/// <summary>
		/// Build a DownloadRequest
		/// </summary>
		/// <param name="url"></param>
		/// <param name="throughProxy"></param>
		/// <param name="method"></param>
		/// <param name="data"></param>
		public DownloadRequest(string url, bool throughProxy, HttpMethod method, byte[] data)
		{
			this.url = url;
			this.throughProxy = throughProxy;
			this.method = method;
			this.data = data;
		}

		/// <summary>
		/// Build a POST DownloadRequest
		/// </summary>
		/// <param name="url"></param>
		/// <param name="throughProxy"></param>
		/// <param name="data"></param>
		public DownloadRequest(string url, bool throughProxy, byte[] data)
			: this(url, throughProxy, HttpMethod.post, data)
		{
		}
		/// <summary>
		/// Build a POST DownloadRequest, without proxy
		/// </summary>
		/// <param name="url"></param>
		/// <param name="data"></param>
		public DownloadRequest(string url, byte[] data)
			: this(url, false, data)
		{
		}

		/// <summary>
		/// Build a GET DownloadRequest
		/// </summary>
		/// <param name="url"></param>
		/// <param name="throughProxy"></param>
		public DownloadRequest(string url, bool throughProxy)
			: this(url, throughProxy, HttpMethod.get, new byte[0])
		{
		}
		/// <summary>
		/// Build a GET DownloadRequest, without proxy
		/// </summary>
		/// <param name="url"></param>
		public DownloadRequest(string url)
			: this(url, false)
		{
		}

		public DownloadRequest()
		{
			this.url = null;
			this.throughProxy = false;
			this.method = HttpMethod.get;
			this.data = null;
		}
	}

	
}
