﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;
using System.Net.Sockets;
using System.IO;
using System.IO.Pipes;
using System.Xml.Serialization;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters;
using System.Runtime.Serialization.Formatters.Binary;
using System.Runtime.Serialization.Formatters.Soap;
using MySql.Data.MySqlClient;
using System.IO.Compression;

namespace mDownloaderService
{
	public partial class mDownloaderService : ServiceBase
	{
		/// <summary>
		/// Client thread, receives commands sent by clients
		/// </summary>
		/// <param name="threadParam"></param>
		private void threadClient(object threadParam)
		{
			activeClients++;
			string threadSignature = "ClientThread";
			thparamClient param = null;
			try
			{
				using (DownloadDatabase dbInterface = new DownloadDatabase(cfgDbConnectionString, Encoding.GetEncoding(cfgDbTextEncoding)))
				{
					param = (thparamClient)threadParam;
					threadSignature = string.Format("{0} {1} ClientThread({2}): ", DateTime.Now.ToShortDateString(), DateTime.Now.ToShortTimeString(), param.client.Client.RemoteEndPoint.ToString());

					NetworkStream stream = param.client.GetStream();
					string[] command = GetClientCommand(stream);
					string result = GetClientHelp(); ;

					if (null != command && command.Length >= 1)
					{
						switch (command[0].ToLower())
						{
							case "get":
								{
									if (command.Length == 2 || command.Length == 3)
									{
										string url = command[1];
										bool useProxy = (command.Length == 3 && "no-proxy" == command[2]) ? false : true;

										ClientRequest request = dbInterface.DownloadRequestToClientRequest(new DownloadRequest(url, useProxy));
										result = request.callId.ToString();

										enqueueClientRequest(request);
									}
									else
									{
										result = "-1";
									}
								} break;
							case "post":
								{
									if (command.Length == 3 || command.Length == 4)
									{
										string url = command[1];
										byte[] data = Encoding.UTF8.GetBytes(command[2]);
										bool useProxy = (command.Length == 4 && "no-proxy" == command[3]) ? false : true;

										ClientRequest request = dbInterface.DownloadRequestToClientRequest(new DownloadRequest(url, useProxy, data));
										result = request.callId.ToString();

										enqueueClientRequest(request);
									}
									else
									{
										result = "-1";
									}
								} break;
							case "multi":
								{
									if (command.Length == 2)
									{
										long callId = long.Parse(command[1]);

										ClientRequest[] requests = dbInterface.FetchRequests(callId);
										if (null != requests && requests.Length > 0)
										{
											result = requests[0].callId.ToString();
											foreach (ClientRequest request in requests)
											{
												enqueueClientRequest(request);
											}
										}
										else
										{
											result = "-1";
										}
									}
								} break;
							case "makemulti":
								{
									string[] arguments = command.Where((str, index) => index != 0).ToArray();
									int remainder = 0;
									Math.DivRem(arguments.Length, 4, out remainder);
									if (0 != arguments.Length && 0 == remainder)
									{

										List<DownloadRequest> requests = new List<DownloadRequest>();
										for (int offset = 0; offset < arguments.Length / 4; offset += 4)
										{
											string method = arguments[0].ToLower();
											string url = arguments[1];
											string data = arguments[2];
											bool useProxy = arguments[3] == "no-proxy" ? false : true;

											if ("post" == method)
											{
												requests.Add( new DownloadRequest(url, useProxy, Encoding.UTF8.GetBytes(data)));
											}
											else
											{
												requests.Add( new DownloadRequest(url, useProxy));
											}
										}
										ClientRequest[] clientRequests = dbInterface.DownloadRequestToClientRequest(requests.ToArray());
										if (null != clientRequests && clientRequests.Length > 0)
										{
											result = clientRequests[0].callId.ToString();
											foreach (ClientRequest request in clientRequests)
											{
												enqueueClientRequest(request);
											}
										}
										else
										{
											result = "-1";
										}
									}
								} break;
							case "pending":
								{
									if (command.Length == 2)
									{
										long callId = long.Parse(command[1]);
										long pending = dbInterface.FetchPendingDownloads(callId);
										result = pending.ToString();
									}
								} break;
							case "reset":
								{
									if (command.Length == 2)
									{
										long callId = long.Parse(command[1]);
										int rc = dbInterface.ResetResponses(callId);
										result = rc.ToString();
									}
								} break;
							case "delete":
								{
									if (command.Length == 2)
									{
										long callId = long.Parse(command[1]);
										int rc = dbInterface.DeleteRequest(callId);
										result = rc.ToString();
									}
								} break;
							case "result":
								{
									if (command.Length >= 2)
									{
										long callId = long.Parse(command[1]);
										string[] arguments = command.Where((str, index) => index > 1).ToArray();

										List<int> UrlIdList = new List<int>();
										if (0 != arguments.Length)
										{
											foreach (string urlId in arguments)
											{
												UrlIdList.Add(int.Parse(urlId));
											}
										}
										SavedCallResult documents = dbInterface.FetchResults(callId, UrlIdList.ToArray());

										MemoryStream ms = new MemoryStream();
										using (GZipStream gz = new GZipStream(ms, CompressionMode.Compress, true))
										{
											XmlSerializer ser = new XmlSerializer(typeof(SavedCallResult));
											ser.Serialize(gz, documents);
										}
										ms.Position = 0;
										result = Convert.ToBase64String(ms.ToArray());
										ms.Close();

										/*
										StringWriter wri = new StringWriter();
										XmlSerializer ser = new XmlSerializer( typeof(SavedCallResult));
										ser.Serialize( wri, documents );
										result = wri.ToString();
										ms.Close();
										*/
										/*SoapFormatter ser = new SoapFormatter();
										MemoryStream ms = new MemoryStream();
										ser.Serialize( ms, documents );
										ms.Position = 0;
										result = (new StreamReader(ms)).ReadToEnd();
										ms.Close();
										*/
										/*
										IFormatter ser = new BinaryFormatter();
										MemoryStream ms = new MemoryStream();
										ser.Serialize(ms, documents);
										ms.Position = 0;
										result = (new StreamReader(ms)).ReadToEnd();
										ms.Close();
										*/
										/*result = string.Empty;
										result += "CallId:" + documents.callId.ToString() + "\n";
										foreach (SavedDocument doc in documents.urls)
										{
											result += "UrlId:" + doc.urlId + ";";
											if (null != doc.response.Error)
											{
												result += "Error:" + Convert.ToBase64String(Encoding.Unicode.GetBytes(doc.response.Error)) + ";";
											}
											else
											{
												result += "CharacterSet:" + doc.response.CharacterSet.WebName + ";";
												result += "ContentType:" + doc.response.ContentType + ";";
												result += "ContentLength:" + doc.response.ContentLength.ToString() + ";";
												result += "Content:" + Convert.ToBase64String(Encoding.Unicode.GetBytes(doc.response.Content)) + ";";
											}
											result += "\n";
										}
										ms.Close();
										*/

									}
								} break;
							case "help":
								{
									//result = GetClientHelp();
								} break;
							default:
								{
									//result = GetClientHelp();
								} break;
						}
					}

					byte[] response = Encoding.UTF8.GetBytes(result);
					if (response.Length > 0)
					{
						stream.Write(response, 0, response.Length);
					}
				}
			}
			catch (Exception e)
			{
				eventLog.WriteEntry(threadSignature + "Exception: " + e.Message + Environment.NewLine + e.StackTrace, EventLogEntryType.Error);
			}
			finally
			{
				if (null != param)
				{
					param.client.Close();
				}
				activeClients--;
			}
		}

		private string[] GetClientCommand(NetworkStream stream)
		{
			System.IO.MemoryStream ms = new System.IO.MemoryStream();
			int read_buffer_size = cfgBytesToReadAtOnce;
			byte[] read_buffer = new byte[read_buffer_size];
			do
			{
				int bytes_read = stream.Read(read_buffer, 0, read_buffer.Length);
				ms.Write(read_buffer, 0, bytes_read);
			} while (stream.DataAvailable);
			
			if( 0 == ms.Length ) {
				return null;
			}
			return Encoding.UTF8.GetString(ms.ToArray()).Split( new char[] {' ', '\t', '\n'} /*, 3*/);
		}

		private string GetClientHelp()
		{
			string help_buffer = "Available commands: " + Environment.NewLine;
			help_buffer += "- HELP:  Returns this message" + Environment.NewLine;
			help_buffer += "- GET:   Fetches a document using HTTP GET method" + Environment.NewLine;
			help_buffer += "   Syntax: GET http[s]://URL [no-proxy]" + Environment.NewLine;
			help_buffer += "- POST:  Fetches a document using HTTP POST method" + Environment.NewLine;
			help_buffer += "   Syntax: POST http[s]://URL POST-DATA [no-proxy]" + Environment.NewLine;
			help_buffer += "   Note:   POST-DATA must be escaped and valid; format: NAME=VALUE&NAME2=VALUE2&..." + Environment.NewLine;
			help_buffer += "- MULTI: Fetches several documents using settings from the configured database" + Environment.NewLine;
			help_buffer += "   Syntax: MULTI MultiID" + Environment.NewLine;
			help_buffer += "- MAKEMULTI: Fetches several documents" + Environment.NewLine;
			help_buffer += "   Syntax: MAKEMULTI (GET|POST URL POST-DATA proxy|no-proxy)+" + Environment.NewLine;
			return help_buffer;
		}

		/// <summary>
		/// Class of parameters passsed to threadClient threads
		/// </summary>
		protected class thparamClient
		{
			/// <summary>
			/// Connection with the client
			/// </summary>
			public TcpClient client;

			public thparamClient(TcpClient client)
			{
				this.client = client;
			}
		}

		private volatile int _activeClients = 0;
		private object lockActiveClients = new object();
		/// <summary>
		/// Counter indicating how many clients are currently being processed (how many threadClient in the ThreadPool)
		/// </summary>
		public int activeClients
		{
			get
			{
				lock (lockActiveClients)
				{
					return _activeClients;
				}
			}
			set
			{
				lock (lockActiveClients)
				{
					_activeClients = value;
				}
			}
		}
		private volatile int _receivedRequests = 0;
		private object lockReceivedRequests = new object();
		/// <summary>
		/// Counter indicating the total number of client requests received until now
		/// </summary>
		public int receivedRequests
		{
			get
			{
				lock (lockReceivedRequests)
				{
					return _receivedRequests;
				}
			}
			set
			{
				lock (lockReceivedRequests)
				{
					_receivedRequests = value;
				}
			}
		}
	}
}