﻿/*
 * © EUROPEAN COMMISSION, 2009-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la
«Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que
conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse
suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le
logiciel distribué sous la Licence est distribué «en
l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT,
expresses ou implicites.
 * Consultez la Licence pour les autorisations et les
restrictions linguistiques spécifiques relevant de la
Licence.
 *
 * Auteur de l'oeuvre: Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *
 */
using System;
using System.Collections;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Diagnostics;
using System.Linq;
using System.ServiceProcess;
using System.Text;
using System.Threading;
using System.Configuration;
using System.Net;
using System.Net.Sockets;
using System.IO;
using System.IO.Pipes;
using System.Runtime.Serialization;
using System.Runtime.Serialization.Formatters;
using System.Runtime.Serialization.Formatters.Binary;
using MySql.Data.MySqlClient;

namespace mDownloaderService
{
	public partial class mDownloaderService : ServiceBase
	{
		/// <summary>
		/// Downloader thread, downloads documents requested by clients
		/// </summary>
		/// <param name="threadParam"></param>
		private void threadDownload(object threadParam)
		{
			activeDownloads++;
			string threadSignature = "DownloadThread";
			try
			{
				thparamDownload param = (thparamDownload)threadParam;
				threadSignature = string.Format("{0} {1} DownloadThread({2}): ", DateTime.Now.ToShortDateString(), DateTime.Now.ToShortTimeString(), param.instanceNumber.ToString());

				while (!stopService.WaitOne(threadYieldTime))
				{
					ClientRequest request = dequeueClientRequest();
					if (null == request)
					{
						continue;
					}
/*					DateTime tiStart = DateTime.Now;
*/					mWebDocument response = Download(request);
/*					DateTime tiDlDone = DateTime.Now;
*/					enqueueSaveRequest(new SaveRequest(request, response));
/*					DateTime tiEnd = DateTime.Now;
					eventLog.WriteEntry(threadSignature + Environment.NewLine +
						"Url: " + request.callId + ", " + request.urlId + ": " + request.request.url + Environment.NewLine +
						"Starting download: " + tiStart.Hour + ":" + tiStart.Minute + ":" + tiStart.Second + "." + tiStart.Millisecond + Environment.NewLine +
						"Downloaded:        " + tiDlDone.Hour + ":" + tiDlDone.Minute + ":" + tiDlDone.Second + "." + tiDlDone.Millisecond + Environment.NewLine +
						"Sent for backup:   " + tiEnd.Hour + ":" + tiEnd.Minute + ":" + tiEnd.Second + "." + tiEnd.Millisecond + Environment.NewLine +
						"Total: " + (tiEnd - tiStart) + "; DL: " + (tiDlDone-tiStart) + "; SAVE: " + (tiEnd - tiDlDone)+ Environment.NewLine
					);
 * */
				}
			}
			catch (Exception e)
			{
				eventLog.WriteEntry(threadSignature + "Exception: " + e.Message + Environment.NewLine + e.StackTrace, EventLogEntryType.Error);
			}
			finally
			{
				activeDownloads--;
			}
		}

		/// <summary>
		/// Class of parameters passsed to threadDownload threads
		/// </summary>
		protected class thparamDownload
		{
			private static int _staticInstanceNumber = 0;
			private int _instanceNumber;

			public int instanceNumber
			{
				get
				{
					return _instanceNumber;
				}
			}

			public thparamDownload()
			{
				lock (lockThparamDownload)
				{
					_instanceNumber = _staticInstanceNumber++;
				}

			}
		}
		private static object lockThparamDownload = new object();

		private mWebDocument Download(ClientRequest request)
		{
			mWebDocumentRequestSettings settings = new mWebDocumentRequestSettings();
			settings.AllowAutoRedirect = true;
			settings.MaximumAutomaticRedirections = cfgHttpMaxRedirects;
			settings.Timeout = cfgHttpRequestTimeout;
			if (cfgUseProxy && request.request.throughProxy)
			{
				settings.Proxy = new WebProxy();
				settings.Proxy.Address = new Uri(ConfigurationSettings.AppSettings["proxyHost"]);
				if (null != ConfigurationSettings.AppSettings["proxyUser"])
				{
					settings.Proxy.Credentials = new NetworkCredential(ConfigurationSettings.AppSettings["proxyUser"], ConfigurationSettings.AppSettings["proxyPassword"]);
				}
				if (null != ConfigurationSettings.AppSettings["proxyBypass"])
				{
					settings.Proxy.BypassList = ConfigurationSettings.AppSettings["proxyBypass"].Split(';');
				}
			}
			mWebDocument document = null;
			if (DownloadRequest.HttpMethod.post == request.request.method)
			{
				document = mWebDocument.httpPost(request.request.url, request.request.data, settings);
			}
			else
			{
				document = mWebDocument.httpGet(request.request.url, settings);
			}

			return document;
		}

		private object lockDownloadQueue = new object();
		private volatile Queue<ClientRequest> downloadQueue = new Queue<ClientRequest>();
		protected void enqueueClientRequest(ClientRequest request)
		{
			lock (lockDownloadQueue)
			{
				downloadQueue.Enqueue(request);
			}
		}
		protected ClientRequest dequeueClientRequest()
		{
			if (downloadQueue.Count > 0)
			{
				lock (lockDownloadQueue)
				{
					if (downloadQueue.Count > 0)
					{
						return downloadQueue.Dequeue();
					}
				}
			}
			return null;
		}
		public int downloadQueueLength
		{
			get
			{
				lock (lockDownloadQueue)
				{
					return downloadQueue.Count();
				}
			}
		}

		private volatile int _activeDownloads = 0;
		private object lockActiveDownloads = new object();
		/// <summary>
		/// Counter indicating how many downloads are currently being processed (how many threadDownload in the ThreadPool)
		/// </summary>
		public int activeDownloads
		{
			get
			{
				lock (lockActiveDownloads)
				{
					return _activeDownloads;
				}
			}
			set
			{
				lock (lockActiveDownloads)
				{
					_activeDownloads = value;
				}
			}
		}
		private volatile int _initiatedDownloads = 0;
		private object lockInitiatedDownloads = new object();
		/// <summary>
		/// Counter indicating the total number of downloads started in response of client requests
		/// </summary>
		public int initiatedDownloads
		{
			get
			{
				lock (lockInitiatedDownloads)
				{
					return _initiatedDownloads;
				}
			}
			set
			{
				lock (lockInitiatedDownloads)
				{
					_initiatedDownloads = value;
				}
			}
		}
	}
}