<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Commission {
	
	/**
	 * SMTP e-mail messaging, set on the European Commission's SMTP server
	 * @author Pascal Havelange
 	 * @copyright © EUROPEAN COMMISSION, 2008
 	 * @package MetaNull\Commission
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class EC_SMTP extends \MetaNull\Net\mSmtp {
		
		/**
		 * Server Host
		 * @var string
		 */
		const EC_SMTP_SERVER = "internal-smtp.cec.eu.int";
		
		/**
		 * Server Host
		 * @var string
		 */
		const EC_SMTP_SERVER_PORT = 25;
		
		/**
		 * E-mail address to be used as the originating address
		 * @var string
		 * @access private
		 */
		private $mailbox = false;
		
		/**
		 * Create the Object
		 * @var string $mailbox E-mail address to be used as the originating address
		 */
		public function __construct( $mailbox ) {
			parent::__construct( $mailbox, self::EC_SMTP_SERVER, self::EC_SMTP_SERVER_PORT );
		}
		
		/**
		 * Quickly send a simple e-mail message 
		 * @static
		 * @param string $from The originating e-mail address
		 * @param string|array The destinataire addresses
		 * @param string Subject of the message
		 * @param bool $copy_sender Send a copy of the message to the sender
		 */
		static function quickSend( $from, $to, $subject, $message, $copy_sender = false ) {
			$smtp = new EC_SMTP( $from );
			$smtp->setRecipients( $to );
			$smtp->setSubject( $subject );
			$smtp->setMessage( $message );
			$smtp->send();

			if( $copy_sender ) {
				$smtp->setRecipients( $from );
				$smtp->send();
			}
		}
	}
}
?>