<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\News{

	/**
	 * Base class for a query (for the news articles - any engine, any source)
	 * @author Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @package MetaNull\News
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class newsQuery {

		/**
		 * The engine identifier
		 * @var int
		 * @access public
		 */
		public $engine_id = null;

		/**
		 * The query string
		 * @var string
		 * @access public
		 */
		public $query = null;

		/**
		 * The engine specific data
		 * @var string
		 * @access public
		 */
		public $specific_data = null;

		/**
		 * The time range (in days)
		 * @var string
		 * @access public
		 */
		public $range = null;

		/**
		 * The query name
		 * @var string
		 * @access public
		 */
		public $query_name = null;

		/**
		 * Constructs the object
		 * @param int $engine_id The engine identifier [OPTIONAL]
		 * @param string $query The query string [OPTIONAL]
		 * @param int $start_date The date from which to start the search (UNIX timestamp) [OPTIONAL]
		 * @param int $end_date The date to which to end the search (UNIX timestamp) [OPTIONAL]
		 * @param int $first The first article to fetch [OPTIONAL]
		 * @param int $count The number of articles to fetch [OPTIONAL]
		 * @param string $specific_data Engine specific data [OPTIONAL]
		 * @access public
		 * @return void
		 */
		public function __construct($engine_id = null, $query = null, $start_date = null, $end_date = null, $first = null, $count = null, $specific_data = null) {
			$this->engine_id = $engine_id;
			$this->query = $query;
			$this->start_date = $start_date;
			$this->end_date = $end_date;
			$this->first = $first;
			$this->count = $count;
			$this->specific_data = $specific_data;
		}

		/**
		 * The source identifier
		 * @var int
		 * @access public
		 */
		public $source_id;

		/**
		 * The date from which to start the search (UNIX timestamp)
		 * @var int
		 * @access private
		 */
		public $start_date;

		/**
		 * The date to which to end the search (UNIX timestamp)
		 * @var int
		 * @access private
		 */
		public $end_date;

		/**
		 * The first article to fetch
		 * @var int
		 * @access private
		 */
		public $first;

		/**
		 * The number of articles to fetch
		 * @var int
		 * @access private
		 */
		public $count;

		/**
		 * Sets the date range
		 * @param int $start_date The start date (UNIX timestamp)
		 * @param int $end_date The end date (UNIX timestamp)
		 * @access public
		 * @return void
		 */
		public function setDate($start_date, $end_date) {
			$this->start_date = $start_date;
			$this->end_date = $end_date;
		}

		/**
		 * Sets the results range
		 * @param int $first The first article to fetch
		 * @param int $count The count of articles to fetch
		 * @access public
		 * @return void
		 */
		public function setRanges($first, $count) {
			$this->first = $first;
			$this->count = $count;
		}
	}
}
?>