<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Tools {

	/**
	 * Helper functions to load and save configuration files (cache enabled)
	 * @author Cosmin Popescu, Pascal Havelange
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @package MetaNull\Tools
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class mConfig {
		/**
		 * Loads the configuration file and stores it as an array in the object
		 * @param string $config_path The full path to the configuration file
		 * @param string $config_format The file format used by the configuration file [OPTIONAL]
		 * @param string $cache_name The name of the cache file [OPTIONAL]
		 * @return array
		 */
		public static function loadConfiguration( $config_path, $config_format = 'xml', $cache_name = 'app_config' ) {
			$config = \MetaNull\Tools\mCache::loadVariable($cache_name, $config_path, true);

			if ($config === null) {
				if ($config_path === null) {
					throw new \InvalidArgumentException('$config_path argument is null');
				}
				if( false === realpath($config_path)) {
					throw new configException( 'Configuration file "' . $config_path . '" does not exist!' );
				}

				$config = new \Config();
				$config_root = &$config->parseConfig( $config_path, $config_format );
				if( \PEAR::isError( $config_root )) {
					throw new configException( 'Error parsing configuration file: ' . $config_root->getMessage() );
				}
				$config_array = $config_root->toArray();
				$config = $config_array['root']['config'];

				\MetaNull\Tools\mCache::saveVariable($config, $cache_name, true);
			}

			return $config;

		}

		/**
		 * Saves the configuration array into a file
		 * @param string $config_path The full path to the configuration file
		 * @param array $config The config array to be saved
		 * @param string $config_format The file format used by the configuration file
		 *
		 */
		protected function saveConfiguration( $config_path, $config_array, $config_format = 'xml' ) {
			if( is_array( $config_array )) {
				$config = new \Config();
				$config_root = &$config->parseConfig( $config_array, 'phparray', array('name' => 'config') );
				if( \PEAR::isError( $config_root )) {
					throw new \Exception( 'Error saving configuration file: ' . $config_root->getMessage );
				}
				$result = $config->writeConfig( $config_path, $config_format );
				if( \PEAR::isError( $result )) {
					throw new \Exception( 'Error saving configuration file: ' . $result->getMessage );
				}
			} else {
				throw new \Exception( 'Error configuration not loaded!' );
			}
		}

	}
}

?>