<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace MetaNull\Tools {

/**
 * Helper functions & classes for HTTP REQUESTS using the libcurl library
 * @author Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2007-2010
 * @package MetaNull\Tools
 * @license http://ec.europa.eu/idabc/eupl
 */
class mCurl {
    /**
     * Send a GET request to an HTTP Server and retrieves its results
     *
     * @param string $url Url to fetch
     * @param integer &$http_code Reference to a variable that will receive the HTTP error code returned by the server.
     * @param string $ssl_cert_path Full path rto the CA Certificate to use in case of SSL
     * @param string $http_proxy Http Proxy setup (http://[user:password@]host:port
     * @param string $debug If this is set, then should be a file on the server, where all the debug information will be dump.
     * @param string $real_url It returns the real url (in case of redirection or something)
     * @return The returned data on success, false otherwise.
     */
    public static function Get( $url, &$http_code, $ssl_cert_path = false, $http_proxy = false, $debug = false, $saveToFile = false, &$real_url = null ) {
	$http_code = false;
	$http_return = false;
	$hcurl = @curl_init();
	do {
	    if( false === $hcurl ) {
		throw new \Exception( 'Unable to initialize libCurl!' );
		break;
	    }
	    if( false === @curl_setopt( $hcurl, CURLOPT_URL, $url )) {
		throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		break;
	    }
	    if( false === @curl_setopt( $hcurl, CURLOPT_RETURNTRANSFER, 1 )) {
		throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		break;
	    }

	    if ($debug !== false) {
		if( false === @curl_setopt( $hcurl, \CURLOPT_VERBOSE, 1 )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
		$f = fopen($debug, 'w');
		if( false === @curl_setopt( $hcurl, \CURLOPT_STDERR, $f )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
	    }

	    if( false !== $ssl_cert_path ) {
		if( false === @curl_setopt( $hcurl, CURLOPT_SSL_VERIFYHOST, 2 )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
		if( false === @curl_setopt( $hcurl, CURLOPT_SSL_VERIFYPEER, 1 )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
		if( false !== $ssl_cert_path ) {
		    if( false === @curl_setopt( $hcurl, CURLOPT_CAINFO, $ssl_cert_path )) {
			throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
			break;
		    }
		}
	    }

	    if( false !== $http_proxy ) {
		$proxy = Array( 'login' => false, 'host' => false, 'port' => false );
		$proxstr = ereg_replace( '^.*://', '', $http_proxy );
		$proxarr = explode( '@', $proxstr, 2 );
		if( 1 == count($proxarr )) {
		    $tmp = explode( ':', $proxarr[0], 2 );
		    $proxy['host'] = $tmp[0];
		    if( isset( $tmp[1]) ) {
			$proxy['port'] = $tmp[1];
		    }
		} else {
		    $proxy['login'] = $proxarr[0];
		    $tmp = explode( ':', $proxarr[1], 2 );
		    $proxy['host'] = $tmp[0];
		    if( isset( $tmp[1]) ) {
			$proxy['port'] = $tmp[1];
		    }
		}
		if( false === @curl_setopt( $hcurl, CURLOPT_PROXY, $proxy['host'] )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
		if( false !== $proxy['port'] ) {
		    if( false === @curl_setopt( $hcurl, CURLOPT_PROXYPORT, (int) $proxy['port'] )) {
			throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
			break;
		    }
		}
		if( false === @curl_setopt( $hcurl, CURLOPT_PROXYTYPE, CURLPROXY_HTTP )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
		if( false !== $proxy['login'] ) {
		    if( false === @curl_setopt( $hcurl, CURLOPT_PROXYAUTH, CURLAUTH_BASIC )) {
			throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
			break;
		    }
		    if( false === @curl_setopt( $hcurl, CURLOPT_PROXYUSERPWD, $proxy['login'] )) {
			throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
			break;
		    }
		} else {
		    if( false === @curl_setopt( $hcurl, CURLOPT_PROXYAUTH, CURLAUTH_NONE )) {
			throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
			break;
		    }
		}
	    }
	    else {
		if( false === @curl_setopt( $hcurl, CURLOPT_PROXY, false )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}

	    }

	    if( false === @curl_setopt( $hcurl, CURLOPT_FOLLOWLOCATION, True )) {
		throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		break;
	    }
	    
	    if( false === @curl_setopt( $hcurl, CURLOPT_MAXREDIRS, 3 )) {
		throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		break;
	    }

	    /*if( false === @curl_setopt( $hcurl, CURLOPT_HEADER, True )) {
		throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		break;
	    }*/

	    if ($saveToFile){
		$file = tempnam(sys_get_temp_dir(), 'curl_');
		$f = fopen($file, 'wb');
		if( false === @curl_setopt( $hcurl, CURLOPT_RETURNTRANSFER, 0 )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
		if( false === @curl_setopt( $hcurl, CURLOPT_FILE, $f )) {
		    throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_errno($hcurl), E_USER_ERROR );
		    break;
		}
	    }

	    $http_return = curl_exec( $hcurl );
	    if( false === $http_return ) {
		throw new \Exception( 'libCurl error #'.curl_errno($hcurl).': '.curl_error($hcurl), E_USER_ERROR );
		break;
	    }

	    $http_code = curl_getinfo( $hcurl, CURLINFO_HTTP_CODE );
	    $headers = curl_getinfo($hcurl);
	    if (array_key_exists('content_type', $headers)){
		$ct = $headers['content_type'];
		$parts = preg_split('/;[ ]*charset=/', $ct);
		if (count($parts) > 1){
		    $ct = $parts[1];
		    if (strtolower($ct) != 'utf-8'){
			$http_return = iconv($ct, 'UTF-8//TRANSLIT', $http_return);
		    }
		}
	    }

	    if (array_key_exists('url', $headers)){
		$real_url = $headers['url'];
	    }
	} while( false );
	if( false !== $hcurl ) {
	    curl_close( $hcurl );
	    $hcurl = false;
	}

	if ($debug != false) {
	    fclose($f);
	}

	return ($saveToFile?$file:$http_return);
    }

    /**
     * Gets the body as a hole from a chunked HTTP transfer
     * @param string $body The body
     * @static
     * @access protected
     * @return string
     */
    protected static function getChunkedBody($body) {
	$result = '';
	do {
	    echo mDump::dumpVariable(strlen($body), true);
	    preg_match_all('/^([^;]*)[;]*[^\n]*\n/m', $body, $matches);
	    mDump::dumpVariable($matches);
	    $body = preg_replace('/^([^;]*)[;]*[^\n]*\n/m', '\1' . "\n", $body, 1);
	    mDump::dumpVariable(strlen($body));
	    $tmp = preg_split('/\n/m', $body, 2);
	    $size = $tmp[0];
	    if ($size != '0'){
		$body = preg_replace('/^' . $size . '[\r]*\n/im', '', $body);
		$size = hexdec($size);
		$result .= substr($body, 0, $size);
		$body = substr($body, $size + 1);
	    }
	} while ($size != '0');

	mDump::dumpVariable($result);

	return $result;
    }

    /**
     * Do a HTTP request
     * @param string $host The url
     * @param int $port The port [OPTIONAL]
     * @param string $method The method [OPTIONAL]
     * @param string $query_string The query string [OPTIONAL]
     * @param string $post_data The POST data [OPTIONAL]
     * @static
     * @access public
     * @return array
     */
    public static function doHttp($host, $port = 80, $method = 'GET', $query_string = null, $headers = null, $post_data = null) {
	$f = fsockopen($host, $port, $errno, $errstr, 30);
	if (!$f) {
	    throw new \Exception("$errstr ($errno)");
	}

	$output = $method . ' /';
	if ($query_string != null) {
	    $output .= '?' . $query_string;
	}
	$output .= " HTTP/1.0\r\n";
	$output .= "Host: {$host}\r\n";
	if ($method == 'POST') {
	    $output .= 'Content-Length: ' . strlen($post_data) . "\r\n";
	}

	if ($headers != null){
	    if (!is_array($headers)){
		$parts = preg_split('/[\r]*\n/m', $headers);
		$headers = array();
		foreach ($parts as $header){
		    $headers[] = $header;
		}
	    }

	    foreach ($headers as $header){
		$output .= $header . "\r\n";
	    }
	}

	$output .= "Connection: Close\r\n\r\n";
	if ($method == 'POST') {
	    $output .= $post_data . "\r\n\r\n";
	}

	mDump::dumpVariable($output);

	fwrite($f, $output);
	$result = '';
	$i = 0;
	while (!feof($f)) {
	    //echo mDump::dumpVariable($i . ' - ' . microtime(), true);
	    $r = fgets($f);
	    //ob_start();echo '.';ob_end_clean();ob_flush();flush();
	    $result .= $r;
	    $i++;
	}
	
	fclose($f);
	//echo mDump::dumpVariable($i, true);
	//mDump::dumpVariable($output);

	$parts = preg_split('/[\r]*\n[\r]*\n/m', $result, 2);
	$headers = preg_split('/[\r]*\n/m', $parts[0]);
	$body = $parts[1];

	$chunked = false;

/*	$chunked = true;
	$body = <<<str
1a; ignore-stuff-here
abcdefghijklmnopqrstuvwxyz
10
1234567890abcdef
0
some-footer: some-value
another-footer: another-value
[blank line here]
str;
*/
	foreach ($headers as $header){
	    if (preg_match('/Transfer-Encoding:[\s]*chunked/im', $header)){
		$chunked = true;
		break;
	    }
	}

	if ($chunked){
	    $body = self::getChunkedBody($body);
	}

	$pattern = '/^HTTP\/[\d\.]+ ([\d]+) ([^\n]*)[\n]/';

	return array('headers' => $headers, 'body' => $body);
    }
}
}
?>