<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace MetaNull\Tools {
	/**
	 * Helper Class: Calls Apache FOP java application (Renders XSL-FO files to PDf)
	 * NOTE: Output methods will automatically add "pragma: hack", "cache-control: public" headers to standard headers in order to allow download from internet explorer when over internet explorer.
	 * @author Pascal Havelange
 	 * @copyright © EUROPEAN COMMISSION, 2010
	 * @package MetaNull\Tools
	 * @license http://ec.europa.eu/idabc/eupl
 	 */
	class mFop {
		
		/**
		 * @var string Temporary files
		 * */
		const temp_folder = 'd:\webserver\temp';
		
		/**
		 * @var string FOP Home
		 * */
		const fop_home = 'd:\tools\fop';
		
		/**
		 * @var string windows Directory
		 * */
		const windir = 'c:\windows';
		
		/**
		 * @var bool If set to true, put FOP warnings are not written to the error log
		 * */
		public $disable_warnings;
		
		/**
		 * Constructor
		 * */
		public function __construct() {
			$this->disable_warnings = true;
		}
		
		/**
		 * Converts an FO file into PDF and return its content
		 * @param string $fo_path Location of the FO file
		 * @return string|false PDF data or FALSE in case of error
		 * */
		public function getPdfFromFO( $fo_path ) {
			$tmp_pdf = tempnam( self::temp_folder, 'pdf' );
			$tmp_log = tempnam( self::temp_folder, 'log' );
			$cmd = self::getCmd( $tmp_pdf, $fo_path );
			$fop_output = shell_exec( $cmd . ' 1>nul 2>' . $tmp_log );
			if( file_exists( $tmp_log ) && filesize( $tmp_log )) {
				if( !file_exists( $tmp_pdf )) {
					trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )), E_USER_ERROR );
					@unlink( $tmp_log );
					@unlink( $tmp_pdf );
					return false;					
				} else {
					if( true !== $this->disable_warnings ) {
						trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )), E_USER_NOTICE );
						@unlink( $tmp_log );
					}
				}
			}
			
			$pdf = file_get_contents( $tmp_pdf );
			@unlink( $tmp_pdf );
			@unlink( $tmp_log );
			return $pdf;
		}
		
		/**
		 * Converts an FO file into PDF and output it to the browser
		 * @param string $fo_path Location of the FO file
		 * @return string|false PDF data or FALSE in case of error
		 * */
		public function outputPdfFromFO( $fo_path, $exit = true ) {
			$tmp_pdf = tempnam( self::temp_folder, 'pdf' );
			$tmp_log = tempnam( self::temp_folder, 'log' );
			$cmd = self::getCmd( $tmp_pdf, $fo_path );
			$fop_output = shell_exec( $cmd . ' 1>nul 2>' . $tmp_log );
			if( file_exists( $tmp_log ) && filesize( $tmp_log )) {
				if( !file_exists( $tmp_pdf )) {
					trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )), E_USER_ERROR );
					@unlink( $tmp_log );
					@unlink( $tmp_pdf );
					return false;					
				} else {
					if( true !== $this->disable_warnings ) {
						trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )) . "\n", E_USER_NOTICE );
						@unlink( $tmp_log );
					}
				}
			}
			
			header( 'Content-Type: application/pdf' );
			header( 'Content-Length: ' . filesize($tmp_pdf) );
			header( 'Content-Disposition: inline; filename=' . basename($_SERVER['REQUEST_URI'],'.pdf').'.pdf' );
			header( 'Pragma: no-cache, public, hack' );
			header( 'Cache-Control: public, no-store, no-cache, must-revalidate' );
			header( 'Expires: ' . date( 'r', time() - 86400 ));
			$fp_pdf = fopen( $tmp_pdf, 'rb' );
			fpassthru( $fp_pdf );
			fclose( $fp_pdf );
			@unlink( $tmp_pdf );
			@unlink( $tmp_log );
			if( $exit ) {
				exit();
			}
		}
		
		/**
		 * Converts an XML file into PDF using XSL and return its content
		 * @param string $xml_path Location of the XML file
		 * @param string $xsl_path Location of the XSL file
		 * @return string|false PDF data or FALSE in case of error
		 * */
		public function getPdfFromXML( $xml_path, $xsl_path ) {
			$tmp_pdf = tempnam( self::temp_folder, 'pdf' );
			$tmp_log = tempnam( self::temp_folder, 'log' );
			$cmd = self::getCmd( $tmp_pdf, null, $xml_path, $xsl_path );
			$fop_output = shell_exec( $cmd . ' 1>nul 2>' . $tmp_log );
			if( file_exists( $tmp_log ) && filesize( $tmp_log )) {
				if( !file_exists( $tmp_pdf )) {
					trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )), E_USER_ERROR );
					@unlink( $tmp_log );
					@unlink( $tmp_pdf );
					return false;					
				} else {
					if( true !== $this->disable_warnings ) {
						trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )), E_USER_NOTICE );
						@unlink( $tmp_log );
					}
				}
			}
			
			$pdf = file_get_contents( $tmp_pdf );
			@unlink( $tmp_pdf );
			@unlink( $tmp_log );
			return $pdf;
		}
		
		/**
		 * Converts an XML file into PDF using XSL and output it to the browser
		 * @param string $xml_path Location of the XML file
		 * @param string $xsl_path Location of the XSL file
		 * @return string|false PDF data or FALSE in case of error
		 * */
		public function outputPdfFromXML( $xml_path, $xsl_path, $exit = true ) {
			$tmp_pdf = tempnam( self::temp_folder, 'pdf' );
			$tmp_log = tempnam( self::temp_folder, 'log' );
			$cmd = self::getCmd( $tmp_pdf, null, $xml_path, $xsl_path );
			$fop_output = shell_exec( $cmd . ' 1>nul 2>' . $tmp_log );
			if( file_exists( $tmp_log ) && filesize( $tmp_log )) {
				if( !file_exists( $tmp_pdf )) {
					trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )), E_USER_ERROR );
					@unlink( $tmp_log );
					@unlink( $tmp_pdf );
					return false;					
				} else {
					if( true !== $this->disable_warnings ) {
						trigger_error( 'fop::outputPdf() : ' . $cmd . " >>\n" . ereg_replace( "\r\n", "\n", file_get_contents( $tmp_log )) . "\n", E_USER_NOTICE );
						@unlink( $tmp_log );
					}
				}
			}
			
			header( 'Content-Type: application/pdf' );
			header( 'Content-Length: ' . filesize($tmp_pdf) );
			header( 'Content-Disposition: inline; filename=' . basename($_SERVER['REQUEST_URI'],'.pdf').'.pdf' );
			header( 'Pragma: no-cache, public, hack' );
			header( 'Cache-Control: public, no-store, no-cache, must-revalidate' );
			header( 'Expires: ' . date( 'r', time() - 86400 ));
			$fp_pdf = fopen( $tmp_pdf, 'rb' );
			fpassthru( $fp_pdf );
			fclose( $fp_pdf );
			@unlink( $tmp_pdf );
			@unlink( $tmp_log );
			if( $exit ) {
				exit();
			}
		}
		
		/**
		 * Converts an FO string into PDF and return its content
		 * @param string $fo Full FO document data
		 * @return string PDF data
		 * */
		public function getPdfFromFOString( $fo ) {
			$tmp_fo = tempnam( self::temp_folder, 'fo' );
			file_put_contents( $tmp_fo, $fo );
			$pdf = $this->getPdfFromFO( $tmp_fo );
			@unlink( $tmp_fo );
			return $pdf;
		}
		
		/**
		 * Converts an FO string into PDF and output it to the browser
		 * @param string $fo Full FO document data
		 * @return string PDF data
		 * */
		public function outputPdfFromFOString( $fo, $exit = true ) {
			$tmp_fo = tempnam( self::temp_folder, 'fo' );
			file_put_contents( $tmp_fo, $fo );
			$this->outputPdfFromFO( $tmp_fo, false );
			@unlink( $tmp_fo );
			if( $exit ) {
				exit();
			}
		}
		
		/**
		 * Converts an XML string into PDF and return its content
		 * @param string $xml Full XML document data
		 * @param string $xsl Full XSL document data OR XSL file path
		 * @return string PDF data
		 * */
		public function getPdfFromXMLString( $xml, $xsl ) {
			$tmp_xml = tempnam( self::temp_folder, 'xml' );
			file_put_contents( $tmp_xml, $xml );
			$xsl_exists = @file_exists( $xsl );
			$tmp_xsl = false;
			if( !$xsl_exists ) {
				$tmp_xsl = tempnam( self::temp_folder, 'xsl' );
				file_put_contents( $tmp_xsl, $xsl );
			} else {
				$tmp_xsl = $xsl;
			}
			$pdf = $this->getPdfFromXML( $tmp_xml, $tmp_xsl );
			@unlink( $tmp_xml );
			if( !$xsl_exists ) {
				@unlink( $tmp_xsl );
			}
			return $pdf;
		}
		
		/**
		 * Converts an XML string into PDF and output it to the browser
		 * @param string $xml Full XML document data
		 * @param string $xsl Full XSL document data OR XSL file path
		 * @return string PDF data
		 * */
		public function outputPdfFromXMLString( $xml, $xsl, $exit = true ) {
			$tmp_xml = tempnam( self::temp_folder, 'xml' );
			file_put_contents( $tmp_xml, $xml );
			$xsl_exists = file_exists( $xsl );
			$tmp_xsl = false;
			if( !$xsl_exists ) {
				$tmp_xsl = tempnam( self::temp_folder, 'xsl' );
				file_put_contents( $tmp_xsl, $xsl );
			} else {
				$tmp_xsl = $xsl;
			}
			$this->outputPdfFromXML( $tmp_xml, $tmp_xsl, false );
			@unlink( $tmp_xml );
			if( !$xsl_exists ) {
				@unlink( $tmp_xsl );
			}
			if( $exit ) {
				exit();
			}
		}
		
		/**
		 * Returns the shell command that runs FOP
		 * @param string $fo Location of the FO file
		 * @param string $pdf Location where to save the PDF file
		 * @return string
		 * */
		private static function getCmd( $pdf, $fo = null, $xml = null, $xsl = null) {
			$class_path = array(
				self::fop_home . DIRECTORY_SEPARATOR . 'build\fop.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'build\fop-sandbox.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'build\fop-hyph.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\xml-apis-1.3.04.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\xml-apis-ext-1.3.04.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\xercesImpl-2.7.1.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\xalan-2.7.0.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\serializer-2.7.0.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\batik-all-1.7.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\xmlgraphics-commons-1.4.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\avalon-framework-4.2.0.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\commons-io-1.3.1.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\commons-logging-1.0.4.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\jai_imageio.jar',
				self::fop_home . DIRECTORY_SEPARATOR . 'lib\fop-hyph.jar',
			);
			$class_path = implode( ';', $class_path );
			if( empty( $fo )) {
				return 'java.exe -Denv.windir=' . self::windir . ' -cp "'.$class_path.'" org.apache.fop.cli.Main -q -xml "'.$xml.'" -xsl "'.$xsl.'" -pdf "'.$pdf.'"';
			} else {
				return 'java.exe -Denv.windir=' . self::windir . ' -cp "'.$class_path.'" org.apache.fop.cli.Main -q -fo "'.$fo.'" -pdf "'.$pdf.'"';
			}
		}
	}
}
?>