/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

//The multi AJAX CALL_IDs (the ids that are currently executing and for which a result is expected)
var CALL_ID = Array();
//The multi AJAX timer
var CALL_TIMER_ID = null;
//If set to false, the multi ajax will be paused
var CALL_RUNNING = true;
var PAUSE_ID = null;
var onEnd = Array();
var fGetResults = Array();

var LOCK_MULTI_AJAX = 0;

/**
 * Converts the urls to be sent to QUERY STRING parameters
 * @param urls The array of urls
 * @param delimiter The delimiter that will be used
 * @return
 */
function URLS2str(urls, delimiter){
	var data = '';

	for (var i = 0; i < urls.length; i++){
		data += (data == ''?'':'&') + 'url[]=' + encodeURIComponent(urls[i].get_url() + delimiter + urls[i].get_use_proxy() + delimiter + urls[i].get_method());
	}

	data += (data == ''?'':'&') + 'delimiter=' + delimiter;
	
	return data;
}

/**
 * Sends a list of urls to multi AJAX (to be processed in a multi threading fashion)
 * @param urls The list of urls
 * @param fGetResults The function that will be called for each result
 * @param onBegin The function that will be executed before the urls are sent
 * @param onEnd The function that will be executed when we have no more results
 * @param set_user If set to true, will also add the user get variable to the urls
 * @return void
 */
function sendURLS(urls, fGetResults, onBegin, onEnd, set_user){
	multiAjaxResume();
	var delimiter = '###';
	var data = URLS2str(urls, delimiter);

	var s_set_user = '';
	if (typeof(set_user) != 'undefined' && set_user){
		s_set_user = '&set_user=';
	}
	
	if (typeof(onBegin) != 'undefined') if (onBegin != null) onBegin();
	
	sendAjax(URL('index.php', 'module=ajax&action=multiAjax&what=set_urls&root_node=multi_result' + s_set_user), 'post', function(response){
		urlsSent(response, fGetResults, onBegin, onEnd);
	}, null, data);
}

/**
 * This function is called after the urls were sent to be processed. It will trigger the timer (if needed)
 * @param response The response from the server
 * @param fGetResults The function that will be called for each result
 * @param onBegin The function that will be executed before the urls are sent
 * @param onEnd The function that will be executed when we have no more results
 * @return void
 */
function urlsSent(response, _fGetResults, onBegin, _onEnd){

	//Check if the multi ajax mechanism is locked by another request
	if (LOCK_MULTI_AJAX > 0){
		LOCK_MULTI_AJAX++;
		if (LOCK_MULTI_AJAX == 150) LOCK_MULTI_AJAX = 0;
		setTimeout(function(){
			urlsSent(response, _fGetResults, onBegin, _onEnd);
			}, 100);
		return ;
	}

	//Gets the call id returned by the server
	var xp = new xpath(response);
	var result = xp.doXPath('/multi_result/call_id');
	var id = result.firstNode();
	if (id)
		id = id.firstChild.data;
	else id = null;

	//Check if there was any error
	result = xp.doXPath('/multi_result/error');
	if (result.firstNode())	var error = result.firstNode().firstChild.data;
	else var error = null;
	
	if (error != null || id == null){
		//If so, display the error and execute the onEnd function
		tariqaAlert(error, 'Error', TYPE_ALERT_ERROR);
		if (typeof(_onEnd) != 'undefined') if (_onEnd != null) _onEnd();
	}
	else {
		//Add the new received id to the list of call id's currently in progress
		if (typeof(_onEnd) != 'undefined') if (_onEnd != null){
			onEnd[id] = _onEnd;
		}

		if (typeof(_fGetResults) != 'undefined') if (_fGetResults != null){
			fGetResults[id] = _fGetResults;
		}

		if (CALL_TIMER_ID == null){
			LOCK_MULTI_AJAX++;
		}

		CALL_ID.push(id);
		
		//If the timer is not allready set (this is the first call) then check the results. 
		//The checkResults functions will call the getResults function which will trigger the timer
		if (CALL_TIMER_ID == null){
			setTimeout(function(){checkResults();}, 500);
		}
	}
	
}

/**
 * Checks the results for each AJAX request that still waits for a response
 * @return void
 */
function checkResults(){
	var call_ids = '';
	for (var i = 0; i < CALL_ID.length; i++){
		call_ids += (call_ids == ''?'':'&') + 'call_ids[]=' + CALL_ID[i];
	}
	if (call_ids != ''){
		sendAjax(URL('index.php', 'module=ajax&action=multiAjax&what=check_result&root_node=multi_result&' + call_ids), 'get', getResults);
	}
}

function doClearMultiAjax(){
    while (CALL_ID.length > 0){
            CALL_ID.pop();
    }
    while (fGetResults.length > 0){
            fGetResults.pop();
    }
    while (onEnd.length > 0){
            onEnd.pop();
    }
    CALL_TIMER_ID = null;
    multiAjaxStop();
}

/**
 * Stops all multi AJAX calls and clears the que of multi ajax calls (no result will be received any more)
 **/
function clearMultiAjax(){
	//If there is no more response to be expected, clear the CALL_ID list and kill the timer
	var call_ids = '';
	for (var i = 0; i < CALL_ID.length; i++){
		call_ids += (call_ids == ''?'':'&') + 'call_ids[]=' + CALL_ID[i];
	}
	if (call_ids != ''){
            sendAjax(URL('index.php', 'module=ajax&action=multiAjax&what=check_result&root_node=multi_result&' + call_ids), 'get', function(response){

                var xp = new xpath(response);
                var result = xp.doXPath('/multi_result/no_more_results');

                var no_more_results = 'false';
                if (result.firstNode()) no_more_results = result.firstNode().firstChild.data;

                if (no_more_results == 'true'){
                    doClearMultiAjax();
                }
                else {
                    //Set the function to be executed again in 300 miliseconds
                    CALL_TIMER_ID = setTimeout(function(){checkResults();}, 300);
                    LOCK_MULTI_AJAX = 0;
                }
            });
	}
        else {
            doClearMultiAjax();
        }
}

/**
 * This function is called when there is a response from the multi AJAX server
 * @param response The server response - DHTMLX object
 * @return void
 */
function getResults(response){
	 //If the multi ajax mechanism is stopped
	 if (!CALL_RUNNING){
		 //PAUSE_ID = setTimeout(function(){getResults(response)}, 300);
		 return ;
	 }
	//Checks if there was actually a response for one of the requests
	var xp = new xpath(response);
	var result = xp.doXPath('/multi_result/no_response');
	if (result.firstNode())	var no_response = result.firstNode().firstChild.data;
	else var no_response = false;

	if (!no_response){
	}
	
	//If true, then it means that there are no more results to be expected
	result = xp.doXPath('/multi_result/no_more_results');

	var no_more_results = 'false';
	if (result.firstNode()) no_more_results = result.firstNode().firstChild.data;
	
	//If this is not null, it means that there was a problem with some of the calls - alert the user
	result = xp.doXPath('/multi_result/error');
	var error = result.firstNode();
	if (typeof(error) != 'boolean' || error != false) error = error.firstChild.data;

	if (typeof(error) != 'boolean' || error != false){
		for (var i = 0; i < CALL_ID.length; i++){
			if (typeof(onEnd[CALL_ID[i]]) != 'undefined') if (onEnd[CALL_ID[i]] != null){
				onEnd[CALL_ID[i]]();
			}
		}
		tariqaAlert(error, 'Error', TYPE_ALERT_ERROR);
		doClearMultiAjax();
		no_more_results = 'true';
		return ;
	}
	
	//This variable will contain the actual responses
	result = xp.doXPath('/multi_result/response');
	var call_id;
	var rsp;
	//For each of the responses call the fGetResults function
	rsp = result.nextNode();
	while (typeof(rsp) != 'boolean' || rsp != false){
		var xp2 = new xpath(rsp);
		var result2 = xp2.doXPath('//call_id');
		call_id = null;
		if (result2.firstNode()){
			call_id = result2.firstNode().firstChild.data;
		}
		if (call_id != null){
			if (typeof(fGetResults[call_id]) != 'undefined'){
				fGetResults[call_id](rsp);
			}
			else {
				tariqaAlert(MESSAGES['ERROR_COMUNICATING'], 'Error', TYPE_ALERT_ERROR);
			}
		}
		rsp = result.nextNode();
	}

//If we had any response, check if any of the calls finished
	if (result.length > 0){
		result = xp.doXPath('/multi_result/finished_call');
		var node;
		while (node = result.nextNode()){
			var call_id = node.firstChild.data;
			if (typeof(onEnd[call_id]) != null) if (onEnd[call_id] != null){
				onEnd[call_id]();
			}
		}
	}
	
	//If there are still requests waiting for responses
	if (no_more_results != 'true'){
		//Set the function to be executed again in 300 miliseconds
		CALL_TIMER_ID = setTimeout(function(){checkResults();}, 300);
		LOCK_MULTI_AJAX = 0;
	}
	else {
		//alert('no more results');
		clearMultiAjax();
	}
}

/**
 * Stops the multi AJAX mechanism
 * @return void
 */
function multiAjaxStop(){
	//alert('multi ajax stopped');
	CALL_RUNNING = false;
}

/**
 * Resumes the multi AJAX mechanism
 * @return void
 */
function multiAjaxResume(){
	CALL_RUNNING = true;
}

/**
 * Returns the call content of an AJAX multi call response (an object with the call_content, the http_code, call_content_length, call_header, call_error and duration tags)
 * @param response The AJAX multi call response
 * @return Object
 */
function multiAjaxResponse(xmlResponse){
	this._xmlResponse = xmlResponse;

	this.http_code = false;
	this.content = false;
	this.content_length = 0;
	this.header = false;
	this.error = false;
	this.duration = -1;

	var xp = new xpath(xmlResponse);
	var result = xp.doXPath('//http_code');
	this.http_code = result.firstNode();
	if (this.http_code){
		this.http_code = this.http_code.firstChild.data;
		if (this.http_code == 200){
			result = xp.doXPath('//call_content');
			this.content = result.firstNode();
			if (this.content){
				this.content = myDecode(this.content.firstChild.data);
				result = xp.doXPath('//call_content_length');
				this.content_length = result.firstNode();
				if (this.content_length){
					this.content_length = this.content_length.firstChild.data;
				}
				result = xp.doXPath('//call_header');
				this.header = result.firstNode();
				if (this.header){
					this.header = this.header.firstChild.data;
				}
				result = xp.doXPath('//duration');
				this.duration = result.firstNode();
				if (this.duration){
					this.duration = this.duration.firstChild.data;
				}
				else {
					this.duration = -1;
				}
			}
			else {
				this.error = "There was an error retrieving the multi AJAX call result. Please contact the Tariqa Team (RELEX-TARIQA@eeas.europa.eu)";
			}
		}
		else {
			result = xp.doXPath('//call_error');
			this.error = result.firstNode();
			if (this.error){
				this.error = this.error.firstChild.data;
			}
			else {
				this.error = "There was an error processing the multi AJAX call. Please contact the Tariqa Team (RELEX-TARIQA@eeas.europa.eu)";
			}
		}
	}
	else {
		this.error = "There was an error processing the multi AJAX call. Please contact the Tariqa Team (RELEX-TARIQA@eeas.europa.eu)";
	}
}

function multiAjaxURL(url){
	this._url = url;
	this._method = 'get';
	this._use_proxy = false;

	this.set_use_proxy = function(use_it){
		if (typeof(use_it) != 'undefined' && use_it != null){
			this._use_proxy = use_it;
		}
		else {
			this._use_proxy = true;
		}
	}

	this.get_use_proxy = function(){
		return this._use_proxy ? 'yes' : 'no';
	}

	this.set_method = function(method){
		if (typeof(method) != 'undefined' && method != null) {
			this._method = method;
		}
		else this._method = 'get';
	}

	this.get_method = function(){
		return this._method;
	}

	this.get_url = function(){
		return this._url;
	}
	
}

function quickFetchMulti(call_id, processResult){
	CALL_ID.push(call_id);
	fGetResults[call_id] = processResult;
	CALL_RUNNING = true;
	checkResults();
}