/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Class for parsing XPath expressions
 * @param xml The xml document (a DOMDocument object)
 * @author Cosmin Popescu
 * @param expression The expression
 */
function xpath(xml){
	this._xml = xml;

	this._result = null;

	/**
	 * Executes the XPath
	 * @access public
	 * @return xpath_result
	 */
	this.doXPath = function(expression){
		this._expression = expression;
		if (_isIE){
			var r = new RegExp(/\[[\d]+\]/g);
			var results, n;
			while ((results = r.exec(this._expression)) != null){
				n = results[0].substr(1, results[0].length - 2) * 1 - 1;
				this._expression = this._expression.substr(0, results.index + 1) + n + this._expression.substr(results.lastIndex - 1);
				r.lastIndex = results.lastIndex;
			}
		}

		this._result = null;

		if (typeof(this._xml) == "string" || this._xml.ownerDocument != null){
			var str = typeof(this._xml) == "string" ? this._xml : element2string(this._xml);
			if (_isIE){
				this._xml = new ActiveXObject("Msxml2.DOMDocument");
				this._xml.loadXML(str);
			}
			else {
				var parser = new DOMParser();
				this._xml = parser.parseFromString(str, "text/xml");
			}
		}
		
		var result = new xpath_result();

		if (_isIE){
			this._result = this._xml.selectNodes(this._expression);
			result.length = this._result.length;
			if (result.length != 0){
				for (var i = 0; i < this._result.length; i++){
					result._children.push(this._result.item(i));
				}
			}
		}
		else {
			var xpath_expr = this._xml.createExpression(this._expression, null);
			
			this._result = xpath_expr.evaluate(this._xml, XPathResult.UNORDERED_NODE_ITERATOR_TYPE, null);
			result.length = 0;
			var item = this._result.iterateNext();
			while (item){
				result._children.push(item);
				result.length++;
				item = this._result.iterateNext();
			}
		}

		return result;
	}
}

function xpath_result(){
	this._children = Array();
	
	this._currentPosition = null;
	this.length = null;

	/**
	 * Returns the first node of the collection
	 * @return DOMNode
	 */
	this.firstNode = function(){
		if (this.length == 0) return false;
		return this._children[0];
	}

	/**
	 * Returns the last node of the collection
	 * @return DOMNode
	 */
	this.lastNode = function(){
		if (this.length == 0) return false;
		return this._children[this.length - 1];
	}

	/**
	 * Returns the next node of the collection
	 * @return DOMNode
	 */
	this.nextNode = function(){
		if (this.length == 0)
			return false;
		if (this._currentPosition == this.length){
			return false;
		}

		return this._children[this._currentPosition++];
	}

	/**
	 * Returns the previous of the collection
	 * @return DOMNode
	 */
	this.previousNode = function(){
		if (this.length == 0)
			return false;
		if (this._currentPosition == 0){
			return false;
		}

		return this._children[this._currentPosition--];
	}
	
}

function element2string(element){
	if (element.nodeName == "#text") return element.nodeValue;
	if (element.nodeName == "#cdata-section"){
		return "<![CDATA[" + element.nodeValue + "]]>";
	}
	var result = "<" + element.nodeName;

	for (var i = 0; i < element.attributes.length; i++){
		result += " " + element.attributes[i].name + "=" + "\"" + element.attributes[i].value + "\"";
	}

	if (element.childNodes.length > 0){
		result += ">";
		var childNodesResult = "";
		for (i = 0; i < element.childNodes.length; i++){
			childNodesResult += element2string(element.childNodes[i]);
		}

		return result + childNodesResult + "</" + element.nodeName + ">";
	}
	
	if (element.nodeValue == null) return result + "/>";

	result += ">";
	return result + element.nodeValue + "</" + element.nodeName + ">";
}