<?php
/*
 * © EUROPEAN COMMISSION, 2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3 {

	define('DEBUG', true);

	define( 'APPLICATION_MAIN_CONFIG_FILE', 'config/main_config.xml');
	define( 'APPLICATION_NEWS_CONFIG_FILE', 'config/news_config.xml');
	define( 'APPLICATION_SOAP_CONFIG_FILE', 'config/soap_config.xml');
	define( 'APPLICATION_CONFIG_FORMAT', 'xml');

	mb_internal_encoding('UTF-8');

	require_once( 'PEAR.php' );
	require_once( 'Config.php' );
	require_once( 'lib/MetaNull.php' );

	require_once( 'tariqa3/Application.class.php' );
	require_once( 'tariqa3/ECASLogoff.class.php' );
	require_once( 'tariqa3/statics.class.php');

	require_once( 'tariqa3/baseModule.class.php' );
	require_once( 'tariqa3/baseModuleWithAuthentication.class.php' );
	require_once( 'tariqa3/baseModuleWithAuthenticationAndLanguages.class.php' );
	require_once( 'tariqa3/baseModule_RELEX_TARIQARX.class.php' );
	require_once( 'tariqa3/baseModule_RELEX_TARIQAEC.class.php' );
	require_once( 'tariqa3/baseModule_RELEX_TARIQAMS.class.php' );
	require_once( 'tariqa3/baseModule_RELEX_TARIQANG.class.php' );
	require_once( 'tariqa3/tariqa3ModuleSectionManager.class.php' );
	require_once( 'tariqa3/tariqa3ModuleSection.class.php' );
	require_once( 'tariqa3/timeRange.class.php' );
	require_once( 'tariqa3/multiAjaxURL.class.php' );
	require_once( 'tariqa3/multiAjaxSearch.class.php' );
	require_once( 'tariqa3/multiAjaxCall.class.php' );
	require_once( 'tariqa3/tariqa3Module.class.php' );
	require_once( 'tariqa3/tariqa3ModuleDescriptor.class.php' );
	require_once( 'tariqa3/treeFolder.class.php' );

	require_once( 'tariqa3/SOAP/TariqaAuthenticationClient.class.php' );
	require_once( 'tariqa3/SOAP/TariqaClient.class.php' );

	require_once( 'tariqa3/modules/ajax/Ajax.class.php');
	require_once( 'tariqa3/modules/special_pages/Ifs.class.php');
	require_once( 'tariqa3/modules/special_pages/Analysis.class.php');
	require_once( 'tariqa3/modules/special_pages/RSS.class.php');
	require_once( 'tariqa3/modules/special_pages/MultiPages.class.php');
	require_once( 'tariqa3/modules/special_pages/Egypt.class.php');
    require_once( 'tariqa3/modules/special_pages/BriefcaseFolder.class.php');
    require_once( 'tariqa3/modules/special_pages/Login.class.php');
	require_once( 'tariqa3/modules/special_pages/Documents.class.php');
	require_once( 'tariqa3/modules/special_pages/mVideoEncoderMail.class.php');
	require_once( 'tariqa3/modules/special_pages/Newsletters.class.php');
	require_once( 'tariqa3/modules/special_pages/Screencasts.class.php');
	require_once( 'tariqa3/modules/special_pages/Files.class.php');
	require_once( 'tariqa3/modules/special_pages/Redirect.class.php');
	require_once( 'tariqa3/modules/special_pages/multimediaNewsletter.class.php');
	require_once( 'tariqa3/modules/special_pages/filesExplorer.class.php');
    require_once( 'tariqa3/modules/special_pages/WebOffice.class.php');
	
    require_once( 'tariqa3/modules/special_pages/StrategicCommunications.class.php');
    require_once( 'tariqa3/modules/special_pages/SStatus.class.php');

	try {
		if( false === Application::checkPhpSettings() ) {
			throw new \Exception('Invalid PHP settings. Could not run Tarîqa 3.0 ');
		}

		$the_app = new Application(array('path' => APPLICATION_MAIN_CONFIG_FILE, 'format' => APPLICATION_CONFIG_FORMAT));
		$the_app_config = $the_app->getConfig();

		$the_app->setAutoSaveConfig( false );

		//Get the ajax module
		$ajax = new Ajax($the_app_config);
		$ajax->translationTable = $the_app->getModuleTranslationTable('countries');

		$modules = array(
		    new Ifs('ifs', $the_app_config),
		    new Analysis('analysis', $the_app_config),
		    new RSS('rss', $the_app_config),
		    new MultiPages('multi_pages', $the_app_config),
		    new Egypt('egypt', $the_app_config),
		    new Documents('documents', $the_app_config),
		    new Newsletters('newsletters', $the_app_config),
		    new Screencasts('screencasts', $the_app_config),
            new BriefcaseFolderPublished('briefcase-folder', $the_app_config),
		    new Files('files', $the_app_config),
		    new Redirect('redirect', $the_app_config),
		    new multimediaNewsletter('multimedia-newsletter', $the_app_config),
		    new filesExplorer('files-explorer', $the_app_config),
		    new mVideoEncoderMail('mVideoEncoderMail', $the_app_config),
            new Login('login', $the_app_config),
            new WebOffice('weboffice', $the_app_config), 
			
				new StrategicCommunications('StrategicCommunications', $the_app_config),
            new SStatus('sstatus', $the_app_config),
		);

		$moduleDescriptors = array();
		foreach( $modules as $midx => $module ) {
			if( is_a( $module, 'tariqa3\\tariqa3Module' )) {
				$module->db = $the_app->db;
				$module->translationTable = $the_app->getModuleTranslationTable($module->getName());
				$module->currentLanguage = $the_app->getCurrentLanguage();
				$module->defaultLanguage = $the_app->getDefaultLanguage();
				$module->languageList = $the_app->getLanguageList();
				if( $module->isMenuable() ) {
					$moduleDescriptors[] = new tariqa3ModuleDescriptor($module);
				}
			} else {
				// Not a tariqa3Module, should not be added into the menu of the application
				// => application should provide appropriate links to this module to make it available to the end-user
			}
		}
		foreach( $modules as $midx => $module ) {
			if( is_a( $module, 'tariqa3\\tariqa3Module' ) && $module->isMenuable()) {
				$module->moduleDescriptors = $moduleDescriptors;
			}
			$the_app->addModule( $module, 0 == $midx ? true : false );
		}
		/* @var $the_app Application */
		$the_app->run();

	} catch( \Exception $e ) {
		error_log((string)$e);
		$error_report =
			"\n" . '------------------------------' . "\n" .
			'Error report:'."\n".
			(string)$e .
			"\n" . '------------------------------' . "\n";
		try {
			$template = new \MetaNull\Application\MTemplate( 'm' );
			$template->loadTemplate( 'themes/fatalError.html' );
			$template->data['appName'] = 'Tarîqa 3.0';
			$template->data['recipient'] = 'RELEX-TARIQA@ec.europa.eu'.
				'?subject=' . rawurlencode('Bug Report') .
				'&body=' . rawurlencode($error_report);
			$template->data['error'] = '<strong>'.$e->getMessage() . '</strong>'."\n\n" . (string)$e;
			$template->data['content-type'] = 'Content-type: text/html; charset=utf-8';
			echo $template->transform();
		} catch( \Exception $e ) {
			if( !headers_sent() ) {
				\header( 'Content-Type: text/plain; charset=utf-8' );
				echo $error_report;
			}
		}
	}

}
?>