<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */
namespace tariqa3{
	/**
	 * Class for generating the navigation for articles
	 */
	class Navigation extends BaseModule {
		/**
		 * The template file
		 * @var string
		 * @access private
		 */
		private $template_file;

		/**
		 * The multi AJAX search for which the navigation is performed
		 * @var multiAjaxSearch
		 * @access private
		 */
		private $search;

		/**
		 * The text to display between the icons
		 * @var string
		 * @access protected
		 */
		protected $text = '&nbsp;&nbsp;&nbsp;';

		/**
		 * The translation table (used to translate the texts from the navigation
		 * @var array
		 * @access private
		 */
		private $translationTable;

		/**
		 * The javascript code to be executed before navigating
		 * @var string
		 * @access private
		 */
		private $onBeginNavigate = null;

		/**
		 * The javascript code to be executed after navigating
		 * @var string
		 * @access private
		 */
		private $onAfterNavigate = null;

		/**
		 * Constructs the object
		 * @param array $config The configuration array
		 * @param multiAjaxSearch $search The multi AJAX search for which the navigation is performed
		 * @param array $translationTable The translation table (used to translate the texts from the navigation
		 * @param string $text The text to display between the icons [OPTIONAL]
		 * @access public
		 * @return void
		 */
		public function __construct($config, $search, $translationTable, $text = null) {
			parent::__construct($config);
			$this->template_file = "{$config['templates']['base']}/{$config['templates']['default']}/navigation.html";
			$this->search = $search;
			$this->translationTable = $translationTable;
			if ($text != null){
				$this->text = $text;
			}
		}
		/**
		 * Render the module
		 * @return string
		 */
		public function onExecute() {
			$tpl = new \MetaNull\Application\MTemplate('m');
			$tpl->loadTemplate($this->template_file);

			$tpl->data = $this->translationTable;
			$tpl->data['source_id'] = $this->search->getSourceId();
			$tpl->data['navigation_id'] = $this->search->getNavigationId();
			$tpl->data['img_path'] = "{$this->config['templates']['baseurl']}/{$this->config['templates']['default']}/images";
			$tpl->data['text'] = $this->text;
			$dom = new \DOMDocument();

			$el = $dom->createElement('js_code');
			$js_code = $this->search->generate_js();
			if ($this->onBeginNavigate != null){
				$js_code .= <<<js
	{$this->search->getName()}.setOnBeforeNavigate(function(){{$this->onBeginNavigate}});

js;
			}

			if ($this->onAfterNavigate != null){
				$js_code .= <<<js
	{$this->search->getName()}.setOnAfterNavigate(function(){{$this->onAfterNavigate}});

js;
			}
			$el_cont = $dom->createCDATASection($js_code);
			$el->appendChild($el_cont);
			$dom->appendChild($el);

			$el = $dom->createElement('html_code');
			$el_cont = $dom->createCDATASection($tpl->transform());
			$el->appendChild($el_cont);
			$dom->appendChild($el);

			$el = $dom->createElement('object_name', $this->search->getName());
			$dom->appendChild($el);

			$output = '';
			foreach ($dom->childNodes as $node){
				$output .= $dom->saveXML($node);
			}

			return $output;
		}

		/**
		 * Gets the applications headers set by the module
		 * @access public
		 * @return array
		 */
		public function getHeaders() {
			return array("Content-type: text/xml");
		}

		/**
		 * Gets the default template file
		 * @param param_type $param_name param_desc
		 * @access public
		 * @return string|null
		 */
		public function getDefaultTemplateFile() {
			return "ajax.html";
		}

		/**
		 * Process the request that have the page set to ajax
		 */
		public function canProcessRequest() {
			return true;
		}

		/**
		 * Sets the javascript code to be executed before navigating
		 * @param string $code The javascript code
		 * @access public
		 * @return void
		 */
		public function setOnBeforeNavigate($code) {
			$this->onBeginNavigate = $code;
		}

		/**
		 * Sets the javascript code to be executed after navigating
		 * @param string $code The javascript code
		 * @access public
		 * @return void
		 */
		public function setOnAfterNavigate($code) {
			$this->onAfterNavigate = $code;
		}
	}
}
?>
