<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - SOAP Components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */
namespace tariqa3\SOAP{
    /**
     * Class for instantiating the SOAP class directly without using the SOAP service
     */

    require_once('d:/Applications/tariqapro_soap/Tariqa/Tariqa.class.php');
    class TariqaClientLocal extends \Tariqa {
        /**
         * The current retry
         * @var int
         * @access protected
         */
        
        protected $retry = 0;

        /**
         * The ECAS user
         * @var tariqaUser
         * @access private
         */
        private $user;

        /**
         * @param array $options An array of options to pass to the SoapClient constructor
         * @param array $config The configuration array
         * @param tariqaUser $user The ECAS user
         * @return TariqaClient
         * */
        public function __construct( $options = null, $config, $user ) {
            // Load Configuration File
            $this->config = $config;

            $this->user = $user;

            parent::__construct( "no soap" );
			if( array_key_exists( "ssl", $this->config ) && array_key_exists( "certificate", $this->config["ssl"] )) {
				if( "" != $this->config["ssl"]["certificate"] ) {
					$this->_local_cert = $this->config["ssl"]["certificate"];
				}
			}
        }

        /**
         * Calls a SOAP method
         * @param string $name The name of the method
         * @param array $arguments The arguments of the method
         * @access public
         * @return mixed
         */
        public function __call($name, $arguments) {
            //Because we allways suppose that the client is logged in if he has a token which is not expired, without checking (to gain time),
            //every time we have a SOAP call we have to check if the token is really not expired.
            try {
                /*$cdir = getcwd();
                  chdir("d:/Applications/tariqapro_soap/Tariqa");*/
                $result = parent::__call($name, $arguments);
                //chdir($cdir);
                return $result;
            }
            catch (\Exception $e) {
                //If we have an error from the SOAP, check if that error is that the token is expired
                if ($e->faultcode == TariqaClientLocal::e_session) {
                    //If so, try to relogin the client and then try again to call the SOAP.
                    error_log("Session expired. Trying to relogin...");
                    $appConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'main_config');
                    $soapConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_SOAP_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'soap_config');
                    \tariqa3\statics::tariqaClientLogIn($this->user, $appConfig, $soapConfig);
                    //\MetaNull\Tools\mDump::dumpVariable($arguments);
                    foreach ($arguments as $key => $arg) {
                        $arguments[$key] = \tariqa3\statics::$tariqaToken;
                        break;
                    }
                    $result = parent::__call($name, $arguments);
                    //chdir($cdir);
                    return $result;
                }
                else {
                    //chdir($cdir);
                    //error_log($e->getTraceAsString());
                    if ($this->retry == 0 && $e->faultcode != 24577){
                        $this->retry++;
                        error_log("Error trying to execute " . $name . ". Retrying...");
                        return $this->__call($name, $arguments);
                    }
                    $this->retry = 0;
                    throw $e;
                }
            }
        }

        // -- Error codes ------------------------------------------------------

        /**
         * Error code/message - Internal Server Error
         * */
        const e_internal_error = 0x0001;
        const e_internal_error_msg = "Internal Server Error";

        /**
         * Error code/message - Invalid/Missing argument
         * */
        const e_invalid_argument = 0x0002;
        const e_invalid_argument_msg = "Invalid/Missing argument";

        /**
         * Error code/message - Not implemented
         * */
        const e_not_implemented = 0x0003;
        const e_not_implemented_msg = "Not implemented";

        /**
         * Error code/message - Invalid login
         * */
        const e_login = 0x1001;
        const e_login_msg = "Invalid Username/Password";

        /**
         * Error message - User account is locked
         * */
        const e_account_locked = 0x1002;
        const e_account_locked_msg = "User account locked";

        /**
         * Error message - Invalid Token/Session Identifier
         * */
        const e_session = 0x1003;
        const e_session_msg = "Invalid Session Identifier";

        /**
         * Error message - Insufficient privileges
         * */
        const e_privilege = 0x1004;
        const e_privilege_msg = "Insufficient privileges";

        /**
         * Error message - Forbidden access
         * */
        const e_forbidden = 0x1005;
        const e_forbidden_msg = "Access Forbidden";

        /**
         * Error message - Invalid Configuration File
         * */
        const e_config = 0x1011;
        const e_config_msg = "Invalid Configuration";

        /**
         * Error message - Database error
         * */
        const e_database = 0x1021;
        const e_database_msg = "Database error";

        /**
         * Error message - Record not found
         * */
        const e_missing_record = 0x1022;
        const e_missing_record_msg = "Database record not found";

        /**
         * Error code/message - Invalid format
         * */
        const e_invalid_format = 0x1031;
        const e_invalid_format_msg = "Invalid file format";

        /**
         * Error code/message - HTTP Error
         * */
        const e_http = 0x2001;
        const e_http_msg = "HTTP Error";

        /**
         * Error code/message - HTTP 404 Error
         * */
        const e_http404 = 0x2002;
        const e_http404_msg = "Not found";

        /**
         * Error code/message - SMTP Error
         * */
        const e_smtp = 0x3001;
        const e_smtp_msg = "SMTP Error";
    }
}
?>