<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */


	/**
	 * Encloses a Virage Document
	 */
	class VirageDocument {
	
		/**
		 * The document identifier
		 * @var int
		 */
		public $document_id = null;

		/**
		 * The document file name
		 * @var string
		 */
		public $fileName = null;

		/**
		 * The section
		 * @var int
		 */
		public $section = null;

		/**
		 * The document title
		 * @var string
		 */
		public $title = null;

		/**
		 * The document DRE title
		 * @var string
		 */
		public $dre_title = null;

		/**
		 * The document date
		 * @var string
		 */
		public $date = null;

		/**
		 * The document database name
		 * @var string
		 */
		public $database = null;

		/**
		 * The document start time
		 * @var int
		 */
		public $startTime = null;

		/**
		 * The document end time
		 * @var int
		 */
		public $endTime = null;

		/**
		 * The document content type
		 * @var string
		 */
		public $contentType = null;

		/**
		 * The document swf location
		 * @var string[]
		 */
		public $swfLocation = null;

		/**
		 * The document swf time
		 * @var int[]
		 */
		public $swfTime = null;

		/**
		 * The document OCR words
		 * @var string[]
		 */
		public $ocrWords = null;

		/**
		 * The document OCR msec time
		 * @var int[]
		 */
		public $ocrMsecTime = null;

		/**
		 * The document OCR weights
		 * @var int[]
		 */
		public $ocrWeights = null;

		/**
		 * The document soft sound msec time
		 * @var int[]
		 */
		public $softSoundMsecTime = null;

		/**
		 * The document soft sound words
		 * @var string[]
		 */
		public $softSoundWords = null;

		/**
		 * The document soft sound weights
		 * @var int[]
		 */
		public $softSoundWeights = null;

		/**
		 * The document content
		 * @var string
		 */
		public $documentContent = null;
                
		/**
		 * The document images
		 * @var VirageDocumentImages
		 */
		public $images = null;

		/**
		 * The found terms in the document (comma separated)
		 * @var string
		 * @access public
		 */
		public $links;

		/**
		 * Sets the SWF locations from an string (| delimiter)
		 * @param string $location
		 * @return void
		 * */
                public function setSWFLocation($location){
                    $this->swfLocation = array_filter($location == ""?array():explode("|", $location));
                }

		/**
		 * Gets the SWF locations
		 * @return string
		 * */
                public function getSWFLocation(){
                    $rez = "";
                    foreach ($this->swfLocation as $location)
                        $rez .= ($rez == ""?"":"|") . $location;
                        
                    return $rez;
                }

		/**
		 * Sets the SWF time from an string (| delimiter)
		 * @param string $time The SWF time
		 * @return void
		 * */
                public function setSWFTime($time){
                    $this->swfTime = array_filter($time == ""?array():explode("|", $time));
                }

		/**
		 * Gets the SWF time
		 * @return string
		 * */
                
                public function getSWFTime(){
                    $rez = "";
                    foreach ($this->swfTime as $time)
                        $rez .= ($rez == ""?"":"|") . $time;
                        
                    return $rez;
                }

		/**
		 * Sets the OCR Words from an string (| delimiter)
		 * @param string $words The OCR words
		 * @return void
		 * */
                public function setOCRWords($words){
                    $this->ocrWords = array_filter($words == ""?array():explode("|", $words));
                }

		/**
		 * Gets the OCR words
		 * @return string
		 * */
                
                public function getOCRWords(){
                    $rez = "";
                    foreach ($this->ocrWords as $word)
                        $rez .= ($rez == ""?"":"|") . $word;
                        
                    return $rez;
                }

		/**
		 * Sets the OCR MSec time from an string (space delimiter)
		 * @param string $time The OCR MSec time
		 * @return void
		 * */
                public function setOCRMSecTime($time){
                    $this->ocrMsecTime = array_filter($time == ""?array():explode(" ", $time));
                }

		/**
		 * Gets the OCR MSecTime
		 * @return string
		 * */
                
                public function getOCRMSecTime(){
                    $rez = "";
                    foreach ($this->ocrMsecTime as $time)
                        $rez .= ($rez == ""?"":" ") . $time;
                        
                    return $rez;
                }

		/**
		 * Sets the OCR weights from an string (space delimiter)
		 * @param string $weights The OCR weights
		 * @return void
		 * */
                public function setOCRWeight($weights){
                    $this->ocrWeights = array_filter($weights == ""?array():explode(" ", $weights));
                }

		/**
		 * Gets the OCR weights
		 * @return string
		 * */
                
                public function getOCRWeights(){
                    $rez = "";
                    foreach ($this->ocrWeights as $weight)
                        $rez .= ($rez == ""?"":" ") . $weight;
                        
                    return $rez;
                }

		/**
		 * Sets the soft sound MSec time from an string (space delimiter)
		 * @param string $time The sound time
		 * @return void
		 * */
                public function setSoftSoundMSecTime($time){
                    $this->softSoundMsecTime = array_filter($time == ""?array():explode(" ", $time));
                }

		/**
		 * Gets the soft sound MSec time
		 * @return string
		 * */
                
                public function getSoftSoundMSecTime(){
                    $rez = "";
                    foreach ($this->softSoundMsecTime as $time)
                        $rez .= ($rez == ""?"":" ") . $time;
                        
                    return $rez;
                }

		/**
		 * Sets the soft sound words from an string (| delimiter)
		 * @param string $words The sound words
		 * @return void
		 * */
                public function setSoftSoundWords($words){
                    $this->softSoundWords = array_filter($words == ""?array():explode("|", $words));
                }

		/**
		 * Gets the soft sound words
		 * @return string
		 * */
                
                public function getSoftSoundWords(){
                    $rez = "";
                    foreach ($this->softSoundWords as $word)
                        $rez .= ($rez == ""?"":"|") . $word;
                        
                    return $rez;
                }

		/**
		 * Sets the soft sound weights from an string (| delimiter)
		 * @param string $weights The sound words
		 * @return void
		 * */
                public function setSoftSoundWeights($weights){
                    $this->softSoundWeights = array_filter($weights == ""?array():explode("|", $weights));
                }

		/**
		 * Gets the soft sound weights
		 * @return string
		 * */
                
                public function getSoftSoundWeights(){
                    $rez = "";
                    foreach ($this->softSoundWeights as $weight)
                        $rez .= ($rez == ""?"":"|") . $weight;
                        
                    return $rez;
                }

		/**
		 * Transform the SWF locations if the path is not correctly set-up
		 * @param string $correctLocation The correct location of SWF Files
		 * @return string
		 * */
		
		public function correctSWFLocation($correctLocation){
			if (is_array($this->swfLocation))
				foreach ($this->swfLocation as $key => $location){
					$parts = explode("/", $location);
					$this->swfLocation[$key] = $correctLocation . $parts[count($parts) - 1];
				}
		}
                
        }

?>