<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{

	/**
	 * Class providing an LDAP independent authentication mechanism for Tariqa
	 * @package tariqa3
	 * @author Pascal Havelange, Cosmin Popescu
	 * @copyright © EUROPEAN COMMISSION, 2009-2010
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	class TariqaAuthentication implements iCustomAuthentication {

        public function __construct($config){
            $this->config = $config;
        }
		
	    /**
	     * Starts the php session and performs the authentication
	     * @param array $config The application configuration
	     * @access public
	     * @return tariqaUser|false
	     */
	    public function startSession($config){
            \setcookie('auth', 'Tariqa');
            \session_name($this->config['application']['name']);
            \session_start();

            if (array_key_exists('uid', $_SESSION)){
                if ($_SESSION['uid'] != null && $_SESSION['uid'] != ''){
                    $user = \MetaNull\Tools\mCache::loadVariable('users/' . $_SESSION['uid']);
                    if ($user == null){
                        $db = statics::open_db_connection($this->config['database']);
                        $sql = "select * from known_users where user_id = '" . $_SESSION['uid'] . "'";
                        $query = $db->mQuery($sql);
                        if ($row = $query->fetch_assoc()){
                            $user = new TariqaUser($row);
                            \MetaNull\Tools\mCache::saveVariable($user, 'users/' . $user->user_id);
                            return $user;
                        }                        
                    }
                    else {
                        return $user;
                    }
                }
            }

            $url = \MetaNull\Tools\mTools::rawurlencode($_SERVER['SCRIPT_URI'] . '?' . $_SERVER['QUERY_STRING']);
            $u = $this->config['application']['url'];
            if (substr($u, -1) != '/') $u .= '/';
            $location = $u . 'special_page.php?' . 'module=login&s=' . $this->config['application']['name'] . '&u=' . $url;
            
            $_SESSION['uid'] = null;
            \header("Location: " . $location);
	    }
	}

}
?>