<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3 {

/**
 * Video archive module
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
class Archive extends tariqa3ModuleSectionManager {
	/**
	 * The number of videos per page
	 * @var int
	 
	 */
	const VIDEOS_PER_PAGE = 20;

	/**
	 * The list of video archive records
	 * @var VideoArchiveRecord[]
	 * @access private
	 */
	private $records;

	/**
	 * The current page number
	 * @var int
	 * @access private
	 */
	private $page;

	/**
	 * The filtered channel name
	 * @var string
	 * @access private
	 */
	private $channel_name;

	/**
	 * The start date of the video to see
	 * @var int
	 * @access private
	 */
	private $start_date;

	/**
	 * The end date of the video to see
	 * @var int
	 * @access private
	 */
	private $end_date;

	/**
	 * The total number of videos
	 * @var int
	 * @access private
	 */
	private $records_count;

	/**
	 * Construct the Module object
	 * @param array $config The multidimentionnal array containing the application's configuration
	 */
	public function __construct( $config ) {
		parent::__construct($config);
	}

	/**
	 * Render the module
	 * @return string
	 */
	public function getPageContent() {
		$tpl = new \MetaNull\Application\MTemplate( 'm' );
		$tpl->loadTemplate($this->getTemplateFilePath('archive.html'));
		$tpl->data = $this->translationTable;

		$tpl->data['channel_name'] = $this->channel_name;
		$tpl->data['start_date'] = $this->start_date;
		$tpl->data['end_date'] = $this->end_date;
		$tpl->data['form_url'] = statics::URL('index.php', 'module=' . $this->getName());
		$tpl->data['module'] = $this->getName();

		$tpl->data['has_navigation'] = ($this->records_count > self::VIDEOS_PER_PAGE?true:false);

		$tpl->data['display1'] = ($this->page > 0?'block':'none');
		$tpl->data['display2'] = ($this->page < floor(($this->records_count - 1) / self::VIDEOS_PER_PAGE)?'block':'none');

		$query = 'module=' . $this->getName() . '&channel_name=' . $this->channel_name .
			'&start_date=' . $this->start_date . '&end_date=' . $this->end_date;

		$tpl->data['first_link'] = statics::URL('index.php', $query . '&page=0');
		$tpl->data['prev_link'] = statics::URL('index.php', $query . '&page=' . ($this->page - 1));
		$tpl->data['next_link'] = statics::URL('index.php', $query . '&page=' . ($this->page + 1));
		$tpl->data['last_link'] = statics::URL('index.php', $query . '&page=' . floor(($this->records_count - 1) / self::VIDEOS_PER_PAGE));

		$this->info_setJavascript(
			array(
				'scripts/archive.js',
			)
		);

		$tpl->data['videos'] = array();

		$i = 0;

		/* @var $video VideoArchiveRecord */
		foreach ($this->records as $video){
			$tpl->data['videos'][] = array(
				'url' => $video->url,
				'img_src' => $video->thumbnail,
				'channel' => $video->channel,
				'title' => $video->title,
				'date' => date('d/m/Y h:i', $video->date),
				'length' => $video->raw_length,
				'new_row' => ($i++ % 2 == 1),
			);
		}

		$this->info_setBodyOnLoad('initJQueryUI()');

		return $tpl->transform();
	}

	/**
	* Initializes the module
	* @access public
	* @return void
	*/
	public function onInitialize(){
		parent::onInitialize();
		$this->page = 0;
		$this->channel_name = null;
		$this->start_date = null;
		$this->end_date = null;
		if (array_key_exists('channel_name', $_GET) && $_GET['channel_name'] != '') $this->channel_name = $_GET['channel_name'];
		if (array_key_exists('page', $_GET)) $this->page = $_GET['page'];
		if (array_key_exists('start_date', $_GET) && $_GET['start_date'] != '') $this->start_date = $_GET['start_date'];
		if (array_key_exists('end_date', $_GET) && $_GET['end_date'] != '') $this->end_date = $_GET['end_date'];

		//\MetaNull\Tools\mDump::dumpVariable(strtotime($this->start_date));
		
		$this->records = statics::$tariqaClient->listVideoArchiveRecords(statics::$tariqaToken, $this->page * self::VIDEOS_PER_PAGE, self::VIDEOS_PER_PAGE, $this->channel_name, strtotime($this->start_date), strtotime($this->end_date));
		$this->records_count = statics::$tariqaClient->countVideoArchiveRecords(statics::$tariqaToken, $this->channel_name, strtotime($this->start_date), strtotime($this->end_date));
	}

	/**
	 * Process all requests (this is the default module)
	 */
	public function canProcessRequest() {
		return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
	}

	/**
	 * Returns the name of the class (what it should appear in the menu
	 * @access public
	 * @return string
	 */
	public function getName() {
		return 'archive';
	}

	/**
	 * Returns the title of the page
	 * @access public
	 * @return string
	 */
	public function getTitle() {
		return 'Tariqa 3 Video Archive page';
	}

	/**
	 * Returns the description of the page
	 * @access public
	 * @return string
	 */
	public function getDescription() {
		return 'The video archive page';
	}

	/**
	 * Gets the link of the module
	 * @access public
	 * @return string
	 */
	public function getLink() {
		return statics::URL('index.php', 'module=' . $this->getName());
	}

	/**
	 * Return the items of the current breadcrumb path
	 * @return tariqa3ModuleDescriptor[]
	 */
	public function getBreadCrumb() {
		$breadCrumb = array();
		$breadCrumb[] = new tariqa3ModuleDescriptor($this);
		return $breadCrumb;
	}
}

}

?>