<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

require_once('tariqa3/modules/sharing/Sharing.class.php');

/**
 * News Article
 * @author Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class Article extends tariqa3Module {

    /**
     * The selected article
     * @var DOMDocument
     * @access private
     */
    private $article;

    /**
     * The engine of the article
     * @var string
     * @access private
     */
    private $engine;

    /**
     * The title of the article
     * @var string
     * @access private
     */
    private $article_title;

    /**
     * The news configuration array
     * @var array
     * @access private
     */
    private $newsConfig;

    /**
     * The article form
     * @var string
     * @access protected
     */
    protected $af = search\AggregatorsEngine::ARTICLE_LONG;

    /**
     * Construct the Module object
     * @param array $config The multidimentionnal array containing the application's configuration
     */
    public function __construct( $config ) {
	parent::__construct($config);
	$this->_isMenuable = false;
	$this->_displayMenu = true;
    }

    /**
     * Changes the frame link for IE 8.
     * @access protected
     * @return void
     */
    protected function changeLink() {
	$xp = new \DOMXPath($this->article);
	$rs = $xp->query('//document_id');
	if ($rs->length > 0){
	    $item = $rs->item(0);
	    $message = str_replace('#REF#', $item->nodeValue, $this->translate('ie8_warning'));
	    $item->nodeValue = statics::URL('special_page.php', 'module=redirect&amp;l=' . \MetaNull\Tools\mTools::rawurlencode($item->nodeValue) . '&amp;d=');
	    $nodes = $this->article->getElementsByTagName('article');
	    if ($nodes->length > 0) {
		$nodes->item(0)->setAttribute('warning', $message);
	    }
	}
    }

    /**
     * Render the module
     * @return string
     */
    public function getPageContent() {
	//\MetaNull\Tools\mDump::dumpVariable(statics::$tariqaToken);
	$this->info_setTitle($this->article_title);

	$this->info_setJavascript(array(
		'scripts/briefcase.js',
		'scripts/article.js?',
		'scripts/jquery.path.js',
		'scripts/flowplayer-3.2.6.js',
	));
	$type = 'new';
	if (array_key_exists('type', $_GET)) $type = $_GET['type'];

	if ($this->externalArticle()){
	    if ($type == 'new') {
		$xsl = 'site';
		$txt = $this->article->saveXML();
		$txt = preg_replace('/[\x00-\x08\x0b\x0c\x0e-\x1f]/', '', $txt);
		$this->article = new \DOMDocument('1.0', 'UTF-8');
		$this->article->loadXML($txt);
		$this->info_setBodyOnLoad('setFrameHeight()');

		if (statics::_isIE()){
		    $this->changeLink();
		}
		//$this->info_setBodyOnLoad('getExternalArticleTitle();');
		/*header('Content-Type: text/xml; charset=UTF-8');
				echo $this->article->saveXML();
				die();*/

	    }
	    else {
		if (array_key_exists('force_briefcase', $_GET)) {
		    $xsl = 'intern';
		}
		else {
		    $xsl = 'site';
		    if (statics::_isIE()){
			$this->changeLink();
		    }
		    $this->info_setBodyOnLoad('setFrameHeight();');
		}
	    }
	}
	else {
	    $xsl = 'intern';
	}

	$xp = new \DOMXPath($this->article);
	if ($xsl == 'intern' && !array_key_exists('print', $_GET)) {
	    $tpl = new \MetaNull\Application\MTemplate('m');
	    $tpl->data = $this->translationTable;
	    $tpl->loadTemplate($this->getTemplateFilePath('controls.html'));
	    $title = str_replace("\n", ' ', $this->article_title);
	    $title = str_replace("\r", ' ', $title);
	    $title = str_replace("'", "\\'", $title);
	    $tpl->data['article_title'] = $title;
	    $tpl->data['article_url'] = statics::URL('index.php', $_SERVER['QUERY_STRING'] . '&print=');
	    $tpl->data['has_long_form'] = false;
	    if (array_key_exists('long_form', $this->newsConfig['search']['default'][$this->engine])) {
		if (preg_match('/^[1|yes|on|true]$/', $this->newsConfig['search']['default'][$this->engine]['long_form'])) {
		    $tpl->data['has_long_form'] = true;
		}
	    }

	    $tpl->data['short_form'] = search\AggregatorsEngine::ARTICLE_SHORT;
	    $tpl->data['long_form'] = search\AggregatorsEngine::ARTICLE_LONG;

	    $rs = $xp->query('/article/id');
	    $tpl->data['article_id'] = $rs->item(0)->nodeValue;

        $xpath = new \DOMXPath($this->article);
        $tpl->data['additional_main_controls'] = '';
        $rs = $xpath->query('//additional_main_controls');
        if ($rs->length > 0){
            $tpl->data['additional_main_controls'] = $rs->item(0)->nodeValue;
        }

	    $node = $this->article->createElement('article_controls');
	    $html = $tpl->transform();
	    $cdata = $this->article->createCDATASection($tpl->transform());
	    $node->appendChild($cdata);

	    $rs = $xp->query('/article');
	    $rs->item(0)->appendChild($node);
	}

	/*header('Content-Type: text/xml; charset=UTF-8');
		echo $this->article->saveXML();
		die();*/

	$rs = $xp->query('/article/template');
	if ($rs->length > 0){
	    if ($rs->item(0)->nodeValue != ''){
		$xsl = $rs->item(0)->nodeValue;
	    }
	}

	if (array_key_exists('t', $_GET)){
	    $xsl = $_GET['t'];
	}
	else if (array_key_exists('t', $_POST)){
	    $xsl = $_POST['t'];
	}

	$printer = new \MetaNull\Tools\xslTransform($this->article, 'newsPrinter/' . $xsl, \MetaNull\Tools\xslTransform::FORMAT_TEXT, $this->newsConfig);
	return $printer->transform();
    }

    /**
     * Is the article from an external site?
     * @access protected
     * @return boolean
     */
    protected function externalArticle() {
	return array_key_exists('external', $this->newsConfig['search']['default'][$this->engine]) || array_key_exists('external', $this->newsConfig['search']['default'][strtolower($this->engine)]);
    }

    /**
     * At initialisation, request authentication, or throw an exception on failure
     */
    protected function onInitialize() {
	parent::onInitialize();

	if (array_key_exists('print', $_GET)) {
	    $this->setDefaultLayout('empty_page.html');
	    $this->info_setBodyOnLoad("$('#share_results_form').remove(); $('#share_search_form').remove(); window.print();");
	}

	$this->newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

	if (!array_key_exists('id', $_GET) && !(array_key_exists('oxan_page', $_GET))) {
	    error_log('Trying to fetch an article without specifying the type (new or briefcase)');
	    return false;
	}

	$this->af = $this->user->get_preference('general/article_form');
	if ($this->af == null){
	    $this->af = search\AggregatorsEngine::ARTICLE_LONG;
	}

	$_SESSION['article_form'] = $this->af;
	$_SESSION['article_' . md5($_GET['id'])] = (array_key_exists('af', $_GET)?$_GET['af']:$this->af);

	$db = \tariqa3\statics::open_db_connection($this->config['database']);
	if (!array_key_exists('oxan_page', $_GET)) {
	    $id = $db->real_escape_string($_GET['id']);
	}

	$type = 'new';
	if (array_key_exists('type', $_GET)) $type = $_GET['type'];

	if ($type == 'new') {
	    if (!$this->canReadArticle($this->user, $id)) {
		throw new \MetaNull\Authentication\insufficientPrivilegesException( 'Access to this page is restricted' );
	    }
	    if (array_key_exists('oxan_page', $_GET)) {
		$id = '';
		$data = statics::post2array($_SERVER['QUERY_STRING']);
		foreach ($data as $key => $value) {
		    if ($key != 'module' && $key != 'type' && $key != 'oxan_page') {
			$id .= ($id == ''?'':'&') . $key . '=' . $value;
		    }
		}

		$id = 'OxfordAnalytica:3:' . $_GET['oxan_page'] . ($_GET['oxan_page'] == ''?'':'?') . $id;
	    }

	    $this->article = newsAdapter::fetchArticle($id, $this->newsConfig);
	}
	else if ($type == 'briefcase') {
	    $table = 'briefcase_content';
	    if (array_key_exists('general', $_GET)){
		$id = Briefcase::autoImport($this->user, $this->db, $id);
		$_GET['id'] = $id;
	    }
	    $sql = "select * from `briefcase_content` where `content_id` = '{$id}'";
	    $query = $db->mQuery($sql);
	    if ($row = $query->fetch_assoc()) {
		if (array_key_exists('general', $_GET)){
		    $row['user_id'] = $this->user->user_id;
		}
		if ($row["user_id"] != $this->user->user_id) {
		    error_log('Access denied to ' . $this->user->user_id . ' to the ' . $id . ' article. ');
		    throw new \MetaNull\Authentication\insufficientPrivilegesException( 'Access to this page is restricted' );
		}
		$this->article = new \DOMDocument();
		$this->article->loadXML($row["data"]);
	    }
	    else {
		throw new \Exception('The ' . $id . ' article was not found in the briefcase database. ');
	    }
	}
	else {
	    throw new \Exception('The ' . $type . ' is not defined for article types.');
	}

	$xpath = new \DOMXPath($this->article);
	$rs = $xpath->query('//engine');
	if ($rs->length == 0) {
	    throw \Exception('The engine for the ' . $id . ' article was not set');
	}
	$this->engine = $rs->item(0)->nodeValue;

	$rs = $xpath->query('//additional_js');
	if ($rs->length > 0){
	    $js_code = $rs->item(0)->nodeValue;
	    if ($js_code != ''){
		$this->info_setInlineJavascript($js_code);
	    }
	}

	$rs = $xpath->query('//additional_jsonload');
	if ($rs->length > 0){
	    $js_code = $rs->item(0)->nodeValue;
	    if ($js_code != ''){
		$this->info_setBodyOnLoad($js_code);
	    }
	}

	$rs = $xpath->query('//extra_headers');
	if ($rs->length != 0) {
	    $this->info_setRawHeaders($rs->item(0)->nodeValue);
	}

	/*$rs = $xpath->query('//body');
		if ($rs->length != 0){
		    $xml = new \DOMDocument('1.0', 'utf-8');
		    $xml->loadHTML($rs->item(0)->nodeValue);
		    $xpath = new \DOMXPath($xml);
		    $rs = $xpath->query("//div[@id='doc4']/div[@id='bd']/div[@id='yui-main']/div[@class='yui-b']/div[@id='yn-story']/div[@class='bd']");
		    $xml2 = new \DOMDocument('1.0', 'utf-8');
		    $xml2->loadXML('<div></div>');
		    $node = $xml2->importNode($rs->item(0), true);
		    $xml2->documentElement->appendChild($node);
		    \MetaNull\Tools\mDump::dumpVariable($xml2->saveXML());
		}*/

	$rs = $xpath->query('//title');
	$this->article_title = '';
	if ($rs->length != 0) {
	    if ($rs->item(0)->nodeValue != '') {
		$this->article_title = ' - ' . $rs->item(0)->nodeValue;
	    }
	    else {
		$title = preg_replace('/^.*\/([^\/]*)$/U', '\1', $_GET['id']);
		if ($title != '' && $title != null) {
		    $this->article_title = ' - ' . $this->engine . ':' . $title;
		}
	    }
	}
	$this->article_title = $this->config['application']['name'] . $this->article_title;

	$nodes = $this->article->getElementsByTagName('article');
	if ($nodes->length > 0) {
	    $nodes->item(0)->setAttribute('link1', $this->translate('send_article_to_briefcase'));
	    $nodes->item(0)->setAttribute('warning', '');
	    $nodes->item(0)->setAttribute('link2', $this->translate('share_article'));
	    $nodes->item(0)->setAttribute('link4', $this->translate('print_article'));

	    if (array_key_exists('short_form', $this->newsConfig['search']['default'][$this->engine])) {
		if (preg_match('/^[1|yes|on|true]$/', $this->newsConfig['search']['default'][$this->engine]['short_form']) && $_SESSION['article_form'] == search\AggregatorsEngine::ARTICLE_LONG) {
		    $nodes->item(0)->setAttribute('link5', $this->translate('module/short_form'));
		    $nodes->item(0)->setAttribute('short_form_link', statics::URL('index.php', preg_replace('/#$/', '', $_SERVER['QUERY_STRING']) . '&af=short'));
		}
	    }

	    $base_url = $this->config['application']['url'];
	    if (substr($base_url, -1) != '/') {
		$base_url .= '/';
	    }
	    $app_url = $this->config['application']['url'];
	    if (substr($app_url, -1) != '/') {
		$app_url .= '/';
	    }
	    if ($type == 'new') {
		preg_match_all('/id=([^:]*):([^:]*):([^&]*)/', $_SERVER['QUERY_STRING'], $matches);
		if (count($matches) >= 4) {
		    if (count($matches[3]) > 0) {
			$url = $matches[3][0];
		    }
		}

		//Work around not to hard code the RSS_aggregator engine.
		//If the url is not in the right format (this is the case if there is an RSS_aggregator article
		//and from the preferences there is the full article opened instead of the short article.

		if (!preg_match('/^http:\/\/.*$/', $url)) {
		    $rs = $xpath->query('//document_id');
		    if ($rs->length > 0) {
			if (preg_match('/^http:\/\/.*$/', $rs->item(0)->nodeValue)) {
			    $url = $rs->item(0)->nodeValue;
			}
		    }
		}
	    }
	    else if ($type == 'briefcase') {
		$rs = $xpath->query('//document_id');
		if ($rs->length > 0) {
		    $url = \MetaNull\Tools\mTools::rawurlencode($rs->item(0)->nodeValue);
		}
	    }

	    $nodes->item(0)->setAttribute('print_link', statics::URL($app_url . 'article/' . \MetaNull\Tools\mTools::rawurlencode($url) . '/print-site/'));
	    $nodes->item(0)->setAttribute('display', (array_key_exists('print', $_GET)?'none':'inherit'));
	    if (!array_key_exists('force_briefcase', $_GET) && $this->externalArticle() && $type == 'briefcase') {
		$nodes->item(0)->setAttribute('link3', $this->translate('open_article_from_briefcase'));
		$nodes->item(0)->setAttribute('link3_id', $_GET['id']);
	    }
	    $nodes->item(0)->setAttribute('load_src', $this->config['templates']['baseurl'] . '/' . $this->config['templates']['default'] .
		    '/images/ajax-loader-mini.gif');
	    $sharing = new Sharing($this->config, $this->translationTable);
	    $txt = '<span>' . $sharing->run() . "</span>";
	    $doc = new \DOMDocument('1.0', 'UTF-8');
	    $txt = str_replace('&nbsp;', ' ', $txt);
	    $doc->loadXML($txt);
	    $divs = $doc->getElementsByTagName('div');
	    $id1 = 0;
	    $id2 = 0;
	    for ($i = 0; $i < $divs->length && $id1 == 0 && $id2 == 0; $i++) {
		if ($divs->item($i)->getAttribute('id') == 'share_search_form') {
		    $id1 = $i;
		}
		if ($divs->item($i)->getAttribute('id') == 'share_results_form') {
		    $id2 = $i;
		}
	    }
	    $root = $nodes->item(0);
	    $node = $this->article->createElement('sharing_form');
	    $node2 = $this->article->importNode($divs->item($id1), true);
	    $node->appendChild($node2);
	    $node2 = $this->article->importNode($divs->item($id2), true);
	    $node->appendChild($node2);
	    $root->appendChild($node);
	    $this->setMoreInfos($sharing->getInfo());
	    $js_title = str_replace("\n", ' ', $this->article_title);
	    $js_title = str_replace("'", "\\'", $js_title);
	    $nodes->item(0)->setAttribute("js_title", $js_title);
	}
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {
	return array_key_exists('module', $_GET) && $_GET['module'] == 'article';
    }

    /**
     * Returns the short name of the module (used by menus)
     * @return string
     */
    public function getName() {
	return 'article';
    }
    /**
     * Returns the title of the module (used in html/head/title)
     * @return string
     */
    public function getTitle() {
	return '';
    }
    /**
     * Returns the description of the module (used in html/head/description)
     * @return string
     */
    public function getDescription() {
	return '';
    }
    /**
     * Returns the url to the current module (used in menus)
     * @return string
     */
    public function getLink() {
	$params = array(
	    'module'=>$this->getName(),
	    'type' => $_GET['type'],
	    'id' => $_GET['id'],
	);
	if (array_key_exists('t', $_GET)){
	    $params['t'] = $_GET['t'];
	}
	return statics::URL( 'index.php', $params, true);
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();
	$b = new tariqa3ModuleDescriptor($this);
	$b->label = $this->translate('module/tabTitle');
	$breadCrumb[] = $b;
	return $breadCrumb;
    }
}

}

?>