<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

require_once('CountryTree.class.php');
require_once('MapsSection.class.php');
require_once('tariqa3/modules/sharing/Sharing.class.php');

/**
 * Country Module
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class Countries extends tariqa3ModuleSectionManager {

    /**
     * The listing type
     * @var int
	 
     */
    const LISTING = 0;

    /**
     * The country display type
     * @var int
	 
     */
    const COUNTRY_DISPLAY = 1;

    /**
     * The country to display
     * @var Country
     * @access private
     */
    private $country = null;

    /**
     * The list of countries
     * @var Country[]
     * @access private
     */
    private $countries;

    /**
     * The list of continents
     * @var Continent[]
     * @access private
     */
    private $continents;

    /**
     * The type of the rendering (one country page or the list of the countries)
     * @var int
     * @access private
     */
    private $type = 0;

    /**
     * The list of flavours
     * @var Flavour[]
     * @access private
     */
    private $flavours;

    /**
     * The list of queries
     * @var Query[][]
     * @access private
     */
    private $queries;

    /**
     * Construct the Module object
     * @param array $config The multidimentionnal array containing the application's configuration
     */
    public function __construct( $config ) {
	parent::__construct($config);
    }

    /**
     * Renders the listing of the countries
     * @param mTemplate $tpl The template of the page
     * @access protected
     * @return string
     */
    protected function listCountries($tpl) {
	$this->info_setJavascript(
		array(
		'scripts/jquery.cookie.js',
		'scripts/jquery.jstree.js',
		'scripts/briefcase.js',
		)
	);

	$this->info_setStylesheet(
		array(
		$this->getThemeFileUrl( 'styles/jquery/tree/jquery.treeview.css' ),
		)
	);

	$list_types = '';
	$desc_type = '';

	/* @var $country Country */
	foreach ($this->countries as $country) {
	    $list_types .= ($list_types == ''?'':', ') . "'country_{$country->code_iso2}'";
	    $png = \strtolower($country->code_iso2);
	    $desc_type .= ($desc_type == ''?'':",\n") . <<<js
'country_{$country->code_iso2}': {
    'max_children': 0,
    'icon': {
        'image': 'themes/default/images/countries/{$png}.png'
    }
}
js;
	}

	$types_config = <<<js
var types =
{
    'valid_children': ['continent', {$list_types}],
    'types':{
            'continent': {
                    'valid_children': [{$list_types}]
            },
		{$desc_type}
    }
};

js;

	$this->info_setInlineJavascript($types_config);

	$initEachContinent = '';

	$tpl->data['continents'] = array();

	$i = 0;

	/* @var $continent Continent */
	foreach ($this->continents as $continent) {
	    $tree = new CountryTree(array($continent), $this->countries, 'countries_folder.html');
	    $tpl->data['continents'][] = array(
		    'id' => $continent->continent_id,
		    'html' => '', //(statics::_isIE() ? '' : $tree->folderHTML('test', null)),
		    'new_row' => (++$i % 3 == 0? true: false),
	    );

	    $initEachContinent .= ($initEachContinent == ''?'':'; ') . 'initJQueryContinent("' . $continent->continent_id . '", types)';
	}

	$js_code = <<<js
function initAllContinents(){
		{$initEachContinent};
}
js;

	$this->info_setInlineJavascript($js_code);

	$this->info_setBodyOnLoad('initJQueryUI(); initAllContinents();');

	return $tpl->transform();
    }

    /**
     * Renders the country page
     * @param mTemplate $tpl The template of the page
     * @access protected
     * @return string
     */
    protected function displayCountry($tpl) {
	//The prefix used to retrieve the user preferences regarding the selected country
	$this->info_setJavascript(
		array(
		'scripts/jquery.cookie.js',
		'scripts/jquery.treeview.min.js',
        'scripts/swfobject.js',
		)
	);

	$this->info_setStylesheet(
		array(
		$this->getThemeFileUrl( 'styles/jquery/tree/jquery.treeview.css' ),
		)
	);

	$propertiesSection = 'country_page/' . $this->country->code_iso2 . '/';

	$news = new NewsSection($this->config, $this->base_folder, 'news_tabs', $this->translationTable, $this->flavours, $this->queries, $propertiesSection);
	$this->addSection($news);

	$maps = new MapsSection($this->config, $this->base_folder, 'wiki_tab', $this->translationTable, $this->country);
	$maps->currentLanguage = $this->currentLanguage;
	$this->addSection($maps);

	$tpl->data['country_name'] = $this->country->name;
	$tpl->data['country_id'] = $this->country->code_iso2;

	$tpl->data['sections_html'] = $this->renderSections();

	$this->info_setJavascript(
		array(
		'scripts/search.js',
		'scripts/briefcase.js',
		'scripts/news_section.js',
		)
	);

	$this->info_setBodyOnLoad('initJQueryUI(1)');

	$sharing = new Sharing($this->config, $this->translationTable);
	$tpl->data['sharing_form'] = $sharing->run();
	$tpl->data['display_hotspot'] = ($this->country->hotspot?'':'none');
	$this->setMoreInfos($sharing->getInfo());

	return $tpl->transform();
    }

    /**
     * Render the module
     * @return string
     */
    public function getPageContent() {
	$tpl = new \MetaNull\Application\MTemplate( 'm' );
	$tpl->data = $this->translationTable;

	$this->info_setJavascript(
		array(
		'scripts/countries.js',
		)
	);

	switch ($this->type) {
	    case self::COUNTRY_DISPLAY:
		$tpl->loadTemplate($this->getTemplateFilePath( 'country_page.html' ));
		return $this->displayCountry($tpl);
		break;
	    case self::LISTING:
		$tpl->loadTemplate( $this->getTemplateFilePath( 'listing.html' ));
		return $this->listCountries($tpl);
		break;
	}

	return null;
    }

    /**
     * Variable used for filtering the queries by the flavour_id
     * @var int
     * @access private
     * @static
     */
    private static $flavour_id;

    /**
     * Function used for filtering the queries by the flavour_id
     * @param Query $query The query to check
     * @access private
     * @static
     * @return boolean
     */
    private static function filterQueries($query) {
	return $query->flavour->flavour_id == self::$flavour_id;
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	if (array_key_exists('country_id', $_GET)) {
	    //if ($_GET['country_id'] == 'US') $_GET['country_id'] = 'RO';
	    //die('test');
	    $this->type = self::COUNTRY_DISPLAY;
	    $this->country = statics::get_country($_GET['country_id'], true, true);
	    $this->flavours = statics::listFlavours();
	    $queries = statics::listCountryQueries($this->country, $this->user->get_access_level());
	    $this->queries = array();

	    /* @var $flavour Flavour */
	    foreach ($this->flavours as $flavour) {
		self::$flavour_id = $flavour->flavour_id;
		$this->queries[$flavour->flavour_id] = array_filter($queries, array($this, 'filterQueries'));
	    }

	    //\MetaNull\Tools\mDump::dumpVariable($this->queries);
	}
	else {
	    $this->type = self::LISTING;
	    $this->countries = statics::listCountries();
	    $this->continents = statics::listContinents();
	}
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {
	return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
    }

    /**
     * Returns the name of the class (what it should appear in the menu
     * @access public
     * @return string
     */
    public function getName() {
	return 'countries';
    }

    /**
     * Returns the title of the page
     * @access public
     * @return string
     */
    public function getTitle() {
	return 'Tariqa 3 Country page';
    }

    /**
     * Returns the description of the page
     * @access public
     * @return string
     */
    public function getDescription() {
	return 'The country page';
    }

    /**
     * Gets the link of the module
     * @access public
     * @return string
     */
    public function getLink() {
	return statics::URL('index.php', 'module=' . $this->getName());
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();
	$breadCrumb[] = new tariqa3ModuleDescriptor($this);
	if ($this->country != null) {
	    $b = new tariqa3ModuleDescriptor();
	    $b->label = $this->country->name;
	    $b->link = statics::URL('index.php', 'module=countries&country_id=' . $this->country->code_iso2);
	    $breadCrumb[] = $b;
	}
	return $breadCrumb;
    }
}

}

?>