<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

/**
 * Help page for Tariqa
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class Help extends tariqa3ModuleSectionManager {

    /**
     * The screen casts
     * @var array
     * @access protected
     */
    protected $screencasts;

    /**
     * The help page specific configuration
     * @var array
     * @access protected
     */
    protected $own_config;

    /**
     * Construct the Module object
     * @param array $config The multidimentionnal array containing the application's configuration
     */
    public function __construct( $config ) {
	parent::__construct($config);
    }

    /**
     * Render the module
     * @return string
     */
    public function getPageContent() {
	$tpl = new \MetaNull\Application\MTemplate( 'm' );
	$tpl->loadTemplate($this->getTemplateFilePath('main.html'));
	$tpl->data = $this->translationTable;

	$tpl->data['screencasts'] = array();
	$i = 0;
	foreach ($this->screencasts as $key => $screencast){
	    $screencast['id'] = $key;
	    $screencast['break'] = ++$i % $this->own_config['columns'] == 0;
	    $screencast['base'] = $this->own_config['base'];
	    $tpl->data['screencasts'][] = $screencast;
	}

	return $tpl->transform();
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	$this->own_config = \MetaNull\Tools\mConfig::loadConfiguration('misc/help/help.xml', 'xml', 'help_config');
	$this->screencasts = $this->own_config['screencasts'];
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {
	return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
    }

    /**
     * Returns the name of the class (what it should appear in the menu
     * @access public
     * @return string
     */
    public function getName() {
	return 'help';
    }

    /**
     * Returns the title of the page
     * @access public
     * @return string
     */
    public function getTitle() {
	return 'Tariqa 3 Help page';
    }

    /**
     * Returns the description of the page
     * @access public
     * @return string
     */
    public function getDescription() {
	return 'The help page';
    }

    /**
     * Gets the link of the module
     * @access public
     * @return string
     */
    public function getLink() {
	return statics::URL('index.php', 'module=' . $this->getName());
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();
	$desc = new tariqa3ModuleDescriptor($this);
	$desc->label = strip_tags($desc->label);
	$breadCrumb[] = $desc;

	return $breadCrumb;
    }
}

}

?>