<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

/**
 * Newswires module (LatestNews)
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class NewsWires extends tariqa3ModuleSectionManager {

    /**
     * The list of the weblog queries
     * @var Query[][]
     * @access protected
     */
    protected $queries;

    /**
     * The list of the weblog flavours
     * @var Flavour[]
     * @access protected
     */
    protected $flavours;

    /**
     * Construct the Module object
     * @param array $config The multidimentionnal array containing the application's configuration
     */
    public function __construct( $config ) {
	parent::__construct( $config );
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {
	return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
    }

    /**
     * Returns the short name of the module (used by menus)
     * @return string
     */
    public function getName() {
	return 'newswires';
    }
    /**
     * Returns the title of the module (used in html/head/title)
     * @return string
     */
    public function getTitle() {
	return 'Tarîqa 3.0 - Newswires';
    }
    /**
     * Returns the description of the module (used in html/head/description)
     * @return string
     */
    public function getDescription() {
	return 'Latest news from the major newswires';
    }

    /**
     * Returns the url to the current module (used in menus)
     * @return string
     */
    public function getLink() {
	return statics::URL( 'index.php', array( 'module'=>$this->getName() ), true );
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();
	$breadCrumb[] = new tariqa3ModuleDescriptor($this);
	return $breadCrumb;
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	$queries = statics::listQueries($this->user->get_access_level(), $this->config['news-wires']['weblogs-source'], true);
	$query = statics::getQuery($this->config['news-wires']['query_id']);
	$query->block_description = $query->title;
	$query->block_label = $query->title;
	$query->block_display_order = 1;

	$flavour = new \Flavour();
	$flavour->flavour_id = 0;
	$flavour->name = $this->translate('module/flavour');
	$flavour->description = $query->description;

	$query->flavour = $flavour;

	$i = 1;
	/* @var $q Query */
	foreach ($queries as $q) {
	    $q->block_display_order = $i++ * 10;
	    $q->flavour = $flavour;
	    $q->block_label = $q->title;
	    $q->block_description = $q->title;
	}

	$queries = array_merge(array($query), $queries);

	$this->queries[$flavour->flavour_id] = $queries;
	$this->flavours[] = $flavour;

	$pid = null;

	if (array_key_exists('id', $_GET)) {
	    /* @var $query Query */
	    foreach ($this->queries[$flavour->flavour_id] as $query) {
		//\MetaNull\Tools\mDump::dumpVariable($this->queries[$flavour->flavour_id]);
		if ($query->weblog_id == $_GET['id']) {
		    $pid = $query->query_id;
		    break;
		}
	    }
	}
	else if (array_key_exists('pid', $_GET)) {
	    $pid = $_GET['pid'];
	}

	if ($pid != null) {
	    $this->user->set_preference('news_wires/0/queries/flavours/0', $pid, $this->db);
	}
    }

    /**
     * Render the module's page (will be embedded in general layout)
     * @return string
     */
    public function getPageContent() {
	$template = new \MetaNull\Application\MTemplate( 'm' );
	$template->loadTemplate( $this->getTemplateFilePath( 'main.html' ));

	//\MetaNull\Tools\mDump::dumpVariable($this->flavours);

	$news = new NewsSection($this->config, $this->base_folder, 'news_tabs', $this->translationTable, $this->flavours, $this->queries, 'news_wires/0/', true);
	$this->addSection($news);

	$template->data = $this->translationTable;
	$template->data['content'] = $this->renderSections();

	$this->info_setStylesheet(
		array(
		$this->getThemeFileUrl( 'styles/jquery/tree/jquery.treeview.css' ),
		)
	);

	$this->info_setJavascript(
		array(
		'scripts/jquery.cookie.js',
		'scripts/jquery.treeview.min.js',
		'scripts/search.js',
		'scripts/briefcase.js',
		'scripts/riskmap.js',
		'scripts/news_section.js',
		'scripts/newswires.js',
		)
	);
	$this->info_setBodyOnLoad('initJQueryUI(1)');

	/*if (!array_key_exists('all_results', $_GET)){
	    $this->info_setBodyOnLoad('addMoreLink()');
	}*/

	$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
	$n = round($newsConfig['search']['default']['refresh-interval'] / 60, 1);
	$template->data['help_text'] = str_replace('[N]', $n, $this->translate('module/help_text'));

	$sharing = new Sharing($this->config, $this->translationTable);
	$template->data['sharing_form'] = $sharing->run();
	$this->setMoreInfos($sharing->getInfo());

	return $template->transform();
    }

}
}
?>