<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

require_once('tariqa3/modules/sharing/Sharing.class.php');
require_once('FullLexisNexis.class.php');
require_once('FullLatestNews.class.php');
require_once('FullLatestNewsIDOL.class.php');
require_once('FullVirage.class.php');
require_once('FullGoogleWeb.class.php');
require_once('FullFactiva.class.php');
require_once('FullOxfordAnalytica.class.php');
require_once('FullAggregators.class.php');
require_once('FullGoogleNews.class.php');
require_once('FullRSS_aggregatorIDOL.class.php');
require_once('FullGoogleBlogs.class.php');
require_once('FullGoogleImages.class.php');

/**
 * Search section
 * @author Cosmin Popescu, Pascal Havelange
 * @copyright © EUROPEAN COMMISSION, 2010
 * @package tariqa3
 * @license http://ec.europa.eu/idabc/eupl
 */
class Search extends tariqa3ModuleSectionManager {

    /**
     * The quick search type
     * @var int
	 
     */
    const QUICK_SEARCH = 0;

    /**
     * The advanced search type
     * @var int
	 
     */
    const ADVANCED_SEARCH = 1;

    /**
     * The full search type
     * @var int
	 
     */
    const FULL_SEARCH = 2;

    /**
     * The results type
     * @var int
	 
     */
    const RESULTS = 3;

    /**
     * The type of the search
     * @var int
     * @access private
     */
    private $type = 1;

    /**
     * Construct the Module object
     * @param array $config The multidimentionnal array containing the application's configuration
     */
    public function __construct( $config ) {
	parent::__construct($config);
    }

    /**
     * Renders the quick search page
     * @param mTemplate $tpl The template to render
     * @access private
     * @return string
     */
    private function quickSearch($tpl) {
    }

    /**
     * Gets the date restrictions
     * @param string $template_file The template file
     * @param string $radio_name The name of the radio checkbox
     * @param string $select_name The select name
     * @param string $from_name The from textbox name
     * @param string $to_name The to textbox name
     * @param array $translationTable The translation matrix
     * @access public
     * @static
     * @return string
     */
    public static function getDateRestrictions($template_file, $radio_name, $select_name, $from_name, $to_name, $translationTable) {
	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->data = $translationTable;
	//$this->getTemplateFilePath( 'date_restrictions.html' )
	$tpl->loadTemplate( $template_file );
	$tpl->data['radio_name'] = $radio_name;

	$type = 'range';
	if (array_key_exists($radio_name, $_POST)){
	    $type = $_POST[$radio_name];
	}

	$tpl->data['checked1'] = ($type == 'range'?'checked="checked"':'');
	$tpl->data['checked2'] = ($type == 'interval'?'checked="checked"':'');

	$tpl->data['select_name'] = $select_name;
	$range = 'null';
	if (array_key_exists($select_name, $_POST)){
	    $range = $_POST[$select_name];
	}
	$tpl->data['null_selected'] = ($range == 'null'?'selected="selected"':'');
	$tpl->data['week_selected'] = ($range == '7'?'selected="selected"':'');
	$tpl->data['month_selected'] = ($range == '30'?'selected="selected"':'');
	$tpl->data['month6_selected'] = ($range == '180'?'selected="selected"':'');
	$tpl->data['year_selected'] = ($range == '365'?'selected="selected"':'');
	$tpl->data['year2_selected'] = ($range == '730'?'selected="selected"':'');
	$tpl->data['year5_selected'] = ($range == '1825'?'selected="selected"':'');
	$tpl->data['year10_selected'] = ($range == '3650'?'selected="selected"':'');

	$urldecode = false;
	if (array_key_exists('urldecode', $_GET)){
	    $urldecode = true;
	}

	$tpl->data['from_name'] = $from_name;
	$tpl->data['to_name'] = $to_name;
	$tpl->data['default_start_date'] = (array_key_exists($from_name, $_POST)?($urldecode?\MetaNull\Tools\mTools::rawurldecode($_POST[$from_name]):$_POST[$from_name]):'');
	$tpl->data['default_end_date'] = (array_key_exists($to_name, $_POST)?($urldecode?\MetaNull\Tools\mTools::rawurldecode($_POST[$to_name]):$_POST[$to_name]):'');

	return $tpl->transform();
    }

    /**
     * Renders the advanced search page
     * @param mTemplate $tpl The template to render
     * @access private
     * @return string
     */
    private function advancedSearch($tpl) {
	//Get the quick search sources from the SOAP
	$sources = statics::ListQuickSearchSources($this->user->get_access_level());

	$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

	$tpl->data['search_url'] = statics::URL('index.php', 'module=' . $this->getName() . '&type=' . self::RESULTS . '&search_type=' . $this->type);
	$tpl->data['date_restrictions'] = self::getDateRestrictions($this->getTemplateFilePath( 'date_restrictions.html' ), 'date_type', 'range', 'start_date', 'end_date', $this->translationTable);
	$tpl->data['default_results_per_page'] = (array_key_exists('results_per_page', $_POST)?$_POST['results_per_page']:$newsConfig['search']['default']['results-per-page']);
	$tpl->data['default_query'] = array_key_exists('query', $_POST) ? \MetaNull\Tools\mTools::rawurldecode($_POST['query']) : '';
	$tpl->data['adv_url'] = statics::URL('index.php', 'module=search&type=2');

	$tpl->data['sources'] = array();
	for ($i = 0; $i < count($sources); $i++) {
	    $checked = (array_key_exists('source_' . $sources[$i]->source->source_id, $_POST)?($_POST['source_' . $sources[$i]->source->source_id] == 'on'?'checked="checked"':''):'');
	    if ($i % 2 == 0) {
		$row = array(
			'source_id1' => $sources[$i]->source->source_id,
			'source_name1' => $sources[$i]->display_title,
			'checked1' => $checked,
			'right_column' => false
		);
	    }
	    else {
		$row['right_column'] = true;
		$row = array_merge($row, array(
			'source_id2' => $sources[$i]->source->source_id,
			'source_name2' => $sources[$i]->display_title,
			'checked2' => $checked
		));
		$tpl->data['sources'][] = $row;
		$row = null;
	    }
	}

	if ($row != null) {
	    $tpl->data['sources'][] = $row;
	}

        $tpl->data['help_dialog'] = $this->initHelp('help_dialog', $this->translate('module/help_title'), $this->translate('module/help_text'));

	//\MetaNull\Tools\mDump::dumpVariable($tpl->data['sources']);

	return $tpl->transform();
    }

    /**
     * Renders the full search page
     * @param mTemplate $tpl The template to render
     * @access private
     * @return string
     */
    private function fullSearch($tpl) {
	//General settings

	$sources = statics::ListFullSearchSources($this->user->get_access_level());
	$sources[6]->id = "RSS_aggregatorIDOL";

	$selected = 0;
	if (array_key_exists('selected', $_POST)) $selected = $_POST['selected'];
	
	$this->info_setBodyOnLoad("initFullSearchUI({$selected})");

	$this->info_setJavascript('scripts/jquery.cookie.js');

	$newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

	$tpl->data['sources'] = array();

	$i = 0;

	/* @var $source FullSearchSource */
	foreach ($sources as $source) {
	    /*if (strpos($source->id, 'aggregator')) $class_name = 'tariqa3\\FullAggregators';
	    else */$class_name = 'tariqa3\\Full' . $source->id;

	    $section = new $class_name($this->config, $this->base_folder, $source->id, $this->translationTable, $this->getName(), $newsConfig, $i++);
	    $this->addSection($section);

	    $tpl->data['sources'][] = array(
		    'id' => $source->id,
		    'title' => $this->translate('module/' . $source->id . '_title'),
	    );
	}

	//General settings

	$tpl->data['forms_html'] = $this->renderSections();

	return $tpl->transform();
    }

    /**
     * Renders the search results page
     * @param mTemplate $tpl The template object
     * @param boolean $get_searches If true, then return the multiAjaxSearch objects
     * @access public
     * @return string
     */
    public function results($tpl, $get_searches = false) {
	//See what kind of full search is performed
	$search_type = self::QUICK_SEARCH;
	if (array_key_exists('search_type', $_GET)) $search_type = $_GET['search_type'];

	$urls = array();

	$tpl->data['img_path'] = $this->config['templates']['baseurl'] . '/' . $this->config['templates']['default'] . '/images';

	//Generate the form_get and form_post data - this will be displayed in the template in a hidden field and will be used to save the
	//search in the briefcase. Saving a search in the briefcase is simply saving all it's post and get values. When the user will
	//load the search from the briefcase, we will simply make a post request with the same post and get parameters.
	$get = '';
	foreach ($_GET as $key => $value){
	    $get .= ($get == ''?'':'&') . $key . '=' . \MetaNull\Tools\mTools::rawurlencode($value);
	}
	$tpl->data['form_get'] = $_SERVER['SCRIPT_URI'] . '?' . $get;// . $_SERVER['QUERY_STRING'];
	$tpl->data['form_post'] = '';
	foreach ($_POST as $key => $value) {
	    $tpl->data['form_post'] .= ($tpl->data['form_post'] == ''?'':'&') . $key . '=' . \MetaNull\Tools\mTools::rawurlencode($value);
	}

	$tariqa_service_url = $this->config['application']['service_url'];
	$this->info_setJavascript('scripts/jquery.treeview.min.js');
	$query = $_POST['query'];

	switch ($search_type) {
	    case self::ADVANCED_SEARCH:
	    case self::FULL_SEARCH:
		$type = 'range';
		$startDate = null;
		$endDate = null;
		if (array_key_exists($_POST['date_type_field_name'], $_POST)){
		    $type = $_POST[$_POST['date_type_field_name']];
		}
		if ($type == 'range'){
		    if ($_POST[$_POST['range_field_name']] != 'null'){
			$endDate = new \DateTime();
			$startDate = new \DateTime();
			$startDate->setTimestamp($endDate->getTimestamp() - $_POST[$_POST['range_field_name']] * 24 * 60 * 60);
		    }
		}
		else {
		    if ($_POST[$_POST['from_field_name']] != '') $startDate = new \DateTime($_POST[$_POST['from_field_name']]);
		    if ($_POST[$_POST['to_field_name']] != '') $endDate = new \DateTime($_POST[$_POST['to_field_name']]);
		}

		$tpl->data['search_terms'] = $query;
		$count = $_POST['results_per_page'];
		$from = 0;

		if ($search_type == self::ADVANCED_SEARCH) {
		    $sources = statics::ListQuickSearchSources($this->user->get_access_level());
		    $tpl->data['result_ids'] = array();
		    $searches = array();

		    foreach ($sources as $source) {
			//Check each source to see if it was checked by the user
			if (array_key_exists('source_' . $source->source->source_id, $_POST) && $_POST['source_' . $source->source->source_id] == 'on') {
			    //If yes, include it into a multi ajax search
			    $search = new multiAjaxSearch($query, $source->source->source_id, $tariqa_service_url,
				    'searchResult_' . $source->source->source_id, false, ($startDate == null?null:$startDate->getTimestamp() + $startDate->getOffset()),
				    ($endDate == null?null:$endDate->getTimestamp() + $endDate->getOffset()), 0, $count, multiAjaxSearch::UNIFIED_QUERY_SYNTAX);
			    $searches[] = $search;
			    $tpl->data['result_ids'][] = array('source_id' => $source->source->source_id);
			}
		    }
		}
		else {
		    //If it was a full search, then only one engine was selected. Just check which one and make a multi ajax search with only one engine
		    $newsConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');

		    $searches = array();

		    if ($_POST['engine'] != '' && $_POST['engine'] != null){
			require_once('tariqa3/search/' . $_POST['engine'] . 'Engine.class.php');
			$class_name = "tariqa3\\search\\" . $_POST['engine'] . 'Engine';

			/*@var $class searchEngine */
			$class = new $class_name($newsConfig);

			/*@var $search multiAjaxSearch */
			$search = $class->multiAjaxSearch($query, $from, $count, $startDate, $endDate);

			$tpl->data['result_ids'][] = array('source_id' => $search->getSourceId());
			$searches = array($search);
		    }
		}

		if ($get_searches) {
		    return $searches;
		}

		$this->performMultiAjaxSearch($searches, 'showLoading("block");', 'showLoading("none");');

		break;
	    case self::QUICK_SEARCH:
		break;
	}

	$sharing = new Sharing($this->config, $this->translationTable);
	$tpl->data['sharing_form'] = $sharing->run();
	$this->setMoreInfos($sharing->getInfo());

	return $tpl->transform();
    }

    /**
     * Init's the help
     * @param string $id The div identifier
     * @param string $title The dialog title
     * @param string $text The help text
     * @access public
     * @return string
     */
    public function initHelp($id, $title, $text) {
	$tpl = new \MetaNull\Application\MTemplate('m');
        $tpl->loadTemplate($this->getTemplateFilePath('help.html'));
        $tpl->data['id'] = $id;
        $tpl->data['title'] = $title;
        $tpl->data['text'] = $text;

        $this->info_setBodyOnLoad('initHelp(\'' . $id . '\')');

        return $tpl->transform();
    }

    /**
     * Render the module
     * @return string
     */
    public function getPageContent() {
	$tpl = new \MetaNull\Application\MTemplate( 'm' );
	$tpl->data = $this->translationTable;
	/*if (!$this->config['jquery']['use-it']){
			$tpl->loadTemplate( $this->getTemplateFilePath( 'error.html' ));

			return $tpl->transform();
		}*/

	$this->info_setJavascript(
		array(
		'scripts/search.js',
		)
	);

	switch ($this->type) {
	    case self::QUICK_SEARCH:
		$tpl->loadTemplate( $this->getTemplateFilePath( 'quick_search.html' ));
		return $this->quickSearch($tpl);
		break;
	    case self::ADVANCED_SEARCH:
		$this->info_setBodyOnLoad('initForm()');
		$tpl->loadTemplate( $this->getTemplateFilePath( 'advanced_search.html' ));
		return $this->advancedSearch($tpl);
		break;
	    case self::FULL_SEARCH:
		$tpl->loadTemplate( $this->getTemplateFilePath( 'full_search.html' ));
		return $this->fullSearch($tpl);
		break;
	    case self::RESULTS:
		$this->info_setBodyOnLoad('initTabs()');
		$tpl->loadTemplate( $this->getTemplateFilePath( 'results.html' ));
		return $this->results($tpl);
		break;
	}

	return null;
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	if (!array_key_exists('type', $_GET)) $this->type = self::ADVANCED_SEARCH;
	else $this->type = $_GET['type'];
	$this->info_setJavascript('scripts/briefcase.js');
    }

    /**
     * Process all requests (this is the default module)
     */
    public function canProcessRequest() {
	return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
    }

    /**
     * Returns the name of the class (what it should appear in the menu
     * @access public
     * @return string
     */
    public function getName() {
	return 'search';
    }

    /**
     * Returns the title of the page
     * @access public
     * @return string
     */
    public function getTitle() {
	return 'Tariqa 3 Search page';
    }

    /**
     * Returns the description of the page
     * @access public
     * @return string
     */
    public function getDescription() {
	return 'The search page (you can select from basic search, advanced search or full search)';
    }

    /**
     * Gets the link of the module
     * @access public
     * @return string
     */
    public function getLink() {
	return statics::URL('index.php', 'module=' . $this->getName());
    }

    /**
     * Return the items of the current breadcrumb path
     * @return tariqa3ModuleDescriptor[]
     */
    public function getBreadCrumb() {
	$breadCrumb = array();

	if (array_key_exists('breadCrumb', $_SESSION) && array_key_exists('query', $_POST)) {
	    if (strpos(strtolower($_SESSION['breadCrumb'][0]->label), 'briefcase') !== false) {
		$breadCrumb[] = $_SESSION['breadCrumb'][0];
	    }
	}

	if ($this->type == self::RESULTS) {
	    $b = new tariqa3ModuleDescriptor($this);
	    $post = '';
	    foreach ($_POST as $key => $value) {
		$post .= ($post == ''?'':'&') . $key . '=' . \MetaNull\Tools\mTools::rawurlencode($value);
	    }

	    $post = str_replace('"', "\\" . '"', $post);
	    $post = str_replace('%22', "\\%22", $post);

	    $b->link = 'javascript: js_open("' . statics::URL('index.php',
		    'module=search&type=' . $_GET['search_type']) . '", "_self", "post", "' . $post . '")';
	    $breadCrumb[] = $b;
	    $b = new tariqa3ModuleDescriptor();
	    $b->label = $this->translate('module/results');
	    $b->link = 'javascript: js_open("' . statics::URL('index.php',
		    'module=search&type=' . self::RESULTS . '&search_type=' . $_GET['search_type']) . '", "_self", "post", "' . $post . '")';
	    $breadCrumb[] = $b;
	}
	else {
	    $breadCrumb[] = new tariqa3ModuleDescriptor($this);
	}
	return $breadCrumb;
    }
}

}

?>