<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{


/**
 * Class used for displaying multiple Tariqa articles in the same page. 
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
class MultiPages extends SpecialPage {
    /**
     * The list of urls
     * @var array[][]
     * @access protected
     */
    protected $urls;
    /**
     * Constructs the object
     * @param string $page_id The page identifier
     * @param array $config The configuration array
     * @access public
     * @return void
     */
    public function __construct($page_id, $config) {
	$this->blacklisted_infos['onload'] = true;
	parent::__construct($page_id, $config);
    }

    /**
     * Renders the page (sets all the template data)
     * @access protected
     * @return void
     */
    protected function renderPage() {
	$this->setTemplate($this->getTemplateFilePath('multi_pages.html'));
	$this->template->data['pages'] = array();

	$this->info_setJavascript('scripts/multi_pages.js?rnd=10101010');
	$this->info_setJavascript('scripts/jquery.cookie.js');
	$this->info_setBodyOnLoad('initURLS()', true);

	foreach ($this->urls as $url){
	    $this->template->data['pages'][] = array(
		'url' => \MetaNull\Tools\mTools::rawurldecode($url->url),
		'name' => \MetaNull\Tools\mTools::rawurldecode($url->title),
		'id' => \MetaNull\Tools\mTools::rawurldecode($url->id)
	    );
	}

	//\MetaNull\Tools\mDump::dumpVariable($this->urls);
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	//statics::load_user_prefs($this->user, $this->db);
	$this->setDefaultLayout('empty_page.html');
	$_POST['obj'] = str_replace(array("\n", "\r"), '', $_POST['obj']);
	if (array_key_exists('obj', $_POST)){
	    $this->urls = json_decode($_POST['obj']);
	}
    }

}
}
?>
