<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{


/**
 * Base class to redirect a Tariqa page
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
class Redirect extends SpecialPage {
    /**
     * Constructs the object
     * @param string $page_id The page identifier
     * @param array $config The configuration array
     * @access public
     * @return void
     */
    public function __construct($page_id, $config) {
	$this->blacklisted_infos['onload'] = true;
	parent::__construct($page_id, $config);
    }

    /**
     * Fixes the URLs which are resulting from applying an XPATH query
     * @param DOMDocument $doc The HTML document
     * @param string $query The xpath query
     * @param string $baseURL The base url of the site
     * @access protected
     * @return void
     */
    protected function fixURLS($doc, $query, $baseURL) {
	$fixed_url = statics::URL(statics::completePath($this->config['url']) . 'special_page.php', 'module=redirect');
	$xp = new \DOMXPath($doc);
	$rs = $xp->query($query);
	for ($i = 0; $i < $rs->length; $i++){
	    $item = $rs->item($i);
	    $url = $item->nodeValue;
	    if (!$this->absolute($url)){
		$_base = $baseURL;
		if (substr($url, 0, 1) == '/'){
		    $_base = statics::baseURL($baseURL, true);
		    $url = substr($url, 1);
		}
		$url = $_base . $url;
	    }

	    $url = \MetaNull\Tools\mTools::rawurlencode($url);
	    $url = $fixed_url . '&amp;l=' . $url . '';
	    $item->nodeValue = $url;
	}
    }

    /**
     * If true, then the url is an absolute link, otherwise, is a relative link
     * @param string $url The url
     * @access protected
     * @return boolean
     */
    protected function absolute($url) {
	return preg_match('/^http:\/\//', $url);
    }

    /**
     * Renders the page (sets all the template data)
     * @access protected
     * @return void
     */
    protected function renderPage() {
	$urls = $this->own_config['url'];

	$location = $urls['default'];

	if (array_key_exists('u', $_GET)){
	    if (array_key_exists($_GET['u'], $urls)){
		$location = $urls[$_GET['u']];
	    }
	}
	else if (array_key_exists('l', $_GET)){
	    $location = $_GET['l'];
	}
	if (!array_key_exists('d', $_GET)){
	    header( "Location: " . $location );
	    die();
	}
	else {
	    $http_code = 200;
	    $proxy = 'http://' . $this->config['proxy']['user'] . ':' . $this->config['proxy']['password'] . '@' . $this->config['proxy']['host'] . ':' . $this->config['proxy']['port'];
	    $real_url = null;
	    $body = \MetaNull\Tools\mCurl::Get($location, $http_code, false, $proxy, false, false, $real_url);
	    if ($http_code == 200){
		if ($real_url != null){
		    $location = statics::baseURL($real_url);
		}
		else {
		    $location = statics::baseURL($location);
		}
		$tidy_opt = array(
			"indent" => true,
			"show-body-only" => false,
			"input-encoding" => "UTF-8",
			"output-encoding" => "UTF-8",
			"output-xhtml" => true,
			"word-2000" => true,
			"lower-literals" => true,
			"drop-font-tags" => true,
			"drop-proprietary-attributes" => true,
			"wrap" => 160,
			'preserve-entities' => true,
			"newline" => "LF",
		);

		$tidy = tidy_parse_string($body, $tidy_opt);
		tidy_clean_repair($tidy);

		$body = $tidy->value;
		$body = str_replace("&", "&amp;", $body);
		$doc = new \DOMDocument('1.0', 'UTF-8');
		$doc->loadHTML($body);
		$this->fixURLS($doc, '//@src', $location);
		$this->fixURLS($doc, '//@href', $location);

		echo htmlspecialchars_decode($doc->saveHTML());
		die();
	    }
	    else {
		throw new \Exception('The request returned a ' . $http_code . ' error code');
	    }
	}
    }

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    public function onInitialize() {
	parent::onInitialize();
	//statics::load_user_prefs($this->user, $this->db);
	$this->setDefaultLayout('empty_page.html');
    }

}
}
?>