<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{

    require_once('tariqa3/auth/TariqaAuthentication.class.php');

    /**
     * Base class for providing the web office functionality. 
     * @package tariqa3
     * @author Pascal Havelange, Cosmin Popescu
     * @copyright © EUROPEAN COMMISSION, 2009-2010
     * @license http://ec.europa.eu/idabc/eupl
     */
    class WebOffice extends SpecialPage {
        /**
         * The weboffice menu
         * @var array
         * @access protected
         */
        
        protected $menu = array();

        /**
         * The current section to edit
         * @var string
         * @access protected
         */
        
        protected $section;

        /**
         * The section title
         * @var string
         * @access protected
         */
        
        protected $title;

        /**
         * The weboffice database connection
         * @var resource
         * @access protected
         */
        
        protected $own_db;
        /**
         * Constructs the object
         * @param string $page_id The page identifier
         * @param array $config The configuration array
         * @access public
         * @return void
         */
        public function __construct($page_id, $config) {
            $auth = new TariqaAuthentication($config);
            parent::__construct($page_id, $config, $auth);
        }

        /**
         * Initializes the module
         * @access public
         * @return void
         */
        public function onInitialize() {
            parent::onInitialize();
            $this->own_db = statics::open_db_connection($this->own_config['database']['tariqapro']);
            if (!$this->user->isMemberOf('TARIQA_ADMIN', false)){
                throw new \MetaNull\Authentication\authenticationException('You are not allowed to admin Tariqa');
            }

            foreach ($this->own_config['modules'] as $key => $value){
                $this->section = $key;
                break;
            }

            if (array_key_exists('s', $_GET)){
                $this->section = $_GET['s'];
            }

            foreach ($this->own_config['modules'] as $key => $value){
                $this->menu[] = array('id' => $key, 'label' => $value, 'checked' => ($this->section == $key ? 'checked="checked"' : ''));
                if ($this->section == $key){
                    $this->title = $value;
                }
            }
        }

        /**
         * Renders the page (sets all the template data)
         * @access protected
         * @return void
         */
        protected function renderPage(){
            if (array_key_exists('dojo', $_GET)){
                require_once('tariqa3/modules/special_pages/weboffice/dojo_connector.class.php');
                $dojo = new dojo_connector($this->own_db, 'misc/dojo-json/' . $_GET['t'] . '.json');
                switch ($_GET['a']){
                case 'select':
                    echo json_encode($dojo->select());
                    break;
                case 'update':
                    echo json_encode($dojo->update());
                    break;
                case 'insert':
                    echo json_encode($dojo->insert());
                    break;
                case 'delete':
                    echo json_encode($dojo->delete());
                    break;
                }

                die();
            }
            $this->setTemplate($this->getTemplateFilePath('weboffice.html'));
            $this->template->data['menu'] = $this->menu;
            $this->info_setJavascript('scripts/weboffice.js');
            $this->info_setJavascript('scripts/dojo/dojo/dojo.js');
            $this->info_setInlineJavascript('dojoConfig = {isDebug: false, parseOnLoad: true}');
            $this->info_setBodyOnLoad('initInterface()');

            require_once('tariqa3/modules/special_pages/weboffice/WebOfficeModule.class.php');
            if (file_exists('tariqa3/modules/special_pages/weboffice/' . $this->section . '.class.php')){
                require_once('tariqa3/modules/special_pages/weboffice/' . $this->section . '.class.php');
                $name = "tariqa3\\" . $this->section;
                $module = new $name($this);
                $this->template->data['title'] = $module->getTitle();
                $this->template->data['body'] = $module->doExecute();
            }
            else {
                $this->template->data['title'] = $this->title;
                $this->template->data['body'] = '<div class="ui-state-highlight">' . $this->section . ' module has not been implemented yet</div>';
            }
            $this->info_setInlineJavascript('CURRENT = "'  . $this->section . '";');
        }

        /**
         * Checks that the caller (which wants to access a private method) is a friend class
         * @param boolean $call If true, it is a function call. If not, it is a property check
         * @access private
         * @return boolean
         */
        private function friend($call = false){
            $trace = debug_backtrace();

            $idx = ($call ? 3 : 2);

            if (isset($trace[$idx]['class'])){
                $class = $trace[$idx]['class'];
                if ($class == "tariqa3\\WebOfficeModule" || $class == "tariqa3\\" . $this->section){
                    return true;
                }
            }

            return false;
        }

        /**
         * Magic php function
         * @param string $key The key to retrieve
         * @access public
         * @return mixed
         */
        public function __get($key){
            if ($this->friend()){
                return $this->$key;
            }

            throw new \Exception('You tried to access a private property of WebOffice class [' . $key . ']');
        }

        /**
         * Magic PHP function
         * @param string $key The key to set
         * @param mixed $value The value to set;
         * @access public
         * @return void
         */
        public function __set($key, $value){
            if ($this->friend()){
                $this->$key = $value;
            }
            else {
                ob_start();
                var_dump($value);
                $v = ob_get_contents();
                ob_end_clean();
                throw new \Exception('You tried to set a private property of WebOffice class [' . $key . '] = [' . $v . ']');
            }
        }

        /**
         * Magic PHP function
         * @param string $name The name of the method to be called
         * @param array $arguments The arguments of the method to be called
         * @access public
         * @return mixed
         */
        public function __call($name, $arguments){
            if (!$this->friend(true)){
                throw new \Exception('You tried to access a private method of WebOffice class [' . $name . ']');
            }

            return call_user_func_array(array($this, $name), $arguments);
        }

        /**
         * Gets the applications headers set by the module
         * @access public
         * @return array
         */
        public function getHeaders() {
            if (!array_key_exists('dojo', $_GET))
                return array("Content-type: text/html; charset=utf-8");
            else {
                return array("Content-type: text/plain; charset=utf-8");
            }
        }

    }
}
?>
