<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3 {

	/**
	 * Extend this class to create a new section inside the weboffice
	 * @author Cosmin popescu
 	 * @copyright © EUROPEAN COMMISSION, 2008
 	 * @package tariqa3
	 * @license http://ec.europa.eu/idabc/eupl
	 */
	abstract class WebOfficeModule {
        /**
         * The weboffice class
         * @var WebOffice
         * @access protected
         */
        
        protected $weboffice;
        /**
         * The constructor
         * @param WebOffice $weboffice The weboffice class
         * @access public
         * @return void
         */
        public function __construct($weboffice){
            $this->weboffice = $weboffice;
        }
        
		/**
         * Function which do the initializing. You can overwrite this function to do your initializing
         * @param WebOffice $weboffice The weboffice class
         * @access public
         * @return void
         */
        public function onInitialize(){}

        /**
         * The actual execution (it return the HTML code of the module)
         * @access public
         * @return string
         */
        abstract public function onExecute();

        /**
         * If needed, a function that is called before the module is discarted. You can overwrite this function to do your de-initializing. 
         * @access public
         * @return void
         */
        public function onDestroy(){}

        /**
         * Gets the module title
         * @access public
         * @return string
         */
        final public function getTitle(){
            return $this->weboffice->title;
        }

        /**
         * Internal function which triggers the execution of the module
         * @access public
         * @return string
         */
        final public function doExecute($param_name){
            $success = true;
            $exception = null;
            $output = '';
            try{
                $this->onInitialize();
                $output = $this->onExecute();
            }
            catch (\Exception $e){
                $success = false;
                $exception = $e;
            }
            $this->onDestroy();

            if (!$success){
                throw $exception;
            }

            return $output;
        }
	}
}
?>