<?php
/*
 * Class representing a briefcase folder
 */

namespace tariqa3{
class ThemesTree extends TreeFolder {
	/**
	 * The list of themes
	 * @var Theme[]
	 * @access private
	 */
	private $themes;

	/**
	 * The name of the root node
	 * For now, it will be List of themes. Maybe later will want to categorize the themes. In this case, will have to modify the
	 * getSubFolders function
	 * @var string
	 * @access private
	 */
	private $root_name;

	/**
	 * The default template file
	 * @var string
	 * @access private
	 */
	private $tfile = 'tree_folder.html';

	/**
	 * Constructs the object
	 * @param string $root_name The name of the root node
	 * @param string $template_file The template file [OPTIONAL]
	 * @access public
	 * @return void
	 */
	public function __construct($root_name, $template_file = null) {
		if ($template_file != null) $this->tfile = $template_file;
		$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE);
		$templates_folder = "{$config['templates']['base']}/{$config['templates']['default']}";
		parent::__construct($templates_folder . '/' . $this->tfile, false);

		$this->themes = statics::listThemes();
		$this->root_name = $root_name;
	}

	/**
	 * Returns the subfolders of the current folder as an associative array with all the subfolders
	 * @param int $continent_id The continent identifier
	 * @access public
	 * @return array|boolean
	 */
	public function getSubFolders($folder_id){
		if ($folder_id != null) return array();
		return array(
			array(
				'folder_id' => 'themes_list_id',
				'name' => $this->root_name,
                                'type' => 'folder',
			)
		);
	}

	/**
	 * Returns the files of the current folder as an associative array
	 * @param int $folder_id The folder identifier
	 * @access public
	 * @return array|boolean
	 */
	public function getFiles($folder_id){
		if ($folder_id == null) return array();
		$result = array();

		/* @var $theme Theme */
		foreach ($this->themes as $theme){
			$open_link = 'js_open("' . statics::URL('index.php', 'module=themes&theme_id=' . $theme->theme_id) . '", "_self", "get")';
			$result[] = array(
				'file_id' => $theme->theme_id,
				'name' => $theme->title,
				'open_link' => $open_link,
                                'type' => 'theme',
			);
		}
		
		return $result;
	}
}
}

?>
