<?php
/*
 * Â© EUROPEAN COMMISSION, 2007-2010
 *
 * ConcÃ©dÃ©e sous licence EUPL, version 1.1 uniquement (la Â«LicenceÂ»).
 * Vous ne pouvez utiliser la prÃ©sente oeuvre que conformÃ©ment Ã  la Licence.
 * Vous pouvez obtenir une copie de la Licence Ã  lâadresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation lÃ©gale ou contractuelle Ã©crite, le logiciel distribuÃ© sous la Licence est distribuÃ© Â«en lâÃ©tatÂ»,
 * SANS GARANTIES OU CONDITIONS QUELLES QUâELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spÃ©cifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

namespace tariqa3{

    /**
     * Class for rendering a multi ajax timeout error
     * @author Cosmin Popescu, Pascal Havelange
     * @copyright Â© EUROPEAN COMMISSION, 2010
     * @package tariqa3
     * @license http://ec.europa.eu/idabc/eupl
     */
    class Timeouts extends tariqa3Module {

        /**
         * The error message
         * @var string
         * @access protected
         */
        
        protected $errorMessage;

        /**
         * Construct the Module object
         * @param array $config The multidimentionnal array containing the application's configuration
         */
        public function __construct( $config ) {
            parent::__construct( $config );
            $this->_isMenuable = false;
        }

        /**
         * Process all requests (this is the default module)
         */
        public function canProcessRequest() {
            return array_key_exists('module', $_GET) && $_GET['module'] == $this->getName();
        }

        /**
         * Returns the short name of the module (used by menus)
         * @return string
         */
        public function getName() {
            return 'timeout_error';
        }
        /**
         * Returns the title of the module (used in html/head/title)
         * @return string
         */
        public function getTitle() {
            return 'Tarîqa 3.0 - Multi ajax timeout error';
        }
        /**
         * Returns the description of the module (used in html/head/description)
         * @return string
         */
        public function getDescription() {
            return 'Checks and explains a multiajax error';
        }

        /**
         * Initializes the module
         * @access public
         * @return void
         */
        public function onInitialize() {
            parent::onInitialize();
            $ids = explode(', ', $_GET['ids']);
            $cond = '';
            foreach ($ids as $id){
                $cond .= ($cond == '' ? '' : ' or ') . ' call_id = ' . $this->db->real_escape_string($id);
            }
            $sql = "select url_id, call_id, http_code, duration from ajax_call_urls where " . $cond;

            $tpl = new \MetaNull\Application\MTemplate('m');
            $tpl->loadTemplate($this->getTemplateFilePath('message.html'));

            $tpl->data['list'] = array();

            $query = $this->db->query($sql);
            while ($row = $query->fetch_assoc()){
                $text = 'The call with the ID ' . $row['call_id'] . '-' . $row['url_id'] . ' ';
                if ($row['http_code'] == "200"){
                    $text .= 'finished succesfully. It took ' . $row['duration'] .
                        ' therefor making Tariqa return a timeout error and not wait for it to finish. ';
                }
                else if ($row['http_code'] == null){
                    $text = 'did not finish yet. You can refresh the page in a little while and see the code with which will finish. If it finished with an error code, please report it to the Tariqa team.';
                }
                else {
                    $text .= 'finished with the error code ' . $row['http_code'] . '. Please report it to the Tariqa team.';
                }

                $tpl->data['list'][] = array('text' => $text);
            }

            $this->errorMessage = $tpl->transform();
        }

        /**
         * Render the module's page (will be embedded in general layout)
         * @return string
         */
        public function getPageContent() {
            return $this->errorMessage;
        }

        /**
         * Return the items of the current breadcrumb path
         * @return tariqa3ModuleDescriptor[]
         */
        public function getBreadCrumb() {
            $breadCrumb = array();
            $breadCrumb[] = new tariqa3ModuleDescriptor($this);
            return $breadCrumb;
        }

        /**
         * Returns the url to the current module (used in menus)
         * @return string
         */
        public function getLink() {
            return statics::URL( 'index.php', array( 'module'=>$this->getName() ), true );
        }

    }
}
?>