<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
 */

/**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */
namespace tariqa3{
	/**
	 * Helper class to generate javascript multiAjaxURL object (see multi_ajax.js)
	 */
	class multiAjaxURL{
		/**
		 * The multi ajax URL
		 * @var string
		 * @access private
		 */
		private $url;

		/**
		 * The method
		 * @var string
		 * @access private
		 */
		private $method;

		/**
		 * If set to true, use proxt
		 * @var boolean
		 * @access private
		 */
		private $use_proxy;

		/**
		 * The name of the javascript object
		 * @var string
		 * @access private
		 */
		private $js_name;

		/**
		 * Constructs the object
		 * @param string $url The url of the call
		 * @param string $method The method (post or get)
		 * @param boolean $use_proxy If true, use proxy
		 * @param string $js_name The name of the javascript object [OPTIONAL]
		 * @access public
		 * @return void
		 */
		public function __construct($url, $method, $use_proxy, $js_name = 'generic_call') {
			$this->js_name = $js_name;
			$this->url = $url;
			$this->method = $method;
			$this->use_proxy = $use_proxy;
		}

		/**
		 * Gets the javascript name
		 * @access public
		 * @return string
		 */
		public function getName() {
			return $this->js_name;
		}

		/**
		 * Generates the javascript code
		 * @access public
		 * @return string
		 */
		public function generate_js() {
			$use_proxy = ($this->use_proxy?'true':'false');
			$result = <<<js
{$this->js_name} = new multiAjaxURL('{$this->url}');
{$this->js_name}.set_use_proxy({$use_proxy});
{$this->js_name}.set_method('{$this->method}');

js;

			return $result;
		}


	}
}
?>
