<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the RSS_aggregator or LatestNews_aggregator engine
 * @author Cosmin Popescu
 *
 */
class AggregatorsEngine extends searchEngine {

    /**
     * The short article form constant
     * @var string
     */
    const ARTICLE_SHORT = 'short';

    /**
     * The long article form constant
     * @var string
     */
    const ARTICLE_LONG = 'long';

    /**
     * Function used for sorting the articles by date
     * @param RSS_article $a1 The first article
     * @param RSS_article $a2 The second article
     * @static
     * @access public
     * @return boolean
     */
    public static function sortArticles($a1, $a2) {
	if ($a1->date == 0) return 1;
	if ($a2->date == 0) return -1;
	return ($a1->date < $a2->date?1:-1);
    }

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$qstr = null;
	$data = \tariqa3\statics::post2array(\rawurldecode($query->specific_data));
	if (is_numeric(trim($query->query))) {
	    $feed_id = trim($query->query);
	    if (array_key_exists('query', $data)) $qstr = rawurldecode($data['query']);
	}
	else {
	    $d = \tariqa3\statics::post2array($query->query);
	    if (array_key_exists('feed_id', $d) && array_key_exists('query', $d) && count($d) == 2) {
		$qstr = $d['query'];
		$feed_id = $d['feed_id'];
	    }
	    else {
		$qstr = $query->query;
		if (array_key_exists('feed_id', $data)) $feed_id = rawurldecode($data['feed_id']);
		else {
		    throw new \Exception("Feed id not defined");
		}
	    }
	}

	$first = null;
	$count = $this->newsConfig['default']['results-per-page'];

	if ($query->first !== null) $first = $query->first - 1;
	if ($query->count !== null) $count = $query->count;

	$start_date = null;
	$end_date = null;

	if ($query->start_date != null) {
	    $start_date = $this->date2range($query->start_date);
	}
	if ($query->end_date != null) {
	    $end_date = $start_date - $this->date2range($query->end_date);
	}

	$qstr = trim($qstr);
	if ($qstr == '') {
	    $qstr = null;
	}

	if ($query->engine_id == 'RSS_aggregator' || $query->engine_id == 'RSS_live_aggregated') {
	    $results = \tariqa3\statics::$tariqaClient->ListAggregatedRSSArticles(
		    \tariqa3\statics::$tariqaToken, $feed_id, $start_date, $first, $count, $end_date, $qstr
	    );
	    $articles_number = \tariqa3\statics::$tariqaClient->GetAggregatedRSSArticlesNumber(
		    \tariqa3\statics::$tariqaToken, $feed_id, $start_date, $end_date, $qstr
	    );

	}
	else {
	    $results = \tariqa3\statics::$tariqaClient->ListAggregatedLatestnewsArticles(
		    \tariqa3\statics::$tariqaToken, $feed_id, $start_date, $first, $count, $end_date, $qstr
	    );
	    $articles_number = \tariqa3\statics::$tariqaClient->GetAggregatedLatestnewsArticlesNumber(
		    \tariqa3\statics::$tariqaToken, $feed_id, $start_date, $end_date, $qstr
	    );
	}


	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->engine = $engine->engine_id;
	$result->source = $query->source_id;
	$result->from = $query->first;

	$feed = \tariqa3\statics::getAggregatedFeed($feed_id);

	if ($query->engine_id == 'RSS_live_aggregated' && $qstr == null){
	    $feed_articles = \tariqa3\statics::$tariqaClient->fetchRSS(\tariqa3\statics::$tariqaToken, $feed->url, $query->first, null);

	    /* @var $feed_article Article */
	    /* @var $article RSS_article */
	    $extra_articles = array();
	    foreach ($feed_articles->articles as $feed_article){
		$new = true;
		foreach ($results as $article){
		    $d = new \DateTime();
		    $d->setTimestamp($article->date);

		    if (strtotime($feed_article->date) < $d->getTimestamp() + $d->getOffset()){
			$new = false;
			break;
		    }

		    if ($feed_article->url == $article->link){
			$new = false;
			break;
		    }
		}

		if ($new){
		    $article = new \RSS_article();
		    $article->article_id = null;
		    $article->author = null;
		    $article->comments = null;
		    $article->date = strtotime($feed_article->date);
		    $article->description = $feed_article->body;
		    $article->feed_id = $feed->feed_id;
		    $article->headline = $feed_article->body;
		    $article->link = $feed_article->url;
		    $article->title = $feed_article->title;

		    $extra_articles[] = $article;

		    $articles_number++;

		    unset($results[count($results) - 1]);
		}
	    }

	    usort($extra_articles, array($this, 'sortArticles'));

	    //\MetaNull\Tools\mDump::dumpVariable($extra_articles);

	    $results = array_merge($extra_articles, $results);
	}

	if ($feed->picture == null) {
	    $result->logo = $engine->logo_url;
	}
	else {
	    $result->logo = $feed->picture;
	}

	$result->provider_url = ($feed->link != null?$feed->link:$feed->url);

	if (array_key_exists('source_name', $data)) {
	    $result->source_name = $data['source_name'];
	}

	$result->count = $articles_number;
	$result->results_per_page = $query->count !== null?$query->count:count($results);

	$source = \tariqa3\statics::getSource($query->source_id);
	$result->disclaimer = $source->disclaimer;

	$result->documents = array();

	/* @var $article RSS_article */
	foreach ($results as $article) {
	    $document = new tariqaDocument();

	    $document->title = $article->title;
	    if ($article->article_id != null){
		$document->id = $query->engine_id . ':' .
			$query->source_id. ':'  .
			urlencode($article->article_id);
		$document->url = $this->link($query->engine_id . '::' . urlencode($article->article_id));
		$document->js_link = $this->js_link($query->engine_id . '::' . urlencode($article->article_id), $article->title);

		$d = new \DateTime();
		$d->setTimestamp($article->date);

		$document->date = $d->getTimestamp() + $d->getOffset();
	    }
	    else {
		$document->id = $query->engine_id . ':' . $query->source_id. ':'  . urlencode($article->link);
		$document->url = $this->link('RSS::' . urlencode($article->link));
		$document->js_link = $this->js_link('RSS::' . urlencode($article->link), $article->title);
		$document->date = $article->date;
	    }

	    //\MetaNull\Tools\mDump::dumpVariable($document->date);

	    $document->summary = ($query->engine_id == 'RSS_aggregator' || $query->engine_id == 'RSS_live_aggregated'?$article->description:($query->engine_id == 'LatestNews_aggregator' ? $article->summary : ''));
	    $document->publisher = ($query->engine_id == 'RSS_aggregator' || $query->engine_id == 'RSS_live_aggregated'?$article->author:$query->engine_id == 'LatestNews_aggregator' ? $article->agency : '');

	    $result->documents[] = $document;
	}

	return $result;
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$article_form = $_SESSION['article_' . md5($article_id)];
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	if ($parts[0] == 'RSS_aggregator') $type = 0;
	else if ($parts[0] == 'LatestNews_aggregator') $type = 1;

	if ($type == 0) {
	    $document = \tariqa3\statics::$tariqaClient->GetAggregatedRSSArticle(\tariqa3\statics::$tariqaToken, $parts[2]);
	}
	else if ($type == 1) {
	    $document = \tariqa3\statics::$tariqaClient->GetAggregatedLatestnewsArticle(\tariqa3\statics::$tariqaToken, $parts[2]);
	}

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];

	$result->document_id = $document->article_id;
	$result->title = $document->title;

	$result->date = $document->date;
	$result->publisher = ($type == 0?$document->link:(($type == 1?$document->agency:null)));

	if ($type == 0) {
	    if ($article_form == self::ARTICLE_LONG){
		$engine = new RSSEngine($this->newsConfig);
		$doc = $engine->getArticle('RSS::' . \MetaNull\Tools\mTools::rawurlencode($document->link));
		$content = $doc->body;
		$result->engine = 'RSS';
		$result->source = '';
		$result->id = 'RSS::' . $document->link;
		$result->document_id = $document->link;
		$result->publisher = '';
		$result->html_headers = $doc->html_headers;
	    }
	    else {
		$content = ($type == 0?$document->description:(($type == 1?$document->content:null)));
		$config = \MetaNull\Tools\mConfig::loadConfiguration(
			APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config'
		);
		$template = $config['templates']['baseurl'] . '/' .
			$config['templates']['default'] .
			'/modules/tariqa3/Article/read_more.html';
		$tpl = new \MetaNull\Application\MTemplate('m');
		$tpl->loadTemplate($template);
		$tpl->data['id'] = $result->document_id;
		if ($_SESSION['article_form'] == self::ARTICLE_LONG && $article_form == self::ARTICLE_SHORT){
		    $tpl->data['url'] = \tariqa3\statics::URL('index.php', 'module=article&type=new&id=' . $article_id);
		}
		else {
		    $tpl->data['url'] = \tariqa3\statics::URL('index.php', 'module=article&type=new&id=RSS::' . \MetaNull\Tools\mTools::rawurlencode($document->link));
		}
		$content .= $tpl->transform();
	    }
	}
	else {
	    $body = $document->content;
	    if (\tariqa3\statics::_isIE()){
		$content = '<pre style="word-wrap: break-word; font-family: Verdana, Arial">' . $body . "</pre>";
	    }
	    else {
		$content = '<span style="white-space: pre-wrap;">' . $body . "</span>";
	    }
	}

	$result->body = $content;

	return $result;
    }

    /**
     * Gets the multi ajax search object for any page but the search page. For example country pages, home page, news wires page etc.
     * @param Flavour $flavour The flavour
     * @param array $filtering The filtering data
     * @param Query $flavour_query The flavour current query
     * @access public
     * @return multiAjaxSearch
     */
    public function newsSection($flavour, $filtering, $flavour_query) {
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$search = new \tariqa3\multiAjaxSearch($filtering['query'], $flavour_query->source_id, $app_config['application']['service_url'],
	    'search_' . $flavour->flavour_id, true, $filtering['start_date'], $filtering['end_date'], 0, $this->newsConfig['search']['default']['results-per-page'],
	    \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition($flavour_query->query);
	$specific_data = "source_name=" . $flavour_query->title;
	if (array_key_exists('string', $c)) {
	    $specific_data .= '&feed_id=' . $c['query'];
	    //$search->setSpecificData(rawurlencode('feed_id=' . $c['query']));
	} else {
	    //$search->setSpecificData(rawurlencode('feed_id=' . $flavour_query->query));
	    $specific_data .= '&feed_id=' . $flavour_query->query;
	}

	$search->setSpecificData(rawurlencode($specific_data));

	$search->noNewTab();
	$search->setNavigationId('navigation_' . $flavour->flavour_id);
	$search->setResultId('news_' . $flavour->flavour_id);

	return $search;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$defaults = $this->newsConfig['default'];
	$search = new \tariqa3\multiAjaxSearch($query, $defaults[$_POST['engine']]['source_id'], $app_config['application']['service_url'],
	    'searchResult', false, ($startDate == null?null:$startDate->getTimestamp() + $startDate->getOffset()),
	    ($endDate == null?null:$endDate->getTimestamp() + $endDate->getOffset()), $from, $count, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);
	$specific_data = 'feed_id=' . $_POST['selected_feed_' . $_POST['engine']];
	$search->setSpecificData($specific_data);

	return $search;
    }

    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()){
	$c = null;
	if ($start_date == null || $end_date == null){
	    $c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
	}

	error_log(\MetaNull\Tools\mDump::dumpVariable($additional_parameters, true));
	
	if ($additional_parameters[0] == null) {
	    $feed_id = $query_txt;
	    $query_txt = '';
	}
	else {
	    $feed_id = $query->query;
	}

	if ($query->source->engine_id == 'LatestNews_aggregator') {
	    $feed = \tariqa3\statics::$tariqaClient->GetAggregatedLatestnewsFeed(\tariqa3\statics::$tariqaToken, $feed_id);
	}
	else if ($query->source->engine_id == 'RSS_aggregator') {
	    $feed = \tariqa3\statics::$tariqaClient->GetAggregatedRSSFeed(\tariqa3\statics::$tariqaToken, $feed_id);
	}

	$selected = ($query->source->engine_id == 'RSS_aggregator'?6:($query->source->engine_id == 'LatestNews_aggregator'?7:-1));

	$range = '';
	$range_days = '';
	if ($start_date != null) $range = floor((time() - $start_date) / (60 * 60 * 24));
	if ($end_date != null) $range_days = $range - floor((time() - $end_date) / (60 * 60 * 24));

	if ($start_date != null || $end_date != null) {
	    $range = "&agg_range={$range}&range_days={$range_days}";
	}
	else {
	    $range = "&agg_range=null&range_days=null";
	}

	$post_data = "selected={$selected}&engine={$query->source->engine_id}&query={$query_txt}{$range}" .
		"&agg_date_type=range&agg_start_date=&agg_end_date&from_field_name=agg_start_date" .
		"&to_field_name=agg_end_date&range_field_name=agg_range&date_type_field_name=agg_date_type" .
		"&results_per_page={$newsConfig['search']['default']['results-per-page']}&selected_feed_{$query->source->engine_id}={$feed_id}" .
		"&feed_{$query->source->engine_id}={$feed->title}";

	return $post_data;
    }

}
}
?>