<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search {

/**
 * Base class for fetching the news results from the LatestnewsIDOL engine
 * @author Cosmin Popescu
 *
 */
class LatestNewsIDOLEngine extends searchEngine {

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Sets the highlight
     * @param string $text The text to highlight
     * @access public
     * @static
     * @return string
     */
    public static function highlight($text) {
	$text = preg_replace('/<font[^>]*>/', '<strong>', $text);
	$text = preg_replace('/<\/font[^>]*>/', '</strong>', $text);

	return $text;
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$q = new \LatestNewsQuery();
	$q->from = $query->start_date;
	$q->to = $query->end_date;

	if ($query->count == null) {
	    $query->count = $this->newsConfig['default']['results-per-page'];
	}
	$q->count = $query->count;
	$q->start = $query->first;
	$min_score = $this->newsConfig['default']['latestnews']['min-confidence'];
	$max_score = 100;
	$no_sport = true;

    $country_id = null;

	if ($query->specific_data != null){
	    $data = \tariqa3\statics::post2array($query->specific_data);
	    foreach ($data as $key => $value){
		if ($key == 'languages'){
		    $q->language = $value;
		}
		else if ($key == 'MinScore'){
		    $min_score = (int) $value;
		}
		else if ($key == 'MaxScore'){
		    $max_score = (int) $value;
		}
		else if ($key == 'sort_by'){
		    $q->sort = $value;
		}
		else if ($key == 'no_sport'){
		    if ($value == 'false'){
			$no_sport = false;
		    }
		}
		else if ($key == 'spell_check'){
		    if ($value == 'true'){
			$q->spell_check = true;
		    }
		}
        else if ($key == 'country_id'){
            $country_id = $value;
        }
	    }
	}
	
	$q->query = $query->query;
	if ($no_sport){
	    $q->query = '(' . $q->query . ') <AND> <NOT> (' . $this->newsConfig['default']['latestnewsidol']['sport-query' . ($query->source_id == 17?'-hotspots':'')] . ')';
	}

    if ($query->source_id == 17){
        $min_score = 0;
    }

	$q->min_confidence = $min_score;
	$q->max_confidence = $max_score;

	//$qstr = $query->query;
	/*$extra_options = null;
	$pattern = '/AND \(([^<]*)<in> summary\)/i';
	\MetaNull\Tools\mDump::dumpVariable($qstr);
	if (preg_match($pattern, $qstr)){
	    preg_match_all($pattern, $qstr, $matches);
	    $qstr = preg_replace($pattern, '', $qstr);
	}
	\MetaNull\Tools\mDump::dumpVariable($matches);*/
	//$q->query = $qstr;

	//\MetaNull\Tools\mDump::dumpVariable($min_score);

	/* @var $results LatestNewsResultSetIDOL */

	$results = \tariqa3\statics::$tariqaClient->latestNewsSearchIDOL(\tariqa3\statics::$tariqaToken, $q, $query->source_id == 17 ? 'Predict=False' : '');

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->engine = $query->engine_id;
	$result->source = $query->source_id;
	$result->from = $query->first;

	$result->logo = $engine->logo_url;
	$result->provider_url = $engine->doc_url;
	$result->count = $results->docs;
	$result->results_per_page = $query->count !== null ? $query->count : $results->count;
	$result->spell_check = null;
	if ($results->spell_check != null){
	    $translations = \tariqa3\statics::getTranslations('search');
	    $_q = $translations['module/spell_check'];
	    $_q = str_replace('#ORIGINAL_QUERY#', $result->query, $_q);
	    $new_query = $results->spell_check;
	    $new_query = str_replace(array("\r", "\n"), '', $new_query);
	    $_q = str_replace('#NEW_QUERY#', $new_query, $_q);
	    $tpl = new \MetaNull\Application\MTemplate('m');
	    $path = TARIQA3_REL_PATH;
	    if (substr($path, -1) != '/'){
		$path .= '/';
	    }
	    $tpl->loadTemplate($path . 'themes/default/modules/tariqa3/Search/spell_check.html');
	    $tpl->data['text'] = $_q;
	    $result->spell_check = $tpl->transform();
	}

	$data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));

	if (array_key_exists('source_name', $data)) {
	    $result->source_name = $data['source_name'];
	}

	$result->documents = array();

	/* @var $article LatestNewsDocument */
	foreach ($results->documents as $article) {
	    $document = new tariqaDocument();
	    $text = preg_replace('/<p[^>]*>/', '', $article->text);
	    $text = preg_replace('/<\/p>/', ' ', $text);

	    $document->title = $article->headline;
	    $document->id = $query->engine_id . ':' . $query->source_id . ':' . urlencode($article->id);
	    $document->url = $this->link('LatestNewsIDOL::' . urlencode($article->id . '_' . $article->highlights));
	    $document->js_link = $this->js_link('LatestNewsIDOL::' . urlencode($article->id . '_' . $article->highlights), $article->headline);

	    $document->date = $article->date;

	    $document->summary = self::highlight($article->summary);

	    preg_match_all('/(\w+[\s,\t\n\r\-"\'\.]+){0,6}<font color=red>([^>]*)<\/font>[\s,\t\n\r\-"\'\.]+(\w+[\s,\t\n\r\-"\'\.]+){0,6}/i', $text, $matches);
	    if (count($matches) > 0){
		if (count($matches[0]) > 0){
		    $text_matches = '';
		    $tpl = new \MetaNull\Application\MTemplate('m');
		    $path = TARIQA3_REL_PATH;
		    if (substr($path, -1) != '/'){
			$path .= '/';
		    }
		    $tpl->loadTemplate($path . 'themes/default/modules/tariqa3/Search/ln_idol.html');
		    foreach ($matches[0] as $phrase){
			$text_matches .= ($text_matches == ''?'':' ... ') . self::highlight($phrase);
		    }
		    $tpl->data = array();
		    $tpl->data['matches'] = $text_matches;
		    $document->summary .= $tpl->transform();
		}
	    }
	    $document->publisher = $article->agency;

	    $result->documents[] = $document;
	}

    if ($query->source_id == 17 && $query->first <= 1 && $country_id != null){
        $this->setGraph2($country_id, $query->source_id, $translations);
        $result->js_code = 'loadGraph("' . $country_id . '", "' . $query->source_id . '");';
    }
	return $result;
    }

    /**
     * Adds a link to the hotspots graphic
     * @param string $country_id The country
     * @param int $source_id The source identifier
     * @param array $translations The translations array for the search module
     * @access protected
     * @return tariqaDocument
     */
    protected function setGraph($country_id, $source_id, $translations){
        $docs = \tariqa3\statics::$tariqaClient->getHistory(\tariqa3\statics::$tariqaToken, $country_id);
        $cd = new \DateTime();
        $dates = array();
        $cd->sub(new \DateInterval('P1D'));
        $__d = new \DateTime($cd->format('Y-m-d 09:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $__d = new \DateTime($cd->format('Y-m-d 12:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $__d = new \DateTime($cd->format('Y-m-d 18:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $__d = new \DateTime($cd->format('Y-m-d 21:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        //$docs = \tariqa3\statics::$tariqaClient->getHistory2(\tariqa3\statics::$tariqaToken, $country_id, $dates, 30);
        $app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
        $base = $app_config['application']['base-folder'] . '/misc/hotspots/';
        $text = file_get_contents($base . 'template');
        $max = $docs[1];
        for ($i = 2; $i < count($docs); $i++){
            if (abs($docs[$i]) > $max){
                $max = abs($docs[$i]);
            }
            
        }
        $text = str_replace('MAX_VALUE', $max, $text);
        $steps = round($max / 20);
        $text = str_replace('STEPS_VALUE', $steps, $text);

        $d = array();

        $docs[0] += 60 * 60 - (count($docs) - 1) * 24 * 60 * 60;
        $date = new \DateTime('@' . $docs[0]);
        $labels = "";

        $t1 = array('colour' => '#ff0000', 'dot-size' => 4, 'type' => 'star');
        $t2 = array();

        for ($i = 1; $i < count($docs); $i++){
            $d1 = $date->getTimestamp();
            $date->add(new \DateInterval('P1D'));
            $labels[] = $date->format("d/m/Y");
            $d2 = $date->getTimestamp();
            $d[] = array_merge(
                               array("y" => abs($docs[$i]), 'on-click' => "loadGraphNews('" . $source_id . "', '" . $d1 . "', '" . $d2 . "')",
                                     'tip' => 'Click to see the #val# corresponding articles'),
                               ($docs[$i] < 0 ? $t1 : $t2) 
                               );
        }

        $t = json_encode($d);
        $text = str_replace('VALUES', '"values": ' . $t, $text);

        $l = "";
        foreach ($labels as $label){
            $l .= ($l == "" ? "" : ', ') . '"' . $label . '"' ;
        }

        $text = str_replace('LABELS', '"labels": [' . $l . ']', $text);
        
        $file_name = $base . $country_id;
        file_put_contents($file_name, $text);
    }

    /**
     * Adds a link to the hotspots graphic
     * @param string $country_id The country
     * @param int $source_id The source identifier
     * @param array $translations The translations array for the search module
     * @access protected
     * @return tariqaDocument
     */
    protected function setGraph2($country_id, $source_id, $translations){
        $cd = new \DateTime();
        $dates = array();
        $cd->sub(new \DateInterval('P1D'));
        $__d = new \DateTime($cd->format('Y-m-d 09:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $__d = new \DateTime($cd->format('Y-m-d 12:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $__d = new \DateTime($cd->format('Y-m-d 18:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $__d = new \DateTime($cd->format('Y-m-d 22:00:00'));
        $dates[] = $__d->getTimestamp() + $__d->getOffset();
        $docs = \tariqa3\statics::$tariqaClient->getHistory2(\tariqa3\statics::$tariqaToken, $country_id, $dates, 30);
        $app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
        $base = $app_config['application']['base-folder'] . '/misc/hotspots/';
        $text = file_get_contents($base . 'template2');
        $max = $docs[0]->articles[0];
        for ($i = 0; $i < count($docs); $i++){
            for ($j = 0; $j < count($docs[$i]->articles); $j++){
                if (abs($docs[$i]->articles[$j]) > $max){
                    $max = abs($docs[$i]->articles[$j]);
                }
            }
        }
        
        $text = str_replace('MAX_VALUE', $max, $text);
        
        $steps = round($max / 20);
        $text = str_replace('STEPS_VALUE', $steps, $text);

        $t1 = array('colour' => '#ff0000');
        $t2 = array();
        $labels = array();

        for ($i = 0; $i < count($docs); $i++){
            $d = array();
            $start_date = $docs[$i]->date - (count($docs[$i]->articles)) * 24 * 60 * 60;
            $date = new \DateTime('@' . $start_date);

            for ($j = 0; $j < count($docs[$i]->articles); $j++){
                $d1 = $date->getTimestamp();
                $date->add(new \DateInterval('P1D'));
                if ($i == 0){
                    $labels[] = $date->format("d/m/Y");
                }
                $d2 = $date->getTimestamp();
                $d[] = array_merge(
                                   array("top" => abs($docs[$i]->articles[$j]), 'on-click' => "loadGraphNews('" . $source_id . "', '" . $d1 . "', '" . $d2 . "')",
                                         'tip' => ($docs[$i]->articles[$j] < 0 ? 'A hotspot value. <br/>' : '') . 'Click to see the #val# corresponding articles at ' . $date->format("H:i")),
                                   ($docs[$i]->articles[$j] < 0 ? $t1 : $t2) 
                                   );
                //$d[] = abs($docs[$i]->articles[$j]);
            }

            $t = json_encode($d);
            $text = str_replace('VALUES' . $i, '"values": ' . $t, $text);
        }

        $l = "";
        foreach ($labels as $label){
            $l .= ($l == "" ? "" : ', ') . '"' . $label . '"' ;
        }

        $text = str_replace('LABELS', '"labels": [' . $l . ']', $text);
        
        $file_name = $base . $country_id;
        file_put_contents($file_name, $text);
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}
	$id = $parts[2];
	$link = null;
	if (strpos($id, '_')){
	    $parts = explode('_', $id, 2);
	    $id = $parts[0];
	    $links = $parts[1];
	}

	/* @var $document \LatestNewsDocument */
	$document = \tariqa3\statics::$tariqaClient->latestNewsGetDocumentIDOL(\tariqa3\statics::$tariqaToken, $id, $links);

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = $document->id;
	$result->title = $document->headline;

	$result->date = $document->date;
	$result->publisher = $document->agency;
	$body = self::highlight($document->text);

	$body = implode('</p><p>', preg_split('/^[ \t]{2,}/m', $body));
	$body = '<p>' . $body . '</p>';

	if (\tariqa3\statics::_isIE()){
	    $result->body = '<pre style="word-wrap: break-word; font-family: Verdana, Arial">' . $body . "</pre>";
	}
	else {
	    $result->body = '<span style="white-space: pre-wrap;">' . $body . "</span>";
	}

	return $result;
    }

    /**
     * Gets the multi ajax search object for any page but the search page. For example country pages, home page, news wires page etc.
     * @param Flavour $flavour The flavour
     * @param array $filtering The filtering data
     * @param Query $flavour_query The flavour current query
     * @access public
     * @return multiAjaxSearch
     */
    public function newsSection($flavour, $filtering, $flavour_query) {
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$search = new \tariqa3\multiAjaxSearch($filtering['query'], $flavour_query->source_id, $app_config['application']['service_url'],
	    'search_' . $flavour->flavour_id, true, $filtering['start_date'], $filtering['end_date'], 0, $this->newsConfig['search']['default']['results-per-page'],
	    \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);
	
	$specific_data = rawurlencode("source_name=" . $flavour_query->title);
	if (array_key_exists('all_results', $_GET)){
	    $specific_data .= '&MinScore=0';
	}

    if (array_key_exists('country_id', $_GET)){
        $specific_data .= '&country_id=' . $_GET['country_id'];
    }
    else if (array_key_exists('country_id', $_POST)){
        $specific_data .= '&country_id=' . $_POST['country_id'];
    }

	$search->setSpecificData($specific_data);

	$search->noNewTab();
	$search->setNavigationId('navigation_' . $flavour->flavour_id);
	$search->setResultId('news_' . $flavour->flavour_id);

	return $search;
    }

    /**
     * Gets the multi ajax search object. This function is used by the search page. For the multiAjaxSearch object used in any other page
     * (country pages, home pages, news wires page etc.) the newsSection method is called. 
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$defaults = $this->newsConfig['default'];
	$search = new \tariqa3\multiAjaxSearch($query, $defaults['latestnewsidol']['source_id'], $app_config['application']['service_url'],
	    'searchResult', false, ($startDate == null?null:$startDate->getTimestamp() + $startDate->getOffset()),
	    ($endDate == null?null:$endDate->getTimestamp() + $endDate->getOffset()), $from, $count, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$languages = \tariqa3\statics::LatestNewsListLanguages();
	$set = false;
	$l = '';
	$spell_check = 0;
	foreach ($languages as $language){
	    if (!array_key_exists('ln_lang_' . $language->id, $_POST) && !array_key_exists('ln_lang_' . $language->id, $_GET)){
		$set = true;
	    }
	    else {
		$spell_check++;
		if (array_key_exists('ln_lang_' . $language->id, $_POST)){
		    $l .= ($l == ''?'':'+') . $_POST['ln_lang_' . $language->id];
		}
		else {
		    $l .= ($l == ''?'':'+') . $_GET['ln_lang_' . $language->id];
		}
	    }
	}

	$specific_data = 'MinScore=' . $_POST['min_confidence'] . '&MaxScore=' . $_POST['max_confidence'] . '&sort_by=' . $_POST['ln_sort_by'] .
	    '&no_sport=false';

	if ($spell_check == 1){
	    $specific_data .= '&spell_check=true';
	}

	if ($set){
	    $specific_data .= '&languages=' . $l;
	}

    if (array_key_exists('country_id', $_GET)){
        $specific_data .= '&country_id=' . $_GET['country_id'];
    }
    else if (array_key_exists('country_id', $_POST)){
        $specific_data .= '&country_id=' . $_POST['country_id'];
    }

	$search->setSpecificData($specific_data);

	return $search;
    }

    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()){
	$range = '';
	$range_days = '';
	if ($start_date != null) $range = floor((time() - $start_date) / (60 * 60 * 24));
	if ($end_date != null) $range_days = $range - floor((time() - $end_date) / (60 * 60 * 24));
	if ($range_days > $range){
	    $range = $range_days;
	}
	$post_data = "ln_date_type=range&selected=1&engine=LatestNewsIDOL&query={$query_txt}&ln_range={$range}&range_days={$range_days}" .
		"&range_field_name=ln_range&date_type_field_name=ln_date_type" .
		"&ln_start_date=&ln_end_date=&from_field_name=ln_start_date&to_field_name=ln_end_date&results_per_page={$this->newsConfig['search']['default']['results-per-page']}";

	return $post_data;
    }

}

}
?>