<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the RSS engine
 * @author Cosmin Popescu
 *
 */
class RSSEngine extends GoogleEngine {

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$url = $query->query;
	$results = \tariqa3\statics::$tariqaClient->fetchRSS(\tariqa3\statics::$tariqaToken, $url, $query->first, null);

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine = $query->engine_id;
	$result->engine_name = $engine->name;
	$result->source = $query->source_id;
	$result->from = $query->first;

	$result->count = count($results->articles);
	$result->results_per_page = count($results->articles);

	$result->documents = array();

	/* @var $article Article */
	foreach ($results->articles as $article) {
	    $document = new tariqaDocument();

	    $document->title = $article->title;
	    $document->id = $query->engine_id . ':' . $query->source_id. ':'  . urlencode($article->url);
	    $document->url = $this->link('RSS::' . urlencode($article->url));
	    $document->js_link = $this->js_link('RSS::' . urlencode($article->id), $article->title);

	    $document->date = strtotime($article->date);

	    $content = $article->lead_para;
	    if ($content == '') $content = '<!--Content not available-->';
	    $document->summary = $content;
	    $document->publisher = $article->copyright;

	    $result->documents[] = $document;
	}

	return $result;
    }

    /**
     * Gets the multi ajax search object for any page but the search page. For example country pages, home page, news wires page etc.
     * @param Flavour $flavour The flavour
     * @param array $filtering The filtering data
     * @param Query $flavour_query The flavour current query
     * @access public
     * @return multiAjaxSearch
     */
    public function newsSection($flavour, $filtering, $flavour_query) {
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$search = new \tariqa3\multiAjaxSearch($filtering['query'], $flavour_query->source_id, $app_config['application']['service_url'],
	    'search_' . $flavour->flavour_id, true, $filtering['start_date'], $filtering['end_date'], 0, $this->newsConfig['search']['default']['results-per-page'],
	    \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$search->noNewTab();
	$search->setNavigationId('navigation_' . $flavour->flavour_id);
	$search->setResultId('news_' . $flavour->flavour_id);

	return $search;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @abstract
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	return null;
    }
}
}
?>