<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the Virage engine
 * @author Cosmin Popescu
 *
 */
class VirageEngine extends searchEngine {
    /**
     * The IDOL url
     * @var string
     */
    const CHANNEL_AJL = 'al-jazeera';

    /**
     * The IDOL url
     * @var string
     */
    const CHANNEL_EN = 'euronews';

    /**
     * The IDOL url
     * @var string
     */
    const CHANNEL_BBC = 'bbc';

    /**
     * The IDOL url
     * @var string
     */
    const CHANNEL_F24FR = 'france24-fr';

    /**
     * The voice match type
     * @var string
     */
    const VOICE_MATCH = 'voice';

    /**
     * The text match type
     * @var string
     */
    const TEXT_MATCH = 'text';

    /**
     * The time zone
     * @var string
     */
    const TIMEZONE = 'Europe/Brussels';

    /**
     * The channel names
     * @var string[]
     * @access protected
     */
    public static $channel_names = array(
	'al-jazeera' => 'Al Jazeera English',
	'euronews' => 'Euro News',
	'bbc' => 'BBC World News',
	'france24-fr' => 'France 24 (French)', 
    );

    /**
     * The hl id
     * @var int
     * @access private
     */
    private $hl_id = 0;

    /**
     * The IDOL url
     * @var string
     */
    const IDOL_URL = 'http://s-relex-crisis:9000/';

    /**
     * The IDOL url
     * @var string
     */
    const IDOL_HOST = 's-relex-crisis';

    /**
     * The archive URL
     * @var string
     */
    const ARCHIVE_URL = 'https://webgate.ec.europa.eu/tariqa/archive/';

    /**
     * The IDOL url
     * @var string
     */
    const HOTFOLDERS_LOCATION = "\\\\s-relex-crisis\\hotfolders$";

    /**
     * The configuration array
     * @var array
     * @access protected
     */
    protected $app_config;

    /**
     * Search for a video in the database using Virage
     * @param VirageSearchQuery $query The query to be executed
     * @param boolean $completeDocs If set to true, it returns the complete document without the images. Else, it returns only a few fields [OPTIONAL]
     * @param boolean $getImages If set to true, also get the images [OPTIONAL]
     * @return VirageSearchResult
     * */
    private function DoVirageSearch($query, $completeDocs = false, $getImages = false) {
	$error = false;

	if ($query->start == null || $query->start == 0){
	    $query->start = 1;
	}

	if( ($query->query == "" || $query->query == null) ) {
	    //throw new \Exception(": 404, You have to set a query text, a file name or a URL");
	    $query->query = "*";
	}
	$url = '';
	if ($query->query != "" && $query->query != null) {
	    $url .= "Text=" . htmlspecialchars($query->query);
	}

	if ($query->fileName != "" && $query->fileName != null) {
	    $query->fileName = rawurldecode($query->fileName);
	    $url .= ($url == ""?"":"&") . "FieldText=STRING{" . htmlspecialchars($query->fileName) . "}:DREREFERENCE";
	}

	/*if ($query->url != "" && $query->url != null) {
	    $url .= ($url == ""?"":"&") . "FieldText=WILD{*" . htmlspecialchars($query->url) . "*}:URL";
	}*/

	if ($query->minDate != "" && $query->minDate != null) {
	    $d = new \DateTime('@' . $query->minDate);
	    $url .= "&MinDate=" . $d->format('H:i:s d/m/Y');
	}

	if ($query->maxDate != "" && $query->maxDate != null) {
	    $d = new \DateTime('@' . $query->maxDate);
	    $url .= "&MaxDate=" . $d->format('H:i:s d/m/Y');
	}

	if ($query->no_predict){
	    $url .= '&Predict=False';
	}

	if ($query->sort != "" && $query->sort != null) {
	    switch ($query->sort) {
		case "Date": $url .= "&Sort=" . ($query->sortOrder == "desc"?"ReverseDate":"Date");
		    break;
		case "Relevance": $url .= "&Sort=Relevance"; //. ($query->sortOrder == "desc"?"ReverseRelevance":"Relevance");
		    break;
		case "STARTTIME": $url .= "&Sort=STARTTIME:" . ($query->sortOrder == "desc"?"numberdecreasing":"numberincreasing");
		    break;
		case "ENDTIME": $url .= "&Sort=ENDTIME:" . ($query->sortOrder == "desc"?"numberdecreasing":"numberincreasing");
		    break;
	    }
	}

	if ($query->maxResults != null) {
	    $url .= "&MaxResults=" . rawurlencode($query->maxResults + $query->start - 1);
	}

	$url .= "&Stemming=true";
	if ($completeDocs) {
	    $fields = "print=Fields&PrintFields=DRETITLE,DREDATE,DREDBNAME,STARTTIME,ENDTIME,CONTENTTYPE,SWF,SWF_TIME,OCR_WORDS,OCR_MSEC_TIME,OCR_WEIGHTS,SOFTSOUND_MSEC_TIME,SOFTSOUND_WORDS,SOFTSOUND_WEIGHTS,DRECONTENT";
	}
	else $fields = "&print=Fields&PrintFields=DRECONTENT";
	if ($getImages) {
	    $fields .= ',SMALL_KEYFRAME_JPEG_MSEC_TIME';
	}
	$url .= '&' . $fields . "&highlight=terms&TotalResults=True&Start=" . $query->start;
	$url = self::IDOL_URL . "?action=query&" . $url;

	//$wResult = \MetaNull\Tools\mCurl::doHttp(self::IDOL_HOST, 9000, 'GET', 'action=query&' . $url, array(
	//'Accept:text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
	//'Accept-Charset:ISO-8859-1,utf-8;q=0.7,*;q=0.3',
	//'Accept-Encoding:gzip,deflate,sdch',
	//'Accept-Language:en-US,en;q=0.8',
	//'Cache-Control:max-age=0',
	//));
	$http_code = 200;
	$wResult = \MetaNull\Tools\mCurl::Get($url, $http_code, false, false, false, false);
	// = file_get_contents($file);
	//$wResult = \MetaNull\Tools\mCurl::Get($url, $http_code);
	$xResult = new \DOMDocument();
	//$xResult->loadXML($wResult->body);

	if ($xResult->loadXML($wResult) === false) {
	    throw new \Exception("Error loading the XML: {$url}\n" . \MetaNull\Tools\mDump::dumpVariable($wResult, true) );
	}

	$xpath = new \DOMXPath($xResult);
	$nodes = $xpath->query("/autnresponse/responsedata/*");

	$Result = new \VirageSearchResult();
	$Result->query = $query;
	$Result->documents = array();
	$images = new \VirageDocumentImages();

	$i = 0;

	foreach ($nodes as $node) {
	    switch ($node->nodeName) {
		case "autn:totalhits":
		    $Result->resultsFound = $node->nodeValue;
		    break;
		case "autn:hit":
		    $document = new \VirageDocument();
		    foreach($node->childNodes as $doc_property) {
			switch ($doc_property->nodeName) {
			    case "autn:weight": $document->weight = $doc_property->nodeValue;
				break;
			    case "autn:links": $document->links = $doc_property->nodeValue;
				break;
			    case "autn:id": $document->document_id = $doc_property->nodeValue;
				break;
			    /*case "autn:section": $document->section = $doc_property->nodeValue;
				break;*/
			    //case "autn:title": $document->title = $doc_property->nodeValue; break;
			    case "autn:reference":
				$document->section = $doc_property->nodeValue;
				$parts = explode("\\", $doc_property->nodeValue);
				$fileName = $parts[count($parts) - 1];
				$fileName = preg_replace('/^(.*)\?start=.*$/', '\1', $fileName);
				$fileName = preg_replace('/^(.*)\.wmv$/', '\1.flv', $fileName);
				//$fileName = \MetaNull\Tools\mTools::rawurlencode($fileName);
				$document->fileName = /*$this->config["virage"]["livestream"] . */$fileName;
				$title = preg_replace('/^(vir_\[[^\]]*\]_)*([^\?]*)\?.*$/', '\2', $fileName);
				$title = preg_replace('/\.[^\.]*$/', '', $title);
				$document->title = $title;
				break;
			}
		    }

		    $doc = $xpath->query("//autn:id[text() = '{$document->document_id}']/../autn:content/DOCUMENT");

		    for( $i = 0; $i < $doc->item(0)->childNodes->length; $i++) {
			$complete_doc = $doc->item(0)->childNodes->item($i);
			switch ($complete_doc->nodeName) {
			    case "DRECONTENT":
				$content = $complete_doc->nodeValue;
				$content = htmlspecialchars_decode($content);
				/*$content = str_replace("<font color=red>", "<span class=\"highlight\">", $content);
								$content = str_replace("</font>", "</span>", $content);*/
				$document->documentContent = $content;
				break;
			    case "CONTENTTYPE": $document->contentType = $complete_doc->nodeValue;
				break;
			    case "DREDBNAME": $document->database = $complete_doc->nodeValue;
				break;
			    case "DREDATE": $document->date = $complete_doc->nodeValue;
				break;
			    case "DREREFERENCE":
				$hf = \tariqa3\statics::completePath(self::HOTFOLDERS_LOCATION, "\\");
				$document->dre_title = self::$channel_names[preg_replace("/([^\\\\]*)\\\\.*$/", '\1', str_replace($hf, '', $complete_doc->nodeValue))];
				break;
			    case "ENDTIME": $document->endTime = $complete_doc->nodeValue;
				break;
			    case "STARTTIME": $document->startTime = $complete_doc->nodeValue;
				break;
			    case "CONTENTTYPE": $document->contentType = $complete_doc->nodeValue;
				break;

			    case "OCR_MSEC_TIME": $document->setOCRMSecTime($complete_doc->nodeValue);
				break;
			    case "OCR_WEIGHTS": $document->setOCRWeight($complete_doc->nodeValue);
				break;
			    case "OCR_WORDS": 
				//$document->setOCRWords($complete_doc->nodeValue);
				$document->ocrWords = json_decode($complete_doc->nodeValue);
				break;
			    case "SOFTSOUND_MSEC_TIME": $document->setSoftSoundMSecTime($complete_doc->nodeValue);
				break;
			    case "SOFTSOUND_WEIGHTS": $document->setSoftSoundWeights($complete_doc->nodeValue);
				break;
			    case "SOFTSOUND_WORDS": $document->setSoftSoundWords($complete_doc->nodeValue);
				break;
			    case "SWF": $document->setSWFLocation($complete_doc->nodeValue);
				break;
			    case "SWF_TIME": $document->setSWFTime($complete_doc->nodeValue);
				break;
			}
			if ($getImages) {
			    switch ($complete_doc->nodeName) {
				/*case "LARGE_KEYFRAME_JPEG_IMAGES": $images->setLargeImageContent($complete_doc->nodeValue);
				    break;
				case "LARGE_KEYFRAME_JPEG_MSEC_TIME": $images->setLargeImageMSecTime($complete_doc->nodeValue);
				    break;
				case "SMALL_KEYFRAME_JPEG_IMAGES": $images->setSmallImageContent($complete_doc->nodeValue);
				    break;*/
				case "SMALL_KEYFRAME_JPEG_MSEC_TIME": $images->setSmallImageMSecTime($complete_doc->nodeValue);
				    break;
			    }
			}

		    }
		    //$document->correctSWFLocation($this->config["virage"]["swf-location"]);

		    if ($getImages) {
			$images->document_id = $document->document_id;
			$document->images = $images;
			$images = new \VirageDocumentImages();

		    }

		    //$document->date = preg_replace('/^.* ([\d]{4})\-([\d]{2})\-([\d]{2}) ([\d]{2})\-([\d]{2})\-([\d]{2})$/', '\1-\2-\3 \4:\5:\6', $document->title);

		    array_push($Result->documents, $document);
		    break;
	    }
	}

	/*error_log('begin compression - ' . microtime());
	$var = serialize($Result);
	error_log('Size un-compressed: ' . strlen($var));
	$zip = gzcompress($var, 9);
	error_log('Zip size: ' . strlen($zip));
	$res = base64_encode($zip);
	error_log('end compression - ' . microtime());
	error_log('Size compressed: ' . strlen($res));

	error_log('end parse - ' . microtime());*/
	return $Result;
    }

    /**
     * Splits an id into document id and searched terms
     * @param string $id The document id
     * @access protected
     * @return array
     */
    protected function splitId($id) {
        $del = null;
        if (strpos($id, '&') !== false) {
            $del = '&';
        }
        else if (strpos($id, '_') !== false) {
            $del = '_';
        }
        if ($del != null) {
            $parts = explode($del, $document_id, 2);
            $id = $parts[0];
            $links = str_replace(',', '+', $parts[1]);

            return array('id' => $id, 'links' => $links);
        }
        return array('id' => $id, 'links' => null);
    }

    /**
     * Get a Virage document without authentication
     * @param string $document_id The document identifier
     * @param boolean $getImages If true, then it also returns the document images
     * @access private
     * @return VirageDocument
     * */
    private function VirageGetDocument($document_id, $getImages) {
	$links = null;
	$del = null;
	if (strpos($document_id, '&') !== false) {
	    $del = '&';
	}
	else if (strpos($document_id, '_') !== false) {
	    $del = '_';
	}
	if ($del != null) {
	    $parts = explode($del, $document_id, 2);
	    $document_id = $parts[0];
	    $links = str_replace(',', '+', $parts[1]);
	}
	//$links = str_replace(' ', '+', $links);
	$fields = "print=Fields&PrintFields=DRETITLE,DREDATE,DREDBNAME,STARTTIME,ENDTIME,CONTENTTYPE,SWF,SWF_TIME,OCR_WORDS,OCR_MSEC_TIME,OCR_WEIGHTS,SOFTSOUND_MSEC_TIME,SOFTSOUND_WORDS,SOFTSOUND_WEIGHTS,DRECONTENT";
	if ($getImages) $fields = "print=all";
	$url = self::IDOL_URL . "action=getcontent&id=" . $document_id . "&" . $fields . ($links != null?'&Highlight=Terms&links=' . $links:'');

	$http_code = 0;

	$wResult = \MetaNull\Tools\mCurl::Get($url, $http_code);

	$xResult = new \DOMDocument();
	if ($xResult->loadXML($wResult) === false) {
	    throw new \Exception("Error loading the XML: {$url}\n{$wResult}" );
	    return null;
	}

	$xpath = new \DOMXPath($xResult);

	$nodes = $xpath->query("/autnresponse/responsedata/autn:hit");

	$Result = new \VirageDocument();
	$images = new \VirageDocumentImages();

	$i = 0;

	foreach ($nodes as $node) {
	    foreach($node->childNodes as $doc_property) {
		switch ($doc_property->nodeName) {
		    case "autn:weight": $Result->weight = $doc_property->nodeValue;
			break;
		    case "autn:links": $Result->links = $doc_property->nodeValue;
			break;
		    case "autn:id": $Result->document_id = $doc_property->nodeValue;
			break;
		    /*case "autn:section": $Result->section = $doc_property->nodeValue;
			break;*/
		    //case "autn:title": $Result->title = $doc_property->nodeValue; break;
		    case "autn:reference":
			$Result->section = $doc_property->nodeValue;
			$parts = explode("\\", $doc_property->nodeValue);
			$fileName = $parts[count($parts) - 1];
			$fileName = preg_replace('/^(.*)\?start=.*$/', '\1', $fileName);
			$fileName = preg_replace('/^(.*)\.wmv$/', '\1.flv', $fileName);
			//$fileName = \MetaNull\Tools\mTools::rawurlencode($fileName);
			$Result->fileName = $fileName;
			$title = preg_replace('/^(vir_\[[^\]]*\]_)*([^\?]*)\?.*$/', '\2', $fileName);
			$title = preg_replace('/\.[^\.]*$/', '', $title);
			$Result->title = $title;
			break;
		}
	    }

	    $doc = $xpath->query("//autn:id[text() = '{$Result->document_id}']/../autn:content/DOCUMENT");

	    for( $i = 0; $i < $doc->item(0)->childNodes->length; $i++) {
		$complete_doc = $doc->item(0)->childNodes->item($i);
		switch ($complete_doc->nodeName) {
		    case "DRECONTENT":
			$content = $complete_doc->nodeValue;
			$content = htmlspecialchars_decode($content);
			/*$content = str_replace("<font color=red>", "<span class=\"highlight\">", $content);
						$content = str_replace("</font>", "</span>", $content);*/
			$Result->documentContent = $content;
			break;
		    case "CONTENTTYPE": $Result->contentType = $complete_doc->nodeValue;
			break;
		    case "DREDBNAME": $Result->database = $complete_doc->nodeValue;
			break;
		    case "DREDATE": $Result->date = $complete_doc->nodeValue;
			break;
		    case "DREREFERENCE":
			$hf = \tariqa3\statics::completePath(self::HOTFOLDERS_LOCATION, "\\");
			$Result->dre_title = self::$channel_names[preg_replace("/([^\\\\]*)\\\\.*$/", '\1', str_replace($hf, '', $complete_doc->nodeValue))];
			break;
		    case "ENDTIME": $Result->endTime = $complete_doc->nodeValue;
			break;
		    case "STARTTIME": $Result->startTime = $complete_doc->nodeValue;
			break;
		    case "CONTENTTYPE": $Result->contentType = $complete_doc->nodeValue;
			break;

		    case "OCR_MSEC_TIME": $Result->setOCRMSecTime($complete_doc->nodeValue);
			break;
		    case "OCR_WEIGHTS": $Result->setOCRWeight($complete_doc->nodeValue);
			break;
		    case "OCR_WORDS": 
			//$Result->setOCRWords($complete_doc->nodeValue);
			$Result->ocrWords = json_decode($complete_doc->nodeValue);;
			break;
		    case "SOFTSOUND_MSEC_TIME": $Result->setSoftSoundMSecTime($complete_doc->nodeValue);
			break;
		    case "SOFTSOUND_WEIGHTS": $Result->setSoftSoundWeights($complete_doc->nodeValue);
			break;
		    case "SOFTSOUND_WORDS": $Result->setSoftSoundWords($complete_doc->nodeValue);
			break;
		    case "SWF": $Result->setSWFLocation($complete_doc->nodeValue);
			break;
		    case "SWF_TIME": $Result->setSWFTime($complete_doc->nodeValue);
			break;
		}

		if ($getImages) {
		    switch ($complete_doc->nodeName) {
			/*case "SMALL_KEYFRAME_JPEG_IMAGES": $images->setSmallImageContent($complete_doc->nodeValue);
			    break;*/
			case "SMALL_KEYFRAME_JPEG_MSEC_TIME": $images->setSmallImageMSecTime($complete_doc->nodeValue);
			    break;
		    }
		}
	    }
	    //$Result->correctSWFLocation($this->config["virage"]["swf-location"]);

	    if ($getImages) {
		$Result->images = $images;
	    }

	}

	//$Result->date = preg_replace('/^.* ([\d]{4})\-([\d]{2})\-([\d]{2}) ([\d]{2})\-([\d]{2})\-([\d]{2})$/', '\1-\2-\3 \4:\5:\6', $Result->title);

	if ($Result->links == null){
	    $Result->links = $links;
	}

	return $Result;
    }

    /**
     * Gets the channels list
     * @static
     * @access public
     * @return array
     */
    public static function listChannels() {
	return self::$channel_names;
    }

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	$this->app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	parent::__construct($newsConfig);
    }

    /**
     * Gets the last image frame before a time key. Returns the index
     * @param array $times The images times
     * @param int $time The time to search
     * @param int $start Start from... [OPTIONAL]
     * @access protected
     * @return int
     */
    protected function getImgIdx($times, $time, $start = 0) {
	for ($key = $start; $key < count($times); $key++){
	    if ($times[$key] > $time){
		return $key - 1;
	    }
	}
	return $key - 1;
    }

    /**
     * Generates a new text highlight and adds it to the existing highlights
     * @param string $text The text
     * @param array $data The existing highlights
     * @param string $template The template for which the highlights are designed (search results or article page)
     * @param int $img_idx The corresponding thumbnail index
     * @param string $section The document section
     * @param string $text_type The type of text (voice match or text match) [OPTIONAL]
     * @param array $others Other highlights for the current highlight [OPTIONAL]
     * @access protected
     * @return array
     */
    protected function highlight($text, $data, $template, $img_idx, $section, $text_type = self::VOICE_MATCH, $others = null) {
	$words = preg_split('/[\s,\t\n\r\-]/', strip_tags($text));
	if (count($data) > 0 && $text_type == self::VOICE_MATCH){
	    $data[] = array(
		'word' => ' ... ',
		'has_link' => false
	    );
	}

	foreach ($words as $key => $word){
	    $w = array(
		'word' => $word,
	    );
	    if ($text != self::TEXT_MATCH){
		$w['new_div_begin'] = $key == 0;
		$w['new_div_end'] = $key == count($words) - 1;
	    }
	    $w['has_link'] = false;
	    if (preg_match('/<font color=red>' . $word . '<\/font>/', $text)){
		$w['has_link'] = true;
		$w['id'] = 'hl_' . $this->hl_id++;
		$w['i'] = $img_idx;
		$w['section'] = $section;
		$w['type'] = ($template == 'virage.html'?'long':'short');
	    }

	    if ($others != null && count($others) > 0 && $w['new_div_end']){
		$w['has_others'] = true;
		$id = $section . '_' . md5($text);
		$w['others_id'] = $id;
		$w['others'] = array();
		foreach ($others as $_h){
		    $w['others'][] = array(
			'headline' => preg_replace('/<font color=red>([^<]*)<\/font>/',
			    '<strong>\1</strong>', $_h->h)
		    );
		}
	    }
	    else {
		$w['has_others'] = false;
	    }

	    $data[] = $w;
	}

	return $data;
    }

    /**
     * Used for comparing two headlines by their time
     * @param array $h1 The first headline
     * @param array $h2 The second headline
     * @static
     * @access protected
     * @return boolean
     */
    protected static function headlineCompare($h1, $h2) {
	if ($h1->t < $h2->t){
	    return -1;
	}
	return 1;
    }

    /**
     * Used for adding the javascript code for one match in the text
     * @param int $idx The match index in the text
     * @param VirageDocument $doc The virage document
     * @param int $words the number of words before and after the match
     * @static
     * @access public
     * @return array
     */
    public static function addCuepoint($idx, $doc, $words) {
	$start = $idx - $words;
	if ($start < 0) {
	    $start = 0;
	}

	$end = $idx + $words;
	if ($end >= count($doc->softSoundWords)){
	    $end = count($doc->softSoundWords) - 1;
	}

	$text = '';
	for ($i = $start; $i <= $end; $i++){
	    $text .= ($text == ''?'':' ') . '#' . $i . '[' . $doc->softSoundWords[$i] . ']' . $i . '#';
	}

	$texts = array();
	$idx = array();

	for ($i = $start; $i <= $end; $i++){
	    $word = $doc->softSoundWords[$i];
	    $c = str_replace('#' . $i . '[' . $word . ']' . $i . '#', '<span class="highlight">' . $word . '</span>', '<p>' . $text . '</p>');
	    $c = preg_replace('/#[\d]+\[([^\]]+)\][\d]+#/', '\1', $c);
	    $idx[] = $doc->softSoundMsecTime[$i];
	    $texts['cuepoint_' . $doc->softSoundMsecTime[$i]] = $c;
	}

	return array('texts' => $texts, 'idx' => $idx);
    }

    /**
     * Gets the document summary
     * @param VirageDocument $article The Virage document
     * @param string $app_path The path to the application
     * @param string $img_url The image URL
     * @param string $img_onclick The onclick part of the images
     * @access protected
     * @return string
     */
    protected function getDocumentSummary($article, $path, $img_url, $img_onclick, $template = 'virage.html') {
	if (substr($path, -1) != '/' && $path != '') $path .= '/';

	/*$content = '';
	foreach ($article->softSoundWords as $word){
	    $content .= ($content == ''?'':' ') . $word;
	}*/

	//$c = preg_replace('/<SIL>|<span[^>]*>[^<]*<\/span>/', '', $article->documentContent);

	//$content = preg_replace('/<[^>]*>/', '', $article->documentContent);
	/*$f = fopen("d:/webserver/temp/virage_images_" . $article->document_id, "wt");
	fwrite($f, base64_encode(serialize($article->images)));
	fclose($f);*/

	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->loadTemplate($path . 'themes/default/modules/tariqa3/Search/' . $template);

	$d = substr($article->date, 0, 10);
	$channel = preg_replace('/^.*[\\\\|\/]hotfolders[\$]{0,1}[\\\\|\/]([^\\\\^\/]+).*$/', '\1', $article->section);
	$file_name = preg_replace('/^.*[\\\\|\/]Completed[\\\\|\/]([^\.]+).*$/', '\1', $article->section);

	$idx = unserialize(file_get_contents($this->app_config['application']['base-folder'] . '/misc/virage-images/' . $channel . '/SMKF/' . $d . '/' . $file_name . '.idx'));
	//$idx = array();
	$tpl->data['img_idx'] = json_encode($idx);

	//preg_match_all('/([a-zA-Z]+[\s,\t\n\r\-]+){0,6}<font color=red>([^>]*)<\/font>[\s,\t\n\r\-]+([a-zA-Z]+[\s,\t\n\r\-]+){0,6}/i', $article->documentContent, $matches);
	preg_match_all('/(\w+[\s,\t\n\r\-]+){0,6}<font color=red>([^>]*)<\/font>[\s,\t\n\r\-]+(\w+[\s,\t\n\r\-]+){0,6}/i', $article->documentContent, $matches);

	$n = 0;

	$ii = 0;

	$tpl->data['voice_matches'] = array();

	/*$summary = new \MetaNull\Application\MTemplate('m');
	$summary->loadTemplate($path . 'themes/default/modules/tariqa3/Search/summary.html');

	$summary->data['words'] = array();
	$summary->data['voice_matches'] = true;
	$summary->data['text_matches'] = false;*/

	$summary = '';

	$cuepoints = array();
	$cuepoints_idx = array();

	if (count($matches) > 1) {
	    foreach ($matches[0] as $key => $context) {
		while ( $n < count($article->softSoundWords) && $article->softSoundWords[$n] != $matches[2][$key]) {
		    $n++;
		}

		$_c = self::addCuepoint($n, $article, 6);

		$cuepoints = array_merge($cuepoints, $_c['texts']);
		$cuepoints_idx = array_merge($cuepoints_idx, $_c['idx']);

		if ($n < count($article->softSoundWords)){
		    $ii = $this->getImgIdx($idx, $article->softSoundMsecTime[$n], $ii);
		}
		else {
		    $ii = count($idx) - 1;
		}

		$summary .= ($summary == ''?'':' ... ') . preg_replace('/<font[^>]*>([^<]+)<\/font>/',
			'<strong><a href="#" onclick="moveToThumbnail(\'' . $ii . '\', \'' . md5($article->section) . '\', \'' . ($template == 'virage.html'?'long':'short') . '\'); return false;">\1</a></strong>', $context);

		//$summary->data['words'] = $this->highlight($context, $summary->data['words'], $template, $ii, md5($article->section));

		$n++;
	    }
	}
	$tpl->data['cuepoints_txt'] = str_replace('"', '#QUOTE#', base64_encode(json_encode($cuepoints)));
	$tpl->data['cuepoints_idx'] = str_replace('"', '', json_encode($cuepoints_idx));
	/* $tpl->data['cuepoints_txt'] = str_replace('"', '#QUOTE#', json_encode($cuepoints)); */
	/* $tpl->data['cuepoints_idx'] = str_replace('"', '', json_encode($cuepoints_idx)); */
	$tpl->data['doc_id'] = $article->document_id;

	$tpl->data['images'] = array();
	$tpl->data['doc_id'] = $article->document_id;
	$tpl->data['doc_ref'] = md5($article->section);

	if ($template == 'virage.html') {
	    foreach ($idx as $key => $content) {
		$tpl->data['images'][] = array(
			'idx' => $key,
			'channel' => $channel,
			'name' => $file_name,
			'date' => $d, 
			'href' => str_replace('@time@', $idx[$key], $img_url),
			'onclick' => str_replace('@time@', $idx[$key], $img_onclick),
			'idx' => $key,
		);
	    }
	}

	$tpl->data['channel'] = $channel;
	$tpl->data['name'] = $file_name;
	$tpl->data['date'] = $d;
	/*$tpl->data['summary'] = $summary->transform();
	$tpl->data['has_voice'] = count($summary->data['words']) > 0;*/
	$tpl->data['summary'] = $summary;
	$tpl->data['has_voice'] = $summary != '';

	$tpl->data['mseg_time'] = json_encode($idx);

	$i = 0;

	$headlines = array();

	//\MetaNull\Tools\mDump::dumpVariable($article->ocrWords);

	$nth = 0;

	while (count($headlines) == 0){
	    foreach ($article->ocrWords as $headline) {
		if (preg_match('/<font color=red>/', $headline->h->h) || $nth == 1) {
		    $h = $headline->h;
		    $h->o = $headline->o;
		    $headlines[] = $h;
		}
		else {
		    foreach ($headline->o as $_h){
			if (preg_match('/<font color=red>/', $_h->h)) {
			    $h = $_h;
			    $h->o = array();
			    $headlines[] = $h;
			}
		    }
		}
	    }
	    $nth++;
	    if ($nth == 1){
		break;
	    }
	}

	usort($headlines, array($this, "headlineCompare"));

	/*$summary->data = array();
	$summary->data['words'] = array();
	$summary->data['voice_matches'] = false;
	$summary->data['text_matches'] = true;*/

	//$headlines = array(array('headline' => 'VENEZUELA: CHAVEZS ABSENCE','time' => 644, 'soundex' => 'V524'), array('headline' => 'cHAvEz\'s','time' => 700, 'soundex' => 'C120'));

	$summary = '';

	foreach ($headlines as $headline) {
	    $i = $this->getImgIdx($idx, $headline->t);
	    $summary .= '<div>' . preg_replace('/<font[^>]*>([^<]+)<\/font>/',
		'<strong><a href="#" onclick="moveToThumbnail(\'' . $i . '\', \'' . md5($article->section) . '\', \'' . ($template == 'virage.html'?'long':'short') . '\'); return false;">\1</a></strong>', $headline->h) .
		'</div>';
	    //$summary->data['words'] = $this->highlight($headline->h, $summary->data['words'], $template, $i, md5($article->section), self::TEXT_MATCH, $headline->o);
	}

	/*$tpl->data['ocr_summary'] = $summary->transform();
	$tpl->data['has_text'] = count($summary->data['words']) > 0;*/
	$tpl->data['ocr_summary'] = $summary;
	$tpl->data['has_text'] = $summary != '';

	return ($template == 'virage.html'?'<div style="display: none;" id="scrollToNotLoaded"></div>':'') . $tpl->transform();
    }

    /**
     * Gets the documents summary for testing purposes
     * @param VirageDocument $article The Virage document
     * @access protected
     * @return string
     */
    protected function getDocumentSummaryTest($article) {
	$_summary = $article->documentContent . "<br/><br/>";
	$summary = '';
	/*foreach ($article->ocrMsecTime as $key => $time) {
	    $input = $time;
	    $uSec = $input % 1000;
	    $input = floor($input / 1000);

	    $seconds = $input % 60;
	    $input = floor($input / 60);

	    $minutes = $input % 60;
	    $input = floor($input / 60);

	    $summary .= $minutes . ':' . $seconds  . ' - ' . $article->ocrWords[$key] . '<br/>';
	}*/
	$_summary = $summary;

	$last_time = 0;

	foreach ($article->softSoundWords as $key => $word) {
	    $pre = '';
	    $post = '';
	    if ($article->softSoundWeights[$key] <= 25) {
		$pre = '<span style="color: red">';
		$post = '</span>';
	    }

	    $silence = preg_replace('/<[^>]*>/', '', $word) == '...';

	    //error_log($last_time . ' last time. ' . $article->softSoundMsecTime[$key] . ' : ' . $article->softSoundWeights[$key] . ' -> ' . $pre . $word . $post);
	    if ((!$silence && ($article->softSoundMsecTime[$key] - $last_time > 1500) && $last_time != 0)) {
		$_summary .= '<br/><br/>';
	    }

	    if ($word != '<SIL>' && $word != '<s>') {
		$_summary .= $pre . $word . $post . ' ';
	    }

	    if (!$silence) {
		$last_time = $article->softSoundMsecTime[$key];
	    }
	}

	return $_summary;
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$queryObj = new \VirageSearchQuery();
	$queryObj->query = $query->query;
	if ($queryObj->query == '') $query = '*';
	$queryObj->minDate = $query->start_date;
	$queryObj->maxDate = $query->end_date;
	if ($query->count != null) $queryObj->maxResults = $query->count;
	if ($query->first != null) {
	    $queryObj->start = $query->first;
	}

	$queryObj->stemming = true;
	if ($query->specific_data != null) {
	    $data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));

	    if (array_key_exists('sort_by', $data)) $queryObj->sort = $data['sort_by'];
	    if (array_key_exists('sort_order', $data)) $queryObj->sortOrder = $data['sort_order'];
	    if (array_key_exists('file', $data)) $queryObj->fileName = $data['file'];
	    if (array_key_exists('url', $data)) $queryObj->url = $data['url'];
	    if (array_key_exists('stem', $data) && $data['stem'] == 'no') $queryObj->stemming = false;
	    if (array_key_exists('no_predict', $data)) $queryObj->no_predict = true;
	}

	$results = $this->DoVirageSearch($queryObj, true, true);

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->engine = $query->engine_id;
	$result->source = $query->source_id;
	$result->from = $query->first;

	$result->count = $results->resultsFound;
	$result->results_per_page = $query->count !== null?$query->count:count($results->documents);

	$result->documents = array();

	/* @var $article VirageDocument */
	foreach ($results->documents as $article) {
	    $document = new tariqaDocument();

	    $document->title = $article->title;
	    $document->id = $query->engine_id . ':' .
		    $query->source_id . ':' .
		    urlencode($article->document_id . '&' . $article->links);
	    $document->url = $this->link('Virage::' . urlencode($article->document_id . '&' . $article->links)) . '&t=virage';
	    $document->js_link = $this->js_link('Virage::' . urlencode($article->document_id . '&' . $article->links), $article->title);

	    $document->date = strtotime($article->date);

	    $document->summary = $this->getDocumentSummary($article, TARIQA3_REL_PATH, $document->url . '&start=@time@', '', 'virage2.html');

	    $document->publisher = $article->dre_title;

	    $result->documents[] = $document;
	}


	return $result;
    }
    
    /**
     * Gets the first match in a document
     * @param VirageDocument $doc The document
     * @access protected
     * @return int
     */
    protected function getFirstMatch($doc) {
	$pattern = '/<font[^>]*>([^<]+)<\/font>/';
	preg_match($pattern, $doc->documentContent, $matches);
	if (count($matches) > 1){
	    for ($i = 0; $i < count($doc->softSoundWords); $i++){
		if (strtolower($doc->softSoundWords[$i]) == strtolower($matches[1])){
		    return $doc->softSoundMsecTime[$i];
		}
	    }
	}
	else {
	    foreach ($doc->ocrWords as $word){
		if (preg_match($pattern, $word->h->h)){
		    return $word->h->t;
		}
	    }
	}
	return 0;
    }

    /**
     * Creates a subtitle for a document
     * @param VirageDocument $document The virage document
     * @access protected
     * @return void
     */
    protected function createSubtitle($document) {
	$base_folder = $this->app_config['application']['base-folder'] . '/misc/virage-subtitles';
	if (!file_exists($base_folder . '/' . $document->document_id . '.srt')){
	    $input = $document->getSoftSoundMSecTime() . "\n" . $document->getSoftSoundWords();
	    $in = $base_folder . '/' . $document->document_id;
	    file_put_contents($in, $input);

	    $cmd = $this->app_config['application']['tools'] . '/subtitles/subtitles';
	    shell_exec($cmd . ' ' . $in . ' >' . $in . '.srt');
	    unlink($in);
	}
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$path = (defined('TARIQA3_REL_PATH')?TARIQA3_REL_PATH:'');
	if (substr($path, -1) != '/' && $path != ''){
	    $path .= '/';
	}
	$parts = explode(':', $article_id, 3);
	$translations = \tariqa3\statics::getTranslations('article');
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	$viragedoc = $this->VirageGetDocument($parts[2], true);

    if (is_array($viragedoc->softSoundWords)){
        if (count($viragedoc->softSoundWords) == 1){
            $viragedoc->softSoundWords = explode(" ", preg_replace('/<[^>]+>/', '', $viragedoc->documentContent));
        }
    }
        
	$this->createSubtitle($viragedoc);

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = $viragedoc->document_id;

	$title = $viragedoc->title;
	$title = preg_replace('/([\d]{4})\-([\d]{2})\-([\d]{2}) ([\d]{2})\-([\d]{2})\-([\d]{2})/', '\3/\2/\1 \4:\5', $title);
	$result->title = $title;

	$result->date = strtotime($viragedoc->date);
	if (strpos($viragedoc->fileName, '/') === false) $viragedoc->fileName = '/' . $viragedoc->fileName;
	$pattern = '.*/([^/\?]*)[\?]*(.*)$';
	$query_string = ereg_replace($pattern, '\2', $viragedoc->fileName);

	$file_name = $this->newsConfig['virage']['movie-url'] . '/' .
		ereg_replace($pattern, '\1', $viragedoc->fileName) .
		($query_string != ''?'?' . $query_string : '');
	$result->publisher = $viragedoc->dre_title;
	//$result->body = $viragedoc->documentContent;

	$tpl = new \MetaNull\Application\MTemplate('m');
	$tpl->loadTemplate($path . 'themes/default/modules/tariqa3/Article/virage.html');

	$start = 0;
	if (array_key_exists('start', $_GET)) {
	    $start = round($_GET['start'] / 1000);
	}

	if ($start == 0){
	    $first_match = $this->getFirstMatch($viragedoc);
	}

	preg_match('/archive\/([^\/\?]*)[\?]*.*$/', $file_name, $matches);

	/*if (count($matches) == 2) {
	    $url = 'asx/' . $start . '/' . $matches[1] . '.asx';
	}*/
	$url = $file_name;

	$d = substr($viragedoc->date, 0, 10);
	$channel = preg_replace('/^.*[\\\\|\/]hotfolders[\$]{0,1}[\\\\|\/]([^\\\\^\/]+).*$/', '\1', $viragedoc->section);
	$file_name = preg_replace('/^.*[\\\\|\/]Completed[\\\\|\/]([^\.]+).*$/', '\1', $viragedoc->section);

	$tpl->data['base_url'] = $this->app_config['application']['base'];
	$tpl->data['channel'] = $channel;
	$tpl->data['name'] = $file_name;
	$tpl->data['date'] = $d;
	$tpl->data['url'] = /*$tpl->data['base_url'] . '/' . */$url;
	$tpl->data['doc_id'] = $viragedoc->document_id;
	$tpl->data['doc_ref'] = md5($viragedoc->section);
	$tpl->data['summary'] = $this->getDocumentSummary($viragedoc, $path, '#', 'moveTime(@time@); return false;');

	$result->body = $tpl->transform();

	$tpl->loadTemplate($path . 'themes/default/modules/tariqa3/Article/virage_controls.html');
	$tpl->data = $translations;
	$tpl->data['words'] = $viragedoc->links;

	$result->additional_controls = $tpl->transform();
	if (array_key_exists('flowplayer_content', $_COOKIE)){
	    $with = $_COOKIE['flowplayer_content'];
	}
	else {
	    $with = 0;
	}
	if (array_key_exists('_s', $_GET)){
	    $with = 1;
	}
	else if (array_key_exists('_c', $_GET)){
	    $with = 2;
	}
	$result->js_onload = "setControls('{$url}', {$with}, '{$viragedoc->document_id}');";
	$result->template = 'virage';

	if ($first_match != 0){
	    $result->js_onload .= 'STARTTIME = ' . $first_match . ';';
	}

    $result->additional_main_controls = array('MATCHED_TRANSCRIPTS' => 'flowPlayerContent(1)', 'FULL_TRANSCRIPTS' => 'flowPlayerContent(2)');

	return $result;
    }

    /**
     * Gets the multi ajax search object for any page but the search page. For example country pages, home page, news wires page etc.
     * @param Flavour $flavour The flavour
     * @param array $filtering The filtering data
     * @param Query $flavour_query The flavour current query
     * @access public
     * @return multiAjaxSearch
     */
    public function newsSection($flavour, $filtering, $flavour_query) {
	$search = new \tariqa3\multiAjaxSearch($filtering['query'], $flavour_query->source_id, $this->app_config['application']['service_url'],
	    'search_' . $flavour->flavour_id, true, $filtering['start_date'], $filtering['end_date'], 0, $this->newsConfig['search']['default']['results-per-page'],
	    \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$search->noNewTab();
	$search->setNavigationId('navigation_' . $flavour->flavour_id);
	$search->setResultId('news_' . $flavour->flavour_id);

	return $search;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null) {
	$defaults = $this->newsConfig['default'];
	$search = new \tariqa3\multiAjaxSearch($query, $defaults['virage']['source_id'], $this->app_config['application']['service_url'],
		'searchResult', false, ($startDate == null?null:$startDate->getTimestamp() + $startDate->getOffset()),
		($endDate == null?null:$endDate->getTimestamp() + $endDate->getOffset()), $from, $count, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);
	$data = 'sort_by=' . $_POST['sort_by'] . '&' . /*. 'sort_order=' . ($_POST['sort_by'] == 'Date'?'asc':'desc');*/
        'sort_order=' . $_POST['sort_order'];

	$channels = self::listChannels();

	$channel = '';
	$channels_txt = '';
	foreach ($channels as $key => $value){
	    if (array_key_exists('virage_channel_' . $key, $_POST)){
		$channels_txt .= ($channels_txt == ''?'':',') . $key;
	    }
	}
	$data .= '&file=' . rawurlencode($channels_txt);

	if (array_key_exists('virage_exact_results', $_POST)){
	    $data .= '&no_predict=';
	}

	$search->setSpecificData(rawurlencode($data));

	return $search;
    }

    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()) {
	return '';
    }
}
}
?>