<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3\search{
/**
 * Base class for fetching the news results from the Yahoo engine
 * @author Cosmin Popescu
 *
 */
class YahooNewsEngine extends searchEngine {

    /**
     * Constructs the object
     * @param array $newsConfig The news configuration array
     * @access public
     * @return void
     */
    public function __construct($newsConfig) {
	parent::__construct($newsConfig);
    }

    /**
     * Fetches a list of articles
     * @param newsQuery $query The query
     * @access public
     * @return tariqaSearchResultSet
     */
    public function listArticles($query) {
	$queryObj = new \YahooQuery();
	$queryObj->query = $query->query;

	if ($query->first != null){
	    $queryObj->start = $query->first;
	}

	if ($query->count != null){
	    $queryObj->results = $query->count;
	}

	if ($query->specific_data != null) {
	    $data = \tariqa3\statics::post2array(\MetaNull\Tools\mTools::rawurldecode($query->specific_data));
	    foreach ($data as $key => $value) {
		if ($key == 'type'){
		    $queryObj->type = $value;
		}
		else if ($key == 'sort'){
		    $queryObj->sort = $value;
		}
		else if ($key == 'language'){
		    $queryObj->language = $value;
		}
	    }
	}

	/* @var $results YahooResultSet */
	$results = \tariqa3\statics::$tariqaClient->yahooSearch(\tariqa3\statics::$tariqaToken, $queryObj);

	$result = new tariqaSearchResultSet();

	$result->query = $query->query;
	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->engine_name = $engine->name;
	$result->engine = $query->engine_id;
	$result->source = $query->source_id;
	$result->from = $results->firstResultPosition;

	$engine = \tariqa3\statics::getEngine($query->engine_id);
	$result->logo = $engine->logo_url;
	$result->provider_url = $engine->doc_url;

	$result->count = $results->totalResultsAvailable;
	$result->results_per_page = $results->totalResultsReturned;

	$result->documents = array();

	/* @var $article YahooResult */
	foreach ($results->results as $article) {
	    $document = new tariqaDocument();

	    $document->title = $article->title;
	    $document->id = $query->engine_id . ':' .
		    $query->source_id . ':' .
		    urlencode($article->url);
	    $document->url = $this->link($query->engine_id . '::' . urlencode($article->url));
	    $document->js_link = $this->js_link(
		    $query->engine_id . '::' . urlencode($article->url),
		    $article->title
	    );

	    $document->date = $article->publishDate;

	    $document->summary = $article->summary;

	    $document->publisher = $article->newsSource;

	    $result->documents[] = $document;
	}

	return $result;
    }

    /**
     * Gets a specific article
     * @param string $article_id The article identifier
     * @access public
     * @abstract
     * @return tariqaFullDocument
     */
    public function getArticle($article_id) {
	$parts = explode(':', $article_id, 3);
	if (count($parts) != 3) {
	    throw new \Exception('Document identifier not well formed');
	}

	$document = \tariqa3\statics::$tariqaClient->YahooGetDocument(
		\tariqa3\statics::$tariqaToken, \MetaNull\Tools\mTools::rawurldecode($parts[2])
	);

	$result = new tariqaFullDocument();
	$result->id = $article_id;
	$result->engine = $parts[0];
	$result->source = $parts[1];
	$result->document_id = $parts[2];
	$result->title = '';

	$result->date = 0;
	$result->publisher = '';

	$base64 = base64_decode($document);
	
	$result->body = ($base64 !== false?$base64:$document);

	return $result;
    }

    /**
     * Gets the multi ajax search object for any page but the search page. For example country pages, home page, news wires page etc.
     * @param Flavour $flavour The flavour
     * @param array $filtering The filtering data
     * @param Query $flavour_query The flavour current query
     * @access public
     * @return multiAjaxSearch
     */
    public function newsSection($flavour, $filtering, $flavour_query) {
	$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$search = new \tariqa3\multiAjaxSearch($filtering['query'], $flavour_query->source_id, $app_config['application']['service_url'],
	    'search_' . $flavour->flavour_id, true, $filtering['start_date'], $filtering['end_date'], 0, $this->newsConfig['search']['default']['results-per-page'],
	    \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$search->noNewTab();
	$search->setNavigationId('navigation_' . $flavour->flavour_id);
	$search->setResultId('news_' . $flavour->flavour_id);

	return $search;
    }

    /**
     * Gets the multi ajax search object
     * @param string $query The query string
     * @param int $from The first result to display
     * @param int $count The number of results to display
     * @param DateTime $startDate The start date [OPTIONAL]
     * @param DateTime $endDate The end date [OPTIONAL]
     * @access public
     * @return multiAjaxSearch
     */
    public function multiAjaxSearch($query, $from, $count, $startDate = null, $endDate = null){
	/*$app_config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
	$defaults = $this->newsConfig['default'];

	if ($_POST['google_exact_words'] != '') {
	    $query .= ' "' . $_POST['google_exact_words'] . '" ';
	}
	if ($_POST['google_or_words1'] != '') {
	    $query .= ($query == ''?'':' OR ') . $_POST['google_or_words1'];
	}
	if ($_POST['google_or_words2'] != '') {
	    $query .= ($query == ''?'':' OR ') . $_POST['google_or_words2'];
	}
	if ($_POST['google_or_words3'] != '') {
	    $query .= ($query == ''?'':' OR ') . $_POST['google_or_words3'];
	}
	if ($_POST['google_no_words'] != '') {
	    $words = explode(' ', $_POST['google_no_words']);
	    foreach ($words as $word) {
		$query .= ' -' . $word;
	    }
	}

	$startDate = null;
	$endDate = null;

	$search = new \tariqa3\multiAjaxSearch($query, $defaults[strtolower($_POST['engine'])]['source_id'], $app_config['application']['service_url'],
	    'searchResult', false, null, null, null, null, \tariqa3\multiAjaxSearch::ORIGINAL_SYNTAX);

	$source = \tariqa3\statics::getSource($defaults[strtolower($_POST['engine'])]['source_id']);

	if ($source->source_data != null){
	    $search->setSpecificData($source->source_data);
	}

	return $search;*/
  }

    /**
     * Gets the POST data used for saving a search in the briefcase
     * @param string $query_txt The query string text
     * @param Query $query The query
     * @param int $start_date The start date (unix timestamp) [OPTIONAL]
     * @param int $end_date The end date (unix timestamp) [OPTIONAL]
     * @param array $additional_parameters Additional parameters [OPTIONAL]
     * @access public
     * @return string
     */
    public function getSavePost($query_txt, $query, $start_date = null, $end_date = null, $additional_parameters = array()){
	/*$c = null;
	if ($start_date == null || $end_date == null){
	    $c = \MetaNull\News\unifiedQuerySyntax::getDatesCondition(rawurldecode($query_txt));
	}

	if ($c == null || !array_key_exists('string', $c)) {
	    $query_txt .= ' ' . $query->time_range;
	    $start_date = '';
	    $end_date = '';
	}

	$selected = ($query->source->engine_id == 'GoogleWeb' || $query->source->engine_id == 'Google'?2:
		($query->source->engine_id == 'GoogleNews'?3:
		($query->source->engine_id == 'GoogleBlogs'?4:
		($query->source->engine_id == 'GoogleImages'?5:-1))));
	$engine = $query->source->engine_id;
	if ($engine == 'Google') $engine = 'GoogleWeb';
	$post_data = "selected={$selected}&engine={$engine}&query={$query_txt}&" .
		"&results_per_page={$this->newsConfig['search']['default']['results-per-page']}";

	return $post_data;*/
    }
}
}
?>