<?php

/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 * 	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 * 	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

/**
 * Tarîqa 3.0 - Core components
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 *
 * @license http://ec.europa.eu/idabc/eupl
 */

namespace tariqa3 {

    //define('USE_SOAP', '1'); //If you uncomment this, the application will use again the SOAP. If you want to use the SOAP, after uncommenting
							   // this define statement, please delete the tariqaClientExpire_* and tariqaToken_* files from 
							   // the cache folder. 

//PEAR::Config
require_once( 'Config.php' );

/**
 * Class defining the common functions that will be used without instantiating a class
 * @author Cosmin Popescu, Pascal Havelange
 */
class statics {

    /**
     * Compose an URL from a script and a list of parameters
     * @param string $script The script name
     * @param mixed $params The list of parameters (as a string or as an associative array)[OPTIONAL]
     * @param bool $urlencode Set to true to URL encode arguments. Note: it will be ignored unless $params is an associative array of arguments [OPTIONAL]
     * @access public
     * @static
     * @return string
     */
    public static function URL($script, $parameters = null, $urlencode = false) {
	if (is_null($parameters)) {
	    return $script;
	}
	if (is_string($parameters)) {
	    return $script . '?' . $parameters;
	}
	if (is_array($parameters)) {
	    $url = $script . '?';
	    foreach ($parameters as $k => $v) {
		$url .= $k . '=' . rawurlencode($v) . '&';
	    }
	    return $url;
	}
	throw new \InvalidArgumentException('$parameters should be null, a string or an associative array!');
    }

    /**
     * The SOAP client
     * @var TariqaClient $tariqaClient
     * @access public
     * @static
     */
    public static $tariqaClient = null;
    /**
     * The tariqa client token
     * @var string
     * @access public
     * @static
     */
    public static $tariqaToken = null;
    /**
     * The tariqa client expiration date (UNIX timestamp)
     * @var int
     * @access public
     * @static
     */
    public static $tariqaClientExpire = null;
    /**
     * The tariqa authentication client
     * @var TariqaAuthenticationClient
     * @access private
     * @static
     */
    private static $tariqaAuthClient = null;
    /**
     * If true, the tariqaClient has allready been loaded
     * @var boolean
     * @access private
     * @static
     */
    private static $tariqaClientLoaded = false;

    /**
     * Is the tariqa client logged in?
     * @param array $soapConfig The soap configuration array
     * @access public
     * @static
     * @return boolean
     */
    public static function tariqaClientLoggedIn($soapConfig) {
	// Disable WSDL cache while developping
	if (self::$tariqaAuthClient == null) {
	    $client_config = array("cache_wsdl" => false);
	    self::$tariqaAuthClient = new \tariqa3\SOAP\TariqaAuthenticationClient($client_config, $soapConfig);
	}
	return self::$tariqaAuthClient->isLoggedIn(self::$tariqaToken);
    }

    /**
     * Logs in the tariqa client
     * @param tariqaUser $user The ECAS user
     * @param array $appConfig The main application configuration array
     * @param array $soapConfig The SOAP configuration array
     * @access public
     * @static
     * @return void
     */
    public static function tariqaClientLogIn($user, $appConfig, $soapConfig) {
        if (self::$tariqaAuthClient == null) {
            $client_config = array("cache_wsdl" => false);
            if (
                array_key_exists('proxy', $appConfig) &&
                array_key_exists('enable', $appConfig['proxy']) &&
                1 == $appConfig['proxy']['enable']
                ) {
                $client_config['proxy_host'] = $appConfig['proxy']['host'];
                $client_config['proxy_port'] = (int) $appConfig['proxy']['port'];
                $client_config['proxy_login'] = $appConfig['proxy']['user'];
                $client_config['proxy_password'] = $appConfig['proxy']['password'];
            }

            if (defined('USE_SOAP')){
                self::$tariqaAuthClient = new \tariqa3\SOAP\TariqaAuthenticationClient($client_config, $soapConfig);
            }
            else {
                self::$tariqaAuthClient = new \tariqa3\SOAP\TariqaAuthenticationClientLocal($client_config, $soapConfig);
            }
        }
        $resp = new \AuthenticationResponse();
        $resp = self::$tariqaAuthClient->Login($soapConfig["soap-auth"]["users"][$user->get_access_level()]['user'], $soapConfig["soap-auth"]['users'][$user->get_access_level()]["password"]);
        self::$tariqaToken = $resp->identificationToken;
        self::$tariqaClientExpire = $resp->expirationDate;

        \MetaNull\Tools\mCache::saveVariable(self::$tariqaToken, 'tariqaToken_' . $user->get_access_level());
        \MetaNull\Tools\mCache::saveVariable(self::$tariqaClientExpire, 'tariqaClientExpire_' . $user->get_access_level());
    }

    /**
     * Loads the tariqa client
     * @param tariqaUser $user The ECAS user
     * @param array $appConfig The main application configuration array
     * @param array $soapConfig The SOAP configuration array
     * @access public
     * @static
     * @return void
     */
    public static function loadTariqaClient($user, $appConfig = null, $soapConfig = null) {
        if (!self::$tariqaClientLoaded) {
            try {
                $loggedIn = false;

                self::$tariqaToken = \MetaNull\Tools\mCache::loadVariable('tariqaToken_' . $user->get_access_level());
                self::$tariqaClientExpire = \MetaNull\Tools\mCache::loadVariable('tariqaClientExpire_' . $user->get_access_level());

                if (self::$tariqaToken != null && self::$tariqaClientExpire != null) {
                    if (self::$tariqaClientExpire >= date("U")) {
                        $loggedIn = true;
                    }
                }
                if (!$loggedIn) {
                    if ($appConfig == null) {
                        $appConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_MAIN_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'app_config');
                    }
                    if ($soapConfig == null) {
                        $soapConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_SOAP_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'soap_config');
                    }
                    self::tariqaClientLogIn($user, $appConfig, $soapConfig);
                }

                $client_config = array("cache_wsdl" => false);

                if ($appConfig == null)
                    $appConfig = array();
                if ($soapConfig == null) {
                    $soapConfig = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_SOAP_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'soap_config');
                }

                if (
                    array_key_exists('proxy', $appConfig) &&
                    array_key_exists('enable', $appConfig['proxy']) &&
                    1 == $appConfig['proxy']['enable']
                    ) {
                    $client_config['proxy_host'] = $appConfig['proxy']['host'];
                    $client_config['proxy_port'] = (int) $appConfig['proxy']['port'];
                    $client_config['proxy_login'] = $appConfig['proxy']['user'];
                    $client_config['proxy_password'] = $appConfig['proxy']['password'];
                }

                if (defined('USE_SOAP')){
                    $client = new \tariqa3\SOAP\TariqaClient($client_config, $soapConfig, $user);
                }
                else {
                    $client = new \tariqa3\SOAP\TariqaClientLocal($client_config, $soapConfig, $user);
                }
                

                self::$tariqaClient = $client;
            } catch (\Exception $e) {
                throw new \Exception("SOAP Authentication error. Please see the log for details", E_ERROR);
            }

            self::$tariqaClientLoaded = true;
        }
    }

    /**
     * Initializes the connection to the database
     * @param array $config The database section of the config array
     * @access public
     * @static
     * @return \MetaNull\Tools\mMysql
     */
    public static function open_db_connection($config) {
	//Creates a connection to the database
	return new \MetaNull\Tools\mMysql($config['host'], $config['user'], $config['password'],
		$config['database'], $config['port'], $config['charset'], $config['autocommit']);
    }

    /**
     * Gets the user preferences from the database
     * @param tariqaUser $user The user
     * @param mMysql $db The database connection to load the preferences from
     * @access public
     * @static
     * @return void
     */
    public static function load_user_prefs($user, $db) {
	$user_id = $db->real_escape_string($user->user_id);
	$sql = "select * from user_preferences where user_id = '{$user_id}'";

	$query = $db->mQuery($sql);
	while ($row = $query->fetch_assoc()) {
	    $user->set_preference($row["key"], $row["data"], false);
	}
    }

    /**
     * Gets a country
     * @param string $country_id The country ISO2 code
     * @param boolean $get_maps If true, also get the ReliefWeb and GlobalAtlas maps [OPTIONAL]
     * @param boolean $get_wiki If true, also get the Wikipedia country profile [OPTIONAL]
     * @access public
     * @static
     * @return Country
     */
    public static function get_country($country_id, $get_maps = false, $get_wiki = false) {
	$country = \MetaNull\Tools\mCache::loadVariable('countries/' . $country_id);
	if ($country == null) {
	    $country = statics::$tariqaClient->getCountry(self::$tariqaToken, $country_id, null, null, null, null, null, null, null, null, null, null, $get_maps, false);
	    //\MetaNull\Tools\mDump::dumpVariable($country);
	    if ($country != null) {
		\MetaNull\Tools\mCache::saveVariable($country, 'countries/' . $country_id);
	    }
	}

	return $country;
    }

    /**
     * Gets the wikidata of a country
     * @param string $country_id The country identifier
     * @access public
     * @static
     * @return \WikipediaCountryProfile
     */
    public static function get_wiki_data($country_id) {
	$country = statics::get_country($_GET['country_id']);
	$data = \MetaNull\Tools\mCache::loadVariable('countries/wiki_' . $country_id);
	if ($data == null) {
	    $data = statics::$tariqaClient->GetWikipediaCountryProfile(statics::$tariqaToken, $country);
	    //\MetaNull\Tools\mDump::dumpVariable($country);
	    if ($data != null) {
		\MetaNull\Tools\mCache::saveVariable($data, 'countries/wiki_' . $country_id);
	    }
	}

	return $data;
    }

    /**
     * Gets a theme
     * @param int $theme_id The theme identifier
     * @access public
     * @static
     * @return Theme
     */
    public static function get_theme($theme_id) {
	$theme = \MetaNull\Tools\mCache::loadVariable('themes/' . $theme_id);
	if ($theme == null) {
	    $theme = self::$tariqaClient->GetTheme(self::$tariqaToken, $theme_id);
	    if ($theme != null) {
		\MetaNull\Tools\mCache::saveVariable($theme, 'themes/' . $theme_id);
	    }
	}

	return $theme;
    }

    /**
     * Loads the list of countries
     * @param int $continent_id Restricts the list to a given Continent [OPTIONAL]
     * @param boolean $eu_members_only If true, restricts the list to EU countries, if False, restricts it to NON-EU members [OPTIONAL]
     * @param boolean $official_only It true, restricts the list to official countries, if False, restricts it to non official countries [OPTIONAL]
     * @param int $region_id The official region identifier [OPTIONAL]
     * @param string[] $country_ids A list of countries ids [OPTIONAL]
     * @access public
     * @static
     * @return Country[]
     */
    public static function listCountries($continent_id = null, $eu_members_only = null, $official_only = null, $region_id = null, $country_ids = null) {
	$cache_name = "countries/list";
	$s = '';
	$s = '_' . ($continent_id == null ? 'null' : $continent_id);
	$s .= '_' . ($region_id == null ? 'null' : $region_id);
	$s .= '_' . ($eu_members_only == null ? 'null' : ($eu_members_only ? 1 : 0));
	$s .= '_' . ($official_only == null ? 'null' : ($official_only ? 1 : 0));

	if ($country_ids != null) {
	    $s .= '_' . \MetaNull\Tools\mDump::dumpVariable($country_ids, true);
	}

	$cache_name .= md5($s);

	$countries = \MetaNull\Tools\mCache::loadVariable($cache_name);
	if ($countries == null) {
	    $countries = self::$tariqaClient->listCountries(self::$tariqaToken, $continent_id, $eu_members_only, $official_only, $region_id, $country_ids, true);
	    \MetaNull\Tools\mCache::saveVariable($countries, $cache_name);
	}

	return $countries;
    }

    /**
     * Lists the themes
     * @param int[] $ids A list of theme ids [OPTIONAL]
     * @access public
     * @static
     * @return Theme[]
     */
    public static function listThemes($ids = null) {
	$cache_name = 'themes/list';
	if ($ids != null) {
	    $cache_name .= md5(\MetaNull\Tools\mDump::dumpVariable($ids, true));
	}

	$themes = \MetaNull\Tools\mCache::loadVariable($cache_name);

	if ($themes == null) {
	    $themes = self::$tariqaClient->ListThemes(self::$tariqaToken, false, $ids);
	    \MetaNull\Tools\mCache::saveVariable($themes, $cache_name);
	}

	return $themes;
    }

    /**
     * Loads the list of continents
     * @access public
     * @static
     * @return Continent[]
     */
    public static function listContinents() {
	$continents = \MetaNull\Tools\mCache::loadVariable('countries/continents');
	if ($continents == null) {
	    $continents = self::$tariqaClient->listContinents(self::$tariqaToken, true);
	    \MetaNull\Tools\mCache::saveVariable($continents, 'countries/continents');
	}

	return $continents;
    }

    /**
     * Loads the list of regions
     * @param Continent $continenthe continent [OPTIONAL]
     * @access public
     * @static
     * @return OfficialRegion[]
     */
    public static function listOfficialRegions($continent = null) {
	$cache_name = "countries/regions";
	if ($continent != null)
	    $cache_name .= '_' . str_replace(' ', '_', strtolower($continent->name));

	$regions = \MetaNull\Tools\mCache::loadVariable($cache_name);
	if ($regions == null) {
	    $regions = self::$tariqaClient->listOfficialRegions(self::$tariqaToken, ($continent == null ? null : $continent->continent_id));
	    \MetaNull\Tools\mCache::saveVariable($regions, $cache_name);
	}

	return $regions;
    }

    /**
     * Loads the Source and the Engine into a Query object if they are not loaded
     * @param Query $query The query
     * @access public
     * @static
     * @return void
     */
    public static function loadSourceEngine($query) {
	if ($query->source == null) {
	    $source = self::getSource($query->source_id);
	    $query->source = $source;
	}

	if ($query->engine == null) {
	    $engine = self::getEngine($query->source->engine_id);
	    $query->engine = $engine;
	}
    }

    /**
     * Loads a news query
     * @param int $query_id The query identifier
     * @access public
     * @return Query
     */
    public static function getQuery($query_id) {
	$query = \MetaNull\Tools\mCache::loadVariable('queries/' . $query_id);
	if ($query == null) {
	    try {
		$query = statics::$tariqaClient->GetQuery(statics::$tariqaToken, $query_id, true, true);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading query: ' . $query_id);
	    }

	    if ($query != null){
		self::loadSourceEngine($query);
		\MetaNull\Tools\mCache::saveVariable($query, 'queries/' . $query_id);
	    }
	}

	return $query;
    }

    /**
     * List the queries
     * @param string $access The access level of the current user
     * @param int $source_id The source identifier of the queries to retrieve [OPTIONAL]
     * @param boolean $weblogs_data If true, then get also the weblogs data [OPTIONAL]
     * @access public
     * @return Query[]
     */
    public static function listQueries($access, $source_id, $weblogs_data = false) {
	$queries = \MetaNull\Tools\mCache::loadVariable('queries/list_source_' . $access . $source_id);
	if ($queries == null) {
	    try {
		$queries = statics::$tariqaClient->ListQueries(statics::$tariqaToken, $source_id, $weblogs_data);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading query: ' . $source_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($queries, 'queries/list_source_' . $access . $source_id);
	}

	return $queries;
    }

    /**
     * Retrieves a theme topic
     * @param int $topic_id  The topic identifier
     * @param string $access The current user access level
     * @access public
     * @static
     * @return ThemeTopic
     */
    public static function getThemeTopic($topic_id, $access) {
	$topic = \MetaNull\Tools\mCache::loadVariable('themes/topic_' . $topic_id . $access);
	if ($topic == null) {
	    try {
		$topic = statics::$tariqaClient->GetThemeTopic(statics::$tariqaToken, $topic_id, true);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading topic: ' . $topic_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($topic, 'themes/topic_' . $topic_id . $access);
	}

	return $topic;
    }

    /**
     * Loads a query flavour
     * @param int $flavour_id The flavour identifier
     * @access public
     * @static
     * @return Flavour
     */
    public static function getFlavour($flavour_id) {
	$flavour = \MetaNull\Tools\mCache::loadVariable('flavours/' . $flavour_id);
	if ($flavour == null) {
	    try {
		$flavour = statics::$tariqaClient->GetFlavour(statics::$tariqaToken, $flavour_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading flavour: ' . $flavour_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($flavour, 'flavours/' . $flavour_id);
	}

	return $flavour;
    }

    /**
     * Loads a news source
     * @param int $source_id The source identifier
     * @access public
     * @return Source
     */
    public static function getSource($source_id) {
	$source = \MetaNull\Tools\mCache::loadVariable('sources/' . $source_id);
	if ($source == null) {
	    try {
		$source = statics::$tariqaClient->GetSource(statics::$tariqaToken, $source_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading source: ' . $source_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($source, 'sources/' . $source_id);
	}

	return $source;
    }

    /**
     * Lists the sources for the advanced search
     * @access public
     * @static
     * @return AdvancedSearch[]
     */
    public static function getAdvSearchSources() {
	$sources = \MetaNull\Tools\mCache::loadVariable('sources/adv_search');
	if ($sources == null) {
	    try {
		//$sources = statics::$tariqaClient->ListAdvancedSearchSources(statics::$tariqaToken);
		$sources = statics::$tariqaClient->ListFullSearchSources(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the advanced search sources');
	    }

	    \MetaNull\Tools\mCache::saveVariable($sources, 'sources/adv_search');
	}

	return $sources;
    }

    /**
     * Lists the quick search sources
     * @param string $access The access level of the current user
     * @access public
     * @static
     * @return QuickSearchSource[]
     */
    public static function ListQuickSearchSources($access) {
	$sources = \MetaNull\Tools\mCache::loadVariable('sources/quick_search' . $access);
	if ($sources == null) {
	    try {
		$sources = statics::$tariqaClient->ListQuickSearchSources(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the advanced search sources');
	    }

	    \MetaNull\Tools\mCache::saveVariable($sources, 'sources/quick_search' . $access);
	}

	return $sources;
    }

    /**
     * Loads a news engine
     * @param string $engine_id The engine identifier
     * @access public
     * @return Engine
     */
    public static function getEngine($engine_id) {
	$engine = \MetaNull\Tools\mCache::loadVariable('engines/' . $engine_id);
	$engine = null;
	if ($engine == null) {
	    try {
		$engine = statics::$tariqaClient->GetEngine(statics::$tariqaToken, $engine_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading engine: ' . $engine_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($engine, 'engines/' . $engine_id);
	}

	return $engine;
    }

    /**
     * Loads a RSS feed
     * @param int $feed_id The feed identifier
     * @access public
     * @return RSS_feed
     */
    public static function getAggregatedFeed($feed_id) {
	$feed = \MetaNull\Tools\mCache::loadVariable('feeds/' . $feed_id);
	if ($feed == null) {
	    try {
		$feed = statics::$tariqaClient->GetAggregatedRSSFeed(statics::$tariqaToken, $feed_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading feed: ' . $feed_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($feed, 'feeds/' . $feed_id);
	}

	return $feed;
    }

    /**
     * Adds a '/' at the end of a path if it is the case
     * @param string $path The path
     * @access public
     * @static
     * @return string
     */
    public static function path($path) {
	if (substr($path, -1) != '/' && substr($path, -1) != "\\")
	    return $path . '/';
	return $path;
    }

    /**
     * Gets the list of flavours
     * @access public
     * @static
     * @return Flavour[]
     */
    public static function listFlavours() {
	$flavours = \MetaNull\Tools\mCache::loadVariable('flavours/list');
	if ($flavours == null) {
	    try {
		$flavours = statics::$tariqaClient->ListFlavours(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of flavours');
	    }

	    \MetaNull\Tools\mCache::saveVariable($flavours, 'flavours/list');
	}

	return $flavours;
    }

    /**
     * Gets the list of queries for a given theme
     * @param int $theme_id The theme identifier
     * @param string $access The current user access level
     * @access public
     * @static
     * @return Query[]
     */
    public static function listThemeQueries($theme_id, $access) {
	$queries = \MetaNull\Tools\mCache::loadVariable('queries/list_' . $theme_id . $access);
	if ($queries == null) {
	    try {
		$queries = statics::$tariqaClient->GetThemeQueries(statics::$tariqaToken, $theme_id);
	    } catch (\Exception $e) {
		error_log(\MetaNull\Tools\mDump::dumpVariable($e, true));
		throw new \Exception('Error loading the list of queries for theme ' . $theme_id);
	    }

	    foreach ($queries as $query) {
		self::loadSourceEngine($query);
	    }

	    \MetaNull\Tools\mCache::saveVariable($queries, 'queries/list_' . $theme_id . $access);
	}

	return $queries;
    }

    /**
     * Gets the list of queries for a given country
     * @param string|Country $country The ISO2 code of the country or the Country object
     * @param string $access The current user access level
     * @access public
     * @static
     * @return Query[]
     */
    public static function listCountryQueries($country, $access) {
	/* @var $country Country */
	if (!is_a($country, 'Country')) {
	    $country = self::get_country($country);
	}
	$queries = \MetaNull\Tools\mCache::loadVariable('queries/list_' . $country->code_iso2 . $access);
	if ($queries == null) {
	    try {
		$queries = statics::$tariqaClient->GetCountryQueries(statics::$tariqaToken, $country);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of queries for ' . $country->name);
	    }

	    \MetaNull\Tools\mCache::saveVariable($queries, 'queries/list_' . $country->code_iso2 . $access);
	}
	return $queries;
    }

    /**
     * Converts a POST string (like 'var1=value1&var2=value2') to a PHP array
     * @param string $s The post string
     * @access public
     * @static
     * @return array
     */
    public static function post2array($s) {
	if ($s == '')
	    return array();
	$result = array();
	$datas = explode('&', $s);
	foreach ($datas as $data) {
	    $pair = explode('=', $data, 2);
	    $key = $pair[0];
	    $is_array = false;
	    if (preg_match('/[^\[]*\[\]$/', $key)) {
		$is_array = true;
		$key = substr($key, 0, strlen($key) - 2);
	    }
	    if (count($pair) == 1) {
		if (!$is_array) {
		    $result[$key] = null;
		}
	    } else {
		if (!$is_array) {
		    $result[$key] = $pair[1];
		} else {
		    $result[$key][] = $pair[1];
		}
	    }
	}

	return $result;
    }

    /**
     * List the users that can edit the text for a given theme
     * @param int $theme_id The theme identifier
     * @access public
     * @static
     * @return ThemeUsers
     */
    public static function ListThemeUsers($theme_id) {
	$users = \MetaNull\Tools\mCache::loadVariable('themes/users_' . $theme_id);
	if ($users == null) {
	    try {
		$users = statics::$tariqaClient->ListThemeUsers(statics::$tariqaToken, $theme_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of users for theme ' . $theme_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($users, 'themes/users_' . $theme_id);
	}

	return $users;
    }

    /**
     * Gets the list of theme topics for a given theme
     * @param int $theme_id The theme identifier
     * @param string $access The access level of current user
     * @access public
     * @static
     * @return ThemeTopic[]
     */
    public static function ListThemeTopics($theme_id, $access) {
	$topics = \MetaNull\Tools\mCache::loadVariable('themes/topics_' . $theme_id . $access);
	if ($topics == null) {
	    try {
		$topics = statics::$tariqaClient->ListThemeTopics(self::$tariqaToken, $theme_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of topics for theme ' . $theme_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($topics, 'themes/topics_' . $theme_id . $access);
	}

	return $topics;
    }

    /**
     * Gets the list of TV categories
     * @access public
     * @static
     * @return TariqaTVChannelCategory[]
     */
    public static function ListTVCategories() {
	$categories = \MetaNull\Tools\mCache::loadVariable('tv_categories');
	if ($categories == null) {
	    try {
		$categories = statics::$tariqaClient->ListTVChannelsCategories(statics::$tariqaToken, true);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of tv categories' . $theme_id);
	    }

	    \MetaNull\Tools\mCache::saveVariable($categories, 'tv_categories');
	}

	return $categories;
    }

    /**
     * Gets the list of hotspots
     * @access public
     * @static
     * @return string[]
     */
    public static function ListHotspots() {
	$hotspots = \MetaNull\Tools\mCache::loadVariable('countries/hotspots');
	if ($hotspots != null) {
	    $fullpath = \MetaNull\Tools\mCache::getVariableFileName('countries/hotspots');
	    if (time() - @filemtime($fullpath) > 60 * 5) {
		$hotspots = null;
	    }
	}
	if ($hotspots == null) {
	    try {
		$hotspots = statics::$tariqaClient->ListHotSpots(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of hotspots');
	    }

	    \MetaNull\Tools\mCache::saveVariable($hotspots, 'countries/hotspots');
	}

	return $hotspots;
    }

    /**
     * The current feed id to filter
     * @var int
     * @access private static
     * */
    private static $filtered_feed_id;

    /**
     * Filters the feeds list
     * @param RSS_feed $feed The feed to filter
     * @access private static
     * @return boolean
     * */
    private static function filterFeeds($feed) {
	return $feed->feed_id == self::$filtered_feed_id;
    }

    /**
     * Gets the icon of a given query
     * @param Query $query The query
     * @param array $config The configuration array
     * @access public static
     * @return string
     */
    public static function getQueryIcon($query, $config) {
	if ($query->engine == null) {
	    if ($query->source != null) {
		$query->engine = self::getEngine($query->source->engine_id);
	    } else if ($query->source_id != null) {
		$query->source = self::getSource($query->source_id);
		if ($query->source != null) {
		    $query->engine = self::getEngine($query->source->engine_id);
		}
	    }
	}
	if ($query->engine != null) {
	    $icon = $query->engine->icon_url;
	    return $icon;
	}

	return $config['queries']['no-icon'];
    }

    /**
     * Gets the list of all feeds from the server
     * @access public static
     * @return RSS_feed[]
     */
    public static function getAllAggregatedRSSFeed() {
	$feeds = \MetaNull\Tools\mCache::loadVariable('feeds/list');
	if ($feeds == null) {
	    try {
		$feeds = statics::$tariqaClient->GetAllAggregatedRSSFeed(self::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of feeds');
	    }

	    \MetaNull\Tools\mCache::saveVariable($feeds, 'feeds/list');
	}

	return $feeds;
    }

    /**
     * Loads the LexisNexis sources
     * @param string $folder_id The folder identifier
     * @access public
     * @static
     * @return LexisNexisBrowseSourcesResponse
     */
    public static function browseLexisNexisSources($folder_id) {
	$sources = \MetaNull\Tools\mCache::loadVariable('sources/ln_' . ($folder_id == null ? 'x' : $folder_id));
	if ($sources == null) {
	    try {
		$sources = statics::$tariqaClient->LexisNexisBrowseSources(self::$tariqaToken, $folder_id);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the lexis nexis sources for the ' . $folder_id . ' folder');
	    }

	    \MetaNull\Tools\mCache::saveVariable($sources, 'sources/ln_' . ($folder_id == null ? 'x' : $folder_id));
	}

	return $sources;
    }

    /**
     * Gets the home page tabs
     * @param string $access The current user access level
     * @access public
     * @static
     * @return Flavour[]
     * */
    public static function getHomePageFlavours($access) {
	$flavours = \MetaNull\Tools\mCache::loadVariable('flavours/homepage' . $access);
	if ($flavours == null) {
	    try {
		$flavours = statics::$tariqaClient->GetHomePageFlavours(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the home page flavours');
	    }

	    \MetaNull\Tools\mCache::saveVariable($flavours, 'flavours/homepage' . $access);
	}
	
	return $flavours;
    }

    /**
     * Gets the home page queries
     * @param string $access The current user access level
     * @param Flavour $flavour The flavour of the queries [OPTIONAL]
     * @param array $translationTable The translation table [OPTIONAL]
     * @access public static
     * @return Query[]
     */
    public static function getHomePageQueries($access, $flavour = null, $translationTable = null) {
	$queries = \MetaNull\Tools\mCache::loadVariable('queries/homepage' . $access);
	if ($queries == null) {
	    try {
		$qs = statics::$tariqaClient->GetHomepageQueries(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the home page queries');
	    }

	    $queries = array();

	    /* @var $query Query */
	    foreach ($qs as $query) {
		$query->block_label = $query->block_description;
		$queries[] = $query;
	    }
	    
	    \MetaNull\Tools\mCache::saveVariable($queries, 'queries/homepage' . $access);
	}

	return $queries;
    }

    /**
     * Gets a continent
     * @param int $id The continent identifier
     * @access public
     * @static
     * @return Continent
     */
    public static function getContinent($id) {
	$continent = \MetaNull\Tools\mCache::loadVariable('countries/continent_' . $id);
	if ($continent == null) {
	    $continent = self::$tariqaClient->getContinent(self::$tariqaToken, $id);
	    \MetaNull\Tools\mCache::saveVariable($continent, 'countries/continent_' . $id);
	}

	return $continent;
    }

    /**
     * Returns true if the browser is IE
     * @access public
     * @static
     * @return boolean
     * */
    public static function _isIE() {
	return \strpos($_SERVER['HTTP_USER_AGENT'], "MSIE") !== false;
    }

    /**
     * Gets the lists of OXAN countries
     * @access public
     * @return MultiPair
     */
    public static function listOxanCountries() {
	$countries = \MetaNull\Tools\mCache::loadVariable('countries/oxan');
	if ($countries == null) {
	    try {
		$countries = statics::$tariqaClient->oxanGetStaticCountryList();
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of OXAN countries');
	    }

	    \MetaNull\Tools\mCache::saveVariable($countries, 'countries/oxan');
	}

	return $countries;
    }

    /**
     * Gets the lists of OXAN topics
     * @access public
     * @return MultiPair
     */
    public static function listOxanTopics() {
	$topics = \MetaNull\Tools\mCache::loadVariable('oxan_topics');
	if ($topics == null) {
	    try {
		$topics = statics::$tariqaClient->oxanGetStaticTopicList();
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of OXAN topics');
	    }

	    \MetaNull\Tools\mCache::saveVariable($topics, 'oxan_topics');
	}

	return $topics;
    }

    /**
     * Returns true if $folder_id is in the subtree of $parent_id
     * @param mMysql $db The database connection
     * @param $parent_id The parent folder identifier
     * @param $folder_id The folder identifier
     * @access public
     * @return boolean
     */
    public static function findSubTree($db, $parent_id, $folder_id) {
	if ($parent_id == $folder_id) {
	    return 1;
	}

	if ($parent_id == null) {
	    return 1;
	}

	if ($db->count_rows('briefcase_folders', "parent_id = {$parent_id} and folder_id = {$folder_id}") > 0) {
	    return 1;
	}

	$sql = "select folder_id from briefcase_folders where parent_id = {$parent_id} order by folder_id";
	$query = $db->mQuery($sql);

	while ($row = $query->fetch_assoc()) {
	    if (statics::findSubTree($db, $row['folder_id'], $folder_id)) {
		return 1;
	    }
	}

	return 0;
    }

    /**
     * Gets the number of video archive files
     * @access public
     * @return int
     */
    public static function archiveRecords() {
	$count = \MetaNull\Tools\mCache::loadVariable('videos_count');
	if ($count == null) {
	    try {
		$count = statics::$tariqaClient->countVideoArchiveRecords(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list number of Video files');
	    }

	    \MetaNull\Tools\mCache::saveVariable($count, 'videos_count');
	}

	return $count;
    }

    /**
     * Gets the list of newstickers predefined feeds
     * @access public
     * @static
     * @return RSS_feed[]
     */
    public static function ListNewstickersFeeds() {
	$feeds = \MetaNull\Tools\mCache::loadVariable('feeds/newstickers');
	if ($feeds == null) {
	    try {
		$feeds = statics::$tariqaClient->ListNewstickersFeeds(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list newsticker feeds');
	    }

	    \MetaNull\Tools\mCache::saveVariable($feeds, 'feeds/newstickers');
	}

	return $feeds;
    }

    /**
     * Fetches the list of clusters
     * @access public
     * @static
     * @return Cluster[]
     */
    public static function ListClusters() {
	$clusters = \MetaNull\Tools\mCache::loadVariable('countries/clusters');
	if ($clusters == null) {
	    try {
		$clusters = statics::$tariqaClient->ListClusters(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of clusters');
	    }

	    \MetaNull\Tools\mCache::saveVariable($clusters, 'countries/clusters');
	}

	return $clusters;
    }

    /**
     * Retrieves the RSS link
     * @param tariqaUser $user The tariqa user
     * @param string $page The page from which the RSS is created
     * @param int $flavour_id The flavour identifier (for news page, not for the search page) [OPTIONAL]
     * @param boolean $no_a If set to true, then no a href is generated. Only the img tag [OPTIONAL]
     * @access public
     * @static
     * @return string
     */
    public static function getRssLink($user, $page, $flavour_id = null, $no_a = false) {
	$password = $user->get_preference('general/rss_password');
	$img = 'rss16_active.jpg';
	$jsf = 'saveRSS';
	if ($password == null || $password == '') {
	    $img = 'rss16_inactive.jpg';
	    $jsf = 'saveRSSPassword';
	}

	if (!$no_a) {
	    return '<a class="rss_link" style="text-decoration: none !important;" href="#" onclick="' . $jsf . '(\'' . $page . '\', \'' . $flavour_id . '\'); return false; "><img style="text-decoration: none !important; border-style: no-border;" src="themes/default/icons/' . $img . '"/></a>';
	}
	else {
	    return '<img class="rss_link" onclick="' . $jsf . '(\'' . $page . '\', \'' . $flavour_id . '\'); return false; " src="themes/default/icons/' . $img . '"/>';
	}
    }

    /**
     * String the HTML tags using xslt
     * @param string $html The html string
     * @access protected
     * @return string
     */
    public static function stripTags($html) {
	//\MetaNull\Tools\mDump::dumpVariable($html);
	$config = \MetaNull\Tools\mConfig::loadConfiguration(APPLICATION_NEWS_CONFIG_FILE, APPLICATION_CONFIG_FORMAT, 'news_config');
	$html = "<root>{$html}</root>";
	$xslt = new \MetaNull\Tools\xslTransform($html, 'html/strip_tags', \MetaNull\Tools\xslTransform::FORMAT_TEXT, $config);
	return $xslt->transform();
    }

    /**
     * Ensure that the received html string is xhtml compliant
     * @param string $html Html data
     * @param bool $body_only If set to true (default) only the body of the xhtml document is returned
     */
    public static function makeXhtml($html, $body_only = true) {
	$options = array(
		"drop-proprietary-attributes" => true,
		"clean" => false,
		"output-xhtml" => true,
		"show-body-only" => $body_only,
	);
	$tidy = tidy_parse_string( $html, $options, "utf8" );
	$tidy->cleanRepair();
	return (string)$tidy;
    }

    /**
     * Gets the details for a LexisNexis source
     * @param string $sourceId The source identifier
     * @access public
     * @static
     * @return string[]
     */
    public static function LexisNexisGetSourceDetails($sourceId) {
	$details = \MetaNull\Tools\mCache::loadVariable('sources/l_' . $sourceId);
	if ($details == null) {
	    try {
		$details = statics::$tariqaClient->LexisNexisGetSourceDetails(statics::$tariqaToken, $sourceId);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list newsticker feeds');
	    }

	    \MetaNull\Tools\mCache::saveVariable($details, 'sources/l_' . $sourceId);
	}

	return $details;
    }

    /**
     * Gets a LexisNexis source
     * @param string $sourceId The source identifier
     * @access public
     * @static
     * @return string[]
     */
    public static function LexisNexisGetSource($sourceId) {
	$source = \MetaNull\Tools\mCache::loadVariable('sources/s_' . $sourceId);
	if ($source == null) {
	    try {
		$source = statics::$tariqaClient->LexisNexisGetSource(statics::$tariqaToken, $sourceId);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list newsticker feeds');
	    }

	    \MetaNull\Tools\mCache::saveVariable($source, 'sources/s_' . $sourceId);
	}

	return $source;
    }

    /**
     * Gets the available languages for LatestNews search
     * @access public
     * @static
     * @return LatestNewsLanguage[]
     */
    public static function LatestNewsListLanguages() {
	$languages = \MetaNull\Tools\mCache::loadVariable('sources/ln_languages');
	if ($languages == null) {
	    try {
		$languages = statics::$tariqaClient->latestNewsListLanguages(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of languages for latestnews search');
	    }

	    \MetaNull\Tools\mCache::saveVariable($languages, 'sources/ln_languages');
	}

	return $languages;
    }

    /**
     * Logs the user trace
     * @param tariqaUser $user The current user
     * @param mMysql $db The database connection
     * @static
     * @access public
     * @return void
     */
    public static function log($user, $db) {
	if ($user == null){
	    $user_id = null;
	}
	else {
	    $user_id = $user->user_id;
	}
	$string = $db->real_escape_string($_SERVER['QUERY_STRING']);
	$sql = <<<sql
insert into tariqa3.app_log(user_id, url)
values('{$user_id}', '{$string}');
sql;

	$db->mQuery($sql);

	$id = $db->last_insert_id();

	$values = self::post2array($_SERVER['QUERY_STRING']);

	$sql = '';

	foreach ($values as $key => $value){
	    $key = $db->real_escape_string($key);
	    if (!is_array($value)){
		$value = $db->real_escape_string($value);
	    }
	    else {
		$v = '';
		foreach ($value as $val){
		    $v .= ($v == ''?'':'; ') . $val;
		}
		$v = '[' . $v . ']';
		$value = $db->real_escape_string($v);
	    }
	    $sql .= ($sql == ''?'':', ') . "('{$id}', '{$key}', '{$value}', 'get')";
	}

	foreach ($_POST as $key => $value){
	    $key = $db->real_escape_string($key);
	    if (!is_array($value)){
		$value = $db->real_escape_string(iconv('UTF-8', 'UTF-8//TRANSLIT', substr($value, 0, 1000)));
	    }
	    else {
		$v = '';
		foreach ($value as $val){
		    $v .= ($v == ''?'':'; ') . $val;
		}
		$v = '[' . $v . ']';
		$value = $db->real_escape_string($v);
	    }
	    $sql .= ($sql == ''?'':', ') . "('{$id}', '{$key}', '{$value}', 'post')";
	}

	if ($sql != ''){
	    $sql = 'insert into tariqa3.app_log_details(log_id, `key`, value, type) values' . $sql;
	}
	else {
	    $sql = "insert into tariqa3.app_log_details(log_id, `key`, value, type) values('{$id}', 'module', 'riskmap', 'get')";
	}
	
	$db->mQuery($sql);
    }

    /**
     * Transforms a path by adding a '/' character at the end if it doesn't already has it
     * @param string $path The path
     * @param string $delimiter The path delimiter [OPTIONAL]
     * @access public
     * @static
     * @return string
     */
    public static function completePath($path, $delimiter = '/') {
	if (substr($path, -1) != $delimiter){
	    $path .= $delimiter;
	}

	return $path;
    }

    /**
     * Gets the translation for a specific module
     * @param string $name The module name
     * @access public
     * @static
     * @return array
     */
    public static function getTranslations($name) {
	global $the_app;
	return $the_app->getModuleTranslationTable($name);
    }

    /**
     * Gets the base URL of an url. By default, also the path will be included (for example, http://www.google.com/search?q=test will return
     * http://www.google.com/search/. If you only want http://www.google.com/ to be returned, then set no_path to true
     * @param string $url The URL
     * @access public
     * @static
     * @return string
     */
    public static function baseURL($url, $no_path = false) {
	if ($no_path){
	    preg_match_all('/^(http:\/\/[^\/^\?]*)[\/|\?].*$/', $url, $matches);
	    if (count($matches) > 1){
		return $matches[1][0] . '/';
	    }
	    
	}
	if (strpos($url, '?')){
	    $parts = explode('?', $url, 2);
	    $url = $parts[0];
	}

	if (substr($url, -1) != '/'){
	    $url .= '/';
	}

	return $url;
    }

    /**
     * Gets a list of full search sources
     * @param string $access The current user access level
     * @access public
     * @static
     * @return FullSearchSource[]
     */
    public static function ListFullSearchSources($access) {
	$sources = \MetaNull\Tools\mCache::loadVariable('sources/full_sources_' . $access);
	if ($sources == null) {
	    try {
		$sources = statics::$tariqaClient->ListFullSearchSources(statics::$tariqaToken);
	    } catch (\Exception $e) {
		throw new \Exception('Error loading the list of sources');
	    }

	    \MetaNull\Tools\mCache::saveVariable($sources, 'sources/full_sources_' . $access);
	}

	return $sources;
    }
}

}
?>