<?php
/*
 * © EUROPEAN COMMISSION, 2007-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs:
 *	Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *	Cosmin Popescu,   Adrian.POPESCU@ext.ec.europa.eu
*/

namespace tariqa3{

/**
 * Class for changing the POST and the GET variables so that another page will answer the request.
 * @package tariqa3
 * @author Pascal Havelange, Cosmin Popescu
 * @copyright © EUROPEAN COMMISSION, 2009-2010
 * @license http://ec.europa.eu/idabc/eupl
 */
abstract class tariqa3Redirect {
    /**
     * The application configuration array
     * @var array
     * @access protected
     */
    protected $config;
    /**
     * Constructs the object
     * @param array $config The application configuration array
     * @access public
     * @return void
     */
    public function __construct($config) {
	$this->config = $config;
    }
    /**
     * Gets the URL
     * @access public
     * @return string
     */
    abstract public function getURL();

    /**
     * Gets the POST data
     * @access public
     * @return string
     */
    abstract public function getPostData();

    /**
     * Initializes the module
     * @access public
     * @return void
     */
    abstract public function initialize();

    /**
     * Performs the redirect (changes the GET and POST content)
     * @final
     * @access public
     * @return void
     */
    public final function doRedirect() {
	$this->initialize();
	
	$url = $this->getURL();
	$parts = explode("?", $url, 2);


	$_GET = array();

	if (count($parts) == 2){
	    $data = statics::post2array($parts[1]);
	    foreach ($data as $key => $value){
		$_GET[$key] = \MetaNull\Tools\mTools::rawurldecode($value);
	    }
	}

	$_POST = array();

	$post_data = $this->getPostData();

	if ($post_data != null){
	    $data = statics::post2array($post_data);
	    foreach ($data as $key => $value){
		$_POST[$key] = \MetaNull\Tools\mTools::rawurldecode($value);
	    }
	}

    }
}

}
?>