-- MySQL dump 10.13  Distrib 5.5.16, for Win32 (x86)
--
-- Host: 158.166.117.10    Database: rss_aggregator
-- ------------------------------------------------------
-- Server version	5.5.16

/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;
/*!40103 SET @OLD_TIME_ZONE=@@TIME_ZONE */;
/*!40103 SET TIME_ZONE='+00:00' */;
/*!40014 SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0 */;
/*!40014 SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0 */;
/*!40101 SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='NO_AUTO_VALUE_ON_ZERO' */;
/*!40111 SET @OLD_SQL_NOTES=@@SQL_NOTES, SQL_NOTES=0 */;

--
-- Table structure for table `articles`
--

DROP TABLE IF EXISTS `articles`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `articles` (
  `article_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier of the article (url is wrong as it can appear in several feeds)',
  `feed_id` int(11) unsigned NOT NULL COMMENT 'ID of the feed this article belongs to',
  `date` datetime DEFAULT NULL COMMENT 'Date of publication of the article',
  `title` text COMMENT 'Title of the article',
  `headline` text COMMENT 'Title of the article (full length)',
  `description` longtext COMMENT 'Summary of the article if available',
  `link` text COMMENT 'Link to the article',
  `comments` text COMMENT 'Comment about the article (if available)',
  `author` text COMMENT 'Author of the article (if available)',
  `ts_article` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT 'Load date of the article',
  PRIMARY KEY (`article_id`),
  UNIQUE KEY `articles_link_unique` (`feed_id`,`link`(255)),
  KEY `idx_articles_feed_id_date` (`feed_id`,`date`),
  KEY `ix_articles_ts_article` (`ts_article`),
  KEY `idx_articles_feed_id` (`feed_id`),
  KEY `idx_articles_date` (`date`),
  KEY `articles_link_index` (`link`(255)),
  CONSTRAINT `fk_articles` FOREIGN KEY (`feed_id`) REFERENCES `feeds` (`feed_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB AUTO_INCREMENT=124011562 DEFAULT CHARSET=utf8 ROW_FORMAT=COMPRESSED COMMENT='Stores the list of articles of each feed';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `feeds`
--

DROP TABLE IF EXISTS `feeds`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `feeds` (
  `feed_id` int(11) unsigned NOT NULL AUTO_INCREMENT COMMENT 'Unique identifier for the feed',
  `url` varchar(512) NOT NULL COMMENT 'Full URL of the feed. UNIQUE CONSTRAINT.',
  `title` varchar(255) DEFAULT NULL COMMENT 'Title of the feed',
  `description` text COMMENT 'Description of the feed',
  `picture` varchar(255) DEFAULT NULL COMMENT 'URL to the embeded Logo',
  `link` varchar(255) DEFAULT NULL COMMENT 'URL of the site corresponding to the current feed',
  `language` varchar(20) DEFAULT NULL COMMENT 'Language of the feed (if avialable)',
  `copyright` text COMMENT 'Copyright information',
  `refresh_rate` int(10) unsigned NOT NULL DEFAULT '15' COMMENT 'Refresh rate of the feed (in seconds). 0 means unrestricted',
  `last_refresh` datetime DEFAULT NULL COMMENT 'Date/time at which the feed was last refreshed',
  `use_proxy` tinyint(1) NOT NULL DEFAULT '1' COMMENT 'If set to 1, the feed will be downloaded through the proxy, otherwise direct connection will be used',
  `has_pictures` enum('y','n') NOT NULL DEFAULT 'n',
  `manual_picture` varchar(255) DEFAULT NULL,
  `has_video` enum('y','n') NOT NULL DEFAULT 'n',
  `has_audio` enum('y','n') NOT NULL DEFAULT 'n',
  PRIMARY KEY (`feed_id`),
  KEY `feeds_link_index` (`url`(255))
) ENGINE=InnoDB AUTO_INCREMENT=8504 DEFAULT CHARSET=utf8 COMMENT='Stores the list of RSS feeds';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Table structure for table `newsticker_feeds`
--

DROP TABLE IF EXISTS `newsticker_feeds`;
/*!40101 SET @saved_cs_client     = @@character_set_client */;
/*!40101 SET character_set_client = utf8 */;
CREATE TABLE `newsticker_feeds` (
  `feed_id` int(10) unsigned NOT NULL COMMENT 'The feed identifier',
  `name` varchar(255) NOT NULL COMMENT 'The feed name',
  PRIMARY KEY (`feed_id`),
  CONSTRAINT `new_fk_constraint` FOREIGN KEY (`feed_id`) REFERENCES `feeds` (`feed_id`) ON DELETE CASCADE ON UPDATE CASCADE
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='The list of feeds for newstickers';
/*!40101 SET character_set_client = @saved_cs_client */;

--
-- Dumping routines for database 'rss_aggregator'
--
/*!50003 DROP PROCEDURE IF EXISTS `synchronize_source_names` */;
/*!50003 SET @saved_cs_client      = @@character_set_client */ ;
/*!50003 SET @saved_cs_results     = @@character_set_results */ ;
/*!50003 SET @saved_col_connection = @@collation_connection */ ;
/*!50003 SET character_set_client  = utf8 */ ;
/*!50003 SET character_set_results = utf8 */ ;
/*!50003 SET collation_connection  = utf8_general_ci */ ;
/*!50003 SET @saved_sql_mode       = @@sql_mode */ ;
/*!50003 SET sql_mode              = 'STRICT_TRANS_TABLES,NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION' */ ;
DELIMITER ;;
/*!50003 CREATE*/ /*!50020 */ /*!50003 PROCEDURE `synchronize_source_names`()
BEGIN
    declare _source, _feed varchar(255) default null;
    declare _query_id, _feed_id int(11) default null;
    declare done mediumint(5) default 0;
    declare rec1 cursor for select source, feed from tmp order by id;
    declare rec2 cursor for select feed_id from feeds where url = _feed;
    declare rec3 cursor for select query_id from tariqapro.queries 
        where 
            ((query = _feed_id) or (query like concat('%feed_id=', _feed_id, '&%'))
            or (query like concat('%feed_id=', _feed_id)))
            and source_id = 7 order by query_id;
    
    declare continue handler for sqlstate '02000' set done = 1;
    
    open rec1;
    fetch rec1 into _source, _feed;
    while not done do
        set done = 0;
        open rec2;
        fetch rec2 into _feed_id;
        while not done do
            set done = 0;
            open rec3;
            fetch rec3 into _query_id;
            while not done do
                update tariqapro.queries set title = _source, description = _source where query_id = _query_id;
                update tariqapro.queries_countries set label = _source, description = _source where query_id = _query_id;
                update tariqapro.queries_themes set label = _source, description = _source where query_id = _query_id;
                set done = 0;
                fetch rec3 into _query_id;
            end while;
            close rec3;
            set done = 0;
            fetch rec2 into _feed_id;
        end while;
        close rec2;
        set done = 0;
        fetch rec1 into _source, _feed;
    end while;
    close rec1;
    
END */;;
DELIMITER ;
/*!50003 SET sql_mode              = @saved_sql_mode */ ;
/*!50003 SET character_set_client  = @saved_cs_client */ ;
/*!50003 SET character_set_results = @saved_cs_results */ ;
/*!50003 SET collation_connection  = @saved_col_connection */ ;
/*!40103 SET TIME_ZONE=@OLD_TIME_ZONE */;

/*!40101 SET SQL_MODE=@OLD_SQL_MODE */;
/*!40014 SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS */;
/*!40014 SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS */;
/*!40101 SET CHARACTER_SET_CLIENT=@OLD_CHARACTER_SET_CLIENT */;
/*!40101 SET CHARACTER_SET_RESULTS=@OLD_CHARACTER_SET_RESULTS */;
/*!40101 SET COLLATION_CONNECTION=@OLD_COLLATION_CONNECTION */;
/*!40111 SET SQL_NOTES=@OLD_SQL_NOTES */;

-- Dump completed on 2012-04-25 13:45:00
