<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
*/


class IDOLQuery {
    /**
     * The default query
     * @var string
     */
    const QUERY_TYPE_DEFAULT = 'default';

    /**
     * The Verity Query Language type
     * @var string
     */
    const QUERY_TYPE_VQL = 'vql';

    /**
     * The Concept summary type
     * @var string
     */
    const SUMMARY_TYPE_CONCEPT = 'Concept';

    /**
     * The Context summary type
     * @var string
     */
    const SUMMARY_TYPE_CONTEXT = 'Context';

    /**
     * The Quick summary type
     * @var string
     */
    const SUMMARY_TYPE_QUICK = 'Quick';

    /**
     * The ParagraphConcept summary type
     * @var string
     */
    const SUMMARY_TYPE_PARAGRAPTCONCEPT = 'ParagraphConcept';

    /**
     * The Context summary type
     * @var string
     */
    const SUMMARY_TYPE_PARAGRAPHCONTEXT = 'ParagraphContext';

    /**
     * The Terms highlight type
     * @var string
     */
    const HIGHLIGHT_TYPE_TERMS = 'Terms';

    /**
     * The Sentences highlight type
     * @var string
     */
    const HIGHLIGHT_TYPE_SENTENCES = 'Sentences';

    /**
     * The SummaryTerms highlight type
     * @var string
     */
    const HIGHLIGHT_TYPE_SUMMARYTERMS = 'SummaryTerms';

    /**
     * The SummarySentences highlight type
     * @var string
     */
    const HIGHLIGHT_TYPE_SUMMARYSENTENCES = 'SummarySentences';

    /**
     * The query text
     * @var string
     * @access public
     */
    public $query;

    /**
     * The IDOL server URL
     * @var string
     * @access public
     */
    public $url;

    /**
     * The list of fields to return (comma separated values or "all" for all fields)
     * @var string
     * @access public
     */
    public $fields = 'all';

    /**
     * The query language type
     * @var string
     * @access public
     */
    public $type = self::QUERY_TYPE_DEFAULT;

    /**
     * If true, also get a summary
     * @var boolean
     * @access public
     */
    public $summary = false;

    /**
     * If a summary is to be generated, the type of summary
     * @var string
     * @access public
     */
    public $summary_type = null;

    /**
     * Get the results starting from this date (unit timestamp)
     * @var int
     * @access public
     */
    public $from = null;

    /**
     * Get the results until this date (unit timestamp)
     * @var int
     * @access public
     */
    public $to = null;

    /**
     * The sorting
     * @var string
     * @access public
     */
    public $sort = null;

    /**
     * The number of results to return
     * @var int
     * @access public
     */
    public $count = 20;

    /**
     * The first result to retrieve
     * @var int
     * @access public
     */
    public $start = 0;

    /**
     * If true, highlight the terms in the result
     * @var boolean
     * @access public
     */
    public $highlight = true;

    /**
     * The highlight type
     * @var string
     * @access public
     */
    public $highlight_type = self::HIGHLIGHT_TYPE_TERMS;

    /**
     * The language type (as in the IDOL configuration file)
     * @var string
     * @access public
     */
    public $language = null;

    /**
     * Additional options (string in HTTP GET form)
     * @var string
     * @access public
     */
    public $extra_options;
}
?>