<?php

    /**
     * Holds an LDAP database entry
     * */
    class LDAPEntry {
        
        /**
         * User ID (ldap attribute: uid)
         * @var string
         * */
        public $user_id;
        
        /**
         * Title (Mr, Ms, Mrs) (ldap attribute: title)
         * @var string
         * */
        public $title;
        
        /**
         * Firstname (ldap attribute: givenname)
         * @var string
         * */
        public $firstname;
        
        /**
         * LAstname (ldap attribute: sn)
         * @var string
         * */
        public $lastname;
        
        /**
         * Display name (ldap attribute: cn)
         * @var string
         * */
        public $displayname;
        
        /**
         * Phone number (ldap attribute: telephonenumber)
         * @var string
         * */
        public $phone;
        
        /**
         * e-mail address (ldap attribute: mail)
         * @var string
         * */
        public $email;
        
        /**
         * ISO2 Country Code (ldap attribute: cn)
         * @var string
         * */
        public $country;
        
        /**
         * Building (ldap attribute: building)
         * @var string
         * */
        public $building;
        
        /**
         * Floor number (ldap attribute: floor)
         * @var string
         * */
        public $floor;
        
        /**
         * Office (ldap attribute: physicaldeliveryofficename)
         * @var string
         * */
        public $office;
        
        /**
         * Organisation (ldap attribute: sourceorganisation)
         * @var string
         * */
        public $organisation;
        
        /**
         * Full Department Name (ldap attribute: departmentnumber)
         * @var string
         * */
        public $department;
        
        /**
         * Directorate General (ldap attribute: dg)
         * @var string
         * */
        public $directorate;
        
        /**
         * Unit (ldap attribute: div)
         * @var string
         * */
        public $unit;
        
        /**
         * LDAP uid of the manager (ldap attribute: manager)
         * @var string
         * */
        public $manager;
        
        /**
         * LDAP CUD Groups the users belongs to (ldap attribute: cudgroup)
         * @var string[]
         * */
        public $groups;
        
        /**
         * LDAP object classes (ldap attribute: objectclass)
         * @var string[]
         * */
        public $classes;
        
        /**
         * LDAP 'dn' attribute (ldap attribute: dn)
         * @var string
         * */
        public $dn;


		/**
         * City
         * @var string
         * */
        public $city;
		/**
         * LocationGroup
         * @var string
         * */
        public $locationGroup;
		/**
         * True if the employee belongs to the institution
         * @var boolean
         * */
        public $internalEmployee;
		/**
         * True if the employee works for an external company
         * @var boolean
         * */
        public $externalEmployee;
		/**
         * True if the employee is a "Service Provider"
         * @var boolean
         * */
		public $employeeIsAServiceProvider;
		/**
         * True if the employee is a "Contractual Agent"
         * @var boolean
         * */
		public $employeeIsAContractualAgent;
		/**
         * True if the employee is a "Functionnaire"
         * @var boolean
         * */
		public $employeeIsAFunctionnaire;

		/**
         * If the employee is an END
         * @var boolean
         * */
        public $employeeIsAnEND;

		/**
         * True if the emplyee status is "active"
         * @var boolean
         * */
        public $activeEmployee;
		/**
         * Type of employee
         * @var string
         * */
        public $employeeType;
		/**
         * Subtype of employee
         * @var string
         * */
        public $employeeSubtype;
		/**
         * Status of of employee
         * @var string
         * */
         
		/**
		 * Returns the current object under the form of an associative array
		 * @return array
		 */
		public function toArray() {
			$a = array();
			$vars = get_class_vars(get_class($this));
			foreach( $vars as $k => $v ) {
				$a[$k] = $v;
			}
			return $a;
		}
		
        /**
         * Construct an LDAP entry (empty or by assigning values soted in an array of strings, as returned by a RAW LDAP search)
         * @param string[] $ldap_entry_values_array
         * @return void
         * */
        public function __construct( $ldap_entry_values_array = null ) {

            $this->classes = array();
            $this->groups = array();
            if( null !== $ldap_entry_values_array && is_array( $ldap_entry_values_array )) {
                foreach( $ldap_entry_values_array as $key => $value ) {
                    switch( $key ) {
                        case "uid": {  $this->user_id = $value;   } break;

                        case "title": {  $this->title = $value;   } break;
                        case "cn": {  $this->displayname = $value;   } break;
                        case "givenname": {  $this->firstname = $value;   } break;
                        case "sn": {  $this->lastname = $value;   } break;    
                        case "mail": {  $this->email = $value;   } break;
                        case "telephonenumber": {  $this->phone = $value;   } break;

                        case "c": {  $this->country = $value;   } break;
                        case "building": {  $this->building = $value;   } break;
                        case "floor": {  $this->floor = $value;   } break;
                        case "physicaldeliveryofficename": {  $this->office = $value;   } break;

                        case "departmentnumber": {  $this->department = $value;   } break;
                        case "sourceorganisation": {  $this->organisation = $value;   } break;
                        case "dg": {  $this->directorate = $value;   } break;
                        case "div": {  $this->unit = $value;   } break;

                        case "manager": {  $this->manager = $value;   } break;

                        case "dn": {  $this->dn = $value;   } break;
                        case "objectclass": {
                            if( is_array( $value )) {
                                foreach( $value as $subval ) {
                                    $this->classes[] = $subval;
                                }
                            } else {
                                $this->classes = array($value);
                            }
                        } break;
                        case "cudgroup": {
                            if( is_array( $value )) {
                                foreach( $value as $subval ) {
                                    $this->groups[] = $subval;
                                }
                            } else {
                                $this->groups = array($value);
                            }
                        } break;


						case 'l' : {	$this->city = $value;	} break;
						case 'locationgroup' : {	$this->locationGroup = $value;	} break;
						case 'employeetype' : {	$this->employeeType = $value;	} break;
						case 'euemployeesubtype' : {	$this->employeeSubtype = $value;	} break;
						case 'euemployeestatusdetail' : {	$this->employeeStatus = $value;	} break;
                    }
                }

				$this->internalEmployee = ('E' != $this->employeeType);
				$this->externalEmployee = ('E' == $this->employeeType);
				$this->activeEmployee = ('A' == $this->employeeStatus);
				$this->employeeIsAContractualAgent	= ('f' == $this->employeeType && 'CA' == $this->employeeSubtype);
				$this->employeeIsAFunctionnaire		= ('f' == $this->employeeType && 'FP' == $this->employeeSubtype);
				$this->employeeIsAServiceProvider	= ('E' == $this->employeeType && 'PRE' == $this->employeeSubtype);
				$this->employeeIsAnEND	= ('E' == $this->employeeType && 'END' == $this->employeeSubtype);
            }
        }
    }
?>