<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
*/

class tariqaAtlas extends Tariqa {
    /**
     * Configuration array
     * @var array
     * */
    protected $config = null;

    /**
     * The class is called using SOAP
     * @var boolean
     */
    public $soap;

    /**
     * Constructs a tariqaThemes Object
     * @return Tariqa
     * */

    public function __construct($config, $soap) {
	$this->config = $config;
	$this->soap = $soap;
    }

    /**
     * Returns the list of maps for a country
     * @param string $token The session identifier
     * @param Country $country The country for which to retrieve the map
     * @param int $dayRange The days for which to retrieve the maps [OPTIONAL]
     * @return GlobalAtlas[]
     */
    public function ListGlobalAtlasMaps($token, $country, $dayRange = null) {
	if( false === $this->CheckToken( $token )) {
	    if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
	    return null;
	}

	$days = $dayRange == null ? "" : "&days={$dayRange}";

	$error = false;
	$my = $this->OpenDatabase( "tariqapro", $error );
	if( false === $my ) {
	    if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
	}

	$sql = <<<sql
select `global_atlas`
from `meta_common`.`countries_equiv`
where country_id = '{$country->code_iso2}'
sql;

	if (($q = $my->query($sql)) === false) {
	    if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
	    $my->close();
	    return null;
	}

	$row = $q->fetch_assoc();

	$codes = explode(",", $row["global_atlas"]);

	$baseurl = "{$this->config["global_atlas"]["url"]}";
	foreach ($codes as $code) {
	    $url = "{$baseurl}FIPS={$code}{$days}";
	    $request = new WebRequest($url);
	    $resp = $this->_fetchUrl($request);

	    $xml_doc = new DOMDocument();
	    $xml_doc->loadXML($resp->body);
	    $xpath = new DOMXPath($xml_doc);
	    $items = $xpath->query("/rss/channel/item");

	    $rez = array();

	    foreach($items as $item) {
		$map = new GlobalAtlas();
		foreach ($item->childNodes as $node) {
		    switch ($node->nodeName) {
			case "title":
			    $map->title = $node->nodeValue;
			    break;
			case "country":
			    $map->country = $node->nodeValue;
			    break;
			case "link":
			    $map->link = $node->nodeValue;
			    break;
			case "theme":
			    $map->theme = $node->nodeValue;
			    break;
			case "sub_theme":
			    $map->subtheme = $node->nodeValue;
			    break;
			case "source":
			    $map->source = $node->nodeValue;
			    break;
			case "pubDate":
			    $map->pubDate = strtotime($node->nodeValue);
			    break;
			case "image":
			    $map->image = $node->nodeValue;
			    break;
			case "description":
			    $map->description = $node->nodeValue;
			    break;
			case "scale":
			    $map->scale = $node->nodeValue;
			    break;
		    }
		}

		$map->link = str_replace('globalatlas.jrc.it', '139.191.9.231', $map->link);

		array_push($rez, $map);
	    }

	}

	if (count($rez) == 0) return null;

	return $rez;
    }

    /**
     * Gets the collins maps for a given country
     * @param string $token The session identifier
     * @param Country $country The country
     * @access public
     * @return CollinsMap[]
     */
    public function listCollinsMaps($token, $country) {
	if( false === $this->CheckToken( $token )) {
	    if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
	    return null;
	}
	
	$content = file_get_contents('d:/Applications/tariqapro_soap/Tariqa/config/collins_maps.xml');
	$doc = new DOMDocument('1.0', 'UTF-8');
	$doc->loadXML($content);
	$xpath = new DOMXPath($doc);
	$rs = $xpath->query("//collins_maps/COUNTRY[@ISO2='{$country->code_iso2}']/..");

	$result = array();

	for ($i = 0; $i < $rs->length; $i++){
	    $item = $rs->item($i);
	    $map = new CollinsMap();
	    foreach ($item->childNodes as $node){
		if ($node->nodeName == 'PDF_LINK'){
		    $map->pdf = $node->nodeValue;
		}
		else if ($node->nodeName == 'PNG_LINK'){
		    $map->png = $node->nodeValue;
		}
		else if ($node->nodeName == 'THUMBNAIL_LINK'){
		    $map->thumb = $node->nodeValue;
		}
	    }

	    $result[] = $map;
	}

	return $result;
    }
}
?>