<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaCountry extends Tariqa {

	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Get a list of maps for a given country
	 * @param string $token The session identifier
	 * @param Country $country The country to search for
	 * @param int $day_range The maximum age of the maps in days [OPTIONAL]
	 * @return DMAMap[]
	 * */
	public function GetCountryMaps( $token, $country, $day_range ) {
		$url = 'http://dmaweb2.jrc.it/services/Global_Atlas/catalogueRSS_Global_Atlas.asp?';
		$url .= 'FIPS=' . $country->code_iso2;
		//$url .= 'country=' . $country->name;
		if( null !== $day_range ) {
			$url .= '&days=' . $day_range;
		}

		$dma = $this->fetchUrl( $token, new WebRequest( $url ));
		//return explode( "\n", $dma->body );

		$dom = new DOMDocument;
		$dom->loadXML( $dma->body );

		$xpath = new DOMXPath( $dom );
		$xrs = new DOMNodeList;
		$xrs = $xpath->query( '/rss/channel/item' );

		$maps = array();
		$map = new DMAMap;
		$map->link = $url;
		$map->title = 'DMA';
		$map->description = 'DMA';
		$maps[] = $map;

		for( $i = 0; $i < $xrs->length; $i ++ ) {
			$item = $xrs->item($i);

			$item_xp_idx = $i + 1;
			$map = new DMAMap;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/title' );
			$map->title = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/description' );
			$map->description = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/link' );
			$map->link = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/image' );
			$map->image = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/scale' );
			$map->scale = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/pubDate' );
			$map->pubDate = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/theme' );
			$map->theme = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/sub_theme' );
			$map->sub_theme = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/source' );
			$map->source = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query( '/rss/channel/item['.$item_xp_idx.']/country' );
			$map->country = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$maps[] = $map;
		}

		/*			ob_start();
			var_dump( $maps );
			error_log( ob_get_contents() );
			ob_end_clean();
			*/
		return $maps;
	}

	/**
	 * Get the number of articles per day or per hour for the selected countries
	 * @param string $token The session identifier
	 * @param Country[] $countries The countries for which to retrieve the statistics
	 * @param int $type The type of statistics (0 - per day, 1 - per hour)
	 * @param int $startDate The start date (UNIX timestamp format) - null means current day [OPTIONAL]
	 * @param int $endDate The end date (UNIX timestamp format) - null means current day. For type 1 (articles per hour) it will not be considered [OPTIONAL]
	 * @return CountryStatisticsResult[]
	 * */
	private function GetCountryStatistics($token, $countries, $type, $startDate = null, $endDate = null){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		if ($startDate == null) $startDate = time();
		if ($endDate == null) $endDate = time();

		$error = false;
		$my = $this->OpenDatabase( "hotspots", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		$rez = array();
		foreach($countries as $country){
			$result = new CountryStatisticsResult();
			$result->country = $country;
			$result->articles = array();
			if ($type == 0)
			$sql = <<<sql
select
	unix_timestamp(date(`date`)) as 'date', sum(no) as no
from
	articles_per_day
where
	country_id = '{$country->code_iso2}'
	/*and date(`date`) >= date(from_unixtime('{$startDate}'))
	and date(`date`) <= date(from_unixtime('{$endDate}'))*/
        and (`date`) >= (from_unixtime('{$startDate}'))
	and (`date`) <= date_add(from_unixtime('{$endDate}'), interval 24 hour)
group by
	unix_timestamp(date(`date`))
order by
	unix_timestamp(date(`date`))
sql;
			else
			$sql = <<<sql
select
	hour as 'date', sum(no) as no
from
	articles_per_hour
where
	country_id = '{$country->code_iso2}' and date(`date`) = date(from_unixtime('{$startDate}'))
group by
	date(`date`), hour
order by
	hour
sql;

			if (($query = $my->query($sql)) === false){
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}

			while ($dates = $query->fetch_assoc()){
				$article = new StatisticsArticles();
				$article->date = $dates["date"];
				$article->no = $dates["no"];
				array_push($result->articles, $article);
			}

			array_push($rez, $result);
		}

		return $rez;
	}

	/**
	 * Get the number of articles per day for the selected countries
	 * @param string $token The session identifier
	 * @param Country[] $countries The countries for which to retrieve the statistics
	 * @param int $startDate The start date (UNIX timestamp format) - null means current day [OPTIONAL]
	 * @param int $endDate The end date (UNIX timestamp format) - null means current day. For type 1 (articles per hour) it will not be considered [OPTIONAL]
	 * @return CountryStatisticsResult[]
	 * */
	public function GetCountryStatisticsPerDay($token, $countries, $startDate = null, $endDate = null){
		return $this->GetCountryStatistics($token, $countries, 0, $startDate, $endDate);
	}

	/**
	 * Get the number of articles per hour for the selected countries
	 * @param string $token The session identifier
	 * @param Country[] $countries The countries for which to retrieve the statistics
	 * @param int $date The date (UNIX timestamp format) - null means current day [OPTIONAL]
	 * @return CountryStatisticsResult[]
	 * */
	public function GetCountryStatisticsPerHour($token, $countries, $date = null){
		return $this->GetCountryStatistics($token, $countries, 1, $date);
	}

	/**
	 * Get the master list of countries
	 * @param string $token The session identifier
	 * @param int $continent_id Restricts the list to a given Continent [OPTIONAL]
	 * @param boolean $eu_members_only If true, restricts the list to EU countries, if False, restricts it to NON-EU members [OPTIONAL]
	 * @param boolean $official_only It true, restricts the list to official countries, if False, restricts it to non official countries [OPTIONAL]
	 * @param int $region_id The official region identifier [OPTIONAL]
	 * @param string[] $country_ids A list of country ids [OPTIONAL]
         * @param boolean $group If true, group Oceania + Antarctica [OPTIONAL]
	 * @return Country[]
	 * */
	public function listCountries( $token, $continent_id = null, $eu_members_only = null, $official_only = null, $region_id = null, $country_ids = null, $group = false ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$hotspots = $this->_listHotSpots();
		
		$cond = '';
		$region_id = $my->real_escape_string($region_id);
		
		if ($region_id != null) $cond = " and `region_id` = '{$region_id}'";

		$query = <<<sql
select *
from `countries` c, `countries_equiv` ce
where c.`country_id` = ce.`country_id` {$cond}
sql;
		if( null !== $continent_id ) {
			$query .= " and c.`continent_id` = '".sprintf("%d",$continent_id)."' ";
		}
		if( null !== $eu_members_only ) {
			$query .= " and c.`eu_member` = '".($eu_members_only?"1":"0")."' ";
		}
		if( null !== $official_only ) {
			$query .= " and c.`official` = '".($official_only?"1":"0")."' ";
		}
		if ($country_ids != null){
			$c = '';
			foreach ($country_ids as $id){
				$id = $my->real_escape_string($id);
				$c .= ($c == ''?'':' or ') . "c.`country_id` = '{$id}'";
			}

			if ($c != ''){
				$query .= " and ({$c}) ";
			}
		}
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$countries = array();
		while( $row = $rs->fetch_assoc() ) {
			$country = new Country();
			$country->code_iso2 = $row["country_id"];
			$country->code_iso3 = $row["iso3"];
			$country->name = $row["name_en"];
			$country->eu_member = (int)$row["eu_member"] ? true : false;
			$country->official = (int)$row["official"] ? true : false;
			$country->continent_id = (!$group? (int)$row["continent_id"]: ($row['continent_id'] != 7? (int)$row["continent_id"]: 6));
			$country->parent_code_iso2 = $row["parent_country_id"];
			$country->code_sysper2 = $row["ec_sysper"];
			$country->code_comref = $row["ec_comref"];
			$country->code_ioc = $row["ioc"];
			$country->code_isonum = $row["isonum"];
			$country->code_itu = $row["itu"];
			$country->code_un = $row["un"];
			$country->oxan_id = $row["oxan"];
			$country->code_comref_deleg = $row["ec_comref_del"];
			$country->hotspot = (array_search($row["country_id"], $hotspots) === false?false:true);
			$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
			$country->region_id = $row["region_id"];
			$countries[] = $country;
		}

		$rs->free();
		$my->close();
		return $countries;
	}

	/**
	 * Get the master list of countries
	 * @param string $token The session identifier
	 * @param int $continent_id Restricts the list to a given Continent [OPTIONAL]
	 * @param boolean $eu_members_only If true, restricts the list to EU countries, if False, restricts it to NON-EU members [OPTIONAL]
	 * @param boolean $official_only It true, restricts the list to official countries, if False, restricts it to non official countries [OPTIONAL]
	 * @return Country2[]
	 * */
	public function listCountries2( $token, $continent_id = null, $eu_members_only = null, $official_only = null ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$hotspots = $this->_listHotSpots();

		$query = <<<sql
select *
from `countries` c, `countries_equiv` ce
where c.`country_id` = ce.`country_id`
sql;

		if( null !== $continent_id ) {
			$query .= " and c.`continent_id` = '".sprintf("%d",$continent_id)."' ";
		}
		if( null !== $eu_members_only ) {
			$query .= " and c.`eu_member` = '".($eu_members_only?"1":"0")."' ";
		}
		if( null !== $official_only ) {
			$query .= " and c.`official` = '".($official_only?"1":"0")."' ";
		}
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$countries = array();
		while( $row = $rs->fetch_assoc() ) {
			$country = new Country2();
			$country->code_iso2 = $row["country_id"];
			$country->name = $row["name_en"];
			$country->continent_id = (int)$row["continent_id"];
			$country->parent_code_iso2 = $row["parent_country_id"];
			$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
			$countries[] = $country;
		}

		$rs->free();
		$my->close();
		return $countries;
	}

	/**
	 * Get the information about a country identified by a code
	 * @param string $token The session identifier
	 * @param string $iso2 ISO 3166(2 alpha) [OPTIONAL]
	 * @param string $iso3 ISO 3166(3 alpha) [OPTIONAL]
	 * @param int $isonum ISO 3166(numeric) [OPTIONAL]
	 * @param string $comref E.C. COMREF PriKey [OPTIONAL]
	 * @param string $sysper E.C. SYSPER2 [OPTIONAL]
	 * @param string $iana Internet Assigned Numbers Authority [OPTIONAL]
	 * @param string $ioc International Olympic Committee [OPTIONAL]
	 * @param string $un U.N. International Traffic Distinguished Signs [OPTIONAL]
	 * @param string $itu I.T.U Codes for International Telephone calls [OPTIONAL]
	 * @param string $oxan_id Oxford Analytica's Country Name [OPTIONAL]
	 * @param string $comref_del E.C. COMREF - Delegation Country ID (if it differs from $comref) [OPTIONAL]
	 * @param boolean $get_maps If set to true, return also the Maps of the country [OPTIONAL]
	 * @param boolean $get_wiki If set to true, also return the Wikipedia country profile data [OPTIONAL]
	 * @return Country
	 * */
	public function getCountry( $token, $iso2, $iso3, $isonum, $comref, $sysper, $iana, $ioc, $un, $itu, $oxan_id, $comref_del, $get_maps = false, $get_wiki = false ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		$country = $this->_getCountry( $iso2, $iso3, $isonum, $comref, $sysper, $iana, $ioc, $un, $itu, $oxan_id, $comref_del );
		if ($get_maps){
			$country->relief_web_maps = $this->GetReliefWebMaps($token, $iso2);
			$country->global_atlas_maps = $this->ListGlobalAtlasMaps($token, $country);
			$country->collin_maps = $this->listCollinsMaps($token, $country);
		}
		if ($get_wiki){
			$country->wiki_data = $this->GetWikipediaCountryProfile($token, $country);
		}
		return $country;
	}

	/**
	 * Get the information about a country identified by a code
	 * @param string $token The session identifier
	 * @param string $iso2 ISO 3166(2 alpha) [OPTIONAL]
	 * @param string $iso3 ISO 3166(3 alpha) [OPTIONAL]
	 * @param int $isonum ISO 3166(numeric) [OPTIONAL]
	 * @param string $comref E.C. COMREF PriKey [OPTIONAL]
	 * @param string $sysper E.C. SYSPER2 [OPTIONAL]
	 * @param string $iana Internet Assigned Numbers Authority [OPTIONAL]
	 * @param string $ioc International Olympic Committee [OPTIONAL]
	 * @param string $un U.N. International Traffic Distinguished Signs [OPTIONAL]
	 * @param string $itu I.T.U Codes for International Telephone calls [OPTIONAL]
	 * @param string $oxan_id Oxford Analytica's Country Name [OPTIONAL]
	 * @param string $comref_del E.C. COMREF - Delegation Country ID (if it differs from $comref) [OPTIONAL]
	 * @param boolean $get_maps If set to true, return also the Maps of the country [OPTIONAL]
	 * @param boolean $get_wiki If set to true, also return the Wikipedia country profile data [OPTIONAL]
	 * @return string
	 * */
	public function getCountry3( $token, $iso2, $iso3, $isonum, $comref, $sysper, $iana, $ioc, $un, $itu, $oxan_id, $comref_del, $get_maps = false, $get_wiki = false ) {
		$country = $this->getCountry($token, $iso2, $iso3, $isonum, $comref, $sysper, $iana, $ioc, $un, $itu, $oxan_id, $comref_del, $get_maps, $get_wiki);
		return '1';
	}

	/**
	 * Get the information about a country identified by a code
	 * @param string $iso2 ISO 3166(2 alpha) [OPTIONAL]
	 * @param string $iso3 ISO 3166(3 alpha) [OPTIONAL]
	 * @param int $isonum ISO 3166(numeric) [OPTIONAL]
	 * @param string $comref E.C. COMREF PriKey [OPTIONAL]
	 * @param string $sysper E.C. SYSPER2 [OPTIONAL]
	 * @param string $iana Internet Assigned Numbers Authority [OPTIONAL]
	 * @param string $ioc International Olympic Committee [OPTIONAL]
	 * @param string $un U.N. International Traffic Distinguished Signs [OPTIONAL]
	 * @param string $itu I.T.U Codes for International Telephone calls [OPTIONAL]
	 * @param string $oxan_id Oxford Analytica's Country Name [OPTIONAL]
	 * @param string $comref_del E.C. COMREF - Delegation Country ID (if it differs from $comref) [OPTIONAL]
	 * @return Country
	 * */
	protected function _getCountry( $iso2 = null, $iso3 = null, $isonum = null, $comref = null, $sysper = null, $iana = null, $ioc = null, $un = null, $itu = null, $oxan_id = null, $comref_del = null ) {
		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$hotspots = $this->_listHotSpots();
		
		ob_start();
		var_dump($hotspots);
		error_log(ob_get_contents());
		ob_end_clean();

		$query = <<<sql
select *
from `countries` c, `countries_equiv` ce
where c.`country_id` = ce.`country_id`

sql;

		$query_filter = "";
		if( null != $iso2 ) {
			$query_filter .= " and c.`country_id` = '".$my->real_escape_string($iso2)."' ";
		}
		if( null != $iso3 ) {
			$query_filter .= " and ce.`iso3` = '".$my->real_escape_string($iso3)."' ";
		}
		if( null != $isonum ) {
			$query_filter .= " and ce.`isonum` = '".$my->real_escape_string($isonum)."' ";
		}
		if( null != $comref ) {
			$query_filter .= " and (ce.`ec_comref` = '".$my->real_escape_string($comref)."' ";
			$query_filter .= " or ce.`ec_comref_del` = '".$my->real_escape_string($comref)."' ) ";
		}
		if( null != $comref_del ) {
			$query_filter .= " and ce.`ec_comref_del` = '".$my->real_escape_string($comref_del)."' ";
		}
		if( null != $sysper ) {
			$query_filter .= " and ce.`ec_sysper` = '".$my->real_escape_string($sysper)."' ";
		}
		if( null != $iana ) {
			$query_filter .= " and ce.`iana` = '".$my->real_escape_string($iana)."' ";
		}
		if( null != $ioc ) {
			$query_filter .= " and ce.`ioc` = '".$my->real_escape_string($ioc)."' ";
		}
		if( null != $un ) {
			$query_filter .= " and ce.`un` = '".$my->real_escape_string($un )."' ";
		}
		if( null != $itu ) {
			$query_filter .= " and ce.`itu` = '".$my->real_escape_string($itu)."' ";
		}
		if( null != $oxan_id ) {
			$query_filter .= " and ce.`oxan` = '".$my->real_escape_string($oxan_id)."' ";
		}

		if( 0 == strlen( $query_filter )) {
			if (!$this->soap) throw new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg ); return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
			return null;
		}
		$query .= $query_filter;
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			$my->close();
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}
		$row = $rs->fetch_assoc();
		$country = new Country();
		$country->code_iso2 = $row["country_id"];
		$country->code_iso3 = $row["iso3"];
		$country->name = $row["name_en"];
		$country->eu_member = (int)$row["eu_member"] ? true : false;
		$country->official = (int)$row["official"] ? true : false;
		$country->continent_id = (int)$row["continent_id"];
		$country->parent_code_iso2 = $row["parent_country_id"];
		$country->code_sysper2 = $row["ec_sysper"];
		$country->code_comref = $row["ec_comref"];
		$country->code_ioc = $row["ioc"];
		$country->code_isonum = $row["isonum"];
		$country->code_itu = $row["itu"];
		$country->code_un = $row["un"];
		$country->oxan_id = $row["oxan"];
		$country->code_comref_deleg = $row["ec_comref_del"];
		$country->hotspot = (array_search($row["country_id"], $hotspots) === false?false:true);
		$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
		$rs->free();
		$my->close();

		return $country;
	}

	/**
	 * Get the master list of continents
	 * @param string $token The session identifier
         * @param boolean $group If true, group Oceania and Antarctica [OPTIONAL]
	 * @return Continent[]
	 * */
	public function listContinents( $token, $group = false ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$query = <<<sql
select *
from `continents` c order by display_order
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$continents = array();
		while( $row = $rs->fetch_assoc() ) {
                    if (!$group || $row['continent_id'] != 7){
			$continent = new Continent();
			$continent->continent_id = (int)$row["continent_id"];
			$continent->name = (!$group || $row['continent_id'] != 6? $row["name_en"]: 'Oceania and Antarctica');
                        $continent->display_order = $row['display_order'];
			$continents[] = $continent;
                    }
		}

		$rs->free();
		$my->close();

		return $continents;
	}

	/**
	 * Get the information about a continent
	 * @param string $token The session identifier
	 * @param int $continent_id Id of the continent
	 * @return Continent
	 * */
	public function getContinent( $token, $continent_id ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$continent_id = sprintf("%d",$continent_id );
		$query = <<<sql
select *
from `continents` c
where c.`continent_id` = '{$continent_id}'
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}

		$row = $rs->fetch_assoc();
		$continent = new Continent();
		$continent->continent_id = (int)$row["continent_id"];
		$continent->name = $row["name_en"];

		$rs->free();
		$my->close();

		return $continent;
	}

	/**
	 * Get the master list of regions (Regions containing regions I.E: Continents)
	 * @param string $token The session identifier
	 * @param int $level What level of data to fetch (0 ::= Only Main Regions; 1 ::= Main Regions + Sub regions; 2 ::= Main Regions + Sub regions + Countries ) [OPTIONAL]
	 * @return MainRegion[]
	 * */
	public function getRegionList( $token, $level = null ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		switch( $level ) {
			case 0: {
				return $this->_getMainRegionList();
			} break;

			case 1: {
				return $this->_getMainRegionSubRegionsList();
			} break;

			case 2:
			case null:
			default: {
				return $this->_getMainRegionCountriesList();
			} break;
		}
	}



	protected function _getMainRegionList() {
		$error = false;
		$my = $this->openDatabase( 'common', $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		$query = 'select * from `v_main_regions`';
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		$main_regions = array();
		while( $row = $rs->fetch_assoc() ) {
			$mr = new MainRegion;
			$mr->region_id = $row['parent_region_id'];
			$mr->name = $row['parent_region_name_en'];
			$mr->regions = array();
			$main_regions[] = $mr;
		}
		return $main_regions;
	}
	protected function _getMainRegionSubRegionsList() {
		$error = false;
		$my = $this->openDatabase( 'common', $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		$query = 'select * from `v_sub_regions`  where `region_id` != `parent_region_id` order by `parent_region_id`';
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		$main_regions = array();
		while( $row = $rs->fetch_assoc() ) {
			if( !array_key_exists( $row['parent_region_id'], $main_regions )) {
				$main_regions[ $row['parent_region_id'] ] = array();
			}
			$main_regions[ $row['parent_region_id'] ][$row['region_id']] = $row;
		}
		$ret = array();
		foreach( $main_regions as $main_region_id => $main_region_data ) {
			$mr = new MainRegion;
			$first = true;
			foreach( $main_region_data as $region_id => $region_data ) {
				if( $first ) {
					$mr->region_id = $region_data['parent_region_id'];
					$mr->name = $region_data['parent_region_name_en'];
					$mr->regions = array();
					$first = false;
				}
				$r = new Region;
				$r->region_id = $region_data['region_id'];
				$r->name = $region_data['region_name_en'];
				$r->countries = array();
				$r->is_sub_region = false;
				$r->comments = $region_data['region_comments'];
				$mr->regions[] = $r;
			}
			$ret[] = $mr;
		}
		return $ret;
	}
	protected function _getMainRegionCountriesList() {
		$error = false;
		$my = $this->openDatabase( 'common', $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		$query = 'select * from `v_countries` order by `parent_region_id`';
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		$main_regions = array();
		while( $row = $rs->fetch_assoc() ) {
			if( !array_key_exists( $row['parent_region_id'], $main_regions )) {
				$main_regions[ $row['parent_region_id'] ] = array();
			}
			if( !array_key_exists( $row['region_id'], $main_regions[ $row['parent_region_id'] ] )) {
				$main_regions[ $row['parent_region_id'] ][ $row['region_id'] ] = array();
			}
			$main_regions[ $row['parent_region_id'] ][$row['region_id']][$row['country_id']] = $row;
		}

		$ret = array();
		foreach( $main_regions as $main_region_id => $main_region_data ) {
			$mr = false;
			$first = true;
			foreach( $main_region_data as $region_id => $region_data ) {
				$r = false;
				$first_r = true;
				foreach( $region_data as $country_id => $country_data ) {
					if( $first ) {
						$mr = new MainRegion;
						$mr->region_id = $country_data['parent_region_id'];
						$mr->name = $country_data['parent_region_name_en'];
						$mr->regions = array();
						$first = false;
					}
					if( $first_r ) {
						$r = new Region;
						$r->region_id = $country_data['region_id'];
						$r->name = $country_data['region_name_en'];
						$r->countries = array();
						$r->comments = $country_data['region_comments'];
						$r->is_sub_region = false;
						$first_r = false;
					}

					// $r->countries[] = $this->_getCountry( $country_id );
					$c = new Country;
					$c->name = $country_data['country_name_en'];
					$c->cluster_id = $country_data['cluster_id'];
					$c->code_comref = $country_data['code_ec_comref'];
					$c->code_comref_deleg = $country_data['code_ec_comref_del'];
					$c->code_iana = $country_data['code_iana'];
					$c->code_ioc = $country_data['code_ioc'];
					$c->code_iso2 = $country_data['code_iso2'];
					$c->code_iso3 = $country_data['code_iso3'];
					$c->code_isonum = $country_data['code_isonum'];
					$c->code_itu = $country_data['code_itu'];
					$c->code_sysper2 = $country_data['code_ec_sysper'];
					$c->code_un = $country_data['code_un'];
					// $c->continent_id = $country_data['continent_id'];
					$c->eu_member = $country_data['is_eu_member'];
					// $c->hotspot = $country_data['hotspot'];
					$c->official = $country_data['is_official'];
					$c->oxan_id = $country_data['code_oxan'];
					$c->parent_code_iso2 = $country_data['parent_country_id'];
					$r->countries[] = $c;
				}
				$mr->regions[] = $r;
			}
			$ret[] = $mr;
		}

		return $ret;
	}
	
	/**
	 * Gets a list of the official regions
	 * @param string $token The session identifier
	 * @param int $continent_id The continent identifier [OPTIONAL]
	 * @access public
	 * @return OfficialRegion[]
	*/
	public function listOfficialRegions($token, $continent_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		
		$continent_id = $my->real_escape_string($continent_id);
		
		$cond = '';
		if ($continent_id != null) {
			$cond = " where `continent_id` = '{$continent_id}'";
		}

		$query = <<<sql
select r.`region_id`, r.`name_en` as `region_name`, r.`comments`, r.`continent_id`
from `official_regions` r {$cond}
order by r.`name_en` asc
sql;
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$regions = array();
		while( $row = $rs->fetch_assoc() ) {
			$region = new OfficialRegion();
			$region->name = $row["region_name"];
			$region->region_id = $row["region_id"];
			$region->comments = $row["comments"];
			$region->continent_id = $row["continent_id"];
			$regions[] = $region;
		}

		$rs->free();
		$my->close();

		return $regions;
	}

		
	/**
	 * Get the list of all regions
	 * @param string $token The session identifier
	 * @param boolean $fetch_countries If set to true, the method will also return the list of countries belonging to the region (default: false) [OPTIONAL]
	 * @return Region[]
	 * */
	public function listRegions( $token, $fetch_countries = null ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$query = <<<sql
select r.`region_id`, r.`name_en` as `region_name`, r.`comments`, r.`sub_region`
from `regions` r
order by r.`name_en` asc
sql;
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$regions = array();
		while( $row = $rs->fetch_assoc() ) {
			$region = new Region();
			$region->name = $row["region_name"];
			$region->region_id = $row["region_id"];
			$region->comments = $row["comments"];
			$region->is_sub_region = (("1" == $row["sub_region"]) ? true : false );
			$region->countries = array();
			if( true === $fetch_countries ) {
				$query = <<<sql
select c.`country_id`, c.`name_en` as `country_name`, c.`eu_member`, c.`official`, c.`continent_id`, c.`parent_country_id`, c.`cluster_id`,
	e.`iso3`, e.`ec_sysper`, e.`ec_comref`, e.`ioc`, e.`isonum`, e.`itu`, e.`un`, e.`oxan`, e.`ec_comref_del`
from `regions_countries` rc, `countries` c, `countries_equiv` e
where rc.`country_id` = c.`country_id`
and c.`country_id` = e.`country_id`
and rc.`region_id` = '{$region->region_id}'
sql;

				$inner_rs = $my->query( $query );
				if( false === $inner_rs ) {
					if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
					$my->close();
					return null;
				}
				while( $row = $inner_rs->fetch_assoc() ) {
					$country = new Country();
					$country->code_iso2 = $row["country_id"];
					$country->code_iso3 = $row["iso3"];
					$country->name = $row["country_name"];
					$country->eu_member = (int)$row["eu_member"] ? true : false;
					$country->official = (int)$row["official"] ? true : false;
					$country->continent_id = (int)$row["continent_id"];
					$country->parent_code_iso2 = $row["parent_country_id"];
					$country->code_sysper2 = $row["ec_sysper"];
					$country->code_comref = $row["ec_comref"];
					$country->code_ioc = $row["ioc"];
					$country->code_isonum = $row["isonum"];
					$country->code_itu = $row["itu"];
					$country->code_un = $row["un"];
					$country->oxan_id = $row["oxan"];
					$country->code_comref_deleg = $row["ec_comref_del"];
					$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
					$region->countries[] = $country;
				}
				$inner_rs->free();
			}
			$regions[] = $region;
		}

		$rs->free();
		$my->close();

		return $regions;
	}

	/**
	 * Get the information about a region
	 * @param string $token The session identifier
	 * @param int $region_id Id of the region
	 * @return Region
	 * */
	public function getRegion( $token, $region_id ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$region_id = sprintf("%d",$region_id );
		$query = <<<sql
select r.`region_id`, r.`name_en` as `region_name`, r.`comments`, r.`sub_region`,
	c.`country_id`, c.`name_en` as `country_name`, c.`eu_member`, c.`official`, c.`continent_id`, c.`parent_country_id`, c.`cluster_id`,
	e.`iso3`, e.`ec_sysper`, e.`ec_comref`, e.`ioc`, e.`isonum`, e.`itu`, e.`un`, e.`oxan`, e.`ec_comref_del`
from `regions` r, `regions_countries` rc, `countries` c, `countries_equiv` e
where r.`region_id` = rc.`region_id`
and rc.`country_id` = c.`country_id`
and c.`country_id` = e.`country_id`
and r.`region_id` = '{$region_id}'
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}
		$region = false;
		while( $row = $rs->fetch_assoc() ) {
			if( false === $region ) {
				$region = new Region();
				$region->name = $row["region_name"];
				$region->region_id = $row["region_id"];
				$region->comments = $row["comments"];
				$region->is_sub_region = (("1" == $row["sub_region"]) ? true : false );
				$region->countries = array();
			}
			$country = new Country();
			$country->code_iso2 = $row["country_id"];
			$country->code_iso3 = $row["iso3"];
			$country->name = $row["country_name"];
			$country->eu_member = (int)$row["eu_member"] ? true : false;
			$country->official = (int)$row["official"] ? true : false;
			$country->continent_id = (int)$row["continent_id"];
			$country->parent_code_iso2 = $row["parent_country_id"];
			$country->code_sysper2 = $row["ec_sysper"];
			$country->code_comref = $row["ec_comref"];
			$country->code_ioc = $row["ioc"];
			$country->code_isonum = $row["isonum"];
			$country->code_itu = $row["itu"];
			$country->code_un = $row["un"];
			$country->oxan_id = $row["oxan"];
			$country->code_comref_deleg = $row["ec_comref_del"];
			$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
			$region->countries[] = $country;
		}

		$rs->free();
		$my->close();

		return $region;
	}

	/**
	 * Get the content of a cluster
	 * @param string $token The session identifier
	 * @param int $cluster_id The cluster identifier
	 * @return Cluster
	 * */

	public function GetCluster($token, $cluster_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($cluster_id);

		$query = <<<sql
				select * from clusters where cluster_id = {$id}
sql;
		if (($_cluster = $my->query($query)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$cluster = $_cluster->fetch_assoc();
		$rez = new Cluster();
		$rez->name = $cluster["name"];
		$rez->description = $cluster["description"];
		$rez->color = $cluster["color"];
		$rez->cluster_id = $cluster["cluster_id"];
		$rez->countries = array();

		$query = <<<sql
select *
from `countries` c, `countries_equiv` e
where c.`country_id` = e.`country_id`
and c.`cluster_id` = '{$rez->cluster_id}'
sql;
		$inner_rs = $my->query( $query );
		if( false === $inner_rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		while( $row = $inner_rs->fetch_assoc() ) {
			$country = new Country();
			$country->code_iso2 = $row["country_id"];
			$country->code_iso3 = $row["iso3"];
			$country->name = $row["name_en"];
			$country->eu_member = (int)$row["eu_member"] ? true : false;
			$country->official = (int)$row["official"] ? true : false;
			$country->continent_id = (int)$row["continent_id"];
			$country->parent_code_iso2 = $row["parent_country_id"];
			$country->code_sysper2 = $row["ec_sysper"];
			$country->code_comref = $row["ec_comref"];
			$country->code_ioc = $row["ioc"];
			$country->code_isonum = $row["isonum"];
			$country->code_itu = $row["itu"];
			$country->code_un = $row["un"];
			$country->oxan_id = $row["oxan"];
			$country->code_comref_deleg = $row["ec_comref_del"];
			$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
			$rez->countries[] = $country;
		}
		$inner_rs->free();

		$_cluster->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the list of available clusters
	 * @param string $token The session identifier
	 * @param boolean $fetch_countries If set to true, the method will also return the list of countries belonging to the region (default: false) [OPTIONAL]
	 * @return Cluster[]
	 * */

	public function ListClusters( $token, $fetch_countries = null ){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "common", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$query = <<<sql
				select * from clusters order by name;
sql;

		if (($clusters = $my->query($query)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$rez = array();
		while ($cluster = $clusters->fetch_assoc()){
			$cl = new Cluster();

			$cl->name = $cluster["name"];
			$cl->description = $cluster["description"];
			$cl->color = $cluster["color"];
			$cl->cluster_id = $cluster["cluster_id"];
			$cl->countries = array();

			if( true === $fetch_countries ) {
				$query = <<<sql
select *
from `countries` c, `countries_equiv` e
where c.`country_id` = e.`country_id`
and c.`cluster_id` = '{$cl->cluster_id}'
sql;

				$inner_rs = $my->query( $query );
				if( false === $inner_rs ) {
					if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
					$my->close();
					return null;
				}
				while( $row = $inner_rs->fetch_assoc() ) {
					$country = new Country();
					$country->code_iso2 = $row["country_id"];
					$country->code_iso3 = $row["iso3"];
					$country->name = $row["name_en"];
					$country->eu_member = (int)$row["eu_member"] ? true : false;
					$country->official = (int)$row["official"] ? true : false;
					$country->continent_id = (int)$row["continent_id"];
					$country->parent_code_iso2 = $row["parent_country_id"];
					$country->code_sysper2 = $row["ec_sysper"];
					$country->code_comref = $row["ec_comref"];
					$country->code_ioc = $row["ioc"];
					$country->code_isonum = $row["isonum"];
					$country->code_itu = $row["itu"];
					$country->code_un = $row["un"];
					$country->oxan_id = $row["oxan"];
					$country->code_comref_deleg = $row["ec_comref_del"];
					$country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
					$cl->countries[] = $country;
				}
				$inner_rs->free();
			}

			array_push($rez, $cl);
		}

		$clusters->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the reliefweb maps for a country
	 * @param string $token The session identifier
	 * @param string $country_id The country ISO2 code
	 * @return ReliefWebMap[]
		*/
	public function GetReliefWebMaps($token, $country_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
			
		$country_id = $my->real_escape_string($country_id);

		$sql = <<<sql
select * from `countries_reliefweb_maps` 
where `country_id` = '{$country_id}'
order by `map_id`
sql;

			
		$maps = $my->query( $sql );
		if( false === $maps ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
			
		$res = array();
			
		while ($map = $maps->fetch_assoc()){
			$m = new ReliefWebMap();
			$m->file = $map["file"];
			$m->map_id = $map["map_id"];
			$m->page = $map["page"];
			$m->thumbnail = $map["thumbnail"];

			array_push($res, $m);
		}
			
		return $res;
	}
}
?>