<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaDelegations extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Get a list of all available delegations (eventually filtered by country)
	 * @param string $token Session identifier
	 * @param Country $country Country filter [OPTIONAL]
	 * @return Delegation[]
	 * */
	public function listDelegations( $token, $country ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$delegations = array();

		$query = <<<sql
select d.del_id, d.del_id_parent, d.nom_en as delegation_name, d.pay_cd as country_code, d.org_id,
	d.vil_nom_en as city_name, d.adr_adm, d.adr_post, d.gmt, d.horaire_en as opening_hours,
	t.nom as deleg_type, t.nom_abrege as deleg_type_short
from delegations d, crf_lib_typ_delegations t
where d.typdel_id = t.typdel_id
and t.lng_cd = 'ENG'

sql;
		if( null !== $country && ! (null === $country->code_comref && null === $country->code_comref_deleg) ) {
			$pay_cd = addslashes( $country->code_comref );
			if( null !== $country->code_comref_deleg ) {
				$pay_cd = addslashes( $country->code_comref_deleg );
			}
			$query .= <<<sql
and d.pay_cd = '{$pay_cd}'
sql;
		}

		$oracle = oci_pconnect( $this->config["databases"]["comref"]["user"], $this->config["databases"]["comref"]["pass"], $this->config["databases"]["comref"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $query);
		if (!$stid) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$ocidesc = oci_new_descriptor( $oracle, OCI_D_LOB);
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		while( false !== ($record = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))) {

			$deleg = new Delegation();

			// Set the values
			$deleg->id = (int)$record["DEL_ID"];
			$deleg->parent_id = null === $record["DEL_ID_PARENT"] ? null : (int) $record["DEL_ID_PARENT"];
			$deleg->name = $record["DELEGATION_NAME"];
			$deleg->country_code = $record["COUNTRY_CODE"];
			$deleg->city_name = $record["CITY_NAME"];
			$deleg->administrative_address = $record["ADR_ADM"];
			$deleg->postal_address = $record["ADR_POST"];
			$deleg->GMT = $record["GMT"];
			$deleg->opening_hours = $record["OPENING_HOURS"];
			$deleg->type_of_delegation = $record["DELEG_TYPE"];
			$deleg->type_of_delegation_short = $record["DELEG_TYPE_SHORT"];
			$deleg->org_id = $record["ORG_ID"];
			$deleg->contacts = array();

			if( null !== $country && ! (null === $country->code_comref && null === $country->code_comref_deleg) ) {
				$deleg->country = $country;
			} else {
				// Fetch the country details
				$deleg->country = $this->_getCountry( false, false, false, $deleg->country_code, false, false, false, false, false, false, false );
			}

			// Fetch delegation contacts
			$query = <<<sql
select p.nom_typ_telecom_en as "TYPE", t.no_telecom as "CONTACT"
from app_crf_p.crf4tariqa_rep_telecom_v t, app_crf_p.crf4tariqa_rep_typ_telecom_v p
where t.del_id = {$record["DEL_ID"]}
and t.typ_telecom_id = p.typ_telecom_id
and p.niv_vie_privee = 0
sql;

			$stid2 = oci_parse($oracle, $query);
			if (!$stid2) {
				$e = oci_error($oracle);
				if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
				return null;
			}
			$r = oci_execute($stid2, OCI_DEFAULT);
			if (!$r) {
				$e = oci_error($stid);
				if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
				return null;
			}
			while( false !== ( $record2 = oci_fetch_array( $stid2, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))) {
				$deleg->contacts[] = new Pair( $record2["TYPE"], $record2["CONTACT"]);
			}

			$delegations[] = $deleg;
		}

		return $delegations;

	}

	/**
	 * Get a list of all available delegations (eventually filtered on a list of countries)
	 * @param string $token Session identifier
	 * @param Country[] $countries Country list filter
	 * @return Delegation[]
	 * */
	public function listDelegations2( $token, $countries ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$delegations = array();

		$country_codes = array();
		foreach( $countries as $country ) {
			if( null === $country->code_comref && null === $country->code_comref_deleg) {
				continue;
			}
			$pay_cd = addslashes( $country->code_comref );
			if( null !== $country->code_comref_deleg ) {
				$pay_cd = addslashes( $country->code_comref_deleg );
			}
			$country_codes[] = $pay_cd;
		}

		if( 0 == count( $country_codes )) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}
		$country_list = implode( "', '", $country_codes );
		$query = <<<sql
select d.del_id, d.del_id_parent, d.nom_en as delegation_name, d.pay_cd as country_code, d.org_id,
	d.vil_nom_en as city_name, d.adr_adm, d.adr_post, d.gmt, d.horaire_en as opening_hours,
	t.nom as deleg_type, t.nom_abrege as deleg_type_short
from delegations d, crf_lib_typ_delegations t
where d.typdel_id = t.typdel_id
and t.lng_cd = 'ENG'
and d.pay_cd in ('{$country_list}')
sql;

		$oracle = oci_pconnect( $this->config["databases"]["comref"]["user"], $this->config["databases"]["comref"]["pass"], $this->config["databases"]["comref"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $query);
		if (!$stid) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		while( false !== ($record = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))) {

			$deleg = new Delegation();

			// Set the values
			$deleg->id = (int)$record["DEL_ID"];
			$deleg->parent_id = null === $record["DEL_ID_PARENT"] ? null : (int) $record["DEL_ID_PARENT"];
			$deleg->name = $record["DELEGATION_NAME"];
			$deleg->country_code = $record["COUNTRY_CODE"];
			$deleg->city_name = $record["CITY_NAME"];
			$deleg->administrative_address = $record["ADR_ADM"];
			$deleg->postal_address = $record["ADR_POST"];
			$deleg->GMT = $record["GMT"];
			$deleg->opening_hours = $record["OPENING_HOURS"];
			$deleg->type_of_delegation = $record["DELEG_TYPE"];
			$deleg->type_of_delegation_short = $record["DELEG_TYPE_SHORT"];
			$deleg->org_id = $record["ORG_ID"];
			$deleg->contacts = array();

			$deleg->country = $this->_getCountry( false, false, false, $deleg->country_code, false, false, false, false, false, false, false );

			// Fetch delegation contacts
			$query = <<<sql
select p.nom_typ_telecom_en as "TYPE", t.no_telecom as "CONTACT"
from app_crf_p.crf4tariqa_rep_telecom_v t, app_crf_p.crf4tariqa_rep_typ_telecom_v p
where t.del_id = {$record["DEL_ID"]}
and t.typ_telecom_id = p.typ_telecom_id
and (p.niv_vie_privee = 0 or p.typ_telecom_id in (4, 23))
sql;

			$stid2 = oci_parse($oracle, $query);
			if (!$stid2) {
				$e = oci_error($oracle);
				if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
				return null;
			}
			$r = oci_execute($stid2, OCI_DEFAULT);
			if (!$r) {
				$e = oci_error($stid);
				if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
				return null;
			}
			while( false !== ( $record2 = oci_fetch_array( $stid2, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))) {
				$deleg->contacts[] = new Pair( $record2["TYPE"], $record2["CONTACT"]);
			}

			$delegations[] = $deleg;
		}

		return $delegations;

	}

	/**
	 * Get information about a delegation
	 * @param string $token Session identifier
	 * @param int $delegation_id Identifier of the delegation
	 * @return Delegation
	 * */
	public function getDelegation( $token, $delegation_id ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$delegation_id = sprintf( "%d", $delegation_id );
		$query = <<<sql
select d.del_id, d.del_id_parent, d.nom_en as delegation_name, d.pay_cd as country_code, d.org_id,
	d.vil_nom_en as city_name, d.adr_adm, d.adr_post, d.gmt, d.horaire_en as opening_hours,
	t.nom as deleg_type, t.nom_abrege as deleg_type_short
from delegations d, crf_lib_typ_delegations t
where d.typdel_id = t.typdel_id
and t.lng_cd = 'ENG'
and d.del_id = {$delegation_id}
sql;

		$oracle = oci_pconnect( $this->config["databases"]["comref"]["user"], $this->config["databases"]["comref"]["pass"], $this->config["databases"]["comref"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $query);
		if (!$stid) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		$record = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS );
		if( false === $record ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}

		$deleg = new Delegation();

		// Set the values
		$deleg->id = (int)$record["DEL_ID"];
		$deleg->parent_id = null === $record["DEL_ID_PARENT"] ? null : (int) $record["DEL_ID_PARENT"];
		$deleg->name = $record["DELEGATION_NAME"];
		$deleg->country_code = $record["COUNTRY_CODE"];
		$deleg->city_name = $record["CITY_NAME"];
		$deleg->administrative_address = $record["ADR_ADM"];
		$deleg->postal_address = $record["ADR_POST"];
		$deleg->GMT = $record["GMT"];
		$deleg->opening_hours = $record["OPENING_HOURS"];
		$deleg->type_of_delegation = $record["DELEG_TYPE"];
		$deleg->type_of_delegation_short = $record["DELEG_TYPE_SHORT"];
		$deleg->org_id = $record["ORG_ID"];
		$deleg->contacts = array();
		$deleg->country = $this->_getCountry( false, false, false, $deleg->country_code, false, false, false, false, false, false, false );
		$deleg->hod = array();

		// Fetch the HOD
		$query = <<<sql
select *
from delegations_hod d
where d.del_id = {$record["DEL_ID"]}
sql;

		$stid = oci_parse($oracle, $query);
		if (!$stid) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$personnel_list = array();
		while( false !== ($record3 = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))){
			$personnel = new DelegationPersonnel();
			$personnel->id = $record3["PER_ID"];
			$personnel->job_id = $record3["JOB_ID"];
			$personnel->firstname = $record3["FIRST_NAME"];
			$personnel->lastname = $record3["LAST_NAME"];
			$personnel->email = $record3["EMAIL"];
			$personnel->phone = $record3["PHONE"];
			$personnel->job_name = $record3["JOB_NAME"];
			$personnel->job_description = $record3["JOB_OBJECTIVES"];

			$personnel_list[] = $personnel;
		}
		$deleg->hod = $personnel_list;


		// Fetch delegation contacts
		$query = <<<sql
select p.nom_typ_telecom_en as "TYPE", t.no_telecom as "CONTACT"
from app_crf_p.crf4tariqa_rep_telecom_v t, app_crf_p.crf4tariqa_rep_typ_telecom_v p
where t.del_id = {$record["DEL_ID"]}
and t.typ_telecom_id = p.typ_telecom_id
and p.niv_vie_privee = 0
sql;

		$stid2 = oci_parse($oracle, $query);
		if (!$stid2) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid2, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		while( false !== ( $record2 = oci_fetch_array( $stid2, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))) {
			$deleg->contacts[] = new Pair( $record2["TYPE"], $record2["CONTACT"]);
		}

		return $deleg;

	}

	/**
	 * Get the list of personnel working in a given delegation
	 * @param string $token Session identifier
	 * @param int $delegation_id Identifier of the delegation
	 * @return DelegationPersonnel[]
	 * */
	public function getDelegationPersonnel( $token, $delegation_id ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$query = <<<sql
select *
from delegations_personnel d
where d.del_id = {$delegation_id}
sql;

		$oracle = oci_pconnect( $this->config["databases"]["comref"]["user"], $this->config["databases"]["comref"]["pass"], $this->config["databases"]["comref"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $query);
		if (!$stid) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		$personnel_list = array();
		while( false !== ($record = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))){
			$personnel = new DelegationPersonnel();
			$personnel->id = $record["PER_ID"];
			$personnel->job_id = $record["JOB_ID"];
			$personnel->firstname = $record["FIRST_NAME"];
			$personnel->lastname = $record["LAST_NAME"];
			$personnel->email = $record["EMAIL"];
			$personnel->phone = $record["PHONE"];
			$personnel->job_name = $record["JOB_NAME"];
			$personnel->job_description = $record["JOB_OBJECTIVES"];

			$personnel_list[] = $personnel;
		}

		return $personnel_list;
	}

	/**
	 * Get the list of Head of Delegation and Deputy Head of Delegation of a given Delegation
	 * @param string $token Session identifier
	 * @param int $delegation_id Identifier of the delegation
	 * @return DelegationPersonnel[]
	 * */
	public function getHeadsOfDelegation( $token, $delegation_id ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$query = <<<sql
select *
from delegations_hod d
where d.del_id = {$delegation_id}
sql;

		$oracle = oci_pconnect( $this->config["databases"]["comref"]["user"], $this->config["databases"]["comref"]["pass"], $this->config["databases"]["comref"]["dsn"], "UTF8" );
		if (!$oracle) {
			$e = oci_error();
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$stid = oci_parse($oracle, $query);
		if (!$stid) {
			$e = oci_error($oracle);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}
		$r = oci_execute($stid, OCI_DEFAULT);
		if (!$r) {
			$e = oci_error($stid);
			if (!$this->soap) throw new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true )); return new SoapFault((string) self::e_database, $e["message"] . "\n" . print_r( $e, true ));
			return null;
		}

		$personnel_list = array();
		while( false !== ($record = oci_fetch_array( $stid, OCI_ASSOC | OCI_RETURN_NULLS | OCI_RETURN_LOBS ))){
			$personnel = new DelegationPersonnel();
			$personnel->id = $record["PER_ID"];
			$personnel->job_id = $record["JOB_ID"];
			$personnel->firstname = $record["FIRST_NAME"];
			$personnel->lastname = $record["LAST_NAME"];
			$personnel->email = $record["EMAIL"];
			$personnel->phone = $record["PHONE"];
			$personnel->job_name = $record["JOB_NAME"];
			$personnel->job_description = $record["JOB_OBJECTIVES"];

			$personnel_list[] = $personnel;
		}

		return $personnel_list;
	}

	/**
	 * Get the list of CrisisCorrepondents (eventually filtered on a list of countries)
	 * @param string $token Session Identifier
	 * @param Country[] $countries Country list filter [OPTIONAL]
	 * @return CrisisCorrespondent[]
	 * */
	public function listCrisisCorrespondents( $token, $countries ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "permanence", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$country_filter = "";
		$country_codes = array();
		if( null != $countries ) {
			foreach( $countries as $country ) {
				if( null === $country->code_iso2 ) {
					continue;
				}
				$country_codes[] = $my->real_escape_string( $country->code_iso2 );
			}
			if( 0 < count( $country_codes )) {
				$country_list = implode( "', '", $country_codes );
				$country_filter = "and d.`country_id in ('{$country_list}')`";
			}
		}

		$query = <<<sql
select
	d.`name_en` as `delegation_name`,
	c.`del_emergency_phone`, c.`del_emergency_fax`, c.`del_video_conference`, c.`cc_name`, c.`cc_phone`, c.`cc_mobile`, c.`hod_name`, c.`hod_phone`, c.`hod_mobile`, c.`permanence_description`,
	co.`name_en` as `country_name`, co.`country_id`, co.`parent_country_id`, co.`eu_member`, co.`official`, co.`continent_id`, co.`cluster_id`,
	e.`country_id` as `iso2`, e.`iso3`, e.`iana`, e.`ioc`, e.`un`,  e.`isonum`, e.`itu`, e.`ec_comref`, e.`ec_comref_del`, e.`ec_min`, e.`ec_sysper`, e.`ec_trade`, e.`oxan`, e.`janes_folder`, e.`janes_base`
from crisis_room.crisis_correspondants c, crisis_room.ec_delegations d, meta_common.countries co, meta_common.countries_equiv e
where c.delegation_id = d.delegation_id
and d.country_id = co.country_id
and co.country_id = e.country_id
		{$country_filter}
sql;
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			$my->close();
			return null;
		}

		$cc_list = array();
		while( false !== ($row = $rs->fetch_assoc())) {
			$cc = new CrisisCorrespondent();
			$cc->cc_mobile = $row["cc_mobile"];
			$cc->cc_phone = $row["cc_phone"];
			$cc->cc_name = $row["cc_name"];
			$cc->hod_mobile = $row["hod_mobile"];
			$cc->hod_phone = $row["hod_phone"];
			$cc->hod_name = $row["hod_name"];
			$cc->description = $row["permanence_description"];
			$cc->phone = $row["del_emergency_phone"];
			$cc->fax = $row["del_emergency_fax"];
			$cc->videoconference = $row["del_video_conference"];
			$cc->country = new Country();
			$cc->country->code_iso2 = $row["iso2"];
			$cc->country->code_iso3 = $row["iso3"];
			$cc->country->name = $row["country_name"];
			$cc->country->eu_member = (int)$row["eu_member"] ? true : false;
			$cc->country->official = (int)$row["official"] ? true : false;
			$cc->country->continent_id = (int)$row["continent_id"];
			$cc->country->parent_code_iso2 = $row["parent_country_id"];
			$cc->country->code_sysper2 = $row["ec_sysper"];
			$cc->country->code_comref = $row["ec_comref"];
			$cc->country->code_ioc = $row["ioc"];
			$cc->country->code_isonum = $row["isonum"];
			$cc->country->code_itu = $row["itu"];
			$cc->country->code_un = $row["un"];
			$cc->country->oxan_id = $row["oxan"];
			$cc->country->code_comref_deleg = $row["ec_comref_del"];
			$cc->country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
			$cc_list[] = $cc;
		}

		$rs->free();
		$my->close();
		return $cc_list;

	}

	/**
	 * Get the details of the Crisis Correpondent Informations of a specific Delegation
	 * @param string $token Session Identifier
	 * @param Country $country Identifier of the Country
	 * @return CrisisCorrespondent
	 * */
	public function getCrisisCorrespondent( $token, $country ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		if( false === $country->code_iso2 ) {
			if (!$this->soap) throw new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg ); return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "permanence", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$country_id = $my->real_escape_string( $country->code_iso2 );

		$query = <<<sql
select
	d.`name_en` as `delegation_name`,
	c.`del_emergency_phone`, c.`del_emergency_fax`, c.`del_video_conference`, c.`cc_name`, c.`cc_phone`, c.`cc_mobile`, c.`hod_name`, c.`hod_phone`, c.`hod_mobile`, c.`permanence_description`,
	co.`name_en` as `country_name`, co.`country_id`, co.`parent_country_id`, co.`eu_member`, co.`official`, co.`continent_id`, co.`cluster_id`,
	e.`country_id` as `iso2`, e.`iso3`, e.`iana`, e.`ioc`, e.`un`,  e.`isonum`, e.`itu`, e.`ec_comref`, e.`ec_comref_del`, e.`ec_min`, e.`ec_sysper`, e.`ec_trade`, e.`oxan`, e.`janes_folder`, e.`janes_base`
from crisis_room.crisis_correspondants c, crisis_room.ec_delegations d, meta_common.countries co, meta_common.countries_equiv e
where c.delegation_id = d.delegation_id
and d.country_id = co.country_id
and co.country_id = e.country_id
and d.`country_id` = '{$country_id}'
sql;
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			$my->close();
			return null;
		}

		$row = $rs->fetch_assoc();

		$cc = new CrisisCorrespondent();
		$cc->cc_mobile = $row["cc_mobile"];
		$cc->cc_phone = $row["cc_phone"];
		$cc->cc_name = $row["cc_name"];
		$cc->hod_mobile = $row["hod_mobile"];
		$cc->hod_phone = $row["hod_phone"];
		$cc->hod_name = $row["hod_name"];
		$cc->description = $row["permanence_description"];
		$cc->phone = $row["del_emergency_phone"];
		$cc->fax = $row["del_emergency_fax"];
		$cc->videoconference = $row["del_video_conference"];
		$cc->country = new Country();
		$cc->country->code_iso2 = $row["iso2"];
		$cc->country->code_iso3 = $row["iso3"];
		$cc->country->name = $row["country_name"];
		$cc->country->eu_member = (int)$row["eu_member"] ? true : false;
		$cc->country->official = (int)$row["official"] ? true : false;
		$cc->country->continent_id = (int)$row["continent_id"];
		$cc->country->parent_code_iso2 = $row["parent_country_id"];
		$cc->country->code_sysper2 = $row["ec_sysper"];
		$cc->country->code_comref = $row["ec_comref"];
		$cc->country->code_ioc = $row["ioc"];
		$cc->country->code_isonum = $row["isonum"];
		$cc->country->code_itu = $row["itu"];
		$cc->country->code_un = $row["un"];
		$cc->country->oxan_id = $row["oxan"];
		$cc->country->code_comref_deleg = $row["ec_comref_del"];
		$cc->country->cluster_id = ((null === $row["cluster_id"]) ? null : (int)$row["cluster_id"]);
		$rs->free();
		$my->close();
		return $cc;
	}
}
?>