<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

require_once( "fdk/factivaClient.class.php" );
class tariqaFactiva extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Gets the headlines result set from a search result
	 * @param factiva_ContentSearchResult $content The factiva query
	 * @param int $first The first result to fetch
	 * @param int $count The number of results to fetch
	 * @return FactivaContentHeadline[]
	 **/
	private function factivaGetHeadlines($content, $first, $count){
		$result = array();
			
		for ($i = $first; $i < $first + $count; $i++){
			$headline = new FactivaContentHeadline();
			$_headline = is_array($content->contentHeadlinesResultSet->contentHeadline) ? $content->contentHeadlinesResultSet->contentHeadline[$i] : $content->contentHeadlinesResultSet->contentHeadline;

			$headline->accessionNo = $_headline->accessionNo;
			$headline->baseLanguage = $_headline->baseLanguage;
			$headline->columnName = $_headline->columnName;
			$headline->copyright = $_headline->copyright;
			$paragraphs = is_array($_headline->headline->paragraph) ? $_headline->headline->paragraph : array($_headline->headline->paragraph);

			$headline->headline = array();

			foreach ($paragraphs as $paragraph){
				$headline->headline[] = $paragraph->_;
			}

			$headline->part = new FactivaContentPart();
			$parts = is_array($_headline->contentParts->part) ? $_headline->contentParts : array($_headline->contentParts->part);

			$headline->part->contentType = $_headline->contentParts->contentType;
			$headline->part->primaryReference = $_headline->contentParts->primaryReference;
			$headline->part->parts = array();
			foreach ($parts as $part){
				$p = new FactivaPart();
				$p->mimeType = $part->mimeType;
				$p->reference = $part->reference;
				$p->size = $part->size;
				$p->subType = $part->subType;
				$p->type = $part->type;
				$headline->part->parts[] = $p;
			}

			$headline->publicationDate = $_headline->publicationDate;
			$headline->sectionName = $_headline->sectionName;
			$paragraphs = is_array($_headline->snippet->paragraph) ? $_headline->snippet->paragraph : array($_headline->snippet->paragraph);
			$headline->snippet = array();

			foreach($paragraphs as $paragraph){
				$headline->snippet[] = $paragraph->_;
			}

			$headline->sourceCode = $_headline->sourceCode;
			$headline->sourceName = $_headline->sourceName;
			$headline->wordCount = $_headline->wordCount;
			$headline->byLIne = $_headline->byline;
			$headline->credit = $_headline->credit;
			$result[] = $headline;
		}
			
		return $result;
	}

	/**
	 * Search for articles using Factiva
	 * @param string $token Session Identifier
	 * @param FactivaContentQuery $query The factiva query
	 * @return FactivaContentResultSet
	 **/
	public function FactivaContentSearch($token, $query){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
			
		$max_results = $this->config["factiva"]["max_results"];
			
		$client = $this->initializeFactivaClient();
			
		$connReused = true;
		$login = $this->factivaLogin($client, $this->config['factiva']['user'],
		$this->config['factiva']['password'], $this->config['factiva']['namespace'],
		$connReused, false);
			
		$srchReq = new factiva_PerformContentSearch();
		$srchReq->controlData = $login->controlData;
		$srchReq->contentCategory = $query->contentCategory;
		$srchReq->dateFormat = $query->dateFormat;
		$count = $query->first + $query->count;
		$srchReq->maxResultsToReturn = $count < $max_results ? $count : $max_results;
		$srchReq->sortOrder = $query->searchOrder;
		$noDuplicates = "";
		if ($query->noDuplicates) $noDuplicates = " not ns=nnam";
		$range = "";
		$sources = "";
			
		if ($query->range != null){
			$d1 = date("Ymd");
			$d2 = date("Ymd", time() - $range * 86400);
			$range = " and (date from {$d1} to {$d2})";
		}
			
		if ($query->sourceCodes != null){
			foreach ($query->sourceCodes as $source){
				$sources .= ($source == "" ? "" : " or ") . " sc = {$source}";
			}
			$sources = " and ({$sources})";
		}
		$srchReq->searchString = "({$query->searchString}){$noDuplicates}{$range}{$sources}";
			
		$srchResp = new factiva_PerformContentSearchResponse();
		try{
			$srchResp = $client->PerformContentSearch( $srchReq );
		}
		catch (Exception  $e){
			$this->dump_to_log($e);
		}
			
		$result = new FactivaContentResultSet();
		$content = $srchResp->contentSearchResponse->contentSearchResult;
		$result->highlightString = $content->highlightString;
		$result->indexOfFirstHeadline = $content->indexOfFirstHeadline;
		$result->queryHitCount = $content->queryHitCount;
		$result->searchContext = $content->searchContext;
		if ($content->contentHeadlinesResultSet->count > 0){
			$fetched = ($count < $content->contentHeadlinesResultSet->count ? $count : $content->contentHeadlinesResultSet->count);
			$result->results = $this->factivaGetHeadlines($content, $query->first, $fetched - $query->first);

			$count -= $fetched;

			$index = $fetched;

			while ($count > 0 && $index < $content->queryHitCount){
				$srchCntReq = new factiva_ContinueContentSearch();
				$srchCntReq->controlData = $login->controlData;
				$srchCntReq->searchContext = $result->searchContext;
				$srchCntReq->firstResultToReturn = $index;
				$srchCntReq->maxResultsToReturn = $count < $max_results ? $count : $max_results;
				if ($srchCntReq->maxResultsToReturn < 10) $srchCntReq->maxResultsToReturn = 10;
				$srchCntResp = new factiva_ContinueContentSearchResponse();
				$srchCntResp = $client->ContinueContentSearch( $srchCntReq );
				$content = $srchCntResp->contentSearchResponse->contentSearchResult;
				$result->results = array_merge($result->results, $this->factivaGetHeadlines($content, 0, ($count < $max_results ? $count : $max_results)));
				$fetched = $count < $max_results ? $count : $max_results;
				$index += $fetched;
				$count -= $fetched;
			}
		}
		else $result->results = array();
			
		return $result;
	}

	/**
	 * Initializes the factiva client
	 * @return FactivaClient
	 * */
	private function initializeFactivaClient(){
		// SOAP Client
		$client_config = array(
                            'cache_wsdl' => false,
                            'trace' => true,
                            'exceptions' => true
		);
		if( array_key_exists( 'proxy', $this->config ) &&
		array_key_exists( 'enable', $this->config['proxy'] ) &&
		$this->config['proxy']['enable'] == 1
		) {
			$client_config['proxy_host'] = $this->config['proxy']['host'];
			$client_config['proxy_port'] = (int)$this->config['proxy']['port'];	// ATTENTION!!! PROXY PORT DOIT  ETRE UN INT!!!!
			$client_config['proxy_login'] = $this->config['proxy']['user'];
			$client_config['proxy_password'] = $this->config['proxy']['password'];
		}
		return new FactivaClient( $client_config, $this->config["application"]["path"] );
	}

	/**
	 * Authenticates and return the controlData
	 * @param FactivaClient $client The factiva client
	 * @param string $user The username
	 * @param string $password The password
	 * @param string $namespace Thenamespace
	 * @param bool $connReused That variable will receive a boolean indicating weither the connection was reused or if a new connection was made
	 * @param bool $freshConnect If set to true, discard existing control data and establish a new session
	 * @return factiva_LoginResultType
	 * */
	private function factivaLogin( $client, $user, $password, $namespace, &$connReused, $freshConnect = false ) {
		$connReused = false;
		if( true === $freshConnect ) {
			$this->factivaLogout($client);
		} else {
			$controlData = $this->factivaLoginGetControlData();
			if( false !== $controlData ) {
				$connReused = true;
				return $controlData;
			}
		}

		// Perform the login
		$login = new factiva_PerformLogin();
		$login->userID = $user;
		$login->password = $password;
		$login->namespace = $namespace;

		$response = new factiva_PerformLoginResponse();
		$response = $client->PerformLogin( $login );

		// Save the Control Data
		$this->factivaLoginSetControlData( $response->loginResponse->loginResult );

		return $response->loginResponse->loginResult;
	}

	/**
	 * Save the control data into the session files
	 * @param factiva_LoginResultType $login_result Login Result
	 * @return boolean
	 * */
	private function factivaLoginSetControlData( $login_result ) {
		return file_put_contents( $this->factivaLoginGetcontrolDataFileName(), serialize( $login_result ) );
	}

	/**
	 * Return the session file name
	 * @return string
	 * */
	private function factivaLoginGetcontrolDataFileName() {
		return $this->config['factiva']['session']['path'] . $this->config['factiva']['user'] . $this->config['factiva']['namespace'] . '.dat';
	}

	/**
	 * Logout from factiva
	 * @param FactivaClient $client The factiva client
	 * @return void
	 * */
	private function factivaLogout($client) {
		$loginData = new factiva_LoginResultType();
		$loginData = $this->factivaLoginGetControlData();

		$logout = new factiva_PerformLogout();
		$logout->controlData = $loginData->controlData;
		if( false !== $loginData ) {
			$response = new factiva_PerformLogoutResponse();
			$response = $client->PerformLogout( $logout );

			// Delete the session
			$this->factivaLoginClearControlData();
		}
	}

	/**
	 * Deletes the session file
	 * @return boolean
	 * */
	private function factivaLoginClearControlData() {
		$filename = $this->factivaLoginGetcontrolDataFileName();
		if( file_exists( $filename )) {
			return  @unlink( $filename );
		}
		return true;
	}

	/**
	 * Retrieve the control data from the session files
	 * @return factiva_LoginResultType
	 * */
	public function factivaLoginGetControlData() {
		$filename = $this->factivaLoginGetcontrolDataFileName();
		if( !file_exists( $filename )) {
			return false;
		}
		if( filemtime( $filename ) < time() - (int)$this->config['factiva']['session']['duration'] ) {
			return false;
		}
		// Set the last modification time of the file

		@touch( $filename );

		return unserialize( file_get_contents( $filename ));
	}

	/**
	 * Retrieve a factiva document
	 * @param string $token Session Identifier
	 * @param string $accessionNo The document identifier
	 * @return FactivaDocument
	 * */
	public function FactivaGetDocument($token, $accessionNo){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
			
		$client = $this->initializeFactivaClient();
		$connReused = true;
		$login = $this->factivaLogin($client, $this->config['factiva']['user'],
		$this->config['factiva']['password'], $this->config['factiva']['namespace'],
		$connReused, false);

		$getArticleReq = new factiva_GetArticle();
		$getArticleReq->controlData = $login->controlData;
		$getArticleReq->references[] = $accessionNo;
		$getArticleReq->responseDataSet = 'FULL'; // values: FULL, FULR, HLPI, KWIC;
		$getArticleReq->highlightString = null;
		$getArticleReq->usageAggregator = null;

		$getArticleResp = new factiva_GetArticleResponse();
		$getArticleResp = $client->GetArticle( $getArticleReq );

		$article = $getArticleResp->articleResponse->articleResultSet->article;
		
		$result = new FactivaDocument();
			
		$result->accessionNo = $article->accessionNo;
		$result->baseLanguage = $article->baseLanguage;
		$paragraphs = is_array($article->headline->paragraph) ? $article->headline->paragraphs : array($article->headline->paragraph);
		$result->headline = array();
		foreach ($paragraphs as $paragraph) {
			$result->headline[] = $paragraph->_;
		}
			
		$result->publicationDate = $article->publicationDate;
		$result->sourceCode = $article->sourceCode;
		$result->sourceName = $article->sourceName;
		$result->wordCount = $article->wordCount;
		$result->columnName = $article->columnName;
		$result->copyright = $article->copyright;
		$result->sectionName = $article->sectionName;
		$result->contact = $article->contact;
		$result->corrections = array();
		if ($article->corrections != null){
			$paragraphs = is_array($article->corrections->paragraph) ? $article->corrections->paragraph : array($article->corrections->paragraph);
			foreach ($paragraphs as $paragraph){
				$result->corrections[] = $paragraph->_;
			}
		}
			
		$result->edition = $article->edition;

		$paragraphs = is_array($article->leadParagraph->paragraph) ? $article->leadParagraph->paragraph : array($article->leadParagraph->paragraph);
		$result->leadParagraph = array();
		foreach ($paragraphs as $paragraph){
			$result->leadParagraph[] = $paragraph->_;
		}

		$result->tailParagraph = array();
		if ($article->tailParagraphs != null){
			$paragraphs = is_array($article->tailParagraphs->paragraph) ? $article->tailParagraphs->paragraph : array($article->tailParagraphs->paragraph);
			foreach ($paragraphs as $paragraph){
				$result->tailParagraph[] = $paragraph->_;
			}
		}

		$result->publisherGroupName = $article->publisherGroupName;
		$result->publisherGroupCode = $article->publisherGroupCode;
		$result->publisherName = $article->publisherName;
		$result->volume = $article->volume;
		$result->byLine = $article->byline;
		$result->credit = $article->credit;

		return $result;
			
	}

	/**
	 * Search for sources using Factiva
	 * @param string $token Session Identifier
	 * @param FactivaSourceQuery $query The factiva query
	 * @return FactivaSourceResultSet
	 **/
	public function FactivaSourceSearch($token, $query){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
			
		$max_results = $this->config["factiva"]["max_results"];
			
		$client = $this->initializeFactivaClient();
		$connReused = true;
		$login = $this->factivaLogin($client, $this->config['factiva']['user'],
		$this->config['factiva']['password'], $this->config['factiva']['namespace'],
		$connReused, false);
			
		$srchReq = new factiva_PerformSourceSearch();
		$srchReq->controlData = $login->controlData;
		$srchReq->contentCategory = array();
		foreach($query->contentCategories as $category){
			$srchReq->contentCategories[] = $category;
		}
		$count = $query->first + $query->count;
		$srchReq->maxResultsToReturn = $count < $max_results ? $count : $max_results;
		$srchReq->responseType = $query->responseType;
		$srchReq->searchString = "({$query->searchString})";
			
		$srchResp = new factiva_PerformSourceSearchResponse();
		$srchResp = $client->PerformSourceSearch( $srchReq );
			
		$result = new FactivaSourceResultSet();
		$content = $srchResp->sourceSearchResponse->sourceSearchResult;
		$result->queryHitCount = $content->queryHitCount;
		$result->indexOfFirstHeadline = $content->indexOfFirstHeadline;
		$result->searchContext = $content->searchContext;
			
		if ($content->sourcesResultSet->count > 0){
			$fetched = ($count < $content->sourcesResultSet->count ? $count : $content->sourcesResultSet->count);
			$result->results = $this->factivaGetSources($content, $query->first, $fetched - $query->first);

			$count -= $fetched;

			$index = $fetched;

			while ($count > 0 && $index < $content->queryHitCount){
				$srchCntReq = new factiva_ContinueSourceSearch();
				$srchCntReq->controlData = $login->controlData;
				$srchCntReq->responseType = $query->responseType;
				$srchCntReq->searchContext = $result->searchContext;
				$srchCntReq->firstResultToReturn = $index;
				$srchCntReq->maxResultsToReturn = $count < $max_results ? $count : $max_results;
				if ($srchCntReq->maxResultsToReturn < 10) $srchCntReq->maxResultsToReturn = 10;
				$srchCntResp = new factiva_ContinueSourceSearchResponse();
				$srchCntResp = $client->ContinueSourceSearch( $srchCntReq );
				$content = $srchCntResp->sourceSearchResponse->sourceSearchResult;
				$result->results = array_merge($result->results, $this->factivaGetSources($content, 0, ($count < $max_results ? $count : $max_results)));
				$fetched = $count < $max_results ? $count : $max_results;
				$index += $fetched;
				$count -= $fetched;
			}
		}
		else $result->results = array();

		return $result;
	}

	/**
	 * Gets the sources result set from a search result
	 * @param factiva_SourceSearchResult $content The factiva result set
	 * @param int $first The first result to fetch
	 * @param int $count The number of results to fetch
	 * @return FactivaSource[]
	 **/
	private function factivaGetSources($content, $first, $count){
		$result = array();
			
		for ($i = $first; $i < $first + $count; $i++){
			$source = new FactivaSource();
			$_source = $content->sourcesResultSet->source[$i];
			$source->sourceCode = $_source->sourceCode;
			$source->availabilityStatus = $_source->availabilityStatus;
			$source->baseLanguage = $_source->baseLanguage;
			$source->compositeSourceCodes = array();
			if ($_source->compositeSourceCodes != null){
				$codes = is_array($_source->compositeSourceCodes->sourceCode) ? $_source->compositeSourceCodes->sourceCode : array($_source->compositeSourceCodes->sourceCode);
				foreach ($codes as $code){
					$source->compositeSourceCodes[] = $code;
				}
			}
			$source->copyright = $_source->copyright;
			$source->description = array();
			if ($_source->description != null){
				$paragraphs = is_array($_source->description->paragraph) ? $_source->description->paragraph : array($_source->description->paragraph);
				foreach ($paragraphs as $paragraph){
					$source->description[] = $paragraph->_;
				}
			}
			$source->frequency = $_source->frequency->code;
			$source->groupCodes = array();
			if ($_source->groupCodes != null){
				$groupCodes = is_array($_source->groupCodes->groupCode) ? $_source->groupCodes->groupCode : array($_source->groupCodes->groupCode);
				foreach ($groupCodes as $groupCode){
					$source->groupCodes[] = $groupCode;
				}
			}

			$source->listName = $_source->listName;
			$source->publicationWebAddress = $_source->publicationWebAddress;
			$source->sourceName = $_source->sourceName;

			$result[] = $source;
		}
			
		return $result;
	}

	/**
	 * Search for articles using Google News
	 * @param string $token Session Identifier
	 * @param FactivaSourceGroupQuery $query The factiva query
	 * @return FactivaSourceGroupResultSet
	 **/
	public function FactivaSourceGroupSearch($token, $query){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
			
		$max_results = $this->config["factiva"]["max_results"];
			
		$client = $this->initializeFactivaClient();
		$connReused = true;
		$login = $this->factivaLogin($client, $this->config['factiva']['user'],
		$this->config['factiva']['password'], $this->config['factiva']['namespace'],
		$connReused, false);
			
		$srchReq = new factiva_PerformSourceGroupSearch();
		$srchReq->controlData = $login->controlData;
		$srchReq->contentCategory = array();
		foreach($query->contentCategories as $category){
			$srchReq->contentCategories[] = $category;
		}
		$count = $query->first + $query->count;
		$srchReq->maxResultsToReturn = $count < $max_results ? $count : $max_results;
		$srchReq->searchString = "({$query->searchString})";
			
		$srchResp = new factiva_PerformSourceGroupSearchResponse();
		$srchResp = $client->PerformSourceGroupSearch( $srchReq );
			
		$result = new FactivaSourceGroupResultSet();
		$content = $srchResp->sourceGroupSearchResponse->sourceGroupSearchResult;
		$result->queryHitCount = $content->queryHitCount;
		$result->indexOfFirstHeadline = $content->indexOfFirstHeadline;
		$result->searchContext = $content->searchContext;
			
		if ($content->sourceGroupsResultSet->count > 0){
			$fetched = ($count < $content->sourceGroupsResultSet->count ? $count : $content->sourceGroupsResultSet->count);
			$result->results = $this->factivaGetSourcesGroups($content, $query->first, $fetched - $query->first);

			$count -= $fetched;

			$index = $fetched;

			while ($count > 0 && $index < $content->queryHitCount){
				$srchCntReq = new factiva_ContinueSourceGroupSearch();
				$srchCntReq->controlData = $login->controlData;
				$srchCntReq->searchContext = $result->searchContext;
				$srchCntReq->firstResultToReturn = $index;
				$srchCntReq->maxResultsToReturn = $count < $max_results ? $count : $max_results;
				if ($srchCntReq->maxResultsToReturn < 10) $srchCntReq->maxResultsToReturn = 10;
				$srchCntResp = new factiva_ContinueSourceGroupSearchResponse();
				$srchCntResp = $client->ContinueSourceGroupSearch( $srchCntReq );
				$content = $srchCntResp->sourceGroupSearchResponse->sourceGroupSearchResult;
				$result->results = array_merge($result->results, $this->factivaGetSourcesGroups($content, 0, ($count < $max_results ? $count : $max_results)));
				$fetched = $count < $max_results ? $count : $max_results;
				$index += $fetched;
				$count -= $fetched;
			}
		}
		else $result->results = array();
			
		return $result;
	}

	/**
	 * Gets the sources groups result set from a search result
	 * @param factiva_SourceGroupSearchResult $content The factiva result set
	 * @param int $first The first result to fetch
	 * @param int $count The number of results to fetch
	 * @return FactivaSourceGroup[]
	 **/
	private function factivaGetSourcesGroups($content, $first, $count){
		$result = array();

		for ($i = $first; $i < $first + $count; $i++){
			$group = new FactivaSourceGroup();
			$_group = $content->sourceGroupsResultSet->sourceGroup[$i];

			$group->groupCode = $_group->groupCode;
			$group->applicableContentCategories = array();
			if ($_group->applicableContentCategories != null){
				$categories = is_array($_group->applicableContentCategories->contentCategory) ? $_group->applicableContentCategories->contentCategory : array($_group->applicableContentCategories->contentCategory);
				foreach ($categories as $category){
					$group->applicableContentCategories[] = $category;
				}
			}
			$group->description = array();
			if ($_group->description != null){
				$paragraphs = is_array($_group->description->paragraph) ? $_group->description->paragraph : array($_group->description->paragraph);
				foreach ($paragraphs as $paragraph){
					$group->description[] = $paragraph->_;
				}
			}
			$group->groupName = $_group->groupName;
			$group->groupType = $_group->groupType;
			$group->parentGroupCode = $_group->parentGroupCode;
			$result[] = $group;
		}
			
		return $result;
	}

}
?>