<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaHotspots extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Get the list of hotspots for a day
	 * @param string $token The session identifier
	 * @param int $day The day for which to retrieve the hotspots (null means the current date) [OPTIONAL]
	 * @return string[] A list of countries iso codes.
	 * */
	public function ListHotSpots($token, $day = null){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_listHotSpots( $day );
	}

	/**
	 * Get the list of hotspots for a day without authentification
	 * @param int $day The day for which to retrieve the hotspots (null means the current date) [OPTIONAL]
	 * @return string[] A list of countries iso codes.
	 * */
	protected function _listHotSpots( $day = null){
		$error = false;
		$my = $this->OpenDatabase( "hotspots", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$date = (is_null($day)?date("Y-m-d"):date("Y-m-d", $day));

		/*		$sql = <<<sql
				select * from `hotspots` where date = '{$date}'
sql;
*/
/*		$sql = <<<sql
				select `country_id`, date_add(`date`, interval 1 day) `date`, 'n' as `forced` from `statsmobiles_hotspots` where date = '{$date}'
sql;*/
		/*$sql = <<<sql
	select *
	from 
	(
			select `country_id`, `date`, `forced`
			from `hotspots`
			where `forced`='y'
			and `date`='{$date}'
		UNION
			select `country_id`, date_add(`date`, interval 1 day) `date`, 'n' as `forced` 
			from `statsmobiles_hotspots` 
			where datediff('{$date}', `date`) = 1
	) dyn
	group by `country_id`, `date`
sql;*/

		$sql = "select max(`time`) as 'time' from hotspots";
		if (($max = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$rez = array();

		if ($query = $max->fetch_assoc()){
		    $d = new DateTime('@' . (time() - 60 * 60 * 2));
		    $time = $query['time'];
		    $min_time = $d->format('Y-m-d H:i:s');
		    $max->free();
		    if ($time > $min_time){
			$sql = "select country_id from hotspots where `time` = '" . $time . "' or forced = 'y'";
			if (($hotspots = $my->query($sql)) === false){
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}
			while ($hotspot = $hotspots->fetch_assoc()){
				array_push($rez, $hotspot["country_id"]);
			}
			$hotspots->free();
		    }
		}

		$my->close();

		return $rez;
	}

    /**
     * Gets the number of articles for all the 63 weeks for a country
	 * @param string $token The session identifier
     * @param string $country_id The country identifier
     * @param int $history_id If specified, the history identifier to retrieve [OPTIONAL]
     * @access public
     * @return int[]
     */
    public function getHistory($token, $country_id, $history_id = null){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
        
		$error = false;
		$my = $this->OpenDatabase( "hotspots", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

        $result = array();

        if ($history_id == null){
            $sql = "select max(history_id) as h, max(`time`) as t from history where country_id = '" . $country_id . "'";
            if (($query = $my->query($sql)) === false){
                if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
                $my->close();
                return null;
            }

            if ($row = $query->fetch_assoc()){
                $history_id = $row['h'];
                $result[] = strtotime($row['t']);
                $d = new DateTime($row['t']);
                $d->sub(new DateInterval('P62D'));
            }
        }

        $sql = "select articles_no from history_values where history_id = '" . $history_id . "' order by `interval` desc";
        if (($query = $my->query($sql)) === false){
            if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
            $my->close();
            return null;
        }

        while ($row = $query->fetch_assoc()){
            $sql = "select count(*) as c from hotspots where country_id = '" . $country_id . "' and date(`time`) = '" . $d->format('Y-m-d') . "'";
            $_q = $my->query($sql);
            if ($_r = $_q->fetch_assoc()){
                if ($_r['c'] > 0){
                    $result[] = -$row['articles_no'];
                }
                else {
                    $result[] = $row['articles_no'];
                }
            }
            $d->add(new DateInterval('P1D'));
        }

        return $result;
    }

    /**
     * Gets the number of articles for all the 63 weeks for a country
	 * @param string $token The session identifier
     * @param string $country_id The country identifier
     * @param int[] $dates The dates to search from (unix timestamp)
     * @param int $intervals The number of intervals to search
     * @access public
     * @return HotspotsResultSet[]
     */
    public function getHistory2($token, $country_id, $dates, $intervals){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
        
		$error = false;
		$my = $this->OpenDatabase( "hotspots", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

        $result = array();
        foreach ($dates as $date){
            $result[] = $this->_getHistory($date, $intervals, $country_id, $my);
        }

        return $result;
    }

    /**
     * Gets the history for a given date
     * @param int $date The date
     * @param int $intervals The number of intervals to get the history
     * @param string $country_id The country identifier
     * @param mysqli $my The mysql database connection
     * @access protected
     * @return HotspotsResultSet
     */
    protected function _getHistory($date, $intervals, $country_id, $my){
        $d = new DateTime('@' . $date);
        $history_id = null;
        $time = null;
        while ($history_id == null){
			$sql = "select history_id, `time` from history where `time` >= '{$d->format("Y-m-d H:i:s")}' and country_id = '{$country_id}' order by `time` limit 1";
			if (($query = $my->query($sql)) === false){
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}
			
			if ($row = $query->fetch_assoc()){
				$history_id = $row['history_id'];
				$time = $row['time'];
			}
			else {
				$d->sub(new DateInterval('P1D'));
			}
		}
		
		error_log("HISTORY_ID: " . $history_id);
		
		$sql = "select * from history_values where history_id = '{$history_id}' and `interval` < {$intervals} order by `interval` desc";
		if (($query = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		
		$result = new HotspotsResultSet();
		$_d = new DateTime($time);
		$result->date = $_d->getTimestamp() + $_d->getOffset();
		$result->articles = array();
		
		while ($row = $query->fetch_assoc()){
			$sql = <<<sql
select 
	count(*) as c 
from 
	hotspots 
where 
	timediff(adddate(`time`, interval {$row['interval']} day), '{$time}') <= '00:30:00' and country_id = '{$country_id}' 
	and `time` >= subdate('{$time}', interval {$row['interval']} day)
sql;

			if (($_q = $my->query($sql)) === false){
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $_q ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}
            if ($_r = $_q->fetch_assoc()){
                if ($_r['c'] > 0){
                    $result->articles[] = -$row['articles_no'];
                }
                else {
                    $result->articles[] = $row['articles_no'];
                }
            }
		}
		
        return $result;
    }
}