<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
*/

class tariqaIDOL extends Tariqa {
    /**
     * Configuration array
     * @var array
     * */
    protected $config = null;

    /**
     * The class is called using SOAP
     * @var boolean
     */
    public $soap;

    /**
     * Constructs a tariqaThemes Object
     * @return Tariqa
     * */

    public function __construct($config, $soap) {
	$this->config = $config;
	$this->soap = $soap;
    }

    /**
     * Parse the document data from an IDOL response XML
     * @param DOMDocument $doc The IDOL document
     * @access protected
     * @return IDOLDocument[]
     */
    protected function IDOLParseResponse($doc) {
	$xp = new DOMXPath($doc);
	$i1 = $xp->query('//autn:hit');
	$documents = array();

	for ($i = 0; $i < $i1->length; $i++){
	    $i2 = $i1->item($i);
	    $d = new IDOLDocument();
	    $d->content = array();
	    $d->general = array();

	    for ($j = 0; $j < $i2->childNodes->length; $j++){
		$i3 = $i2->childNodes->item($j);
		if ($i3->nodeName == 'autn:id'){
		    $d->id = $i3->nodeValue;
		}
		else if ($i3->nodeName == 'autn:content'){
		    for ($k = 0; $k < $i3->childNodes->length; $k++){
			$i4 = $i3->childNodes->item($k);
			if ($i4->nodeName == 'DOCUMENT'){
			    for ($l = 0; $l < $i4->childNodes->length; $l++){
				$i5 = $i4->childNodes->item($l);
				$p = new Pair($i5->nodeName, $i5->nodeValue);
				$d->content[] = $p;
			    }
			    break;
			}
		    }
		}
		else {
		    $p = new Pair($i3->nodeName, $i3->nodeValue);
		    $d->general[] = $p;
		}
	    }

	    $documents[] = $d;
	}

	return $documents;
    }

    /**
     * Performs an IDOL search
     * @param string $token The token identifier
     * @param IDOLQuery $query The query
     * @access public
     * @return IDOLResultSet
     */
    public function IDOLSearch($token, $query) {
	if( false === $this->CheckToken( $token )) {
	    if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
	    return null;
	}

	return $this->_IDOLSearch($query);
    }

    /**
     * Performs an IDOL search without authentication
     * @param IDOLQuery $query The query
     * @access protected
     * @return IDOLResultSet
     */
    protected function _IDOLSearch($query) {
	if ($query->url == null){
	    if (!$this->soap) throw new SoapFault('The IDOL server is not set', self::e_http); return new SoapFault('The IDOL server is not set', self::e_http);
	}

	if ($query->start == null){
	    $query->start = 0;
	}

	if ($query->query == null){
	    $query->query = '*';
	}
	
	$pattern = '/^(\(*)\(\*\)[^\(]*\((.*)$/m';
	
	$pattern2 = '/^\(\*\) <AND> <NOT> \([^\)]*\)$/m';
	
	if (preg_match($pattern, $query->query) && !preg_match($pattern2, $query->query)){
	    $query->query = preg_replace($pattern, '\1(\2', $query->query);
	}

	$url = $query->url;

	if (strpos('?', $url) === false){
	    $url .= '?action=Query';
	}
	else {
	    $url .= '&action=Query';
	}

	if ($query->fields == 'all'){
	    $url .= '&Print=all';
	}
	else {
	    $url .= '&Print=Fields&PrintFields=' . $query->fields;
	}

	$url .= '&Text=' . rawurlencode($query->query);

	if ($query->type == IDOLQuery::QUERY_TYPE_VQL){
	    $url .= '&vql=True';
	}

	if ($query->summary != false){
	    $url .= '&summary=' . $query->summary_type;
	}

	if ($query->start != null){
	    $url .= '&Start=' . $query->start;
	}

	if ($query->count != null){
	    $url .= '&MaxResults=' . ($query->start + $query->count - 1);
	}

	if ($query->from != null){
	    $d = new DateTime('@' . $query->from);
	    $url .= "&MinDate=" . $d->format('H:i:s d/m/Y');
	}

	if ($query->to != null){
	    $d = new DateTime('@' . $query->to);
	    $url .= "&MaxDate=" . $d->format('H:i:s d/m/Y');
	}

	if ($query->sort != null){
	    $url .= '&sort=' . $query->sort;
	}

	if ($query->highlight != false){
	    $url .= '&highlight=' . $query->highlight_type;
	}

	if ($query->language != null){
	    $url .= '&MatchLanguageType=' . $query->language;
	}
	else{
	    $url .= '&AnyLanguage=True';
	}

	if ($query->extra_options != null){
	    $url .= '&' . $query->extra_options;
	}

	$url .= '&TotalResults=True';
	
	$_r = $this->_fetchUrlNoProxy(new WebRequest($url));

	$doc = new DOMDocument('1.0', 'UTF-8');
	if ($doc->loadXML($_r->body) === false){
	    if (!$this->soap) throw new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$_r}" ); return new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$_r}" );
	}

	$result = new IDOLResultSet();
	$result->query = $query;

	$xp = new DOMXPath($doc);
	$rs = $xp->query('/autnresponse/response');
	if ($rs->length > 0){
	    $result->response = $rs->item(0)->nodeValue;
	}

	if ($result->response != 'SUCCESS'){
	    ob_start();
	    var_dump($query);
	    var_dump($_r);
	    error_log(ob_get_contents());
	    ob_end_clean();
	    $result->response .= '. Please see the log for more details';
	    $result->count = 0;
	    $result->results = array();
	    return $result;
	}

	$rs = $xp->query('//autn:totalhits');
	if ($rs->length > 0){
	    $result->docs = $rs->item(0)->nodeValue;
	}

	$result->spell_check = null;
	$rs = $xp->query('//autn:spellingquery');
	if ($rs->length > 0){
	    $result->spell_check = $rs->item(0)->nodeValue;
	}

	$result->documents = $this->IDOLParseResponse($doc);
	$result->count = count($result->documents);

	return $result;
    }

    /**
     * Gets an IDOL document
     * @param string $token The token identifier
     * @param int $id The document id
     * @param string $url The IDOL url
     * @param string $highlight The terms to be highlighted [OPTIONAL]
     * @access public
     * @return IDOLDocument
     */
    public function IDOLGetDocument($token, $id, $url, $highlight = null) {
	if( false === $this->CheckToken( $token )) {
	    if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
	    return null;
	}

	return $this->_IDOLGetDocument($id, $url, $highlight);
    }

    /**
     * Gets an IDOL document without authentication
     * @param int $id The document id
     * @param string $url The IDOL url
     * @param string $highlight The terms to be highlighted [OPTIONAL]
     * @access protected
     * @return IDOLDocument
     */
    protected function _IDOLGetDocument($id, $url, $highlight = null) {
	if ($url == null){
	    if (!$this->soap) throw new SoapFault('The IDOL server is not set', self::e_http); return new SoapFault('The IDOL server is not set', self::e_http);
	}

	if ($id == null){
	    if (!$this->soap) throw new SoapFault('The document id is not set', self::e_http); return new SoapFault('The document id is not set', self::e_http);
	}

	if (strpos('?', $url) === false){
	    $url .= '?action=GetContent';
	}
	else {
	    $url .= '&action=GetContent';
	}
	$url .= '&Print=all';
	$url .= '&ID=' . $id;

	if ($highlight != null){
	    $url .= '&links=' . rawurlencode($highlight) . '&Highlight=Terms';
	}

	$_r = $this->_fetchUrlNoProxy(new WebRequest($url));

	$doc = new DOMDocument('1.0', 'UTF-8');
	if ($doc->loadXML($_r->body) === false){
	    if (!$this->soap) throw new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$_r}" ); return new SoapFault((string) self::e_session, "Error loading the XML: {$url}\n{$_r}" );
	}

	$docs = $this->IDOLParseResponse($doc);

	if (count($docs) > 0){
	    return $docs[0];
	}

	return null;
    }

    /**
     * Transfors an IDOL Document into a given class.
     * The result is returned as an associative array which can then be json decoded setting array to false so we will have a new class. 
     * @param IDOLDocument $doc The document
     * @param array $matrix The transformation matrix (an associative array in which the keys are the new class methods and the values are the IDOL document keys)
     * @param object $obj The object in which the document will be transformed
     * @access protected
     * @return object
     */
    protected function IDOLTransformDocument($doc, $matrix, $obj) {
	foreach ($matrix as $key => $value){
	    $pref = '';
	    if (preg_match('/^general\//', $value)){
		$enumerator = $doc->general;
		$pref = 'general/';
	    }
	    else {
		$enumerator = $doc->content;
		$pref = 'content/';
	    }

	    /* @var $item Pair */
	    foreach ($enumerator as $item){
		if ($pref . $item->key == $value){
		    $obj->$key = $item->value;
		    break;
		}
	    }
	}

	return $obj;
    }

}
?>
