<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaNewsletter extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	 */
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */

	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}

	/**
	 * Get the list of available newsletters
	 * @param string $token The session identifier
	 * @param int $category_id The category identifier [OPTIONAL]
	 * @return Newsletter[]
	 * */
	public function ListNewsletters( $token, $category_id = null ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$cond = '';
		$category_id = $my->real_escape_string($category_id);
		if ($category_id != null) $cond = " where `category_id` = '{$category_id}'";

		$query = <<<sql
select *
from `newsletters` n inner join `newsletters_categories` using(`category_id`)
		{$cond}
order by `newsletter_id` desc
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$newsletters = array();

		while( ($row = $rs->fetch_assoc()) ) {
			$newsletter = new Newsletter();
			$newsletter->id = $row["newsletter_id"];
			$newsletter->date = $row["crea_date"];
			$newsletter->subject = $row["subject"];
			$newsletter->template = $row["template"];
			$newsletter->recipients = array_filter( array_map( "trim", explode( ";", $row["recipients"] )));
			$newsletter->sent = ($row["sent"] == 'y'?true:false);
			$newsletter->body = $row["body"];
			$newsletter->summary = $row["summary"];
				
			$category = new NewsletterCategory();
			$category->id = $row["category_id"];
			$category->name = $row["title"];
			$category->template = $row["def_template"];
			$category->order = $row["order"];
				
			$newsletter->category = $category;

			$newsletters[] = $newsletter;
		}

		$rs->free();
		$my->close();

		return $newsletters;

	}

	/**
	 * Get the content of a newsletter
	 * @param string $token The session identifier
	 * @param int $newsletter_id The newsletter identifier
	 * @return Newsletter
	 * */
	public function getNewsletter( $token, $newsletter_id) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		if( !is_int( $newsletter_id )) {
			if (!$this->soap) throw new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg ); return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$newsletter_id = $my->real_escape_string( $newsletter_id );
		$query = <<<sql
select *
from `newsletters` n inner join `newsletters_categories` using(`category_id`)
where n.`newsletter_id` = '{$newsletter_id}'
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}

		$row = $rs->fetch_assoc();

		$newsletter = new Newsletter();
		$newsletter->id = $row["newsletter_id"];
		$newsletter->date = $row["crea_date"];
		$newsletter->subject = $row["subject"];
		$newsletter->template = $row["template"];
		$newsletter->recipients = array_filter( array_map( "trim", explode( ";", $row["recipients"] )));
		$newsletter->sent = ($row["sent"] == 'y'?true:false);
		$newsletter->body = $row["body"];
		$newsletter->summary = $row["summary"];

		$category = new NewsletterCategory();
		$category->id = $row["category_id"];
		$category->name = $row["title"];
		$category->template = $row["def_template"];
		$category->order = $row["order"];

		$newsletter->category = $category;

		$rs->free();
		$my->close();

		return $newsletter;
	}

	/**
	 * Get the list of available newsletters
	 * @param string $token The session identifier
	 * @return Newsletter[]
	 * */
	public function listIndarNewsletters( $token ) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqa", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$query = <<<sql
select *
from `top5_newsletter` n
order by `newsletter_id` desc
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$newsletters = array();

		while( ($row = $rs->fetch_assoc()) ) {
			$newsletter = new Newsletter();
			$newsletter->articles = false;
			$newsletter->id = $row["newsletter_id"];
			$newsletter->date = $row["crea_date"];
			$newsletter->subject = $row["subject"];
			$newsletter->theme = $row["theme"];
			$newsletter->banner = $row["banner"];
			$newsletter->recipients = array_filter( array_map( "trim", explode( ";", $row["recipients"] )));
			$newsletter->footnote = $row["footer"];
			$newsletter->hasBuzztracker = ("y" == $row["buzz"]) ? true : false;
			$newsletter->hasScreenshot =  ("y" == $row["scrshot"]) ? true : false;

			$newsletters[] = $newsletter;
		}

		$rs->free();
		$my->close();

		return $newsletters;

	}

	/**
	 * Get the content of a newsletter
	 * @param string $token The session identifier
	 * @param int $newsletter_id The newsletter identifier
	 * @return Newsletter
	 * */
	public function getIndarNewsletter( $token, $newsletter_id) {

		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}
		if( !is_int( $newsletter_id )) {
			if (!$this->soap) throw new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg ); return new SoapFault((string) self::e_invalid_argument, self::e_invalid_argument_msg );
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqa", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$newsletter_id = $my->real_escape_string( $newsletter_id );
		$query = <<<sql
select *
from `top5_newsletter` n
where n.`newsletter_id` = '{$newsletter_id}'
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}

		$row = $rs->fetch_assoc();
		$newsletter = new Newsletter();
		$newsletter->articles = array();
		$newsletter->id = $row["newsletter_id"];
		$newsletter->date = $row["crea_date"];
		$newsletter->subject = $row["subject"];
		$newsletter->theme = $row["theme"];
		$newsletter->banner = $row["banner"];
		$newsletter->recipients = array_filter( array_map( "trim", explode( ";", $row["recipients"] )));
		$newsletter->footnote = $row["footer"];
		$newsletter->hasBuzztracker = ("y" == $row["buzz"]) ? true : false;
		$newsletter->hasScreenshot =  ("y" == $row["scrshot"]) ? true : false;

		$rs->free();

		$query = <<<sql
select a.`article_id`, s.`section_id`, s.`title` as `section_name`, a.`title`, a.`link`, a.`content`, a.`n`
from `top5_newsletter_articles` a left join `top5_newsletter_sections` s
	on s.`section_id` = a.`section_id`
where a.`newsletter_id` = '{$newsletter_id}'
order by a.`n` asc
sql;
		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}

		while( $row = $rs->fetch_assoc() ) {
			$article = new NewsletterArticle();
			$article->id = $row["article_id"];
			$article->section = $row["section_name"];
			$article->headline = $row["title"];
			$article->body = $row["content"];
			$article->order = $row["n"];
			$article->url = $row["link"];
			$newsletter->articles[] = $article;
		}

		$rs->free();
		$my->close();

		return $newsletter;
	}

	/**
	 * Lists the newsletters categories
	 * @param string $token The session identifier
	 * @access public
	 * @return NewsletterCategory[]
	 */
	public function listNewslettersCategories($token){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$query = <<<sql
select *
from `newsletters_categories`
order by `order`, `title`
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$categories = array();

		while( ($row = $rs->fetch_assoc()) ) {
			$category = new NewsletterCategory();
			$category->id = $row["category_id"];
			$category->name = $row["title"];
			$category->template = $row["def_template"];
			$category->order = $row["order"];
				
			$categories[] = $category;
		}

		$rs->free();
		$my->close();

		return $categories;
	}

	/**
	 * Gets a newsletter category
	 * @param string $token The session identifier
	 * @param int $category_id The category identifier
	 * @access public
	 * @return NewsletterCategory
	 */
	public function getNewsletterCategory($token, $category_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		
		$category_id = $my->real_escape_string($category_id);

		$query = <<<sql
select *
from `newsletters_categories`
where `category_id` = '{$category_id}'
sql;

		$rs = $my->query( $query );
		if( false === $rs ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		if( 0 == $rs->num_rows ) {
			if (!$this->soap) throw new SoapFault((string) self::e_missing_record, self::e_missing_record_msg ); return new SoapFault((string) self::e_missing_record, self::e_missing_record_msg );
			return null;
		}

		$categories = array();
		$row = $rs->fetch_assoc();

		$category = new NewsletterCategory();
		$category->id = $row["category_id"];
		$category->name = $row["title"];
		$category->template = $row["def_template"];
		$category->order = $row["order"];
	
		$rs->free();
		$my->close();

		return $category;
	}
	
	/**
	 * Tells if an user can edit a newsletter
	 * @param string $token The session identifier
	 * @param string $user_id The user identifier
	 * @param int[] $newsletter_ids An array of newsletter identifiers
	 * @access public
	 * @return int[]
	*/
	public function canEditNewsletter($token, $user_id, $newsletter_ids){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		
		$user_id = $my->real_escape_string($user_id);
		$results = array();
		
		if (count($newsletter_ids) != 0){
			foreach ($newsletter_ids as $id){
				$id = $my->real_escape_string($id);
				$query = <<<sql
select *
from `newsletters_users` inner join `newsletters` using(`category_id`)
where `user_id` = '{$user_id}' and `newsletter_id` = '{$id}'
sql;
		
				$rs = $my->query( $query );
				if( false === $rs ) {
					if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
					$my->close();
					return null;
				}
		
				if( 0 != $rs->num_rows ) {
					$results[] = $id;
				}
		
				$rs->free();
			}
		}
		else {
			$query = <<<sql
select newsletter_id from `newsletters_users` inner join `newsletters` using(`category_id`)
where `user_id` = '{$user_id}' 
sql;

			$results = array();
			$rs = $my->query( $query );
			if( false === $rs ) {
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}
			
			while ($row = $rs->fetch_assoc()){
				$results[] = $row["newsletter_id"];
			}
			
			$rs->free();
		}
		
		$my->close();

		return $results;
	}

	/**
	 * Tells if an user can edit a newsletter category
	 * @param string $token The session identifier
	 * @param string $user_id The user identifier
	 * @param int[] $category_ids An array of newsletter categories identifiers
	 * @access public
	 * @return int[]
	*/
	public function canEditNewsletterCategory($token, $user_id, $category_ids){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		
		$user_id = $my->real_escape_string($user_id);
		$results = array();
		
		if (count($category_ids) != 0){
			foreach ($category_ids as $id){
				$id = $my->real_escape_string($id);
				$query = <<<sql
select *
from `newsletters_users` inner join `newsletters_categories` using(`category_id`)
where `user_id` = '{$user_id}' and `category_id` = '{$id}'
sql;
		
				$rs = $my->query( $query );
				if( false === $rs ) {
					if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
					$my->close();
					return null;
				}
		
				if( 0 != $rs->num_rows ) {
					$results[] = $id;
				}
		
				$rs->free();
			}
		}
		else {
			$query = <<<sql
select `category_id` 
from `newsletters_users` 
where `user_id` = '{$user_id}'
sql;
			$rs = $my->query( $query );
			if( false === $rs ) {
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}
			
			$results = array();
			while ($row = $rs->fetch_assoc()){
				$results[] = $row["category_id"];
			}
			
			$rs->free();
		}
		
		$my->close();

		return $results;
	}
	
	/**
	 * Saves or updates a newsletter into the database database (for insert, just set the newsletter_id to null)
	 * @param string $token The session identifier
	 * @param Newsletter $newsletter The newsletter
	 * @access public
	 * @return int
	*/
	public function saveNewsletter($token, $newsletter){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		
		$id = $my->real_escape_string($newsletter->id);
		$subject = $my->real_escape_string($newsletter->subject);
		$recipients = "";
		foreach ($newsletter->recipients as $recipient){
			$recipients .= ($recipients == ''?'':';') . $recipient;
		}
		$recipients = $my->real_escape_string($recipients);
		$template = $my->real_escape_string($newsletter->template);
		$body = $my->real_escape_string($newsletter->body);
		$summary = $my->real_escape_string($newsletter->summary);
		$category_id = $my->real_escape_string($newsletter->category->id);
		$sent = ($newsletter->sent?'y':'n');
		
		if ($id == null){
			$sql = <<<sql
insert into `newsletters`
(`crea_date`, `subject`, `recipients`, `template`, `sent`, `body`, `summary`, `category_id`)
values
(now(), '{$subject}', '{$recipients}', '{$template}', '{$sent}', '{$body}', '{$summary}', '{$category_id}')
sql;
		}
		else {
			$sql = <<<sql
replace into `newsletters`
(`newsletter_id`, `crea_date`, `subject`, `recipients`, `template`, `sent`, `body`, `summary`, `category_id`)
values
('{$id}', now(), '{$subject}', '{$recipients}', '{$template}', '{$sent}', '{$body}', '{$summary}', '{$category_id}')
sql;
		}
		
		if( false === $my->query($sql) ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		
		if ($id == null){
			$sql = "select last_insert_id() as id";
			$rs = $my->query($sql);

			if( false === $rs ) {
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
				$my->close();
				return null;
			}
			
			$row = $rs->fetch_assoc();
			
			return $row["id"];
		}
		else {
			return $id;
		}
	}
	
	/**
	 * Deletes a newsletter
	 * @param string $token The session identifier
	 * @param int $newsletter_id The newsletter identifier
	 * @access public
	 * @return boolean
	*/
	public function deleteNewsletter($token, $newsletter_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
		
		$newsletter_id = $my->real_escape_string($newsletter_id);
		
		$sql = "delete from `newsletters` where `newsletter_id` = '{$newsletter_id}'";

		if( false === $my->query($sql) ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}
		
		return true;
		
	}
}
?>