<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaRadioTV extends Tariqa {
	
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * List the TV channels category
	 * @param string $token The session identifier
	 * @param boolean $channels If set to true, also fetch the channels for each category [OPTIONAL]
	 * @return TariqaTVChannelCategory[]
	*/
	public function ListTVChannelsCategories($token, $channels = false){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
			
		$sql = <<<sql
select * from `channeltv_categories`
order by `name`
sql;

			
		$categories = $my->query( $sql );
		if( false === $categories ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}
			
		$res = array();
			
		while ($category = $categories->fetch_assoc()){
			$c = new TariqaTVChannelCategory();
			$c->category_id = $category["category_id"];
			$c->name = $category["name"];

			if ($channels){
				$c->channels = $this->_ListTVChannels($category['category_id']);
			}
			
			array_push($res, $c);
		}
			
		return $res;

		
	}

	/**
	 * List the TV channels without authentication
	 * @param int $category_id The category identifier
	 * @access private
	 * @return TariqaTVChannel[]
	 */
	private function _ListTVChannels($category_id) {
		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$cond = " not (category_id is null) ";
		if ($category_id != null) $cond = " category_id = '{$category_id}' ";

		$sql = <<<sql
select c.*, cc.`name` from `channeltv` c inner join `channeltv_categories` cc using(`category_id`)
where {$cond}
order by `display_order` limit 8
sql;


		$channels = $my->query( $sql );
		if( false === $channels ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$res = array();

		while ($channel = $channels->fetch_assoc()){
			$c = new TariqaTVChannel();
			$c->channel_id = $channel["channel_id"];
			$c->logoURL = $channel["logo_url"];
			$c->streamingURL = $channel["streaming_url"];
			$c->category = $channel["name"];
			$c->channel_name = $channel['channel_name'];

			array_push($res, $c);
		}

		return $res;
	}
	
	/**
	 * List the TV channels
	 * @param string $token The session identifier
	 * @param integer $category_id The channel category [OPTIONAL]
	 * @return TariqaTVChannel[]
	 */
	public function ListTVChannels($token, $category_id = null){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_ListTVChannels($category_id);
	}


	/**
	 * List the Radio channels category
	 * @param string $token The session identifier
	 * @return TariqaRadioChannelCategory[]
	*/
	public function ListRadioChannelsCategories($token){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
			
		$sql = <<<sql
select * from `radio_categories`
order by `name`
sql;

			
		$categories = $my->query( $sql );
		if( false === $categories ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}
			
		$res = array();
			
		while ($category = $categories->fetch_assoc()){
			$c = new TariqaRadioChannelCategory();
			$c->category_id = $category["category_id"];
			$c->name = $category["name"];
			
			array_push($res, $c);
		}
			
		return $res;

		
	}
	
	/**
	 * List the Radio channels
	 * @param string $token The session identifier
	 * @param integer $category_id The channel category [OPTIONAL]
	 * @return TariqaRadioChannel[]
	 */
	public function ListRadioChannels($token, $category_id = null){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}
			
		$cond = " not (category_id is null) ";
		if ($category_id != null) $cond = " category_id = '{$category_id}' ";

		$sql = <<<sql
select r.*, rc.`name` from `radios` r inner join `radio_categories` rc using(`category_id`)
where {$cond}
order by `radio_id`
sql;

			
		$channels = $my->query( $sql );
		if( false === $channels ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}
			
		$res = array();
			
		while ($channel = $channels->fetch_assoc()){
			$c = new TariqaRadioChannel();
			$c->channel_id = $channel["channel_id"];
			$c->logoURL = $channel["logo_url"];
			$c->streamingURL = $channel["streaming_url"];
			$c->description = $channel["description"];
			$c->category = $channel["name"];
			
			array_push($res, $c);
		}
			
		return $res;

	}
}
?>
