<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */

class tariqaThemes extends Tariqa {
	
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Get the content of a theme
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @return Theme
	 * */

	public function GetTheme($token, $theme_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($theme_id);

		$sql = <<<sql
				select * from themes where theme_id = {$id};
sql;

		if (($_theme = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$theme = $_theme->fetch_assoc();
		$rez = new Theme();
		$rez->description = $theme["description"];
		$rez->theme_id = $theme["theme_id"];
		$rez->title = $theme["title"];
		$rez->long_text = $theme["long_text"];
		$rez->short_text = $theme["short_text"];
		$rez->query_id = $theme["query_id"];

		$_theme->free();
		$my->close();

		return $rez;
	}

	/**
	 * Get the list of available themes
	 * @param string $token The session identifier
	 * @param boolean $no_texts If true, do not fetch the texts [OPTIONAL]
	 * @param int[] $ids A list of theme ids [OPTIONAL]
	 * @return Theme[]
	 * */

	public function ListThemes($token, $no_texts = false, $ids = null){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$cond = ' theme_id != -1';
		if ($ids != null){
			$cond = '';
			foreach ($ids as $id){
				$id = $my->real_escape_string($id);
				$cond .= ($cond == ''?'':' or ') . "`theme_id` = '{$id}'";
			}

			if ($cond == '') $cond = 'theme_id != -1';
			else $cond = "({$cond})";
		}

		$sql = <<<sql
				select * from themes where {$cond} order by title;
sql;

		if (($themes = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$rez = array();

		while ($theme = $themes->fetch_assoc()){
			$th = new Theme();

			$th->title = $theme["title"];
			$th->description = $theme["description"];
			$th->theme_id = $theme["theme_id"];
			$th->long_text = ($no_texts?null:$theme["long_text"]);
			$th->short_text = ($no_texts?null:$theme["short_text"]);
			$th->query_id = $theme["query_id"];

			array_push($rez, $th);
		}

		$themes->free();
		$my->close();

		return $rez;
	}

	/**
	 * Sets the short text and long text of a theme
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @param string $short_text The short text
	 * @param string $long_text The long text
	 * @return boolean
	 * */
	public function SetThemeText($token, $theme_id, $short_text, $long_text){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$id = $my->real_escape_string($theme_id);
		$short_text = $my->real_escape_string($short_text);
		$long_text = $my->real_escape_string($long_text);

		$sql = <<<sql
update `themes`
set `short_text` = '{$short_text}', `long_text` = '{$long_text}'
where `theme_id` = '{$id}'
sql;

		if (($my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return false;
		}

		return true;
	}

	/**
	 * Get the list of available queries for a defined contry
	 * @param string $token The session identifier
	 * @param int $theme_id The selected theme identifier
	 * @return Query[]
	 * */

	public function GetThemeQueries($token, $theme_id){
		$user_id = $this->CheckToken( $token );
		if( false === $user_id ) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$id = $my->real_escape_string($theme_id);

		$sql = <<<sql
				select queries.*, sources.*, queries.title as qtitle, label as block_label, queries_themes.description as block_description, display_order as block_display_order from queries
				inner join queries_themes on queries.query_id = queries_themes.query_id inner join sources on queries.source_id = sources.source_id
				where queries_themes.theme_id = '{$id}'
				order by display_order;
sql;

		if (($queries = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $query );
			$my->close();
			return null;
		}

		$rez = array();

		while ($query = $queries->fetch_assoc()){
			$q = new Query();

			$q->title = $query["qtitle"];
			$q->description = $query["description"];
			$q->query = $query["query"];
			$q->query_id = $query["query_id"];
			$q->source_id = $query["source_id"];
			$q->block_description = $query["block_description"];
			$q->block_display_order = $query["block_display_order"];
			$q->block_label = $query["block_label"];
			$q->time_range = $query["time_range"];
                        $q->icon = $query['icon'];

			array_push($rez, $q);
		}

		$queries->free();
		$my->close();

		return $this->filterQueries($rez, $user_id);
	}

	/**
	 * Sets the user defined query for the theme
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @param Query $query The query
	 * @return int
	 * */
	public function SetThemeUserDefinedQuery($token, $theme_id, $query){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}
		$theme_id = $my->real_escape_string($theme_id);

		$query_id = $query->query_id;

		if ($query_id == null){
			$sql = <<<sql
insert into `queries`(
	`source_id`, `title`, `description`, `query`, `time_range`, `flavour_id`
)
values(
	'{$query->source_id}', '{$query->title}', '{$query->description}', '{$query->query}', '{$query->time_range}', '{$query->flavour->flavour_id}'
)
sql;
		}
		else {
			$sql = <<<sql
replace into `queries`(
	`query_id`, `source_id`, `title`, `description`, `query`, `time_range`, `flavour_id`
)
values(
	'{$query->query_id}', '{$query->source_id}', '{$query->title}', '{$query->description}', '{$query->query}', '{$query->time_range}', '{$query->flavour->flavour_id}'
)
sql;
		}

		if ($my->query($sql) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		if ($query_id == null) {
			$query_id = $my->insert_id;

			$sql = "update themes set query_id = '{$query_id}' where theme_id = '{$theme_id}'";
			if ($my->query($sql) === false){
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
				$my->close();
				return null;
			}
		}


		return $query_id;
	}

	/**
	 * Lists the topics for a given theme
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @return ThemeTopic[]
	*/
	public function ListThemeTopics($token, $theme_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_ListThemeTopics($token, $theme_id);
	}

	/**
	 * Lists the topics for a given theme
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @return ThemeTopic[]
	*/
	private function _ListThemeTopics($token, $theme_id){
		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$theme_id = $my->real_escape_string($theme_id);

		$sql = "select * from themes_topics where theme_id = '{$theme_id}' order by title";
		if (($qtopics = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}
		$rez = array();
		while ($topic = $qtopics->fetch_assoc()) {
			$t = new ThemeTopic();
			$t->description = $topic["description"];
			$t->theme_id = $topic["theme_id"];
			$t->title = $topic["title"];
			$t->topic_id = $topic["topic_id"];
			$t->queries = $this->_ListTopicQueries($token, $t->topic_id);

			array_push($rez, $t);
		}

		return $rez;
	}

	/**
	 * Get a topic theme
	 * @param string $token The session identifier
	 * @param int $topic_id The topic identifier
	 * @param boolean $queries If true, also get the queries [OPTIONAL]
	 * @return ThemeTopic
	*/
	public function GetThemeTopic($token, $topic_id, $queries = false){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$topic_id = $my->real_escape_string($topic_id);

		$sql = "select * from themes_topics where topic_id = '{$topic_id}'";
		if (($topic = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$_topic = $topic->fetch_assoc();
		$rez = new ThemeTopic();
		$rez->description = $_topic["description"];
		$rez->theme_id = $_topic["theme_id"];
		$rez->title = $_topic["title"];
		$rez->topic_id = $_topic["topic_id"];

		if ($queries){
			$rez->queries = $this->_ListTopicQueries($token, $topic_id);
		}

		return $rez;
	}

	/**
	 * Lists the queries for a theme topic
	 * @param string $token The session identifier
	 * @param int $topic_id The topic identifier
	 * @return TopicQuery[]
	*/
	public function ListTopicQueries($token, $topic_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		return $this->_ListTopicQueries($token, $topic_id);
	}

	/**
	 * Lists the queries for a theme topic
	 * @param string $token The session identifier
	 * @param int $topic_id The topic identifier
	 * @return TopicQuery[]
	*/
	private function _ListTopicQueries($token, $topic_id){
		$error = false;

		$user_id = $this->CheckToken($token);
		$access_level = $this->_GetUserVariable($user_id, 'access_level', false);
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$topic_id = $my->real_escape_string($topic_id);

		$sql = <<<sql
select `query_id`, topics_queries.`title`
from `topics_queries` inner join queries using(query_id)
		inner join sources using(source_id)
		inner join engines using(engine_id)
where `topic_id` = '{$topic_id}' and engines.access_level <= '{$access_level}'
order by `title`
sql;

		if (($queries = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$rez = array();
		while ($row = $queries->fetch_assoc()){
			$query = new TopicQuery();
			$_query = $this->GetQuery($token, $row["query_id"]);
			$query->query = $_query;
			$query->title = $row["title"];
			array_push($rez, $query);
		}

		return $rez;
	}

	/**
	 * Get a topic query
	 * @param string $token The session identifier
	 * @param int $topic_id The topic identifier
	 * @param int $query_id The query identifier
	 * @return TopicQuery
	*/
	public function GetTopicQuery($token, $topic_id, $query_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$topic_id = $my->real_escape_string($topic_id);
		$query_id = $my->real_escape_string($query_id);

		$sql = <<<sql
select `query_id`, `title`
from `topics_queries`
where
	`topic_id` = '{$topic_id}' and `query_id` = '{$query_id}'
sql;

		if (($q = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$rez = new TopicQuery();
		$topic_query = $q->fetch_assoc();
		$rez->title = $topic_query["title"];
		$query = $this->GetQuery($token, $topic_query["query_id"]);
		$rez->query = $query;

		return $rez;

	}

	/**
	 * List the topics themes with queries
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @return ThemeTopicCollection[]
	*/
	public function ListThemeTopicsWithQueries($token, $theme_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$rez = array();
		$topics = $this->_ListThemeTopics($token, $theme_id);

		foreach ($topics as $topic){
			$t = new ThemeTopicCollection();
			$t->topic = $topic;

			$t->queries = $this->_ListTopicQueries($token, $topic->topic_id);
			array_push($rez, $t);
		}

		return $rez;
	}

	/**
	 * Lists the theme users
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @return ThemeUsers
	*/
	public function ListThemeUsers($token, $theme_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$theme_id = $my->real_escape_string($theme_id);

		$sql = <<<sql
select `user_id`
from `theme_users`
where `theme_id` = '{$theme_id}'
sql;

		if (($q = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$rez = new ThemeUsers();
		$rez->theme_id = $theme_id;
		$rez->user_id = array();

		while ($row = $q->fetch_assoc()) {
			$rez->user_id[] = $row["user_id"];
		}

		return $rez;
	}

	/**
	 * Deletes a theme user defined query
	 * @param string $token The session identifier
	 * @param int $theme_id The theme identifier
	 * @return boolean
	*/
	public function DeleteThemeUserDefinedQuery($token, $theme_id){
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqadev", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
			return null;
		}

		$theme_id = $my->real_escape_string($theme_id);

		$sql = <<<sql
select query_id from themes where theme_id = '{$theme_id}'
sql;

		if (($q = $my->query($sql)) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$row = $q->fetch_assoc();

		$query_id = $row["query_id"];

		$sql = "update themes set query_id = null where theme_id = '{$theme_id}'";

		if ($my->query($sql) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		$sql = "delete from queries where query_id = '{$query_id}'";

		if ($my->query($sql) === false){
			if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
			$my->close();
			return null;
		}

		return true;

	}
}
?>