<?php
class tariqaWikipediaCountryProfile extends Tariqa {
	/**
	 * Configuration array
	 * @var array
	 * */
	protected $config = null;

	/**
	 * The class is called using SOAP
	 * @var boolean
	*/
	public $soap;

	/**
	 * Constructs a tariqaThemes Object
	 * @return Tariqa
	 * */
	
	public function __construct($config, $soap){
		$this->config = $config;
		$this->soap = $soap;
	}
	
	/**
	 * Return a country profile from Wikipedia
	 * @param string $token Security Token
	 * @param Country $country Country object
	 * @return WikipediaCountryProfile
	 */
	public function GetWikipediaCountryProfile( $token, $country ) {
		if( false === $this->CheckToken( $token )) {
			if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
			return null;
		}

		$error = false;
		$my = $this->OpenDatabase( "tariqapro", $error );
		if( false === $my ) {
			if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); if (!$this->soap) throw new SoapFault((string) self::e_database, $error ); return new SoapFault((string) self::e_database, $error );
		}

		$sql = <<<sql
select `wikipedia_name`
from `meta_common`.`countries_equiv`
where `country_id` = '{$country->code_iso2}'
sql;

			if (($q = $my->query($sql)) === false){
				if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); if (!$this->soap) throw new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql ); return new SoapFault((string) self::e_database, self::e_database_msg . ": #{$my->errno}, {$my->error}", null, $sql );
				$my->close();
				return null;
			}

			$row = $q->fetch_assoc();

			$code = $row["wikipedia_name"];

			// Prepare the request ---------------------------------------------
			$action = "http://www.wikipedia.org/wiki/{$code}";
			
			// Fetch the document ----------------------------------------------
			$webreq = new WebRequest( $action );
			$webdoc = new WebDocument();
			$webdoc = $this->_fetchUrl( $webreq );

			// Cleanup the resulting document ----------------------------------
			$tidy_opt = array(
				"indent"=>true,
				//"show-body-only" => true,
				"input-encoding" => "utf8",
				"output-encoding" => "utf8",
				"output-xhtml" => true,
				"word-2000" => true,
				"lower-literals" => true,
				"drop-font-tags" => true,
				//"drop-proprietary-attributes" => true,
				//"wrap" => 160,
				"newline" => "LF",
				"doctype" => "omit",
			);
			$tidy = tidy_parse_string($webdoc->body, $tidy_opt);
			tidy_clean_repair($tidy);
			//error_log($tidy);
			$doc_tidy = iconv('UTF-8', 'UTF-8//IGNORE', $tidy );
			
			//error_log( print_r(array( 'ignore'=>iconv('UTF-8', 'UTF-8//IGNORE', $tidy ), 'trqnslit'=>iconv('UTF-8', 'UTF-8//TRANSLIT', $tidy )), true));

			$htmldoc = new DOMDocument();
			$htmldoc->resolveExternals = false;
			$htmldoc->substituteEntities = false;
			$htmldoc->encoding = 'UTF-8';
			$doc_tidy = preg_replace('/style[\s\n\r]*=[\s\n\r]*""/', '', $doc_tidy);
			$htmldoc->loadHTML( $doc_tidy );
			$el = $htmldoc->createElement("div");
			$el->nodeValue = $action;
			$htmldoc->appendChild($el);
			//error_log($htmldoc->saveXML());

			$xsl = iconv('UTF-8', 'UTF-8//IGNORE', (string) file_get_contents("{$this->config["wikipedia"]["xsl"]}"));

			$xsldoc = new DOMDocument();
			$xsldoc->resolveExternals = false;
			$xsldoc->substituteEntities = false;
			$xsldoc->encoding = 'UTF-8';
			$xsldoc->loadXML( $xsl );

			$xslt = new XSLTProcessor();
			$xslt->importStyleSheet( $xsldoc );
			$xmldoc = $xslt->transformToDoc( $htmldoc );
			//$xmldoc->resolveExternals = false;
			//$xmldoc->substituteEntities = false;
			//$xmldoc->encoding = 'UTF-8';

			$xpath = new DOMXPath($xmldoc);

			$profile = new WikipediaCountryProfile();
			$profile->wiki_url = $action;
			$rs = $xpath->query("/country-profile/name");
			$profile->name = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query("/country-profile/capital");
			$profile->capital = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query("/country-profile/flag");
			$profile->flag = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query("//detail/title[@label='Government']/../data[1]");
			$profile->head_of_state = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query("//detail/title[@label='Government']/../data[1]/@label");
			$profile->head_of_state_title = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query("/country-profile/map");
			$profile->map = $rs->length == 0 ? null : $rs->item(0)->nodeValue;
			$rs = $xpath->query("//detail/title[@label='Government']/../data");
			$profile->government = array();
			for ($i = 1 ; $i < $rs->length ; $i++) {
				$p = new Pair($rs->item($i)->getAttribute("label"), $rs->item($i)->nodeValue);
				$profile->government[] = $p;
			}

			$rs = $xpath->query("//detail/title[@label!='Government']/..");
			$profile->details = array();
			foreach ($rs as $node) {
				$detail = new WikipediaDetail();
				$nameNode = $node->getElementsByTagName("title");
				if ($nameNode != null){
					$detail->name = $nameNode->item(0)->getAttribute("label");
					$detail->value = $nameNode->item(0)->nodeValue;
				}
				else {
					$detail->name = null;
					$detail->value = null;
				}

				$dataNodes = $node->getElementsByTagName("data");
				$detail->data = array();
				foreach ($dataNodes as $data){
					$pair = new Pair($data->getAttribute("label"), $data->nodeValue);
					$detail->data[] = $pair;
				}

				$profile->details[] = $detail;
			}

// WIKIPEDIA:	TOC & FIRST PARAGRAPH -------------------------------------------------------------

			$rs = $xpath->query('/country-profile/toc');
			$profile->toc = (($rs->length == 0) ? null : $xmldoc->saveXML($rs->item(0)) );

			$profile->toc = preg_replace('/"(#[^"]*)"/', $action . '\1', $profile->toc);

			// $profile->first_paragraph = array();
			/*
			$rs = $xpath->query("//country-profile/first-paragraph/p");
			$profile->first_paragraph = array();
			for ($i = 1 ; $i < $rs->length ; $i++) {
				$profile->first_paragraph[] = $rs->item($i)->nodeValue;
			}
			*/

// WIKIPEDIA:	TOC & FIRST PARAGRAPH -------------------------------------------------------------
			return $profile;

	}

}
?>