<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
*/

class tariqaYahoo extends Tariqa {
    /**
     * Configuration array
     * @var array
     * */
    protected $config = null;

    /**
     * The class is called using SOAP
     * @var boolean
     */
    public $soap;

    /**
     * Constructs a tariqaThemes Object
     * @return Tariqa
     * */

    public function __construct($config, $soap) {
	$this->config = $config;
	$this->soap = $soap;
    }

    /**
     * Search for articles using Google News
     * @param string $token Session Identifier
     * @param YahooQuery $query Query
     * @return YahooResultSet
     **/
    public function yahooSearch( $token, $query ) {

	if( false === $this->CheckToken( $token )) {
	    if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
	    return null;
	}

	return $this->_yahooSearch( $query );
    }

    /**
     * Search for articles using Google News
     * @param YahooQuery $query Query
     * @return YahooResultset
     **/
    protected function _yahooSearch( $query ) {
	$args = array();
	$args[] = new Pair( 'appid', $this->config['sources']['yahoo']['api-key'] );
	if( null !== $query->query ) {
	    $args[] = new Pair( 'query', $query->query );
	}
	if( null !== $query->type ) {
	    $args[] = new Pair( 'type', $query->type );
	}
	if( null !== $query->results ) {
	    $args[] = new Pair( 'results', $query->results );
	}
	if( null !== $query->start ) {
	    $args[] = new Pair( 'start', $query->start );
	}
	if( null !== $query->sort ) {
	    $args[] = new Pair( 'sort', $query->sort );
	}
	if( null !== $query->language ) {
	    $args[] = new Pair( 'language', $query->language );
	}

	$req = new WebRequest("http://search.yahooapis.com/NewsSearchService/V1/newsSearch", $args, false, WebRequest::HTTP_GET );

	$req->follow_redirect = true;

	$resp = new WebDocument();
	$resp = $this->_fetchUrl( $req );

	$xml = new DOMDocument('1.0', 'utf-8');
	$body = $resp->body;
	$body = preg_replace('/xsi:schemaLocation="[^"]*"/', '', $body);
	$body = preg_replace('/xmlns[:]*[^=]*="[^"]*"/', '', $body);

	if (!$xml->loadXML($body)){
	    if (!$this->soap) throw new SoapFault((string) self::e_http, 'Result not in XML format'); return new SoapFault((string) self::e_http, 'Result not in XML format');
	}

	$result = new YahooResultSet();
	$xp = new DOMXPath($xml);

	$rs = $xp->query('/Error');
	if ($rs->length > 0){
	    $rs = $xp->query('/Error/Message');
	    if ($rs->length > 0){
		if (!$this->soap) throw new SoapFault((string) self::e_http, $rs->item(0)->nodeValue); return new SoapFault((string) self::e_http, $rs->item(0)->nodeValue);
	    }
	    else {
		if (!$this->soap) throw new SoapFault((string) self::e_http, 'Unknown error'); return new SoapFault((string) self::e_http, 'Unknown error');
	    }
	}

	$rs = $xp->query('/ResultSet');
	if ($rs->length <= 0){
	    if (!$this->soap) throw new SoapFault((string) self::e_http, 'Response not in the right format. Could not find ResultSet node'); return new SoapFault((string) self::e_http, 'Response not in the right format. Could not find ResultSet node');
	}

	$result->totalResultsAvailable = $rs->item(0)->getAttribute('totalResultsAvailable');
	$result->firstResultPosition = $rs->item(0)->getAttribute('firstResultPosition');
	$result->totalResultsReturned = $rs->item(0)->getAttribute('totalResultsReturned');

	$rs = $xp->query('/ResultSet/Result');

	foreach ($rs as $node){
	    $_r = new YahooResult();
	    foreach ($node->childNodes as $child){
		switch ($child->nodeName){
		    case 'Title':
			$_r->title = $child->nodeValue;
			break;
		    case 'Summary':
			$_r->summary = $child->nodeValue;
			break;
		    case 'Url':
			$_r->url = $child->nodeValue;
			break;
		    case 'ClickUrl':
			$_r->clickUrl = $child->nodeValue;
			break;
		    case 'NewsSource':
			$_r->newsSource = $child->nodeValue;
			break;
		    case 'NewsSourceUrl':
			$_r->newsSourceUrl = $child->nodeValue;
			break;
		    case 'Language':
			$_r->language = $child->nodeValue;
			break;
		    case 'PublishDate':
			$_r->publishDate = $child->nodeValue;
			break;
		    case 'ModificationDate':
			$_r->modificationDate = $child->nodeValue;
			break;
		    case 'Thumbnail':
			foreach ($child->childNodes as $child2){
			    if ($child2->nodeName == 'Url'){
				$_r->thumbnail = $child2->nodeValue;
				break;
			    }
			}
			break;
		}
	    }

	    $result->results[] = $_r;
	}

	return $result;
    }

    /**
     * Parses an yahoo document
     * @param string $token The session identifier
     * @param string $url The document url
     * @access protected
     * @return string
     */
    public function yahooGetDocument($token, $url) {
	if( false === $this->CheckToken( $token )) {
	    if (!$this->soap) throw new SoapFault((string) self::e_session, self::e_session_msg ); return new SoapFault((string) self::e_session, self::e_session_msg );
	    return null;
	}

	$request = new WebRequest($url);
	$resp = $this->_fetchUrl($request);

	if ($resp->http_code == 200)
	    return $resp->body;

	ob_start();

	var_dump($resp);

	$contents = ob_get_contents();
	ob_end_clean();
	error_log($contents);

	if (!$this->soap) throw new SoapFault((string)self::e_http, "Error fetching Yahoo Document"); return new SoapFault((string)self::e_http, "Error fetching Yahoo Document");

	return null;
    }
}
?>