<?php
	/**
	 * Access to the European Commission's LDAP Directory 
	 * @author Pascal (Meta) Havelange (havelangep@gmail.com)
 	 * @copyright &copy; 2008 All rights reserved
 	 * @package MetaNull
 	 */

	require_once( "mldap.inc.php" );
	
	/**
	 * LDAP Database access, set on the European Commission's database
	 * @author Pascal (Meta) Havelange (havelangep@gmail.com)
 	 * @copyright &copy; 2008 All rights reserved
 	 * @package MetaNull
	 */
	class EC_LDAP extends mldap {
		
		/**
		 * Server Host
		 */
		const EC_LDAP_SERVER = "your-ldap-server";
		/**
		 * Server Port
		 */
		const EC_LDAP_SERVER_PORT = LDAP_PORT;
		/**
		 * Base DN
		 */
		const EC_LDAP_BASE_DN = "your-ldap-base-dn";

		/**
		 * List of existing attributes to fetch. The key in the array are used as aliases to the attributes by the EC_User class
		 */
		static $ldap_attributes = array( "user_id"=>"uid", 
			"user_group"=>"cudgroup", 
			"user_class"=>"objectclass", 
			"title"=>"title", "first_name"=>"givenname", "last_name"=>"sn", "display_name"=>"cn",
			"email"=>"mail", "phone"=>"telephonenumber", "country"=>"c", 
			"organisation"=>"sourceorganisation","directorate_general"=>"dg","directorate"=>"dir","unit"=>"div",
			"department"=>"departmentnumber", "manager_id"=>"manager",
			"building"=>"building","floor"=>"floor","office"=>"room",
			"address"=>"physicaldeliveryofficename",
			"dn"=>"dn"
		);
		
		/**
		 * Construct a mLdap Object, using the EC Settings
		 */
		public function __construct() {
			parent::__construct( self::EC_LDAP_SERVER, self::EC_LDAP_SERVER_PORT );
			$this->max_results = 10;
			$this->max_time = 7;
			$this->deref = LDAP_DEREF_NEVER;
		}
		
		/**
		 * Quick search in the directory
		 * @param string $filter the LDAP filter. ie: (|(uid=MY_USER_ID)(cn=MY_NAME*))
		 * @param false|array $required_attributes If false, retrieves default attributes, otherwise retrieve only specific attributes (the list should only contain real attributes names, as defined in the array values of $this->ldap_attributes )
		 * @return array
		 */
		public function search( $filter, $required_attributes = false ) {
			$attributes = (false === $required_attributes || !is_array($required_attributes)) ? EC_LDAP::$ldap_attributes : $required_attributes;
			sort( $attributes );
			return parent::search( self::EC_LDAP_BASE_DN, $filter, $attributes );
		}
	}
?>