<?php
	/**
	 * This class represents the type of object returned by a Search operation
	 * @see WSKSearchRequest
	 * @example examples/search.php Search for documents
	 * */
	class WSKSearchResponse {
		
		/**
		 * Contains a unique identifier that maintains all pertinent information from the original search.
		 * @var string
		 * */
		public $searchId;
		
		/**
		 * Total number of documents that satisfied this search.
		 * @var int
		 * */
		public $documentsFound;
		
		/**
		 * Encloses one or more diagnostic elements.
		 * @var WSKDiagnosticList
		 * */
		public $diagnosticList;
		
		/**
		 * If useCSP was set on the request, isSaveable will return with a true or false if the search can be saved via SaveSearch or ModifySavedSearch.
		 * @var boolean
		 * */
		public $isSavable;
		
		/**
		 * The continue Id will be returned if a "WithContinue" search type was used and the search was too general for normal processing. To contine the search, add the continueId on the exact same search request that was previously executed.
		 * @var string
		 * */
		public $continueId;
		
		/**
		 * Encloses zero or more documentContainer elements, each of which identifies a single document.
		 * @var WSKDocumentContainerList 
		 * */
		public $documentContainerList;
		
		
		/**
		 * Constructs a searchResponse object
		 * @param string $searchId	Contains a unique identifier that maintains all pertinent information from the original search.
		 * @param int $documentsFound	Total number of documents that satisfied this search.
		 * @param WSKDiagnosticList $diagnosticList	Encloses one or more diagnostic elements.
		 * @param boolean $isSavable	If useCSP was set on the request, isSaveable will return with a true or false if the search can be saved via SaveSearch or ModifySavedSearch.
		 * @param string $continueId	The continue Id will be returned if a "WithContinue" search type was used and the search was too general for normal processing. To contine the search, add the continueId on the exact same search request that was previously executed.
		 * @param WSKDocumentContainerList $documentContainerList	Encloses zero or more documentContainer elements, each of which identifies a single document.
		 * */
		public function __construct( $searchId = null, $documentsFound = null, $diagnosticList = null, $isSavable = null, $continueId = null, $documentContainerList = null ) {
			$this->searchId = $searchId;
			$this->documentsFound = $documentsFound;
			$this->diagnosticList = $diagnosticList;
			$this->isSavable = $isSavable;
			$this->continueId = $continueId;
			$this->documentContainerList = $documentContainerList;
		}
	}
?>