<?php
	/**
	 * Encloses a collection of elements which provide detailed information about a single source in the requested folder.
	 * @see WSKGetSourceDetailsResponse
	 * */
	class WSKSource {
		
		/**
		 * Contains a unique identifier value used to represent a specific source in the source directory.
		 * @var int
		 * */
		public $sourceId;
		
		/**
		 * Contains either the actual name of the publication or the name given to a group of publications.
		 * @var string
		 * */
		public $name;
		
		/**
		 * The SecuredSource flag indicates that this source has secured source information that should or must be displayed to your user before they are permitted to access this source. The GetSourceDetails operation is used to retrieve this secured source information.
		 * @var string
		 * @see tStandard
		 * @see tSecuredSource
		 * @see tTableOfContents
		 * */
		public $type;
		
		/**
		 * @see $type
		 * */
		const tStandard = "Standard";
		
		/**
		 * @see $type
		 * */
		const tSecuredSource = "SecuredSource";
		
		/**
		 * @see $type
		 * */
		const tTableOfContents = "TableOfContents";
		
		/**
		 * true indicates that this source is outside your user's subscription and is only available at an additional charge.
		 * @var boolean
		 * */
		public $premiumSource;
		
		/**
		 * true indicates that this source has an index source associated with it.
		 * @var boolean
		 * */
		public $hasIndex;
		
		/**
		 * true indicates that this source has a table of contents source associated with it.
		 * @var boolean
		 * */
		public $hasTOC;
		
		/**
		 * true indicates that some documents within this source may have multiple versions available. This can be used to determine when offer the ability to retrieve different document versions.
		 * @var boolean
		 * */
		public $versionable;
		
		
		/**
		 * true indicates that the source page can be browsed.
		 * @var boolean
		 * */
		public $isPageBrowsable;
		
		/**
		 * Contains the list of combinability strings for this source.
		 * @var WSKCombinabilityList
		 * */
		public $combinabilityList;
		
		
		/**
		 * Cosntructs a source object
		 * @param int $sourceId Contains a unique identifier value used to represent a specific source in the source directory.
		 * @param string $name Contains either the actual name of the publication or the name given to a group of publications.
		 * @param string $type The SecuredSource flag indicates that this source has secured source information that should or must be displayed to your user before they are permitted to access this source. The GetSourceDetails operation is used to retrieve this secured source information.
		 * @param boolean $premiumSource true indicates that this source is outside your user's subscription and is only available at an additional charge.
		 * @param boolean $hasIndex true indicates that this source has an index source associated with it.
		 * @param boolean $hasTOC true indicates that this source has a table of contents source associated with it.
		 * @param boolean $versionable true indicates that some documents within this source may have multiple versions available. This can be used to determine when offer the ability to retrieve different document versions.
		 * @param boolean $isPageBrowsable true indicates that the source page can be browsed.
		 * @param WSKCombinabilityList Contains the list of combinability strings for this source.
		 * */
		public function __construct( $sourceId = null, $name = null, $type = null, $premiumSource = null, $hasIndex = null, $hasTOC = null, $versionable = null, $isPageBrowsable = null, $combinabilityList = null ) {
			$this->sourceId = $sourceId;
			$this->name = $name;
			$this->type = $type;
			$this->premiumSource = $premiumSource;
			$this->hasIndex = $hasIndex;
			$this->hasTOC = $hasTOC;
			$this->versionable = $versionable;
			$this->isPageBrowsable = $isPageBrowsable;
			$this->combinabilityList = $combinabilityList;
		}
	}
?>