<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */


	require_once( "Config.php" );

	define( "tariqa_authentication_server_config_file", "config/config.xml" );
	define( "tariqa_authentication_server_config_format", "xml" );
	define( "tariqa_authentication_verbose", true );

	/**
	 * Tarîqa SOAP Authentication Server Class
	 * @author Pascal (Meta) Havelange
	 * @copyright © EUROPEAN COMMISSION, 2008.
	 *
	 * @link http://localhost:81/soap/tools/wshelper/service.php?class=Tariqa&wsdl Generates the WSDL
	 * @link http://localhost:81/soap/tools/wshelper/service.php?class=Tariqa View the documentation
	 * @link http://d02di0414709:81/soap/Tariqa?cli Run the demo application, open:
	 * */
	class TariqaAuthenticationLogged extends SoapServer {

		/**
		 * Configuration array
		 * @var array
		 * */
		protected $config = null;

		/**
		 * MySQLi object
		 * @var mysqli
		 * */
		private $my = null;

		/**
		 * DEBUG: Log file name
		 * @var string
		 * */
		private $logfile = 'TariqaAuthentication.log';

		/**
		 * DEBUG: Append a string to the log file (Carriage Return is automatically added)
		 * @param string $str String
		 * @return void
		 * */
		private function logAppend( $str ) {
			$str .= "\n";
			$fp = fopen( $this->logfile, "ab" );
			if( false === $fp ) {
				error_log( "UNABLE TO WRITE TO: {$this->logfile}!\n{$str}" );
			} else {
				if( flock( $fp, LOCK_EX ) ) {
					fwrite( $fp, $str );
					flock( $fp, LOCK_UN );
				} else {
					error_log( 'Unable to lock the log file in ' . __FUNCTION__ . ' (' . __FILE__ . '@line ' . __LINE__ . ')' );
					error_log( $str );
					fwrite( $fp, $str );
				}
				fclose( $fp );
			}
		}

		/**
		 * Constructs a TariqaAuthentication object
		 * @return TariqaAuthentication
		 * @ignore
		 * */
		public function __construct() {
			// Load Configuration File
			$config = new Config();
			$config_root = &$config->parseConfig( tariqa_authentication_server_config_file, tariqa_authentication_server_config_format );
			if( PEAR::isError( $config_root )) {
				throw new Exception( self::e_config . ": " . $config_root->getMessage );
			}
			$config_array = $config_root->toArray();
			$this->config = $config_array["root"]["config"];

			// Constructs SoapServer
			parent::__construct( $this->config["soap"]["wsdl"],
					array_key_exists( "classmap", $this->config )
						? array( "classmap" => $this->config["soap"]["classmap"] )
						: array()
				);

			$this->setClass( "TariqaAuthentication" );

			if( array_key_exists( "disable-remote-access", $this->config )) {
				$disabled = (false !== eregi( "^(1|true|yes)$", $this->config["disable-remote-access"] ));
				if( $disabled ) {
					// Restricts access to Localhost & Developer machine
					if( $_SERVER["REMOTE_ADDR"] != "127.0.0.1" &&
						$_SERVER["REMOTE_ADDR"] != "158.166.117.63"
					) {
						$this->fault( self::e_forbidden, self::e_forbidden_msg );
						return null;
					}
				}
			}
		}

		/**
		 * Destructs the object
		 * @return void
		 * @ignore
		 * */
		public function __destruct() {
			$this->CloseDatabase();
		}



		/**
		 * Authenticates with TariqaSoap
		 * @param string $login The username
		 * @param string $password The password
		 * @return AuthenticationResponse An identification token and its expiry time
		 * */
		public function Login( $login, $password ) {
if( tariqa_authentication_verbose ) {
	$log = '---<'.__FUNCTION__ .'>---'. "\n";
	$log .= '> Function arguments' . "\n";
	$log .= '$login=' . $login . "\n";
	$log .= '$password=' . md5($password) . "\n";
	$this->logAppend( $log );
}
			// Check the parameters
			if( !is_string( $login ) || 0 == strlen( $login ) || !is_string( $password ) || 0 == strlen( $password ) ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> Invalid argument: $login/$password' );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				$this->fault( self::e_login, self::e_login_msg );
				return null;
			}

			$error = false;
			if( false == $this->OpenDatabase( $error )) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> OpenDatabase() failed: ' . $error );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				$this->fault( self::e_database, $error );
				return null;
			}

			$db_login = $this->my->real_escape_string( $login );
			$db_password = $this->my->real_escape_string( $password );
			$db_ip = $this->my->real_escape_string(  $_SERVER["REMOTE_ADDR"] );
if( tariqa_authentication_verbose ) {
	$query = <<<sql
select *
from `sessions` s
sql;
	$rs = $this->my->query( $query );
	$this->logAppend( '> Sessions database:' );
	$cnt = 0;
	while( $row = $rs->fetch_assoc() ) {
		$this->logAppend( sprintf( '%02d.', $cnt ++ ));
		foreach( $row as $k => $v ) {
			$this->logAppend( '  -' . $k . '= ' . $v);
		}
	}
}
			// Fetch the user
			$query = <<<sql
select *
from `users` u
where u.`user_id` = '{$db_login}'
sql;
			$rs = $this->my->query( $query );
			if( false === $rs ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> SQL: find user failed: '.$this->my->error );
	$this->logAppend( 'SQL Query:' . "\n" . $query );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
				return null;
			}
			if( 0 == $rs->num_rows ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> USER NOT FOUND' );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				/* TO DO
				 *
				 * Store the IP address of the client and count the attempts.
				 * If more than 3 attempts, block that IP address
				 */
				// User not found
				$this->fault( self::e_login, self::e_login_msg );
				return null;
			}

			$user = $rs->fetch_assoc();
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> User Details:'  );
	foreach( $user as $k => $v ) {
		$this->logAppend( ' -' . $k . '= ' . $v );
	}
}
			$rs->free();

			// Check if the account is locked
			if( $user["loginfailed_count"] >= $this->config["max-logins"] ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> Max failed login ('.$this->config['max-logins'].') reached ('.$user['loginfailed_count'].')!' );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				$this->fault( self::e_account_locked, self::e_account_locked_msg );
				return null;
			}

			// Check the password
			if( md5( $password ) != $user["password"] ) {
				// Update the login-failed counter
				$query = <<<sql
update `users`
set `loginfailed_count` = `loginfailed_count` + 1
where `user_id` = '{$db_login}'
sql;
				$rs = $this->my->query( $query );
				if( false === $rs ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> SQL: Error updating loginfailed_count: ' . $this->my->error );
	$this->logAppend( 'SQL QUERY:' . "\n" . $query );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
					$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
					return null;
				}
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> Wrong password ('.md5($password).')!' );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				$this->fault( self::e_login, self::e_login_msg );
				return null;
			}

			// If the login-failed counter is != 0
			if( 0 != (int)$user["loginfailed_count"] ) {
				// Update the login-failed counter
				$query = <<<sql
update `users`
set `loginfailed_count` = 0
where `user_id` = '{$db_login}'
sql;
				$rs = $this->my->query( $query );
				if( false === $rs ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> SQL: Error resetting loginfailed_count: ' . $this->my->error );
	$this->logAppend( 'SQL QUERY:' . "\n" . $query );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
					$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
					return null;
				}
			}

			// -- TRANSACTION: generate token, if already exists: loop until generating an unique one, once done, insert onto 'sessions'
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> Create new Token' );
}
			$autocommit = true;
			if( $rs = $this->my->query( "select @@autocommit" )) {
				$tmp_row = $rs->fetch_row();
				$autocommit = ( "1" == $tmp_row[0] ) ? true : false;
				$rs->free();
			}
			$this->my->autocommit( false );
			$compute_token = true;
			$time = false;
			$token = false;
			$db_token = false;
			while( $compute_token ) {
				// Compute the token
				$time = time();
				$token = $this->BuildToken( $user["user_id"], $time );
				$db_token = $this->my->real_escape_string( $token );
if( tariqa_authentication_verbose ) {
	$this->logAppend( 'Time: '.$time );
	$this->logAppend( 'New token:     ' . $token );
	$this->logAppend( 'Escaped token: ' . $db_token );
}
				// Test if it is unique
				$query = <<<sql
select *
from `sessions`
where `token` = '{$db_token}'
sql;
				$rs = $this->my->query( $query );
				if( $rs->num_rows == 0 ) {
					// UNIQUE -> continue
					$compute_token = false;
				} else {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> Token is not unique => Computes a new one' );
}
					// Token already exists -> compute a new one
					$compute_token = true;
				}
			}

			$query = <<<sql
replace into `sessions` (
	`user_id`, `token`, `time`, `ip`
) values (
	'{$db_login}', '{$db_token}', '{$time}', '{$db_ip}'
);
sql;
if( tariqa_authentication_verbose ) {
	$this->logAppend( '> Saving token in the database' );
	$this->logAppend( 'SQL QUERY: ' ."\n" . $query );
}
			$rs = $this->my->query( $query );
			if( false === $rs ) {
				$errno = $this->my->errno;
				$error = $this->my->error;
if( tariqa_authentication_verbose ) {
	$this->logAppend( 'SQL: Error saving token: ' . $error );
	$this->logAppend( 'SQL QUERY:' . "\n" . $query );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
				$this->my->rollback();
				$this->my->autocommit( $autocommit );
				$this->fault( self::e_database, self::e_database_msg . ": #{$errno}, {$error}", null, $query );
				return null;
			}
			$this->my->commit();
			$this->my->autocommit( $autocommit );
			// -- /TRANSACTION --

			$response = new AuthenticationResponse();
			$response->identificationToken = $token;
			$response->expirationDate = $time + (int)$this->config["session-length"];
			$response->https = array_key_exists( "HTTPS", $_SERVER ) ? true : false;

if( tariqa_authentication_verbose ) {
	$log = '';
	$log .= '> Response:' . "\n";
	$log .= '$identificationToken=' . $response->identificationToken . "\n";
	$log .= '$expirationDate=' . $response->expirationDate . "\n";
	$log .= '$https=' . $response->https . "\n";
	$this->logAppend( $log );

	$query = <<<sql
select *
from `sessions` s
sql;
	$rs = $this->my->query( $query );
	$this->logAppend( '> Sessions database:' );
	$cnt = 0;
	while( $row = $rs->fetch_assoc() ) {
		$this->logAppend( sprintf( '%02d.', $cnt ++ ));
		foreach( $row as $k => $v ) {
			$this->logAppend( '  -' . $k . '= ' . $v);
		}
	}

	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}

			return $response;
		}

		/**
		 * Checks if the session is valid
		 * @param string $token The session identifier
		 * @return boolean
		 * */
		public function IsLoggedIn( $token ) {
			return (false === $this->CheckToken( $token )) ? false : true;
		}

		/**
		 * Logout from Tariqa Soap
		 * @param string $token The session identifier
		 * @return boolean
		 * */
		public function Logout( $token ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( '---<'.__FUNCTION__ .'>---' );
}
			$user_id = $this->CheckToken( $token );

			if( false !== $user_id ) {
				$error = false;
				if( false == $this->OpenDatabase( $error )) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( 'OpenDatabase Failed!: ' . $error );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
					$this->fault( self::e_database, $error );
					return false;
				}

				$db_user_id = $this->my->real_escape_string( $user_id );

				$query = <<<sql
delete from `sessions`
where `user_id` = '{$db_user_id}'
sql;
				$rs = $this->my->query( $query );
				if( false === $rs ) {
if( tariqa_authentication_verbose ) {
	$this->logAppend( 'SQL Error deleting session row: ' . $this->my->error );
	$this->logAppend( 'SQL QUERY:' . "\n" . $query );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}
					$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
					return false;
				}
			}
if( tariqa_authentication_verbose ) {
	$this->logAppend( 'Success' );
	$this->logAppend( '---</'.__FUNCTION__ .'>---' );
}

			return true;
		}

		/**
		 * Modify the user password
		 * @param string $token The session identifier
		 * @param string $oldPassword The actual password
		 * @param string $newPassword The new password
		 * @return boolean
		 * */
		public function SetPassword( $token, $oldPassword, $newPassword ) {

			$user_id = $this->CheckToken( $token );
			if( false === $user_id ) {
				$this->fault( self::e_session, self::e_session_msg );
				return false;
			}

			$db_user_id = $this->my->real_escape_string( $user_id );
			$db_old_password = $this->my->real_escape_string( $oldPassword );
			$db_new_password = $this->my->real_escape_string( $newPassword );

			// Check password
			$query = <<<sql
select *
from `users` u
where u.`user_id` = '{$db_user_id}'
and u.`password` = md5('{$db_old_password}')
sql;
			$rs = $this->my->query( $query );
			if( false === $rs ) {
				$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
				return false;
			}
			if( 0 == $rs->num_rows ) {
				$this->fault( self::e_login, self::e_login_msg );
				return false;
			}
			$rs->free();

			// Update password
			$query = <<<sql
update `users`
set `password` = md5('{$db_new_password}')
where `user_id` = '{$db_user_id}'
sql;
			$rs = $this->my->query( $query );
			if( false === $rs ) {
				$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
				return false;
			}

			return true;
		}

		/**
		 * Retrieve the user details
		 * @param string $token The session identifier
		 * @return UserDetails
		 * */
		public function GetUserDetails( $token ) {
			$user_id = $this->CheckToken( $token );
			if( false === $user_id ) {
				$this->fault( self::e_session, self::e_session_msg );
				return false;
			}

			$db_user_id = $this->my->real_escape_string( $user_id );

			// Fetch details
			$query = <<<sql
select *
from `users` u
where u.`user_id` = '{$db_user_id}'
sql;
			$rs = $this->my->query( $query );
			if( false === $rs ) {
				$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
				return false;
			}
			$user = $rs->fetch_assoc();
			$rs->free();

			$userDetails = new UserDetails( $user );
			return $userDetails;

		}

		/**
		 * Modify the user details (Note that user_id and isAdministrator are READ-ONLY!)
		 * @param string $token The session identifier
		 * @param UserDetails $userDetails (Please note that you can't modify the 'isAdministrator')
		 * @return boolean
		 * */
		public function SetUserDetails( $token, $userDetails ) {

			$user_id = $this->CheckToken( $token );
			if( false === $user_id ) {
				$this->fault( self::e_session, self::e_session_msg );
				return false;
			}

			$db_data = array(
				"user_id" => $this->my->real_escape_string( $user_id ),
				"firstname" => $this->my->real_escape_string( $userDetails->firstname ),
				"lastname" => $this->my->real_escape_string( $userDetails->lastname ),
				"email" => $this->my->real_escape_string( $userDetails->email ),
				"phone" => $this->my->real_escape_string( $userDetails->phone ),
				"admin" => $this->my->real_escape_string( $userDetails->isAdministrator ),
			);

			// Update details
			$query = <<<sql
update `users` u
set `firstname` = '{$db_data["firstname"]}',
`lastname` = '{$db_data["lastname"]}',
`email` = '{$db_data["email"]}',
`phone` = '{$db_data["phone"]}'
where u.`user_id` = '{$db_data["user_id"]}'
sql;
			$rs = $this->my->query( $query );
			if( false === $rs ) {
				$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
				return false;
			}
			return true;
		}

		/**
		 * Establish a connection with the database
		 * @return boolean
		 * */
		protected function OpenDatabase( &$error ) {
			// Connects to the database
			$dbsetup = $this->config["database"];

			$this->my = new mysqli( $dbsetup["host"], $dbsetup["user"], $dbsetup["password"], $dbsetup["name"], (int)$dbsetup["port"] );
			if( mysqli_connect_errno() ) {
				$error = self::e_database_msg . ": #".mysqli_connect_errno().", ".mysqli_connect_error();
				$this->my = null;
				return false;
			}
			if( false === $this->my->set_charset( $dbsetup["charset"] )) {
				$error = self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}";
				$this->my->close();
				$this->my = null;
				return false;
			}
			return true;
		}

		/**
		 * Closes the connection with the database
		 * @return void
		 * */
		protected function CloseDatabase() {
			if( is_a( "mysqli", $this->my )) {
				$this->my->close();
				$this->my = null;
			}
		}

		/**
		 * Checks the validity of a token
		 * @param string $token The session identifier
		 * @return string|false Returns false on error, the userId in case of success
		 * */
		protected function CheckToken( $token ) {
			// Check the parameters
			if( !is_string( $token ) || 0 == strlen( $token ) ) {
/**/ error_log( 'CheckToken('.$token.'):: Invalid Token' );
				$this->fault( self::e_session, self::e_session_msg );
				return false;
			}

			$error = false;
			if( false == $this->OpenDatabase( $error )) {
/**/ error_log( 'CheckToken('.$token.'):: DB Conn Error' );
				$this->fault( self::e_database, $error );
				return false;
			}

			$db_token = $this->my->real_escape_string( $token );
			// Fetch the session
			$query = <<<sql
select *
from `sessions` s
where s.`token` = '{$db_token}'
sql;
			$rs = $this->my->query( $query );
			if( false === $rs ) {
/**/ error_log( 'CheckToken('.$token.'):: DB Error: ' . $this->my->error . ' in ' . $query );
				$this->fault( self::e_database, self::e_database_msg . ": #{$this->my->errno}, {$this->my->error}", null, $query );
				return false;
			}
			if( 0 == $rs->num_rows ) {
/**/ error_log( 'CheckToken('.$token.'):: Token not found in sessions' );
				// User not found
				/* TO DO: Store the IP address of the client and count the attempts.
				 * If more than 3 attempts, block that IP address (dangerous if several users on the same host...)
				 */
				return false;
			}
			if( 1 != $rs->num_rows ) {
/**/ error_log( 'CheckToken('.$token.'):: More than one token found!' );
				$error( "More than one record found for session '{$token}' on IP '{$ip}'!" );
				error_log( __FILE__ . "@" . __LINE__ . ":" . $error );
				$this->fault( self::e_internal_error, $error );
				return false;
			}

			$session = $rs->fetch_assoc();
			// Check the expiration of the session
			if( time() > (int)$session["time"] + (int)$this->config["session-length"] ) {
/**/$cur_time = time();
/**/$sess_exp_msg = "\n";
/**/$sess_exp_msg .= '[current:'.$cur_time.']'."\n";
/**/$sess_exp_msg .= '[session:'.(int)$session['time'].']'."\n";
/**/$sess_exp_msg .= '[length:' .(int)$this->config['session-length'].']'."\n";
/**/$sess_exp_msg = "\n";
/**/$sess_exp_msg .= '[current:'.date('d/m/Y h:i:s', $cur_time).']'."\n";
/**/$sess_exp_msg .= '[session:'.date('d/m/Y h:i:s', (int)$session['time']).']'."\n";
/**/$sess_exp_msg .= '[length:' .date('h:i:s', (int)$this->config['session-length']).']'."\n";
/**/$sess_exp_msg = "\n";
/**/$sess_exp_msg .= '[current:'.$cur_time.'] > [session+length:'.((int)$session['time']+(int)$this->config['session-length']).']'."\n";
/**/$sess_exp_msg .= '[current:'.date('h:i:s', $cur_time).'] > [session+length:'.date('h:i:s', ((int)$session['time']+(int)$this->config['session-length'])).']'."\n";
/**/ error_log( 'CheckToken('.$token.'):: Session has expired!' . $sess_exp_msg );
				return false;
			}
			/* DISABLED IP CHECK!!!!
			 * cause: IP is not fixed (because of the proxy/webgate...)
			 * (sometimes 158.166.133.6, sometimes 158.167.133.6, maybe others as well)
			 * */
			/* // Check IP address
			if( $session["ip"] != $_SERVER["REMOTE_ADDR"] ) {
				return false;
			}
			*/
			return $session["user_id"];
		}

		/**
		 * Build a token (64 bytes string)
		 * @param string $userId The login of the user
		 * @param int $time The time of the establishment of the session
		 * @return string
		 * */
		private function BuildToken( $userId, $time ) {
			return md5(str_pad( $userId . sprintf('%d', $time), 64, '-=', STR_PAD_RIGHT ));
		}


		// -- Error codes ------------------------------------------------------

		/**
		 * Error code/message - Internal Server Error
		 * */
		const e_internal_error = 0x0001;
		const e_internal_error_msg = "Internal Server Error";

		/**
		 * Error code/message - Invalid/Missing argument
		 * */
		const e_invalid_argument = 0x0002;
		const e_invalid_argument_msg = "Invalid/Missing argument";

		/**
		 * Error code/message - Not implemented
		 * */
		const e_not_implemented = 0x0003;
		const e_not_implemented_msg = "Not implemented";

		/**
		 * Error code/message - Invalid login
		 * */
		const e_login = 0x1001;
		const e_login_msg = "Invalid Username/Password";

		/**
		 * Error message - User account is locked
		 * */
		const e_account_locked = 0x1002;
		const e_account_locked_msg = "User account locked";

		/**
		 * Error message - Invalid Token/Session Identifier
		 * */
		const e_session = 0x1003;
		const e_session_msg = "Invalid Session Identifier";

		/**
		 * Error message - Insufficient privileges
		 * */
		const e_privilege = 0x1004;
		const e_privilege_msg = "Insufficient privileges";

		/**
		 * Error message - Forbidden access
		 * */
		const e_forbidden = 0x1005;
		const e_forbidden_msg = "Access Forbidden";

		/**
		 * Error message - Invalid Configuration File
		 * */
		const e_config = 0x1011;
		const e_config_msg = "Invalid Configuration";

		/**
		 * Error message - Database error
		 * */
		const e_database = 0x1021;
		const e_database_msg = "Database error";

		/**
		 * Error message - Record not found
		 * */
		const e_missing_record = 0x1022;
		const e_missing_record_msg = "Database record not found";

		/**
		 * Error code/message - Invalid format
		 * */
		const e_invalid_format = 0x1031;
		const e_invalid_format_msg = "Invalid file format";

		/**
		 * Error code/message - HTTP Error
		 * */
		const e_http = 0x2001;
		const e_http_msg = "HTTP Error";

		/**
		 * Error code/message - HTTP 404 Error
		 * */
		const e_http404 = 0x2002;
		const e_http404_msg = "Not found";

		/**
		 * Error code/message - SMTP Error
		 * */
		const e_smtp = 0x3001;
		const e_smtp_msg = "SMTP Error";
	}
?>