<?php
/*
 * © EUROPEAN COMMISSION, 2008-2010
 *
 * Concédée sous licence EUPL, version 1.1 uniquement (la «Licence»).
 * Vous ne pouvez utiliser la présente oeuvre que conformément à la Licence.
 * Vous pouvez obtenir une copie de la Licence à l’adresse suivante:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Sauf obligation légale ou contractuelle écrite, le logiciel distribué sous la Licence est distribué «en l’état»,
 * SANS GARANTIES OU CONDITIONS QUELLES QU’ELLES SOIENT, expresses ou implicites.
 * Consultez la Licence pour les autorisations et les restrictions linguistiques spécifiques relevant de la Licence.
 *
 * Auteurs de l'oeuvre:
 *   Pascal Havelange, Pascal.HAVELANGE@ec.europa.eu
 *   Cosmin POPESCU, Adrian.POPESCU@ext.ec.europa.eu
 *
 */


	class VideoArchiveRecord {
		
		/**
		 * Base URL to access multimedia content
		 * @var string
		 */
		const BASE_STREAM_URL = 'mms://webstream.ec.europa.eu/tariqa/archive';
		
		/**
		 * Base URL to access images
		 * @var string
		 */
		const BASE_IMAGE_URL = 'https://webgate.ec.europa.eu/tariqa/multimedia/';
		
		/**
		 * Base extensions of the video files
		 * @var string
		 */
		const BASE_VIDEO_EXT = 'wmv';

		/**
		 * Channel name
		 * @var string
		 * */
		public $channel;
		
		/**
		 * Capture date (unix timestamp)
		 * @var int
		 * */
		public $date;

		/**
		 * Length of the record (in seconds)
		 * @var int
		 * */
		public $length;
		
		/**
		 * Title of the record
		 * @var string
		 * */
		public $title;
		
		/**
		 * Description of the record
		 * @var string
		 * */
		public $description;
		
		/**
		 * URL of the multimedia file
		 * @var string
		 * */
		public $url;
		
		/**
		 * URL of the thumbnail
		 * @var string
		 * */
		public $thumbnail;
		
		/**
		 * The length of the movie
		 * @var string
		 * */
		public $raw_length;

		/**
		 * Default constructor
		 * @param string[] $mysql_row [OPTIONAL]
		 * */
		public function __construct( $mysql_row = null ) {
			if( null !== $mysql_row ) {
				$this->channel = iconv( 'UTF-8', 'UTF-8//TRANSLIT', $mysql_row['channel_name'] );
				$this->date = strtotime($mysql_row['date']);
				$length = explode( ':', $mysql_row['length'] );
				$this->length = mktime( $length[2], $length[1], $length[0] );
				$this->title = iconv( 'UTF-8', 'UTF-8//TRANSLIT', $mysql_row['title']);
				$this->description = iconv( 'UTF-8', 'UTF-8//TRANSLIT', $mysql_row['description']);
				$this->url = self::BASE_STREAM_URL . '/' . rawurlencode($mysql_row['capture_filename'] . ' ' . str_replace(':', '-', $mysql_row['date'])) . '.wmv';
				$this->raw_length = $mysql_row['raw_length'];
  				$this->thumbnail = self::BASE_IMAGE_URL . rawurlencode($mysql_row['capture_filename'] . ' ' .
                                  str_replace(':', '-', $mysql_row['date'])) . '.' . self::BASE_VIDEO_EXT . '.1.jpg';
			}
		}
	}
?>