<?php
	/**
	 * Class factivaClient
	 */
	class factivaClient extends SoapClient {

		/**
		 * @var string Location of the configuration file
		 */
		const config_file_path = 'fdk/config/factivaClient.xml';
		
		/**
		 * @var string Format of the config file (Please refer to PEAR::Config package for more information) 
		 */
		const config_file_format = 'xml';
		
		/**
		 * @var string Location of the WSDL file
		 */
		const wsdl_path = 'fdk/wsdl/FDKObjects.wsdl';
		
		/**
		 * @param array $options An array of options to pass to the SoapClient constructor
		 * @return void
		 * */
		public function __construct( $options = null ) {
			// Load Configuration File
			$config = new Config();
			$config_root = &$config->parseConfig( factivaClient::config_file_path, factivaClient::config_file_format );
			if( PEAR::isError( $config_root )) {
				throw new Exception( "Error parsing configuration file: " . $config_root->getMessage );
			}
			$config_array = $config_root->toArray();
			$this->config = $config_array["root"]["config"];

			$soap_options = is_array( $options ) ? $options : array();
			$soap_options['trace'] = true;
			$soap_options['exceptions'] = true;
			$soap_options['classmap'] = array(
				'ScreeningContentSets' => 'factiva_ScreeningContentSets',
				'AgeCriteria' => 'factiva_AgeCriteria',
				'AgeValueCriteria' => 'factiva_AgeValueCriteria',
				'AgeRangeCriteria' => 'factiva_AgeRangeCriteria',
				'AuditorCriteria' => 'factiva_AuditorCriteria',
				'CityCriteria' => 'factiva_CityCriteria',
				'CollegeDegreeCriteria' => 'factiva_CollegeDegreeCriteria',
				'CollegeMajorCriteria' => 'factiva_CollegeMajorCriteria',
				'CollegeNameCriteria' => 'factiva_CollegeNameCriteria',
				'CollegeGraduationYearCriteria' => 'factiva_CollegeGraduationYearCriteria',
				'CollegeGraduationYearRangeCriteria' => 'factiva_CollegeGraduationYearRangeCriteria',
				'CollegeGraduationYearValueCriteria' => 'factiva_CollegeGraduationYearValueCriteria',
				'CompanyAssetTurnoverCriteria' => 'factiva_CompanyAssetTurnoverCriteria',
				'CompanyAuditorCriteria' => 'factiva_CompanyAuditorCriteria',
				'CompanyBetaLast60MonthsCriteria' => 'factiva_CompanyBetaLast60MonthsCriteria',
				'CompanyCityAreaCodeCriteria' => 'factiva_CompanyCityAreaCodeCriteria',
				'CompanyCityCriteria' => 'factiva_CompanyCityCriteria',
				'CompanyCodes' => 'factiva_CompanyCodes',
				'CompanyCriteria' => 'factiva_CompanyCriteria',
				'CompanyCriteriaGroup' => 'factiva_CompanyCriteriaGroup',
				'CompanyCriteriaGroupArray1To25' => 'factiva_CompanyCriteriaGroupArray1To25',
				'CompanyCurrentRatioCriteria' => 'factiva_CompanyCurrentRatioCriteria',
				'CompanyDebtAssetsRatioCriteria' => 'factiva_CompanyDebtAssetsRatioCriteria',
				'CompanyDebtEquityRatioCriteria' => 'factiva_CompanyDebtEquityRatioCriteria',
				'CompanyEarningsPerShareCriteria' => 'factiva_CompanyEarningsPerShareCriteria',
				'CompanyEmployeeGrowthCriteria' => 'factiva_CompanyEmployeeGrowthCriteria',
				'CompanyEmployeesCriteria' => 'factiva_CompanyEmployeesCriteria',
				'CompanyIndexCriteria' => 'factiva_CompanyIndexCriteria',
				'CompanyIndustryCriteria' => 'factiva_CompanyIndustryCriteria',
				'CompanyInventoryTurnoverCriteria' => 'factiva_CompanyInventoryTurnoverCriteria',
				'CompanyMarketCapitalizationCriteria' => 'factiva_CompanyMarketCapitalizationCriteria',
				'CompanyMostRecentCloseCriteria' => 'factiva_CompanyMostRecentCloseCriteria',
				'CompanyNetIncomeCriteria' => 'factiva_CompanyNetIncomeCriteria',
				'CompanyNetProfitMarginCriteria' => 'factiva_CompanyNetProfitMarginCriteria',
				'CompanyNewsCodedCriteria' => 'factiva_CompanyNewsCodedCriteria',
				'CompanyNewsSearchCriteria' => 'factiva_CompanyNewsSearchCriteria',
				'CompanyOwnershipTypeCriteria' => 'factiva_CompanyOwnershipTypeCriteria',
				'CompanyPERatioCriteria' => 'factiva_CompanyPERatioCriteria',
				'CompanySearchConstraint' => 'factiva_CompanySearchConstraint',
				'CompanySearchConstraints' => 'factiva_CompanySearchConstraints',
				'CompanyIndustryConstraint' => 'factiva_CompanyIndustryConstraint',
				'CompanyRegionConstraint' => 'factiva_CompanyRegionConstraint',
				'CompanyParentConstraint' => 'factiva_CompanyParentConstraint',
				'CompanyTypeConstraint' => 'factiva_CompanyTypeConstraint',
				'CompanyListingStatusConstraint' => 'factiva_CompanyListingStatusConstraint',
				'CompanyActiveStatusConstraint' => 'factiva_CompanyActiveStatusConstraint',
				'CompanyNewsCodedConstraint' => 'factiva_CompanyNewsCodedConstraint',
				'CompanyReportConstraint' => 'factiva_CompanyReportConstraint',
				'CompanyFocalConstraint' => 'factiva_CompanyFocalConstraint',
				'CompanySearchSortOrders' => 'factiva_CompanySearchSortOrders',
				'CompanyZipPostalCodeCriteria' => 'factiva_CompanyZipPostalCodeCriteria',
				'CompanyPrimaryExchangeCriteria' => 'factiva_CompanyPrimaryExchangeCriteria',
				'CompanyRegionCriteria' => 'factiva_CompanyRegionCriteria',
				'CompanyReturnOnAssetsCriteria' => 'factiva_CompanyReturnOnAssetsCriteria',
				'CompanyReturnOnEquityCriteria' => 'factiva_CompanyReturnOnEquityCriteria',
				'CompanySalesCriteria' => 'factiva_CompanySalesCriteria',
				'CompanySalesGrowthCriteria' => 'factiva_CompanySalesGrowthCriteria',
				'CompanyStatementSection' => 'factiva_CompanyStatementSection',
				'CompanySymbolCriteria' => 'factiva_CompanySymbolCriteria',
				'CompanyTotalAssetsCriteria' => 'factiva_CompanyTotalAssetsCriteria',
				'CompanyTotalLiabilitiesCriteria' => 'factiva_CompanyTotalLiabilitiesCriteria',
				'CompanyTrendLast52WeeksCriteria' => 'factiva_CompanyTrendLast52WeeksCriteria',
				'ContentIDs' => 'factiva_ContentIDs',
				'ContentSearchConstraint' => 'factiva_ContentSearchConstraint',
				'ContentSearchConstraints' => 'factiva_ContentSearchConstraints',
				'ContentCompanyConstraint' => 'factiva_ContentCompanyConstraint',
				'ContentSourceConstraint' => 'factiva_ContentSourceConstraint',
				'ContentIndustryConstraint' => 'factiva_ContentIndustryConstraint',
				'ContentNewsSubjectConstraint' => 'factiva_ContentNewsSubjectConstraint',
				'ContentLanguageConstraint' => 'factiva_ContentLanguageConstraint',
				'ContentSelection' => 'factiva_ContentSelection',
				'ContentSelections' => 'factiva_ContentSelections',
				'CurrencyCodes' => 'factiva_CurrencyCodes',
				'DateRange' => 'factiva_DateRange',
				'EnterpriseSystem' => 'factiva_EnterpriseSystem',
				'EnterpriseSystems' => 'factiva_EnterpriseSystems',
				'ExchangeCodes' => 'factiva_ExchangeCodes',
				'ExecutiveCriteria' => 'factiva_ExecutiveCriteria',
				'ExecutiveCriteriaGroup' => 'factiva_ExecutiveCriteriaGroup',
				'ExecutiveCriteriaGroupArray1To25' => 'factiva_ExecutiveCriteriaGroupArray1To25',
				'ExecutiveJobFunctionCriteria' => 'factiva_ExecutiveJobFunctionCriteria',
				'ExecutiveJobTitleCriteria' => 'factiva_ExecutiveJobTitleCriteria',
				'ExecutiveBoardMembershipCriteria' => 'factiva_ExecutiveBoardMembershipCriteria',
				'ExecutiveIndustryCriteria' => 'factiva_ExecutiveIndustryCriteria',
				'ExecutiveCityCriteria' => 'factiva_ExecutiveCityCriteria',
				'ExecutiveRegionCriteria' => 'factiva_ExecutiveRegionCriteria',
				'ExecutiveZipPostalCodeCriteria' => 'factiva_ExecutiveZipPostalCodeCriteria',
				'ExecutiveCityAreaCodeCriteria' => 'factiva_ExecutiveCityAreaCodeCriteria',
				'ExecutiveCollegeMajorCriteria' => 'factiva_ExecutiveCollegeMajorCriteria',
				'ExecutiveCollegeDegreeCriteria' => 'factiva_ExecutiveCollegeDegreeCriteria',
				'ExecutiveCompanySymbolCriteria' => 'factiva_ExecutiveCompanySymbolCriteria',
				'ExecutiveCompanyOwnershipTypeCriteria' => 'factiva_ExecutiveCompanyOwnershipTypeCriteria',
				'ExecutiveCollegeNameCriteria' => 'factiva_ExecutiveCollegeNameCriteria',
				'ExecutiveCollegeGraduationYearCriteria' => 'factiva_ExecutiveCollegeGraduationYearCriteria',
				'ExecutiveSearchFirstName' => 'factiva_ExecutiveSearchFirstName',
				'ExecutiveSearchLastName' => 'factiva_ExecutiveSearchLastName',
				'ExecutiveAgeCriteria' => 'factiva_ExecutiveAgeCriteria',
				'ExchangeRegionSearchConstraints' => 'factiva_ExchangeRegionSearchConstraints',
				'FolderIDArray1To10' => 'factiva_FolderIDArray1To10',
				'FolderIDArray1To25' => 'factiva_FolderIDArray1To25',
				'GroupCodeArray1To10' => 'factiva_GroupCodeArray1To10',
				'IncludeDescriptors' => 'factiva_IncludeDescriptors',
				'IndexCriteria' => 'factiva_IndexCriteria',
				'IndustryCodes' => 'factiva_IndustryCodes',
				'IndustryCriteria' => 'factiva_IndustryCriteria',
				'IndustryRangeCriteria' => 'factiva_IndustryRangeCriteria',
				'IndustryScreeningSummary' => 'factiva_IndustryScreeningSummary',
				'IndustryValueCriteria' => 'factiva_IndustryValueCriteria',
				'InstrumentCodes' => 'factiva_InstrumentCodes',
				'InstrumentExchangeConstraint' => 'factiva_InstrumentExchangeConstraint',
				'InstrumentIssuingOrganizationConstraint' => 'factiva_InstrumentIssuingOrganizationConstraint',
				'InstrumentSearchConstraint' => 'factiva_InstrumentSearchConstraint',
				'InstrumentSearchConstraints' => 'factiva_InstrumentSearchConstraints',
				'InstrumentStatusConstraint' => 'factiva_InstrumentStatusConstraint',
				'InstrumentTypeConstraint' => 'factiva_InstrumentTypeConstraint',
				'InternalContentFolder' => 'factiva_InternalContentFolder',
				'InternalContentFolders' => 'factiva_InternalContentFolders',
				'JobFunctionCriteria' => 'factiva_JobFunctionCriteria',
				'JobTitleCriteria' => 'factiva_JobTitleCriteria',
				'KeyFact' => 'factiva_KeyFact',
				'KeyFacts' => 'factiva_KeyFacts',
				'Languages' => 'factiva_Languages',
				'LongBusinessDescriptionSection' => 'factiva_LongBusinessDescriptionSection',
				'NavigatorControl' => 'factiva_NavigatorControl',
				'CompanyNavigatorControl' => 'factiva_CompanyNavigatorControl',
				'IndustryNavigatorControl' => 'factiva_IndustryNavigatorControl',
				'NewsSubjectNavigatorControl' => 'factiva_NewsSubjectNavigatorControl',
				'SourceNavigatorControl' => 'factiva_SourceNavigatorControl',
				'KeyWordNavigatorControl' => 'factiva_KeyWordNavigatorControl',
				'TimeNavigatorControl' => 'factiva_TimeNavigatorControl',
				'ClusterNavigatorControl' => 'factiva_ClusterNavigatorControl',
				'NewsSubjectCodes' => 'factiva_NewsSubjectCodes',
				'NewsSubjects' => 'factiva_NewsSubjects',
				'OwnershipTypeCount' => 'factiva_OwnershipTypeCount',
				'OwnershipTypeScreeningSummary' => 'factiva_OwnershipTypeScreeningSummary',
				'PrimaryExchangeCriteria' => 'factiva_PrimaryExchangeCriteria',
				'RangeCount' => 'factiva_RangeCount',
				'RangeScreeningSummary' => 'factiva_RangeScreeningSummary',
				'ReferenceArray1To25' => 'factiva_ReferenceArray1To25',
				'RegionCodes' => 'factiva_RegionCodes',
				'RegionCriteria' => 'factiva_RegionCriteria',
				'RegionScreeningSummary' => 'factiva_RegionScreeningSummary',
				'ScreeningSummary' => 'factiva_ScreeningSummary',
				'SearchContentCategoryArray1ToUnbounded' => 'factiva_SearchContentCategoryArray1ToUnbounded',
				'SearchDates' => 'factiva_SearchDates',
				'SectionIDArray1To10' => 'factiva_SectionIDArray1To10',
				'SourceCodeArray1To10' => 'factiva_SourceCodeArray1To10',
				'StringSearchCriteria' => 'factiva_StringSearchCriteria',
				'SymbolArray1To25' => 'factiva_SymbolArray1To25',
				'SymbolCriteria' => 'factiva_SymbolCriteria',
				'TechnologyEnterpriseSystems' => 'factiva_TechnologyEnterpriseSystems',
				'TechnologyOverview' => 'factiva_TechnologyOverview',
				'TechnologyOverviewSection' => 'factiva_TechnologyOverviewSection',
				'TechnologySiteInfo' => 'factiva_TechnologySiteInfo',
				'UnknownCount' => 'factiva_UnknownCount',
				'AdditionalInformation' => 'factiva_AdditionalInformation',
				'Address' => 'factiva_Address',
				'AnnualBalanceSheetSection' => 'factiva_AnnualBalanceSheetSection',
				'AnnualBalanceSheetSectionEx' => 'factiva_AnnualBalanceSheetSectionEx',
				'AnnualCashFlowSection' => 'factiva_AnnualCashFlowSection',
				'AnnualCashFlowSectionEx' => 'factiva_AnnualCashFlowSectionEx',
				'AnnualIncomeStatementSection' => 'factiva_AnnualIncomeStatementSection',
				'AnnualIncomeStatementSectionEx' => 'factiva_AnnualIncomeStatementSectionEx',
				'ApplicableContentCategories' => 'factiva_ApplicableContentCategories',
				'AuditorInfo' => 'factiva_AuditorInfo',
				'Avocations' => 'factiva_Avocations',
				'Awards' => 'factiva_Awards',
				'BalanceSheetFiscalPeriod' => 'factiva_BalanceSheetFiscalPeriod',
				'BalanceSheetFiscalPeriodEx' => 'factiva_BalanceSheetFiscalPeriodEx',
				'BalanceSheetItems' => 'factiva_BalanceSheetItems',
				'BalanceSheetItemsEx' => 'factiva_BalanceSheetItemsEx',
				'BankBalanceSheetItems' => 'factiva_BankBalanceSheetItems',
				'BankCashFlowItems' => 'factiva_BankCashFlowItems',
				'BankIncomeStatementItems' => 'factiva_BankIncomeStatementItems',
				'Biography' => 'factiva_Biography',
				'Bucket' => 'factiva_Bucket',
				'BusinessDescription' => 'factiva_BusinessDescription',
				'BusinessSegmentInformationSection' => 'factiva_BusinessSegmentInformationSection',
				'Career' => 'factiva_Career',
				'CashFlowFiscalPeriod' => 'factiva_CashFlowFiscalPeriod',
				'CashFlowFiscalPeriodEx' => 'factiva_CashFlowFiscalPeriodEx',
				'CashFlowItems' => 'factiva_CashFlowItems',
				'CashFlowItemsEx' => 'factiva_CashFlowItemsEx',
				'CategorizedWebSite' => 'factiva_CategorizedWebSite',
				'Certificates' => 'factiva_Certificates',
				'CivicInformation' => 'factiva_CivicInformation',
				'ClientCodeDefinitionType' => 'factiva_ClientCodeDefinitionType',
				'Cluster' => 'factiva_Cluster',
				'ClusterSet' => 'factiva_ClusterSet',
				'CodeDescriptor' => 'factiva_CodeDescriptor',
				'CodeDescriptorCount' => 'factiva_CodeDescriptorCount',
				'Colleges' => 'factiva_Colleges',
				'College' => 'factiva_College',
				'CompanyDetails' => 'factiva_CompanyDetails',
				'CompanyDetailsReference' => 'factiva_CompanyDetailsReference',
				'CompanyDetailsExReference' => 'factiva_CompanyDetailsExReference',
				'CompanyBasicsSection' => 'factiva_CompanyBasicsSection',
				'CompanyBasicsSnapshot' => 'factiva_CompanyBasicsSnapshot',
				'CompanyCodeDescriptor' => 'factiva_CompanyCodeDescriptor',
				'CompanyComparisonBySalesProfile' => 'factiva_CompanyComparisonBySalesProfile',
				'CompanyComparisonProfile' => 'factiva_CompanyComparisonProfile',
				'CompanyEvent' => 'factiva_CompanyEvent',
				'CompanyEventsSection' => 'factiva_CompanyEventsSection',
				'CompanyExecutivesSection' => 'factiva_CompanyExecutivesSection',
				'CompanyInfo' => 'factiva_CompanyInfo',
				'CompanyInfoEx' => 'factiva_CompanyInfoEx',
				'CompanyInfoEx2' => 'factiva_CompanyInfoEx2',
				'CompanySubsidiariesSection' => 'factiva_CompanySubsidiariesSection',
				'CompanyProfile' => 'factiva_CompanyProfile',
				'CompanyProfileEx' => 'factiva_CompanyProfileEx',
				'CompanyStatus' => 'factiva_CompanyStatus',
				'CompanyStatusEx' => 'factiva_CompanyStatusEx',
				'CompanyStatusEx2' => 'factiva_CompanyStatusEx2',
				'ComparisonIndustry' => 'factiva_ComparisonIndustry',
				'OtherComparisonIndustries' => 'factiva_OtherComparisonIndustries',
				'OtherComparisonIndustry' => 'factiva_OtherComparisonIndustry',
				'Compensation' => 'factiva_Compensation',
				'CompositeSourceCodes' => 'factiva_CompositeSourceCodes',
				'Contact' => 'factiva_Contact',
				'ContentCategoryCount' => 'factiva_ContentCategoryCount',
				'ContentCategoryCountSet' => 'factiva_ContentCategoryCountSet',
				'ContentParts' => 'factiva_ContentParts',
				'Corrections' => 'factiva_Corrections',
				'CreativeWorks' => 'factiva_CreativeWorks',
				'CurrencyInfo' => 'factiva_CurrencyInfo',
				'CustomerInformationFiscalPeriod' => 'factiva_CustomerInformationFiscalPeriod',
				'CustomerOrder' => 'factiva_CustomerOrder',
				'DataPoints' => 'factiva_DataPoints',
				'Degree' => 'factiva_Degree',
				'DegreeInfo' => 'factiva_DegreeInfo',
				'DepartmentInfo' => 'factiva_DepartmentInfo',
				'Description' => 'factiva_Description',
				'DescriptionNationalLanguage' => 'factiva_DescriptionNationalLanguage',
				'Descriptor' => 'factiva_Descriptor',
				'DividendAggregates' => 'factiva_DividendAggregates',
				'DividendRatios' => 'factiva_DividendRatios',
				'DNBCompany' => 'factiva_DNBCompany',
				'DNBCompanyProfile' => 'factiva_DNBCompanyProfile',
				'DNBKeyFinancialsSnapshot' => 'factiva_DNBKeyFinancialsSnapshot',
				'Editor' => 'factiva_Editor',
				'EditorComment' => 'factiva_EditorComment',
				'EditorInfo' => 'factiva_EditorInfo',
				'EfficiencyAggregates' => 'factiva_EfficiencyAggregates',
				'EfficiencyRatios' => 'factiva_EfficiencyRatios',
				'EntityIdentifier' => 'factiva_EntityIdentifier',
				'ExchangeInfo' => 'factiva_ExchangeInfo',
				'Executive' => 'factiva_Executive',
				'ExecutiveDetails' => 'factiva_ExecutiveDetails',
				'ExecutiveDetailsReference' => 'factiva_ExecutiveDetailsReference',
				'ExecutiveDetailsReferences' => 'factiva_ExecutiveDetailsReferences',
				'ExecutiveProfile' => 'factiva_ExecutiveProfile',
				'ExecutiveColleaguesSection' => 'factiva_ExecutiveColleaguesSection',
				'ExecutiveBiographySection' => 'factiva_ExecutiveBiographySection',
				'ExecutiveBiographySectionEx' => 'factiva_ExecutiveBiographySectionEx',
				'FaultException' => 'factiva_FaultException',
				'FinancialAggregates' => 'factiva_FinancialAggregates',
				'FinancialStatement' => 'factiva_FinancialStatement',
				'FinancialStatementEx' => 'factiva_FinancialStatementEx',
				'FinancialStrengthAggregates' => 'factiva_FinancialStrengthAggregates',
				'FinancialStrengthRatios' => 'factiva_FinancialStrengthRatios',
				'FiscalPeriod' => 'factiva_FiscalPeriod',
				'FiscalPeriodLength' => 'factiva_FiscalPeriodLength',
				'Frequency' => 'factiva_Frequency',
				'GeneralRatioItems' => 'factiva_GeneralRatioItems',
				'GeographicSegmentInformationSection' => 'factiva_GeographicSegmentInformationSection',
				'GroupCodes' => 'factiva_GroupCodes',
				'GrowthRatesAggregates' => 'factiva_GrowthRatesAggregates',
				'GrowthRatesRatios' => 'factiva_GrowthRatesRatios',
				'Headline' => 'factiva_Headline',
				'HistoricalSnapshot' => 'factiva_HistoricalSnapshot',
				'History' => 'factiva_History',
				'HooversKeyCompetitorsSection' => 'factiva_HooversKeyCompetitorsSection',
				'ImmigrationInformation' => 'factiva_ImmigrationInformation',
				'IncomeStatementAggregates' => 'factiva_IncomeStatementAggregates',
				'IncomeStatementFiscalPeriod' => 'factiva_IncomeStatementFiscalPeriod',
				'IncomeStatementFiscalPeriodEx' => 'factiva_IncomeStatementFiscalPeriodEx',
				'IncomeStatementItems' => 'factiva_IncomeStatementItems',
				'IncomeStatementItemsEx' => 'factiva_IncomeStatementItemsEx',
				'IncomeStatementRatios' => 'factiva_IncomeStatementRatios',
				'IndexingCode' => 'factiva_IndexingCode',
				'IndexingCodeSet' => 'factiva_IndexingCodeSet',
				'IndexingCodeSets' => 'factiva_IndexingCodeSets',
				'IndexInfo' => 'factiva_IndexInfo',
				'IndustryCodeDescriptor' => 'factiva_IndustryCodeDescriptor',
				'IndustryAverages' => 'factiva_IndustryAverages',
				'IndustryAggregatesSection' => 'factiva_IndustryAggregatesSection',
				'IndustrialBalanceSheetItems' => 'factiva_IndustrialBalanceSheetItems',
				'IndustrialCashFlowItems' => 'factiva_IndustrialCashFlowItems',
				'IndustryClassification' => 'factiva_IndustryClassification',
				'IndustrialIncomeStatementItems' => 'factiva_IndustrialIncomeStatementItems',
				'IndustryInfo' => 'factiva_IndustryInfo',
				'InformationTechnologyDecisionMakers' => 'factiva_InformationTechnologyDecisionMakers',
				'InstitutionalOwnershipAggregates' => 'factiva_InstitutionalOwnershipAggregates',
				'InsiderTradingRatios' => 'factiva_InsiderTradingRatios',
				'InstitutionalOwnershipRatios' => 'factiva_InstitutionalOwnershipRatios',
				'InstrumentInfo' => 'factiva_InstrumentInfo',
				'InsuranceBalanceSheetItems' => 'factiva_InsuranceBalanceSheetItems',
				'InsuranceCashFlowItems' => 'factiva_InsuranceCashFlowItems',
				'InsuranceIncomeStatementItems' => 'factiva_InsuranceIncomeStatementItems',
				'InterimBalanceSheetSection' => 'factiva_InterimBalanceSheetSection',
				'InterimBalanceSheetSectionEx' => 'factiva_InterimBalanceSheetSectionEx',
				'InterimCashFlowSection' => 'factiva_InterimCashFlowSection',
				'InterimCashFlowSectionEx' => 'factiva_InterimCashFlowSectionEx',
				'InterimIncomeStatementSection' => 'factiva_InterimIncomeStatementSection',
				'InterimIncomeStatementSectionEx' => 'factiva_InterimIncomeStatementSectionEx',
				'JobFunctions' => 'factiva_JobFunctions',
				'JobFunctionInfo' => 'factiva_JobFunctionInfo',
				'JobPosition' => 'factiva_JobPosition',
				'KeyCompetitorsSection' => 'factiva_KeyCompetitorsSection',
				'KeyFinancialsFiscalPeriod' => 'factiva_KeyFinancialsFiscalPeriod',
				'KeyFinancialsItems' => 'factiva_KeyFinancialsItems',
				'KeyFinancialsSection' => 'factiva_KeyFinancialsSection',
				'KeyFinancialsSnapshot' => 'factiva_KeyFinancialsSnapshot',
				'Keyword' => 'factiva_Keyword',
				'KeywordSet' => 'factiva_KeywordSet',
				'LeadParagraph' => 'factiva_LeadParagraph',
				'Logo' => 'factiva_Logo',
				'MajorCustomersSection' => 'factiva_MajorCustomersSection',
				'ManagementEffectivenessAggregates' => 'factiva_ManagementEffectivenessAggregates',
				'ManagementEffectivenessRatios' => 'factiva_ManagementEffectivenessRatios',
				'MarketDataSnapshot' => 'factiva_MarketDataSnapshot',
				'MarketDataSnapshotEx' => 'factiva_MarketDataSnapshotEx',
				'Membership' => 'factiva_Membership',
				'MilitaryService' => 'factiva_MilitaryService',
				'Navigator' => 'factiva_Navigator',
				'NavigatorSet' => 'factiva_NavigatorSet',
				'NewsSubjectInfo' => 'factiva_NewsSubjectInfo',
				'NonPublicationDay' => 'factiva_NonPublicationDay',
				'NonPublicationDays' => 'factiva_NonPublicationDays',
				'Overview' => 'factiva_Overview',
				'OverviewAndDetails' => 'factiva_OverviewAndDetails',
				'OverviewAndHistorySection' => 'factiva_OverviewAndHistorySection',
				'Owner' => 'factiva_Owner',
				'Pages' => 'factiva_Pages',
				'Paragraph' => 'factiva_Paragraph',
				'Paragraphs' => 'factiva_Paragraphs',
				'Part' => 'factiva_Part',
				'PerShareRatios' => 'factiva_PerShareRatios',
				'PeerCompetitorsSnapshot' => 'factiva_PeerCompetitorsSnapshot',
				'PersonName' => 'factiva_PersonName',
				'PhoneNumber' => 'factiva_PhoneNumber',
				'Politics' => 'factiva_Politics',
				'PriceRelatedAggregates' => 'factiva_PriceRelatedAggregates',
				'PriceRelatedRatios' => 'factiva_PriceRelatedRatios',
				'PriceVolumeAggregates' => 'factiva_PriceVolumeAggregates',
				'PriceVolumeRatios' => 'factiva_PriceVolumeRatios',
				'ProfitabilityAggregates' => 'factiva_ProfitabilityAggregates',
				'ProfitabilityRatios' => 'factiva_ProfitabilityRatios',
				'ProductsAndServicesSection' => 'factiva_ProductsAndServicesSection',
				'ProviderDetails' => 'factiva_ProviderDetails',
				'PublicationDates' => 'factiva_PublicationDates',
				'PublicationFormats' => 'factiva_PublicationFormats',
				'PublisherLogo' => 'factiva_PublisherLogo',
				'PublicListing' => 'factiva_PublicListing',
				'PublisherPromotion' => 'factiva_PublisherPromotion',
				'QuantityPrice' => 'factiva_QuantityPrice',
				'QueryTransform' => 'factiva_QueryTransform',
				'QueryTransformSet' => 'factiva_QueryTransformSet',
				'QuoteSnapshot' => 'factiva_QuoteSnapshot',
				'QuoteSnapshotEx' => 'factiva_QuoteSnapshotEx',
				'RegionCodeDescriptor' => 'factiva_RegionCodeDescriptor',
				'RegionDescriptor' => 'factiva_RegionDescriptor',
				'RegionInfo' => 'factiva_RegionInfo',
				'RatioFiscalPeriod' => 'factiva_RatioFiscalPeriod',
				'RatioItems' => 'factiva_RatioItems',
				'RatiosSection' => 'factiva_RatiosSection',
				'RatiosSectionEx' => 'factiva_RatiosSectionEx',
				'RegionTaxonomyCode' => 'factiva_RegionTaxonomyCode',
				'Religion' => 'factiva_Religion',
				'Remuneration' => 'factiva_Remuneration',
				'ReutersKeyCompetitorsSection' => 'factiva_ReutersKeyCompetitorsSection',
				'SalesByLocation' => 'factiva_SalesByLocation',
				'SalesByOperation' => 'factiva_SalesByOperation',
				'SectorAggregatesSection' => 'factiva_SectorAggregatesSection',
				'SECSubmission' => 'factiva_SECSubmission',
				'Segment' => 'factiva_Segment',
				'SegmentInformationFiscalPeriod' => 'factiva_SegmentInformationFiscalPeriod',
				'SegmentItems' => 'factiva_SegmentItems',
				'ShareAggregates' => 'factiva_ShareAggregates',
				'ShareRatios' => 'factiva_ShareRatios',
				'ShortInterestRatios' => 'factiva_ShortInterestRatios',
				'Status' => 'factiva_Status',
				'StockOptions' => 'factiva_StockOptions',
				'Snippet' => 'factiva_Snippet',
				'SWOTAnalysis' => 'factiva_SWOTAnalysis',
				'SWOTAnalysisSection' => 'factiva_SWOTAnalysisSection',
				'IndexAggregatesSection' => 'factiva_IndexAggregatesSection',
				'TailParagraphs' => 'factiva_TailParagraphs',
				'TaxonomyCodeDescriptor' => 'factiva_TaxonomyCodeDescriptor',
				'TaxonomyCodeStatus' => 'factiva_TaxonomyCodeStatus',
				'TenureDates' => 'factiva_TenureDates',
				'Thoughts' => 'factiva_Thoughts',
				'TruncationRules' => 'factiva_TruncationRules',
				'EUROBalanceSheetItems' => 'factiva_EUROBalanceSheetItems',
				'EUROCashFlowItems' => 'factiva_EUROCashFlowItems',
				'EUROIncomeStatementItems' => 'factiva_EUROIncomeStatementItems',
				'EURORatioItems' => 'factiva_EURORatioItems',
				'EUROEfficiencyRatios' => 'factiva_EUROEfficiencyRatios',
				'EUROFinancialStrengthRatios' => 'factiva_EUROFinancialStrengthRatios',
				'EUROManagementEffectivenessRatios' => 'factiva_EUROManagementEffectivenessRatios',
				'EUROProfitabilityRatios' => 'factiva_EUROProfitabilityRatios',
				'PCIBalanceSheetItems' => 'factiva_PCIBalanceSheetItems',
				'PCIIncomeStatementItems' => 'factiva_PCIIncomeStatementItems',
				'PCIRatioItems' => 'factiva_PCIRatioItems',
				'PCIEfficiencyRatios' => 'factiva_PCIEfficiencyRatios',
				'PCIFinancialStrengthRatios' => 'factiva_PCIFinancialStrengthRatios',
				'PCIManagementEffectivenessRatios' => 'factiva_PCIManagementEffectivenessRatios',
				'PCIProfitabilityRatios' => 'factiva_PCIProfitabilityRatios',
				'PCIIndustryFinancialStrengthRatios' => 'factiva_PCIIndustryFinancialStrengthRatios',
				'PCIIndustryManagementEffectivenessRatios' => 'factiva_PCIIndustryManagementEffectivenessRatios',
				'PCIIndustryProfitabilityRatios' => 'factiva_PCIIndustryProfitabilityRatios',
				'URL' => 'factiva_URL',
				'UtilityBalanceSheetItems' => 'factiva_UtilityBalanceSheetItems',
				'UtilityCashFlowItems' => 'factiva_UtilityCashFlowItems',
				'UtilityIncomeStatementItems' => 'factiva_UtilityIncomeStatementItems',
				'USGovernmentExecutive' => 'factiva_USGovernmentExecutive',
				'USGovernmentExecutives' => 'factiva_USGovernmentExecutives',
				'USGovernmentExecutiveSnapshot' => 'factiva_USGovernmentExecutiveSnapshot',
				'USGovernmentOrganization' => 'factiva_USGovernmentOrganization',
				'USGovernmentOrganizationSnapshot' => 'factiva_USGovernmentOrganizationSnapshot',
				'WebSite' => 'factiva_WebSite',
				'YearMonthDay' => 'factiva_YearMonthDay',
				'CompanyComparisonBySalesProfileResultSet' => 'factiva_CompanyComparisonBySalesProfileResultSet',
				'CompanyComparisonProfilesResultSet' => 'factiva_CompanyComparisonProfilesResultSet',
				'CompanyCriteriaGroupResultSet' => 'factiva_CompanyCriteriaGroupResultSet',
				'CompanyCriteriaGroupResult' => 'factiva_CompanyCriteriaGroupResult',
				'CompanyDetailsListResultSet' => 'factiva_CompanyDetailsListResultSet',
				'CompanyDetailsListEx2ResultSet' => 'factiva_CompanyDetailsListEx2ResultSet',
				'CompanyDetailsListEx3ResultSet' => 'factiva_CompanyDetailsListEx3ResultSet',
				'CompanyDetailsResultSet' => 'factiva_CompanyDetailsResultSet',
				'CompanyPeerComparisonResult' => 'factiva_CompanyPeerComparisonResult',
				'CompanyPeerComparisonExResult' => 'factiva_CompanyPeerComparisonExResult',
				'CompanyProfilesExResult' => 'factiva_CompanyProfilesExResult',
				'CompanyProfilesExResultSet' => 'factiva_CompanyProfilesExResultSet',
				'CompanyProfilesResult' => 'factiva_CompanyProfilesResult',
				'CompanyProfilesResultSet' => 'factiva_CompanyProfilesResultSet',
				'CompanyScreeningResult' => 'factiva_CompanyScreeningResult',
				'IndustryAveragesResult' => 'factiva_IndustryAveragesResult',
				'NewsBriefsSearchResult' => 'factiva_NewsBriefsSearchResult',
				'CompanyReportResult' => 'factiva_CompanyReportResult',
				'CompanyReportExResult' => 'factiva_CompanyReportExResult',
				'CompanyReportWithFinancialStatementsResult' => 'factiva_CompanyReportWithFinancialStatementsResult',
				'CompanyReportWithFinancialStatementsExResult' => 'factiva_CompanyReportWithFinancialStatementsExResult',
				'RatioReportResult' => 'factiva_RatioReportResult',
				'RatioReportExResult' => 'factiva_RatioReportExResult',
				'CompanySnapshotResult' => 'factiva_CompanySnapshotResult',
				'CompanySnapshotExResult' => 'factiva_CompanySnapshotExResult',
				'IndustrySnapshotResult' => 'factiva_IndustrySnapshotResult',
				'ExecutiveCriteriaGroupResultSet' => 'factiva_ExecutiveCriteriaGroupResultSet',
				'ExecutiveCriteriaGroupResult' => 'factiva_ExecutiveCriteriaGroupResult',
				'ExecutiveDetailsResultSet' => 'factiva_ExecutiveDetailsResultSet',
				'ExecutiveProfilesResult' => 'factiva_ExecutiveProfilesResult',
				'ExecutiveSearchResult' => 'factiva_ExecutiveSearchResult',
				'ExecutiveProfilesResultSet' => 'factiva_ExecutiveProfilesResultSet',
				'ExecutiveSearchResultSet' => 'factiva_ExecutiveSearchResultSet',
				'ExecutiveScreeningResult' => 'factiva_ExecutiveScreeningResult',
				'DNBCompanyProfileResult' => 'factiva_DNBCompanyProfileResult',
				'DNBCompanyProfileResultSet' => 'factiva_DNBCompanyProfileResultSet',
				'DNBCompanyResultSet' => 'factiva_DNBCompanyResultSet',
				'USGovernmentOrganizationsResult' => 'factiva_USGovernmentOrganizationsResult',
				'USGovernmentOrganizationsResultSet' => 'factiva_USGovernmentOrganizationsResultSet',
				'USGovernmentOrganizationSnapshotResult' => 'factiva_USGovernmentOrganizationSnapshotResult',
				'USGovernmentExecutiveSearchResult' => 'factiva_USGovernmentExecutiveSearchResult',
				'USGovernmentExecutiveSearchResultSet' => 'factiva_USGovernmentExecutiveSearchResultSet',
				'USGovernmentExecutiveSnapshotResult' => 'factiva_USGovernmentExecutiveSnapshotResult',
				'CompanyComparisonResponse' => 'factiva_CompanyComparisonResponse',
				'CompanyDetailsListResponse' => 'factiva_CompanyDetailsListResponse',
				'CompanyDetailsListEx2Response' => 'factiva_CompanyDetailsListEx2Response',
				'CompanyDetailsListEx3Response' => 'factiva_CompanyDetailsListEx3Response',
				'CompanyDetailsListEx4Response' => 'factiva_CompanyDetailsListEx4Response',
				'CompanyDetailsResponse' => 'factiva_CompanyDetailsResponse',
				'CompanyKeyDevelopmentsSearchResponse' => 'factiva_CompanyKeyDevelopmentsSearchResponse',
				'CompanyNewsBriefsSearchResponse' => 'factiva_CompanyNewsBriefsSearchResponse',
				'CompanyPeerComparisonResponse' => 'factiva_CompanyPeerComparisonResponse',
				'CompanyPeerComparisonExResponse' => 'factiva_CompanyPeerComparisonExResponse',
				'CompanyProfilesResponse' => 'factiva_CompanyProfilesResponse',
				'CompanyProfilesExResponse' => 'factiva_CompanyProfilesExResponse',
				'CompanyScreeningResponse' => 'factiva_CompanyScreeningResponse',
				'IndustryAveragesResponse' => 'factiva_IndustryAveragesResponse',
				'IndustryNewsBriefsSearchResponse' => 'factiva_IndustryNewsBriefsSearchResponse',
				'PublishedCompanyReportsSearchResponse' => 'factiva_PublishedCompanyReportsSearchResponse',
				'PublishedIndustryReportsSearchResponse' => 'factiva_PublishedIndustryReportsSearchResponse',
				'ScreeningContextResponse' => 'factiva_ScreeningContextResponse',
				'CompanyReportResponse' => 'factiva_CompanyReportResponse',
				'CompanyReportExResponse' => 'factiva_CompanyReportExResponse',
				'CompanyReportWithFinancialStatementsResponse' => 'factiva_CompanyReportWithFinancialStatementsResponse',
				'CompanyReportWithFinancialStatementsExResponse' => 'factiva_CompanyReportWithFinancialStatementsExResponse',
				'RatioComparisonReportResponse' => 'factiva_RatioComparisonReportResponse',
				'RatioComparisonReportExResponse' => 'factiva_RatioComparisonReportExResponse',
				'CompanySnapshotResponse' => 'factiva_CompanySnapshotResponse',
				'CompanySnapshotExResponse' => 'factiva_CompanySnapshotExResponse',
				'IndustrySnapshotResponse' => 'factiva_IndustrySnapshotResponse',
				'ExecutiveDetailsResponse' => 'factiva_ExecutiveDetailsResponse',
				'ExecutiveNewsBriefsSearchResponse' => 'factiva_ExecutiveNewsBriefsSearchResponse',
				'ExecutiveProfilesResponse' => 'factiva_ExecutiveProfilesResponse',
				'ExecutiveSearchResponse' => 'factiva_ExecutiveSearchResponse',
				'ExecutiveScreeningResponse' => 'factiva_ExecutiveScreeningResponse',
				'DNBCompanyProfileResponse' => 'factiva_DNBCompanyProfileResponse',
				'DNBCompanyChildrenResponse' => 'factiva_DNBCompanyChildrenResponse',
				'DNBCompanyBranchLocationsResponse' => 'factiva_DNBCompanyBranchLocationsResponse',
				'DNBCompanyGlobalUltimateResponse' => 'factiva_DNBCompanyGlobalUltimateResponse',
				'DNBCompanyTreeResponse' => 'factiva_DNBCompanyTreeResponse',
				'USGovernmentOrganizationsResponse' => 'factiva_USGovernmentOrganizationsResponse',
				'USGovernmentOrganizationSnapshotResponse' => 'factiva_USGovernmentOrganizationSnapshotResponse',
				'USGovernmentExecutiveSnapshotResponse' => 'factiva_USGovernmentExecutiveSnapshotResponse',
				'USGovernmentExecutiveSearchResponse' => 'factiva_USGovernmentExecutiveSearchResponse',
				'QuoteResultSet' => 'factiva_QuoteResultSet',
				'Quote' => 'factiva_Quote',
				'QuoteResponse' => 'factiva_QuoteResponse',
				'LoginResultType' => 'factiva_LoginResultType',
				'EncryptedIDResult' => 'factiva_EncryptedIDResult',
				'AccountInfoResult' => 'factiva_AccountInfoResult',
				'ClientCodeResult' => 'factiva_ClientCodeResult',
				'ClientCodeInfo' => 'factiva_ClientCodeInfo',
				'LoginResponse' => 'factiva_LoginResponse',
				'EncryptedIDResponse' => 'factiva_EncryptedIDResponse',
				'AccountInfoResponse' => 'factiva_AccountInfoResponse',
				'ClientCodeResponse' => 'factiva_ClientCodeResponse',
				'NewsstandSourcesResultSet' => 'factiva_NewsstandSourcesResultSet',
				'NewsstandSectionsResult' => 'factiva_NewsstandSectionsResult',
				'NewsstandSectionsResultSet' => 'factiva_NewsstandSectionsResultSet',
				'NewsstandHeadlinesResultSet' => 'factiva_NewsstandHeadlinesResultSet',
				'SectionHeadlinesResultSet' => 'factiva_SectionHeadlinesResultSet',
				'SourceInfo' => 'factiva_SourceInfo',
				'SectionInfo' => 'factiva_SectionInfo',
				'Section' => 'factiva_Section',
				'NewsstandHeadline' => 'factiva_NewsstandHeadline',
				'NewsstandSourcesResponse' => 'factiva_NewsstandSourcesResponse',
				'NewsstandSectionsResponse' => 'factiva_NewsstandSectionsResponse',
				'NewsstandHeadlinesResponse' => 'factiva_NewsstandHeadlinesResponse',
				'EmailTokenResult' => 'factiva_EmailTokenResult',
				'UserDataResult' => 'factiva_UserDataResult',
				'UserDataExResult' => 'factiva_UserDataExResult',
				'UserRegistrationResult' => 'factiva_UserRegistrationResult',
				'EmailAddressRegistrationResult' => 'factiva_EmailAddressRegistrationResult',
				'EmailTokenResponse' => 'factiva_EmailTokenResponse',
				'UserDataResponse' => 'factiva_UserDataResponse',
				'UserDataExResponse' => 'factiva_UserDataExResponse',
				'UserRegistrationResponse' => 'factiva_UserRegistrationResponse',
				'EmailAddressRegistrationResponse' => 'factiva_EmailAddressRegistrationResponse',
				'ArticleResultSet' => 'factiva_ArticleResultSet',
				'Article' => 'factiva_Article',
				'HTMLResultSet' => 'factiva_HTMLResultSet',
				'HTMLDocument' => 'factiva_HTMLDocument',
				'PictureResultSet' => 'factiva_PictureResultSet',
				'Picture' => 'factiva_Picture',
				'PDFResultSet' => 'factiva_PDFResultSet',
				'PDF' => 'factiva_PDF',
				'ExternalURLResultSet' => 'factiva_ExternalURLResultSet',
				'ExternalURL' => 'factiva_ExternalURL',
				'ContentResultSet' => 'factiva_ContentResultSet',
				'ArticleResponse' => 'factiva_ArticleResponse',
				'HTMLResponse' => 'factiva_HTMLResponse',
				'PictureResponse' => 'factiva_PictureResponse',
				'PDFResponse' => 'factiva_PDFResponse',
				'ExternalURLResponse' => 'factiva_ExternalURLResponse',
				'ContentResponse' => 'factiva_ContentResponse',
				'ContentSearchResult' => 'factiva_ContentSearchResult',
				'ContentSearchWithFDTResult' => 'factiva_ContentSearchWithFDTResult',
				'ContentHeadlinesResultSet' => 'factiva_ContentHeadlinesResultSet',
				'ContentHeadline' => 'factiva_ContentHeadline',
				'SourceSearchResult' => 'factiva_SourceSearchResult',
				'SourcesResultSet' => 'factiva_SourcesResultSet',
				'Source' => 'factiva_Source',
				'SourceGroupSearchResult' => 'factiva_SourceGroupSearchResult',
				'SourceGroupsResultSet' => 'factiva_SourceGroupsResultSet',
				'SourceGroup' => 'factiva_SourceGroup',
				'SourcesByCategoryResultSet' => 'factiva_SourcesByCategoryResultSet',
				'ContentSearchResponse' => 'factiva_ContentSearchResponse',
				'ContentSearchWithFDTResponse' => 'factiva_ContentSearchWithFDTResponse',
				'SourceSearchResponse' => 'factiva_SourceSearchResponse',
				'SourceGroupSearchResponse' => 'factiva_SourceGroupSearchResponse',
				'SourcesByCategoryResponse' => 'factiva_SourcesByCategoryResponse',
				'SourcesByTitleResponse' => 'factiva_SourcesByTitleResponse',
				'SourcesByCodeResponse' => 'factiva_SourcesByCodeResponse',
				'SourceGroupsByCodeResponse' => 'factiva_SourceGroupsByCodeResponse',
				'CompanyInfoResultSet' => 'factiva_CompanyInfoResultSet',
				'CompanyInfoExResultSet' => 'factiva_CompanyInfoExResultSet',
				'CompanyInfoEx2ResultSet' => 'factiva_CompanyInfoEx2ResultSet',
				'CompanySearchResult' => 'factiva_CompanySearchResult',
				'CompanySearchExResult' => 'factiva_CompanySearchExResult',
				'CompanySearchEx2Result' => 'factiva_CompanySearchEx2Result',
				'CompanyResult' => 'factiva_CompanyResult',
				'CompanyExResult' => 'factiva_CompanyExResult',
				'CompanyEx2Result' => 'factiva_CompanyEx2Result',
				'CompanyResultSet' => 'factiva_CompanyResultSet',
				'CompanyExResultSet' => 'factiva_CompanyExResultSet',
				'CompanyEx2ResultSet' => 'factiva_CompanyEx2ResultSet',
				'InstrumentInfoResultSet' => 'factiva_InstrumentInfoResultSet',
				'InstrumentSearchResult' => 'factiva_InstrumentSearchResult',
				'InstrumentResult' => 'factiva_InstrumentResult',
				'InstrumentResultSet' => 'factiva_InstrumentResultSet',
				'ExchangeResult' => 'factiva_ExchangeResult',
				'ExchangeInfoResultSet' => 'factiva_ExchangeInfoResultSet',
				'ExchangeResultSet' => 'factiva_ExchangeResultSet',
				'IndustryInfoResultSet' => 'factiva_IndustryInfoResultSet',
				'IndustryResultSet' => 'factiva_IndustryResultSet',
				'IndustryResult' => 'factiva_IndustryResult',
				'IndustryChildrenResultSet' => 'factiva_IndustryChildrenResultSet',
				'IndustryChildrenResult' => 'factiva_IndustryChildrenResult',
				'RegionInfoResultSet' => 'factiva_RegionInfoResultSet',
				'RegionResultSet' => 'factiva_RegionResultSet',
				'RegionResult' => 'factiva_RegionResult',
				'RegionChildrenResultSet' => 'factiva_RegionChildrenResultSet',
				'RegionChildrenResult' => 'factiva_RegionChildrenResult',
				'NewsSubjectInfoResultSet' => 'factiva_NewsSubjectInfoResultSet',
				'NewsSubjectResultSet' => 'factiva_NewsSubjectResultSet',
				'NewsSubjectResult' => 'factiva_NewsSubjectResult',
				'NewsSubjectChildrenResultSet' => 'factiva_NewsSubjectChildrenResultSet',
				'NewsSubjectChildrenResult' => 'factiva_NewsSubjectChildrenResult',
				'JobFunctionInfoResultSet' => 'factiva_JobFunctionInfoResultSet',
				'AuditorInfoResultSet' => 'factiva_AuditorInfoResultSet',
				'DegreeInfoResultSet' => 'factiva_DegreeInfoResultSet',
				'DepartmentInfoResultSet' => 'factiva_DepartmentInfoResultSet',
				'CurrencyInfoResultSet' => 'factiva_CurrencyInfoResultSet',
				'CurrencyResultSet' => 'factiva_CurrencyResultSet',
				'CurrencyResult' => 'factiva_CurrencyResult',
				'IndexInfoResultSet' => 'factiva_IndexInfoResultSet',
				'ListInfoResultSet' => 'factiva_ListInfoResultSet',
				'ListInfo' => 'factiva_ListInfo',
				'CompanySearchResponse' => 'factiva_CompanySearchResponse',
				'CompanySearchExResponse' => 'factiva_CompanySearchExResponse',
				'CompanySearchEx2Response' => 'factiva_CompanySearchEx2Response',
				'CompanyByCodeResponse' => 'factiva_CompanyByCodeResponse',
				'CompanyByCodeExResponse' => 'factiva_CompanyByCodeExResponse',
				'CompanyByCodeEx2Response' => 'factiva_CompanyByCodeEx2Response',
				'InstrumentSearchResponse' => 'factiva_InstrumentSearchResponse',
				'InstrumentByCodeResponse' => 'factiva_InstrumentByCodeResponse',
				'ExchangeSearchResponse' => 'factiva_ExchangeSearchResponse',
				'ExchangeByCodeResponse' => 'factiva_ExchangeByCodeResponse',
				'ExchangeListResponse' => 'factiva_ExchangeListResponse',
				'IndustrySearchResponse' => 'factiva_IndustrySearchResponse',
				'IndustryByCodeResponse' => 'factiva_IndustryByCodeResponse',
				'IndustryChildrenResponse' => 'factiva_IndustryChildrenResponse',
				'IndustryListResponse' => 'factiva_IndustryListResponse',
				'RegionSearchResponse' => 'factiva_RegionSearchResponse',
				'RegionByCodeResponse' => 'factiva_RegionByCodeResponse',
				'RegionChildrenResponse' => 'factiva_RegionChildrenResponse',
				'RegionListResponse' => 'factiva_RegionListResponse',
				'NewsSubjectSearchResponse' => 'factiva_NewsSubjectSearchResponse',
				'NewsSubjectByCodeResponse' => 'factiva_NewsSubjectByCodeResponse',
				'NewsSubjectChildrenResponse' => 'factiva_NewsSubjectChildrenResponse',
				'NewsSubjectListResponse' => 'factiva_NewsSubjectListResponse',
				'JobFunctionListResponse' => 'factiva_JobFunctionListResponse',
				'AuditorListResponse' => 'factiva_AuditorListResponse',
				'DegreeListResponse' => 'factiva_DegreeListResponse',
				'DepartmentListResponse' => 'factiva_DepartmentListResponse',
				'CurrencyListResponse' => 'factiva_CurrencyListResponse',
				'CurrencyByCodeResponse' => 'factiva_CurrencyByCodeResponse',
				'IndexListResponse' => 'factiva_IndexListResponse',
				'ListResponse' => 'factiva_ListResponse',
				'FolderInfoResultSet' => 'factiva_FolderInfoResultSet',
				'FolderInfoExResultSet' => 'factiva_FolderInfoExResultSet',
				'FolderHeadlinesResult' => 'factiva_FolderHeadlinesResult',
				'FolderHeadlinesResultSet' => 'factiva_FolderHeadlinesResultSet',
				'FolderHeadlinesExResultSet' => 'factiva_FolderHeadlinesExResultSet',
				'NewFolderHeadlinesResult' => 'factiva_NewFolderHeadlinesResult',
				'FolderInfo' => 'factiva_FolderInfo',
				'FolderInfoEx' => 'factiva_FolderInfoEx',
				'Folder' => 'factiva_Folder',
				'FolderHeadline' => 'factiva_FolderHeadline',
				'FolderDetails' => 'factiva_FolderDetails',
				'InternalContent' => 'factiva_InternalContent',
				'InternalContentFolderInfo' => 'factiva_InternalContentFolderInfo',
				'FolderInfoResponse' => 'factiva_FolderInfoResponse',
				'FolderInfoExResponse' => 'factiva_FolderInfoExResponse',
				'FolderHeadlinesResponse' => 'factiva_FolderHeadlinesResponse',
				'FolderHeadlinesExResponse' => 'factiva_FolderHeadlinesExResponse',
				'NewFolderHeadlinesResponse' => 'factiva_NewFolderHeadlinesResponse',
				'EditorCommentIDResponse' => 'factiva_EditorCommentIDResponse',
				'EditorCommentResponse' => 'factiva_EditorCommentResponse',
				'FolderIDResponse' => 'factiva_FolderIDResponse',
				'FolderResponse' => 'factiva_FolderResponse',
				'InternalContentIDResponse' => 'factiva_InternalContentIDResponse',
				'InternalContentResponse' => 'factiva_InternalContentResponse',
				'PerformCompanyScreening' => 'factiva_PerformCompanyScreening',
				'PerformCompanyScreeningResponse' => 'factiva_PerformCompanyScreeningResponse',
				'PerformCompanyScreeningEx' => 'factiva_PerformCompanyScreeningEx',
				'PerformCompanyScreeningExResponse' => 'factiva_PerformCompanyScreeningExResponse',
				'SortCompanyProfiles' => 'factiva_SortCompanyProfiles',
				'SortCompanyProfilesResponse' => 'factiva_SortCompanyProfilesResponse',
				'SortCompanyProfilesEx' => 'factiva_SortCompanyProfilesEx',
				'SortCompanyProfilesExResponse' => 'factiva_SortCompanyProfilesExResponse',
				'GetCompanyProfiles' => 'factiva_GetCompanyProfiles',
				'GetCompanyProfilesResponse' => 'factiva_GetCompanyProfilesResponse',
				'GetCompanyProfilesEx' => 'factiva_GetCompanyProfilesEx',
				'GetCompanyProfilesExResponse' => 'factiva_GetCompanyProfilesExResponse',
				'PerformCompanyComparison' => 'factiva_PerformCompanyComparison',
				'PerformCompanyComparisonResponse' => 'factiva_PerformCompanyComparisonResponse',
				'PerformCompanyPeerComparison' => 'factiva_PerformCompanyPeerComparison',
				'PerformCompanyPeerComparisonResponse' => 'factiva_PerformCompanyPeerComparisonResponse',
				'GetCompanyDetailsList' => 'factiva_GetCompanyDetailsList',
				'PerformCompanyPeerComparisonEx' => 'factiva_PerformCompanyPeerComparisonEx',
				'PerformCompanyPeerComparisonExResponse' => 'factiva_PerformCompanyPeerComparisonExResponse',
				'GetCompanyDetailsListResponse' => 'factiva_GetCompanyDetailsListResponse',
				'GetCompanyDetailsListEx' => 'factiva_GetCompanyDetailsListEx',
				'GetCompanyDetailsListExResponse' => 'factiva_GetCompanyDetailsListExResponse',
				'GetCompanyDetailsListEx2' => 'factiva_GetCompanyDetailsListEx2',
				'GetCompanyDetailsListEx2Response' => 'factiva_GetCompanyDetailsListEx2Response',
				'GetCompanyDetailsListEx3' => 'factiva_GetCompanyDetailsListEx3',
				'GetCompanyDetailsListEx3Response' => 'factiva_GetCompanyDetailsListEx3Response',
				'GetCompanyDetailsListEx4' => 'factiva_GetCompanyDetailsListEx4',
				'GetCompanyDetailsListEx4Response' => 'factiva_GetCompanyDetailsListEx4Response',
				'GetCompanyDetails' => 'factiva_GetCompanyDetails',
				'GetCompanyDetailsResponse' => 'factiva_GetCompanyDetailsResponse',
				'GetCompanyDetailsEx' => 'factiva_GetCompanyDetailsEx',
				'GetCompanyDetailsExResponse' => 'factiva_GetCompanyDetailsExResponse',
				'GetIndustryAverages' => 'factiva_GetIndustryAverages',
				'GetIndustryAveragesResponse' => 'factiva_GetIndustryAveragesResponse',
				'PerformCompanyNewsBriefsSearch' => 'factiva_PerformCompanyNewsBriefsSearch',
				'PerformCompanyNewsBriefsSearchResponse' => 'factiva_PerformCompanyNewsBriefsSearchResponse',
				'PerformCompanyNewsBriefsSearchEx' => 'factiva_PerformCompanyNewsBriefsSearchEx',
				'PerformCompanyNewsBriefsSearchExResponse' => 'factiva_PerformCompanyNewsBriefsSearchExResponse',
				'ContinueCompanyNewsBriefsSearch' => 'factiva_ContinueCompanyNewsBriefsSearch',
				'ContinueCompanyNewsBriefsSearchResponse' => 'factiva_ContinueCompanyNewsBriefsSearchResponse',
				'PerformIndustryNewsBriefsSearch' => 'factiva_PerformIndustryNewsBriefsSearch',
				'PerformIndustryNewsBriefsSearchResponse' => 'factiva_PerformIndustryNewsBriefsSearchResponse',
				'PerformIndustryNewsBriefsSearchEx' => 'factiva_PerformIndustryNewsBriefsSearchEx',
				'PerformIndustryNewsBriefsSearchExResponse' => 'factiva_PerformIndustryNewsBriefsSearchExResponse',
				'ContinueIndustryNewsBriefsSearch' => 'factiva_ContinueIndustryNewsBriefsSearch',
				'ContinueIndustryNewsBriefsSearchResponse' => 'factiva_ContinueIndustryNewsBriefsSearchResponse',
				'PerformPublishedCompanyReportsSearch' => 'factiva_PerformPublishedCompanyReportsSearch',
				'PerformPublishedCompanyReportsSearchResponse' => 'factiva_PerformPublishedCompanyReportsSearchResponse',
				'PerformPublishedIndustryReportsSearch' => 'factiva_PerformPublishedIndustryReportsSearch',
				'PerformPublishedIndustryReportsSearchResponse' => 'factiva_PerformPublishedIndustryReportsSearchResponse',
				'PerformCompanyKeyDevelopmentsSearch' => 'factiva_PerformCompanyKeyDevelopmentsSearch',
				'PerformCompanyKeyDevelopmentsSearchResponse' => 'factiva_PerformCompanyKeyDevelopmentsSearchResponse',
				'PerformCompanyKeyDevelopmentsSearchEx' => 'factiva_PerformCompanyKeyDevelopmentsSearchEx',
				'PerformCompanyKeyDevelopmentsSearchExResponse' => 'factiva_PerformCompanyKeyDevelopmentsSearchExResponse',
				'GetCompanyReport' => 'factiva_GetCompanyReport',
				'GetCompanyReportResponse' => 'factiva_GetCompanyReportResponse',
				'GetCompanyReportEx' => 'factiva_GetCompanyReportEx',
				'GetCompanyReportExResponse' => 'factiva_GetCompanyReportExResponse',
				'GetCompanyReportEx2' => 'factiva_GetCompanyReportEx2',
				'GetCompanyReportEx2Response' => 'factiva_GetCompanyReportEx2Response',
				'GetCompanyReportWithFinancialStatements' => 'factiva_GetCompanyReportWithFinancialStatements',
				'GetCompanyReportWithFinancialStatementsResponse' => 'factiva_GetCompanyReportWithFinancialStatementsResponse',
				'GetCompanyReportWithFinancialStatementsEx' => 'factiva_GetCompanyReportWithFinancialStatementsEx',
				'GetCompanyReportWithFinancialStatementsExResponse' => 'factiva_GetCompanyReportWithFinancialStatementsExResponse',
				'GetCompanyReportWithFinancialStatementsEx2' => 'factiva_GetCompanyReportWithFinancialStatementsEx2',
				'GetCompanyReportWithFinancialStatementsEx2Response' => 'factiva_GetCompanyReportWithFinancialStatementsEx2Response',
				'GetRatioComparisonReport' => 'factiva_GetRatioComparisonReport',
				'GetRatioComparisonReportResponse' => 'factiva_GetRatioComparisonReportResponse',
				'GetRatioComparisonReportEx' => 'factiva_GetRatioComparisonReportEx',
				'GetRatioComparisonReportExResponse' => 'factiva_GetRatioComparisonReportExResponse',
				'GetRatioComparisonReportEx2' => 'factiva_GetRatioComparisonReportEx2',
				'GetRatioComparisonReportEx2Response' => 'factiva_GetRatioComparisonReportEx2Response',
				'PerformCompanySnapshot' => 'factiva_PerformCompanySnapshot',
				'PerformCompanySnapshotResponse' => 'factiva_PerformCompanySnapshotResponse',
				'PerformCompanySnapshotEx' => 'factiva_PerformCompanySnapshotEx',
				'PerformCompanySnapshotExResponse' => 'factiva_PerformCompanySnapshotExResponse',
				'PerformIndustrySnapshot' => 'factiva_PerformIndustrySnapshot',
				'PerformIndustrySnapshotResponse' => 'factiva_PerformIndustrySnapshotResponse',
				'PerformExecutiveScreening' => 'factiva_PerformExecutiveScreening',
				'PerformExecutiveScreeningResponse' => 'factiva_PerformExecutiveScreeningResponse',
				'PerformExecutiveScreeningEx' => 'factiva_PerformExecutiveScreeningEx',
				'PerformExecutiveScreeningExResponse' => 'factiva_PerformExecutiveScreeningExResponse',
				'PerformExecutiveScreeningEx2' => 'factiva_PerformExecutiveScreeningEx2',
				'PerformExecutiveScreeningEx2Response' => 'factiva_PerformExecutiveScreeningEx2Response',
				'PerformExecutiveSearch' => 'factiva_PerformExecutiveSearch',
				'PerformExecutiveSearchResponse' => 'factiva_PerformExecutiveSearchResponse',
				'PerformExecutiveSearchEx' => 'factiva_PerformExecutiveSearchEx',
				'PerformExecutiveSearchExResponse' => 'factiva_PerformExecutiveSearchExResponse',
				'PerformExecutiveSearchEx2' => 'factiva_PerformExecutiveSearchEx2',
				'PerformExecutiveSearchEx2Response' => 'factiva_PerformExecutiveSearchEx2Response',
				'PerformExecutiveSearchEx3' => 'factiva_PerformExecutiveSearchEx3',
				'PerformExecutiveSearchEx3Response' => 'factiva_PerformExecutiveSearchEx3Response',
				'ContinueExecutiveSearch' => 'factiva_ContinueExecutiveSearch',
				'ContinueExecutiveSearchResponse' => 'factiva_ContinueExecutiveSearchResponse',
				'ContinueExecutiveSearchEx' => 'factiva_ContinueExecutiveSearchEx',
				'ContinueExecutiveSearchExResponse' => 'factiva_ContinueExecutiveSearchExResponse',
				'SortExecutiveProfiles' => 'factiva_SortExecutiveProfiles',
				'SortExecutiveProfilesResponse' => 'factiva_SortExecutiveProfilesResponse',
				'GetExecutiveProfiles' => 'factiva_GetExecutiveProfiles',
				'GetExecutiveProfilesResponse' => 'factiva_GetExecutiveProfilesResponse',
				'GetExecutiveProfilesEx' => 'factiva_GetExecutiveProfilesEx',
				'GetExecutiveProfilesExResponse' => 'factiva_GetExecutiveProfilesExResponse',
				'GetExecutiveDetails' => 'factiva_GetExecutiveDetails',
				'GetExecutiveDetailsResponse' => 'factiva_GetExecutiveDetailsResponse',
				'GetExecutiveDetailsEx' => 'factiva_GetExecutiveDetailsEx',
				'GetExecutiveDetailsExResponse' => 'factiva_GetExecutiveDetailsExResponse',
				'PerformExecutiveNewsBriefsSearch' => 'factiva_PerformExecutiveNewsBriefsSearch',
				'PerformExecutiveNewsBriefsSearchResponse' => 'factiva_PerformExecutiveNewsBriefsSearchResponse',
				'PerformExecutiveNewsBriefsSearchEx' => 'factiva_PerformExecutiveNewsBriefsSearchEx',
				'PerformExecutiveNewsBriefsSearchExResponse' => 'factiva_PerformExecutiveNewsBriefsSearchExResponse',
				'ContinueExecutiveNewsBriefsSearch' => 'factiva_ContinueExecutiveNewsBriefsSearch',
				'ContinueExecutiveNewsBriefsSearchResponse' => 'factiva_ContinueExecutiveNewsBriefsSearchResponse',
				'GetDNBCompanyProfile' => 'factiva_GetDNBCompanyProfile',
				'GetDNBCompanyProfileResponse' => 'factiva_GetDNBCompanyProfileResponse',
				'GetDNBCompanyChildren' => 'factiva_GetDNBCompanyChildren',
				'GetDNBCompanyChildrenResponse' => 'factiva_GetDNBCompanyChildrenResponse',
				'GetDNBCompanyBranchLocations' => 'factiva_GetDNBCompanyBranchLocations',
				'GetDNBCompanyBranchLocationsResponse' => 'factiva_GetDNBCompanyBranchLocationsResponse',
				'GetDNBCompanyGlobalUltimate' => 'factiva_GetDNBCompanyGlobalUltimate',
				'GetDNBCompanyGlobalUltimateResponse' => 'factiva_GetDNBCompanyGlobalUltimateResponse',
				'GetDNBCompanyTree' => 'factiva_GetDNBCompanyTree',
				'GetDNBCompanyTreeResponse' => 'factiva_GetDNBCompanyTreeResponse',
				'GetUSGovernmentOrganizations' => 'factiva_GetUSGovernmentOrganizations',
				'GetUSGovernmentOrganizationsResponse' => 'factiva_GetUSGovernmentOrganizationsResponse',
				'GetUSGovernmentOrganizationSnapshot' => 'factiva_GetUSGovernmentOrganizationSnapshot',
				'GetUSGovernmentOrganizationSnapshotResponse' => 'factiva_GetUSGovernmentOrganizationSnapshotResponse',
				'PerformUSGovernmentExecutiveSearch' => 'factiva_PerformUSGovernmentExecutiveSearch',
				'PerformUSGovernmentExecutiveSearchResponse' => 'factiva_PerformUSGovernmentExecutiveSearchResponse',
				'GetUSGovernmentExecutiveSnapshot' => 'factiva_GetUSGovernmentExecutiveSnapshot',
				'GetUSGovernmentExecutiveSnapshotResponse' => 'factiva_GetUSGovernmentExecutiveSnapshotResponse',
				'GetQuote' => 'factiva_GetQuote',
				'GetQuoteResponse' => 'factiva_GetQuoteResponse',
				'PerformLogin' => 'factiva_PerformLogin',
				'PerformLoginResponse' => 'factiva_PerformLoginResponse',
				'PerformEncryptedIDLogin' => 'factiva_PerformEncryptedIDLogin',
				'PerformEncryptedIDLoginResponse' => 'factiva_PerformEncryptedIDLoginResponse',
				'PerformEmailAddressLogin' => 'factiva_PerformEmailAddressLogin',
				'PerformEmailAddressLoginResponse' => 'factiva_PerformEmailAddressLoginResponse',
				'PerformLogout' => 'factiva_PerformLogout',
				'PerformLogoutResponse' => 'factiva_PerformLogoutResponse',
				'GetEncryptedID' => 'factiva_GetEncryptedID',
				'GetEncryptedIDResponse' => 'factiva_GetEncryptedIDResponse',
				'GetAccountInfo' => 'factiva_GetAccountInfo',
				'GetAccountInfoResponse' => 'factiva_GetAccountInfoResponse',
				'GetClientCode' => 'factiva_GetClientCode',
				'GetClientCodeResponse' => 'factiva_GetClientCodeResponse',
				'SetClientCode' => 'factiva_SetClientCode',
				'SetClientCodeResponse' => 'factiva_SetClientCodeResponse',
				'GetNewsstandSources' => 'factiva_GetNewsstandSources',
				'GetNewsstandSourcesResponse' => 'factiva_GetNewsstandSourcesResponse',
				'GetNewsstandSections' => 'factiva_GetNewsstandSections',
				'GetNewsstandSectionsResponse' => 'factiva_GetNewsstandSectionsResponse',
				'GetNewsstandHeadlines' => 'factiva_GetNewsstandHeadlines',
				'GetNewsstandHeadlinesResponse' => 'factiva_GetNewsstandHeadlinesResponse',
				'GetUserData' => 'factiva_GetUserData',
				'GetUserDataResponse' => 'factiva_GetUserDataResponse',
				'GetUserDataEx' => 'factiva_GetUserDataEx',
				'GetUserDataExResponse' => 'factiva_GetUserDataExResponse',
				'PerformUserRegistration' => 'factiva_PerformUserRegistration',
				'PerformUserRegistrationResponse' => 'factiva_PerformUserRegistrationResponse',
				'PerformUserRegistrationEx' => 'factiva_PerformUserRegistrationEx',
				'PerformUserRegistrationExResponse' => 'factiva_PerformUserRegistrationExResponse',
				'UpdateUserData' => 'factiva_UpdateUserData',
				'UpdateUserDataResponse' => 'factiva_UpdateUserDataResponse',
				'UpdateUserDataEx' => 'factiva_UpdateUserDataEx',
				'UpdateUserDataExResponse' => 'factiva_UpdateUserDataExResponse',
				'UpdateUserPassword' => 'factiva_UpdateUserPassword',
				'UpdateUserPasswordResponse' => 'factiva_UpdateUserPasswordResponse',
				'ResetUserPassword' => 'factiva_ResetUserPassword',
				'ResetUserPasswordResponse' => 'factiva_ResetUserPasswordResponse',
				'PerformSimplifiedEmailAddressRegistration' => 'factiva_PerformSimplifiedEmailAddressRegistration',
				'PerformSimplifiedEmailAddressRegistrationResponse' => 'factiva_PerformSimplifiedEmailAddressRegistrationResponse',
				'UpdateLoginEmailAddress' => 'factiva_UpdateLoginEmailAddress',
				'UpdateLoginEmailAddressResponse' => 'factiva_UpdateLoginEmailAddressResponse',
				'EnableEmailAddressForLogin' => 'factiva_EnableEmailAddressForLogin',
				'EnableEmailAddressForLoginResponse' => 'factiva_EnableEmailAddressForLoginResponse',
				'SetupUserForEmailAddressLogin' => 'factiva_SetupUserForEmailAddressLogin',
				'SetupUserForEmailAddressLoginResponse' => 'factiva_SetupUserForEmailAddressLoginResponse',
				'PerformEmailAddressRegistration' => 'factiva_PerformEmailAddressRegistration',
				'PerformEmailAddressRegistrationResponse' => 'factiva_PerformEmailAddressRegistrationResponse',
				'PerformEmailAddressRegistrationEx' => 'factiva_PerformEmailAddressRegistrationEx',
				'PerformEmailAddressRegistrationExResponse' => 'factiva_PerformEmailAddressRegistrationExResponse',
				'GetArticle' => 'factiva_GetArticle',
				'GetArticleResponse' => 'factiva_GetArticleResponse',
				'GetHTML' => 'factiva_GetHTML',
				'GetHTMLResponse' => 'factiva_GetHTMLResponse',
				'GetPicture' => 'factiva_GetPicture',
				'GetPictureResponse' => 'factiva_GetPictureResponse',
				'GetPDF' => 'factiva_GetPDF',
				'GetPDFResponse' => 'factiva_GetPDFResponse',
				'GetExternalURL' => 'factiva_GetExternalURL',
				'GetExternalURLResponse' => 'factiva_GetExternalURLResponse',
				'GetContent' => 'factiva_GetContent',
				'GetContentResponse' => 'factiva_GetContentResponse',
				'PerformContentSearch' => 'factiva_PerformContentSearch',
				'PerformContentSearchResponse' => 'factiva_PerformContentSearchResponse',
				'ContinueContentSearch' => 'factiva_ContinueContentSearch',
				'ContinueContentSearchResponse' => 'factiva_ContinueContentSearchResponse',
				'PerformContentSearchWithFDT' => 'factiva_PerformContentSearchWithFDT',
				'PerformContentSearchWithFDTResponse' => 'factiva_PerformContentSearchWithFDTResponse',
				'PerformContentSearchWithFDTEx' => 'factiva_PerformContentSearchWithFDTEx',
				'PerformContentSearchWithFDTExResponse' => 'factiva_PerformContentSearchWithFDTExResponse',
				'GetMaxNavigatorElements' => 'factiva_GetMaxNavigatorElements',
				'GetMaxNavigatorElementsResponse' => 'factiva_GetMaxNavigatorElementsResponse',
				'ContinueContentSearchWithFDT' => 'factiva_ContinueContentSearchWithFDT',
				'ContinueContentSearchWithFDTResponse' => 'factiva_ContinueContentSearchWithFDTResponse',
				'PerformSourceSearch' => 'factiva_PerformSourceSearch',
				'PerformSourceSearchResponse' => 'factiva_PerformSourceSearchResponse',
				'ContinueSourceSearch' => 'factiva_ContinueSourceSearch',
				'ContinueSourceSearchResponse' => 'factiva_ContinueSourceSearchResponse',
				'PerformSourceGroupSearch' => 'factiva_PerformSourceGroupSearch',
				'PerformSourceGroupSearchResponse' => 'factiva_PerformSourceGroupSearchResponse',
				'ContinueSourceGroupSearch' => 'factiva_ContinueSourceGroupSearch',
				'ContinueSourceGroupSearchResponse' => 'factiva_ContinueSourceGroupSearchResponse',
				'GetSourcesByCategory' => 'factiva_GetSourcesByCategory',
				'GetSourcesByCategoryResponse' => 'factiva_GetSourcesByCategoryResponse',
				'GetSourcesByTitle' => 'factiva_GetSourcesByTitle',
				'GetSourcesByTitleResponse' => 'factiva_GetSourcesByTitleResponse',
				'GetSourcesByCode' => 'factiva_GetSourcesByCode',
				'GetSourcesByCodeResponse' => 'factiva_GetSourcesByCodeResponse',
				'GetSourceGroupsByCode' => 'factiva_GetSourceGroupsByCode',
				'GetSourceGroupsByCodeResponse' => 'factiva_GetSourceGroupsByCodeResponse',
				'PerformCompanySearch' => 'factiva_PerformCompanySearch',
				'PerformCompanySearchResponse' => 'factiva_PerformCompanySearchResponse',
				'PerformCompanySearchEx' => 'factiva_PerformCompanySearchEx',
				'PerformCompanySearchExResponse' => 'factiva_PerformCompanySearchExResponse',
				'PerformCompanySearchEx2' => 'factiva_PerformCompanySearchEx2',
				'PerformCompanySearchEx2Response' => 'factiva_PerformCompanySearchEx2Response',
				'ContinueCompanySearch' => 'factiva_ContinueCompanySearch',
				'ContinueCompanySearchResponse' => 'factiva_ContinueCompanySearchResponse',
				'ContinueCompanySearchEx' => 'factiva_ContinueCompanySearchEx',
				'ContinueCompanySearchExResponse' => 'factiva_ContinueCompanySearchExResponse',
				'ContinueCompanySearchEx2' => 'factiva_ContinueCompanySearchEx2',
				'ContinueCompanySearchEx2Response' => 'factiva_ContinueCompanySearchEx2Response',
				'GetCompanyByCode' => 'factiva_GetCompanyByCode',
				'GetCompanyByCodeResponse' => 'factiva_GetCompanyByCodeResponse',
				'GetCompanyByCodeEx' => 'factiva_GetCompanyByCodeEx',
				'GetCompanyByCodeExResponse' => 'factiva_GetCompanyByCodeExResponse',
				'GetCompanyByCodeEx2' => 'factiva_GetCompanyByCodeEx2',
				'GetCompanyByCodeEx2Response' => 'factiva_GetCompanyByCodeEx2Response',
				'PerformInstrumentSearch' => 'factiva_PerformInstrumentSearch',
				'PerformInstrumentSearchResponse' => 'factiva_PerformInstrumentSearchResponse',
				'ContinueInstrumentSearch' => 'factiva_ContinueInstrumentSearch',
				'ContinueInstrumentSearchResponse' => 'factiva_ContinueInstrumentSearchResponse',
				'GetInstrumentByCode' => 'factiva_GetInstrumentByCode',
				'GetInstrumentByCodeResponse' => 'factiva_GetInstrumentByCodeResponse',
				'PerformExchangeSearch' => 'factiva_PerformExchangeSearch',
				'PerformExchangeSearchResponse' => 'factiva_PerformExchangeSearchResponse',
				'GetExchangeByCode' => 'factiva_GetExchangeByCode',
				'GetExchangeByCodeResponse' => 'factiva_GetExchangeByCodeResponse',
				'GetExchangeList' => 'factiva_GetExchangeList',
				'GetExchangeListResponse' => 'factiva_GetExchangeListResponse',
				'PerformIndustrySearch' => 'factiva_PerformIndustrySearch',
				'PerformIndustrySearchResponse' => 'factiva_PerformIndustrySearchResponse',
				'GetIndustryByCode' => 'factiva_GetIndustryByCode',
				'GetIndustryByCodeResponse' => 'factiva_GetIndustryByCodeResponse',
				'GetIndustryChildren' => 'factiva_GetIndustryChildren',
				'GetIndustryChildrenResponse' => 'factiva_GetIndustryChildrenResponse',
				'GetIndustryList' => 'factiva_GetIndustryList',
				'GetIndustryListResponse' => 'factiva_GetIndustryListResponse',
				'PerformRegionSearch' => 'factiva_PerformRegionSearch',
				'PerformRegionSearchResponse' => 'factiva_PerformRegionSearchResponse',
				'GetRegionByCode' => 'factiva_GetRegionByCode',
				'GetRegionByCodeResponse' => 'factiva_GetRegionByCodeResponse',
				'GetRegionChildren' => 'factiva_GetRegionChildren',
				'GetRegionChildrenResponse' => 'factiva_GetRegionChildrenResponse',
				'GetRegionList' => 'factiva_GetRegionList',
				'GetRegionListResponse' => 'factiva_GetRegionListResponse',
				'PerformNewsSubjectSearch' => 'factiva_PerformNewsSubjectSearch',
				'PerformNewsSubjectSearchResponse' => 'factiva_PerformNewsSubjectSearchResponse',
				'GetNewsSubjectByCode' => 'factiva_GetNewsSubjectByCode',
				'GetNewsSubjectByCodeResponse' => 'factiva_GetNewsSubjectByCodeResponse',
				'GetNewsSubjectChildren' => 'factiva_GetNewsSubjectChildren',
				'GetNewsSubjectChildrenResponse' => 'factiva_GetNewsSubjectChildrenResponse',
				'GetNewsSubjectList' => 'factiva_GetNewsSubjectList',
				'GetNewsSubjectListResponse' => 'factiva_GetNewsSubjectListResponse',
				'GetJobFunctionList' => 'factiva_GetJobFunctionList',
				'GetJobFunctionListResponse' => 'factiva_GetJobFunctionListResponse',
				'GetAuditorList' => 'factiva_GetAuditorList',
				'GetAuditorListResponse' => 'factiva_GetAuditorListResponse',
				'GetDegreeList' => 'factiva_GetDegreeList',
				'GetDegreeListResponse' => 'factiva_GetDegreeListResponse',
				'GetDepartmentList' => 'factiva_GetDepartmentList',
				'GetDepartmentListResponse' => 'factiva_GetDepartmentListResponse',
				'GetCurrencyList' => 'factiva_GetCurrencyList',
				'GetCurrencyListResponse' => 'factiva_GetCurrencyListResponse',
				'GetCurrencyByCode' => 'factiva_GetCurrencyByCode',
				'GetCurrencyByCodeResponse' => 'factiva_GetCurrencyByCodeResponse',
				'GetIndexList' => 'factiva_GetIndexList',
				'GetIndexListResponse' => 'factiva_GetIndexListResponse',
				'GetListInfo' => 'factiva_GetListInfo',
				'GetListInfoResponse' => 'factiva_GetListInfoResponse',
				'GetFolderInfo' => 'factiva_GetFolderInfo',
				'GetFolderInfoResponse' => 'factiva_GetFolderInfoResponse',
				'GetFolderInfoByID' => 'factiva_GetFolderInfoByID',
				'GetFolderInfoByIDResponse' => 'factiva_GetFolderInfoByIDResponse',
				'GetFolderHeadlines' => 'factiva_GetFolderHeadlines',
				'GetFolderHeadlinesResponse' => 'factiva_GetFolderHeadlinesResponse',
				'GetFolderHeadlinesEx' => 'factiva_GetFolderHeadlinesEx',
				'GetFolderHeadlinesExResponse' => 'factiva_GetFolderHeadlinesExResponse',
				'GetNewFolderHeadlines' => 'factiva_GetNewFolderHeadlines',
				'GetNewFolderHeadlinesResponse' => 'factiva_GetNewFolderHeadlinesResponse',
				'CreateFolder' => 'factiva_CreateFolder',
				'CreateFolderResponse' => 'factiva_CreateFolderResponse',
				'ReviseFolder' => 'factiva_ReviseFolder',
				'ReviseFolderResponse' => 'factiva_ReviseFolderResponse',
				'DeleteFolder' => 'factiva_DeleteFolder',
				'DeleteFolderResponse' => 'factiva_DeleteFolderResponse',
				'GetFolder' => 'factiva_GetFolder',
				'GetFolderResponse' => 'factiva_GetFolderResponse',
				'PostContent' => 'factiva_PostContent',
				'PostContentResponse' => 'factiva_PostContentResponse',
				'UnpostContent' => 'factiva_UnpostContent',
				'UnpostContentResponse' => 'factiva_UnpostContentResponse',
				'DeleteContent' => 'factiva_DeleteContent',
				'DeleteContentResponse' => 'factiva_DeleteContentResponse',
				'AddEditorComment' => 'factiva_AddEditorComment',
				'AddEditorCommentResponse' => 'factiva_AddEditorCommentResponse',
				'ReviseEditorComment' => 'factiva_ReviseEditorComment',
				'ReviseEditorCommentResponse' => 'factiva_ReviseEditorCommentResponse',
				'GetEditorComment' => 'factiva_GetEditorComment',
				'GetEditorCommentResponse' => 'factiva_GetEditorCommentResponse',
				'DeleteEditorComment' => 'factiva_DeleteEditorComment',
				'DeleteEditorCommentResponse' => 'factiva_DeleteEditorCommentResponse',
				'AddInternalContent' => 'factiva_AddInternalContent',
				'AddInternalContentResponse' => 'factiva_AddInternalContentResponse',
				'ReviseInternalContent' => 'factiva_ReviseInternalContent',
				'ReviseInternalContentResponse' => 'factiva_ReviseInternalContentResponse',
				'GetInternalContent' => 'factiva_GetInternalContent',
				'GetInternalContentResponse' => 'factiva_GetInternalContentResponse',
				'DeleteInternalContent' => 'factiva_DeleteInternalContent',
				'DeleteInternalContentResponse' => 'factiva_DeleteInternalContentResponse',

			);

			parent::__construct( factivaClient::wsdl_path, $soap_options );

			if( array_key_exists( "ssl", $this->config ) && array_key_exists( "certificate", $this->config["ssl"] )) {
				if( "" != $this->config["ssl"]["certificate"] ) {
					$this->_local_cert = $this->config["ssl"]["certificate"];
				}
			}
		}
		/**
		 * @param PerformCompanyScreening $parameters
		 * @return PerformCompanyScreeningResponse
		**/
		public function PerformCompanyScreening ( $parameters ){
			return parent::PerformCompanyScreening( $parameters );
		}

		/**
		 * @param PerformCompanyScreeningEx $parameters
		 * @return PerformCompanyScreeningExResponse
		**/
		public function PerformCompanyScreeningEx ( $parameters ){
			return parent::PerformCompanyScreeningEx( $parameters );
		}

		/**
		 * @param SortCompanyProfiles $parameters
		 * @return SortCompanyProfilesResponse
		**/
		public function SortCompanyProfiles ( $parameters ){
			return parent::SortCompanyProfiles( $parameters );
		}

		/**
		 * @param SortCompanyProfilesEx $parameters
		 * @return SortCompanyProfilesExResponse
		**/
		public function SortCompanyProfilesEx ( $parameters ){
			return parent::SortCompanyProfilesEx( $parameters );
		}

		/**
		 * @param GetCompanyProfiles $parameters
		 * @return GetCompanyProfilesResponse
		**/
		public function GetCompanyProfiles ( $parameters ){
			return parent::GetCompanyProfiles( $parameters );
		}

		/**
		 * @param GetCompanyProfilesEx $parameters
		 * @return GetCompanyProfilesExResponse
		**/
		public function GetCompanyProfilesEx ( $parameters ){
			return parent::GetCompanyProfilesEx( $parameters );
		}

		/**
		 * @param PerformCompanyComparison $parameters
		 * @return PerformCompanyComparisonResponse
		**/
		public function PerformCompanyComparison ( $parameters ){
			return parent::PerformCompanyComparison( $parameters );
		}

		/**
		 * @param PerformCompanyPeerComparison $parameters
		 * @return PerformCompanyPeerComparisonResponse
		**/
		public function PerformCompanyPeerComparison ( $parameters ){
			return parent::PerformCompanyPeerComparison( $parameters );
		}

		/**
		 * @param PerformCompanyPeerComparisonEx $parameters
		 * @return PerformCompanyPeerComparisonExResponse
		**/
		public function PerformCompanyPeerComparisonEx ( $parameters ){
			return parent::PerformCompanyPeerComparisonEx( $parameters );
		}

		/**
		 * @param GetCompanyDetailsList $parameters
		 * @return GetCompanyDetailsListResponse
		**/
		public function GetCompanyDetailsList ( $parameters ){
			return parent::GetCompanyDetailsList( $parameters );
		}

		/**
		 * @param GetCompanyDetailsListEx $parameters
		 * @return GetCompanyDetailsListExResponse
		**/
		public function GetCompanyDetailsListEx ( $parameters ){
			return parent::GetCompanyDetailsListEx( $parameters );
		}

		/**
		 * @param GetCompanyDetailsListEx2 $parameters
		 * @return GetCompanyDetailsListEx2Response
		**/
		public function GetCompanyDetailsListEx2 ( $parameters ){
			return parent::GetCompanyDetailsListEx2( $parameters );
		}

		/**
		 * @param GetCompanyDetailsListEx3 $parameters
		 * @return GetCompanyDetailsListEx3Response
		**/
		public function GetCompanyDetailsListEx3 ( $parameters ){
			return parent::GetCompanyDetailsListEx3( $parameters );
		}

		/**
		 * @param GetCompanyDetailsListEx4 $parameters
		 * @return GetCompanyDetailsListEx4Response
		**/
		public function GetCompanyDetailsListEx4 ( $parameters ){
			return parent::GetCompanyDetailsListEx4( $parameters );
		}

		/**
		 * @param GetCompanyDetails $parameters
		 * @return GetCompanyDetailsResponse
		**/
		public function GetCompanyDetails ( $parameters ){
			return parent::GetCompanyDetails( $parameters );
		}

		/**
		 * @param GetCompanyDetailsEx $parameters
		 * @return GetCompanyDetailsExResponse
		**/
		public function GetCompanyDetailsEx ( $parameters ){
			return parent::GetCompanyDetailsEx( $parameters );
		}

		/**
		 * @param GetIndustryAverages $parameters
		 * @return GetIndustryAveragesResponse
		**/
		public function GetIndustryAverages ( $parameters ){
			return parent::GetIndustryAverages( $parameters );
		}

		/**
		 * @param PerformCompanyNewsBriefsSearch $parameters
		 * @return PerformCompanyNewsBriefsSearchResponse
		**/
		public function PerformCompanyNewsBriefsSearch ( $parameters ){
			return parent::PerformCompanyNewsBriefsSearch( $parameters );
		}

		/**
		 * @param PerformCompanyNewsBriefsSearchEx $parameters
		 * @return PerformCompanyNewsBriefsSearchExResponse
		**/
		public function PerformCompanyNewsBriefsSearchEx ( $parameters ){
			return parent::PerformCompanyNewsBriefsSearchEx( $parameters );
		}

		/**
		 * @param ContinueCompanyNewsBriefsSearch $parameters
		 * @return ContinueCompanyNewsBriefsSearchResponse
		**/
		public function ContinueCompanyNewsBriefsSearch ( $parameters ){
			return parent::ContinueCompanyNewsBriefsSearch( $parameters );
		}

		/**
		 * @param PerformIndustryNewsBriefsSearch $parameters
		 * @return PerformIndustryNewsBriefsSearchResponse
		**/
		public function PerformIndustryNewsBriefsSearch ( $parameters ){
			return parent::PerformIndustryNewsBriefsSearch( $parameters );
		}

		/**
		 * @param PerformIndustryNewsBriefsSearchEx $parameters
		 * @return PerformIndustryNewsBriefsSearchExResponse
		**/
		public function PerformIndustryNewsBriefsSearchEx ( $parameters ){
			return parent::PerformIndustryNewsBriefsSearchEx( $parameters );
		}

		/**
		 * @param ContinueIndustryNewsBriefsSearch $parameters
		 * @return ContinueIndustryNewsBriefsSearchResponse
		**/
		public function ContinueIndustryNewsBriefsSearch ( $parameters ){
			return parent::ContinueIndustryNewsBriefsSearch( $parameters );
		}

		/**
		 * @param PerformPublishedCompanyReportsSearch $parameters
		 * @return PerformPublishedCompanyReportsSearchResponse
		**/
		public function PerformPublishedCompanyReportsSearch ( $parameters ){
			return parent::PerformPublishedCompanyReportsSearch( $parameters );
		}

		/**
		 * @param PerformPublishedIndustryReportsSearch $parameters
		 * @return PerformPublishedIndustryReportsSearchResponse
		**/
		public function PerformPublishedIndustryReportsSearch ( $parameters ){
			return parent::PerformPublishedIndustryReportsSearch( $parameters );
		}

		/**
		 * @param PerformCompanyKeyDevelopmentsSearch $parameters
		 * @return PerformCompanyKeyDevelopmentsSearchResponse
		**/
		public function PerformCompanyKeyDevelopmentsSearch ( $parameters ){
			return parent::PerformCompanyKeyDevelopmentsSearch( $parameters );
		}

		/**
		 * @param PerformCompanyKeyDevelopmentsSearchEx $parameters
		 * @return PerformCompanyKeyDevelopmentsSearchExResponse
		**/
		public function PerformCompanyKeyDevelopmentsSearchEx ( $parameters ){
			return parent::PerformCompanyKeyDevelopmentsSearchEx( $parameters );
		}

		/**
		 * @param GetCompanyReport $parameters
		 * @return GetCompanyReportResponse
		**/
		public function GetCompanyReport ( $parameters ){
			return parent::GetCompanyReport( $parameters );
		}

		/**
		 * @param GetCompanyReportEx $parameters
		 * @return GetCompanyReportExResponse
		**/
		public function GetCompanyReportEx ( $parameters ){
			return parent::GetCompanyReportEx( $parameters );
		}

		/**
		 * @param GetCompanyReportEx2 $parameters
		 * @return GetCompanyReportEx2Response
		**/
		public function GetCompanyReportEx2 ( $parameters ){
			return parent::GetCompanyReportEx2( $parameters );
		}

		/**
		 * @param GetCompanyReportWithFinancialStatements $parameters
		 * @return GetCompanyReportWithFinancialStatementsResponse
		**/
		public function GetCompanyReportWithFinancialStatements ( $parameters ){
			return parent::GetCompanyReportWithFinancialStatements( $parameters );
		}

		/**
		 * @param GetCompanyReportWithFinancialStatementsEx $parameters
		 * @return GetCompanyReportWithFinancialStatementsExResponse
		**/
		public function GetCompanyReportWithFinancialStatementsEx ( $parameters ){
			return parent::GetCompanyReportWithFinancialStatementsEx( $parameters );
		}

		/**
		 * @param GetCompanyReportWithFinancialStatementsEx2 $parameters
		 * @return GetCompanyReportWithFinancialStatementsEx2Response
		**/
		public function GetCompanyReportWithFinancialStatementsEx2 ( $parameters ){
			return parent::GetCompanyReportWithFinancialStatementsEx2( $parameters );
		}

		/**
		 * @param GetRatioComparisonReport $parameters
		 * @return GetRatioComparisonReportResponse
		**/
		public function GetRatioComparisonReport ( $parameters ){
			return parent::GetRatioComparisonReport( $parameters );
		}

		/**
		 * @param GetRatioComparisonReportEx $parameters
		 * @return GetRatioComparisonReportExResponse
		**/
		public function GetRatioComparisonReportEx ( $parameters ){
			return parent::GetRatioComparisonReportEx( $parameters );
		}

		/**
		 * @param GetRatioComparisonReportEx2 $parameters
		 * @return GetRatioComparisonReportEx2Response
		**/
		public function GetRatioComparisonReportEx2 ( $parameters ){
			return parent::GetRatioComparisonReportEx2( $parameters );
		}

		/**
		 * @param PerformCompanySnapshot $parameters
		 * @return PerformCompanySnapshotResponse
		**/
		public function PerformCompanySnapshot ( $parameters ){
			return parent::PerformCompanySnapshot( $parameters );
		}

		/**
		 * @param PerformCompanySnapshotEx $parameters
		 * @return PerformCompanySnapshotExResponse
		**/
		public function PerformCompanySnapshotEx ( $parameters ){
			return parent::PerformCompanySnapshotEx( $parameters );
		}

		/**
		 * @param PerformIndustrySnapshot $parameters
		 * @return PerformIndustrySnapshotResponse
		**/
		public function PerformIndustrySnapshot ( $parameters ){
			return parent::PerformIndustrySnapshot( $parameters );
		}

		/**
		 * @param PerformExecutiveScreening $parameters
		 * @return PerformExecutiveScreeningResponse
		**/
		public function PerformExecutiveScreening ( $parameters ){
			return parent::PerformExecutiveScreening( $parameters );
		}

		/**
		 * @param PerformExecutiveScreeningEx $parameters
		 * @return PerformExecutiveScreeningExResponse
		**/
		public function PerformExecutiveScreeningEx ( $parameters ){
			return parent::PerformExecutiveScreeningEx( $parameters );
		}

		/**
		 * @param PerformExecutiveScreeningEx2 $parameters
		 * @return PerformExecutiveScreeningEx2Response
		**/
		public function PerformExecutiveScreeningEx2 ( $parameters ){
			return parent::PerformExecutiveScreeningEx2( $parameters );
		}

		/**
		 * @param PerformExecutiveSearch $parameters
		 * @return PerformExecutiveSearchResponse
		**/
		public function PerformExecutiveSearch ( $parameters ){
			return parent::PerformExecutiveSearch( $parameters );
		}

		/**
		 * @param PerformExecutiveSearchEx $parameters
		 * @return PerformExecutiveSearchExResponse
		**/
		public function PerformExecutiveSearchEx ( $parameters ){
			return parent::PerformExecutiveSearchEx( $parameters );
		}

		/**
		 * @param PerformExecutiveSearchEx2 $parameters
		 * @return PerformExecutiveSearchEx2Response
		**/
		public function PerformExecutiveSearchEx2 ( $parameters ){
			return parent::PerformExecutiveSearchEx2( $parameters );
		}

		/**
		 * @param PerformExecutiveSearchEx3 $parameters
		 * @return PerformExecutiveSearchEx3Response
		**/
		public function PerformExecutiveSearchEx3 ( $parameters ){
			return parent::PerformExecutiveSearchEx3( $parameters );
		}

		/**
		 * @param ContinueExecutiveSearch $parameters
		 * @return ContinueExecutiveSearchResponse
		**/
		public function ContinueExecutiveSearch ( $parameters ){
			return parent::ContinueExecutiveSearch( $parameters );
		}

		/**
		 * @param ContinueExecutiveSearchEx $parameters
		 * @return ContinueExecutiveSearchExResponse
		**/
		public function ContinueExecutiveSearchEx ( $parameters ){
			return parent::ContinueExecutiveSearchEx( $parameters );
		}

		/**
		 * @param SortExecutiveProfiles $parameters
		 * @return SortExecutiveProfilesResponse
		**/
		public function SortExecutiveProfiles ( $parameters ){
			return parent::SortExecutiveProfiles( $parameters );
		}

		/**
		 * @param GetExecutiveProfiles $parameters
		 * @return GetExecutiveProfilesResponse
		**/
		public function GetExecutiveProfiles ( $parameters ){
			return parent::GetExecutiveProfiles( $parameters );
		}

		/**
		 * @param GetExecutiveProfilesEx $parameters
		 * @return GetExecutiveProfilesExResponse
		**/
		public function GetExecutiveProfilesEx ( $parameters ){
			return parent::GetExecutiveProfilesEx( $parameters );
		}

		/**
		 * @param GetExecutiveDetails $parameters
		 * @return GetExecutiveDetailsResponse
		**/
		public function GetExecutiveDetails ( $parameters ){
			return parent::GetExecutiveDetails( $parameters );
		}

		/**
		 * @param GetExecutiveDetailsEx $parameters
		 * @return GetExecutiveDetailsExResponse
		**/
		public function GetExecutiveDetailsEx ( $parameters ){
			return parent::GetExecutiveDetailsEx( $parameters );
		}

		/**
		 * @param PerformExecutiveNewsBriefsSearch $parameters
		 * @return PerformExecutiveNewsBriefsSearchResponse
		**/
		public function PerformExecutiveNewsBriefsSearch ( $parameters ){
			return parent::PerformExecutiveNewsBriefsSearch( $parameters );
		}

		/**
		 * @param PerformExecutiveNewsBriefsSearchEx $parameters
		 * @return PerformExecutiveNewsBriefsSearchExResponse
		**/
		public function PerformExecutiveNewsBriefsSearchEx ( $parameters ){
			return parent::PerformExecutiveNewsBriefsSearchEx( $parameters );
		}

		/**
		 * @param ContinueExecutiveNewsBriefsSearch $parameters
		 * @return ContinueExecutiveNewsBriefsSearchResponse
		**/
		public function ContinueExecutiveNewsBriefsSearch ( $parameters ){
			return parent::ContinueExecutiveNewsBriefsSearch( $parameters );
		}

		/**
		 * @param GetDNBCompanyProfile $parameters
		 * @return GetDNBCompanyProfileResponse
		**/
		public function GetDNBCompanyProfile ( $parameters ){
			return parent::GetDNBCompanyProfile( $parameters );
		}

		/**
		 * @param GetDNBCompanyChildren $parameters
		 * @return GetDNBCompanyChildrenResponse
		**/
		public function GetDNBCompanyChildren ( $parameters ){
			return parent::GetDNBCompanyChildren( $parameters );
		}

		/**
		 * @param GetDNBCompanyBranchLocations $parameters
		 * @return GetDNBCompanyBranchLocationsResponse
		**/
		public function GetDNBCompanyBranchLocations ( $parameters ){
			return parent::GetDNBCompanyBranchLocations( $parameters );
		}

		/**
		 * @param GetDNBCompanyGlobalUltimate $parameters
		 * @return GetDNBCompanyGlobalUltimateResponse
		**/
		public function GetDNBCompanyGlobalUltimate ( $parameters ){
			return parent::GetDNBCompanyGlobalUltimate( $parameters );
		}

		/**
		 * @param GetDNBCompanyTree $parameters
		 * @return GetDNBCompanyTreeResponse
		**/
		public function GetDNBCompanyTree ( $parameters ){
			return parent::GetDNBCompanyTree( $parameters );
		}

		/**
		 * @param GetUSGovernmentOrganizations $parameters
		 * @return GetUSGovernmentOrganizationsResponse
		**/
		public function GetUSGovernmentOrganizations ( $parameters ){
			return parent::GetUSGovernmentOrganizations( $parameters );
		}

		/**
		 * @param GetUSGovernmentOrganizationSnapshot $parameters
		 * @return GetUSGovernmentOrganizationSnapshotResponse
		**/
		public function GetUSGovernmentOrganizationSnapshot ( $parameters ){
			return parent::GetUSGovernmentOrganizationSnapshot( $parameters );
		}

		/**
		 * @param PerformUSGovernmentExecutiveSearch $parameters
		 * @return PerformUSGovernmentExecutiveSearchResponse
		**/
		public function PerformUSGovernmentExecutiveSearch ( $parameters ){
			return parent::PerformUSGovernmentExecutiveSearch( $parameters );
		}

		/**
		 * @param GetUSGovernmentExecutiveSnapshot $parameters
		 * @return GetUSGovernmentExecutiveSnapshotResponse
		**/
		public function GetUSGovernmentExecutiveSnapshot ( $parameters ){
			return parent::GetUSGovernmentExecutiveSnapshot( $parameters );
		}

		/**
		 * @param GetQuote $parameters
		 * @return GetQuoteResponse
		**/
		public function GetQuote ( $parameters ){
			return parent::GetQuote( $parameters );
		}

		/**
		 * @param PerformLogin $parameters
		 * @return PerformLoginResponse
		**/
		public function PerformLogin ( $parameters ){
			return parent::PerformLogin( $parameters );
		}

		/**
		 * @param PerformEncryptedIDLogin $parameters
		 * @return PerformEncryptedIDLoginResponse
		**/
		public function PerformEncryptedIDLogin ( $parameters ){
			return parent::PerformEncryptedIDLogin( $parameters );
		}

		/**
		 * @param PerformEmailAddressLogin $parameters
		 * @return PerformEmailAddressLoginResponse
		**/
		public function PerformEmailAddressLogin ( $parameters ){
			return parent::PerformEmailAddressLogin( $parameters );
		}

		/**
		 * @param PerformLogout $parameters
		 * @return PerformLogoutResponse
		**/
		public function PerformLogout ( $parameters ){
			return parent::PerformLogout( $parameters );
		}

		/**
		 * @param GetEncryptedID $parameters
		 * @return GetEncryptedIDResponse
		**/
		public function GetEncryptedID ( $parameters ){
			return parent::GetEncryptedID( $parameters );
		}

		/**
		 * @param GetAccountInfo $parameters
		 * @return GetAccountInfoResponse
		**/
		public function GetAccountInfo ( $parameters ){
			return parent::GetAccountInfo( $parameters );
		}

		/**
		 * @param GetClientCode $parameters
		 * @return GetClientCodeResponse
		**/
		public function GetClientCode ( $parameters ){
			return parent::GetClientCode( $parameters );
		}

		/**
		 * @param SetClientCode $parameters
		 * @return SetClientCodeResponse
		**/
		public function SetClientCode ( $parameters ){
			return parent::SetClientCode( $parameters );
		}

		/**
		 * @param GetNewsstandSources $parameters
		 * @return GetNewsstandSourcesResponse
		**/
		public function GetNewsstandSources ( $parameters ){
			return parent::GetNewsstandSources( $parameters );
		}

		/**
		 * @param GetNewsstandSections $parameters
		 * @return GetNewsstandSectionsResponse
		**/
		public function GetNewsstandSections ( $parameters ){
			return parent::GetNewsstandSections( $parameters );
		}

		/**
		 * @param GetNewsstandHeadlines $parameters
		 * @return GetNewsstandHeadlinesResponse
		**/
		public function GetNewsstandHeadlines ( $parameters ){
			return parent::GetNewsstandHeadlines( $parameters );
		}

		/**
		 * @param GetUserData $parameters
		 * @return GetUserDataResponse
		**/
		public function GetUserData ( $parameters ){
			return parent::GetUserData( $parameters );
		}

		/**
		 * @param GetUserDataEx $parameters
		 * @return GetUserDataExResponse
		**/
		public function GetUserDataEx ( $parameters ){
			return parent::GetUserDataEx( $parameters );
		}

		/**
		 * @param PerformUserRegistration $parameters
		 * @return PerformUserRegistrationResponse
		**/
		public function PerformUserRegistration ( $parameters ){
			return parent::PerformUserRegistration( $parameters );
		}

		/**
		 * @param PerformUserRegistrationEx $parameters
		 * @return PerformUserRegistrationExResponse
		**/
		public function PerformUserRegistrationEx ( $parameters ){
			return parent::PerformUserRegistrationEx( $parameters );
		}

		/**
		 * @param UpdateUserData $parameters
		 * @return UpdateUserDataResponse
		**/
		public function UpdateUserData ( $parameters ){
			return parent::UpdateUserData( $parameters );
		}

		/**
		 * @param UpdateUserDataEx $parameters
		 * @return UpdateUserDataExResponse
		**/
		public function UpdateUserDataEx ( $parameters ){
			return parent::UpdateUserDataEx( $parameters );
		}

		/**
		 * @param UpdateUserPassword $parameters
		 * @return UpdateUserPasswordResponse
		**/
		public function UpdateUserPassword ( $parameters ){
			return parent::UpdateUserPassword( $parameters );
		}

		/**
		 * @param ResetUserPassword $parameters
		 * @return ResetUserPasswordResponse
		**/
		public function ResetUserPassword ( $parameters ){
			return parent::ResetUserPassword( $parameters );
		}

		/**
		 * @param PerformSimplifiedEmailAddressRegistration $parameters
		 * @return PerformSimplifiedEmailAddressRegistrationResponse
		**/
		public function PerformSimplifiedEmailAddressRegistration ( $parameters ){
			return parent::PerformSimplifiedEmailAddressRegistration( $parameters );
		}

		/**
		 * @param UpdateLoginEmailAddress $parameters
		 * @return UpdateLoginEmailAddressResponse
		**/
		public function UpdateLoginEmailAddress ( $parameters ){
			return parent::UpdateLoginEmailAddress( $parameters );
		}

		/**
		 * @param EnableEmailAddressForLogin $parameters
		 * @return EnableEmailAddressForLoginResponse
		**/
		public function EnableEmailAddressForLogin ( $parameters ){
			return parent::EnableEmailAddressForLogin( $parameters );
		}

		/**
		 * @param SetupUserForEmailAddressLogin $parameters
		 * @return SetupUserForEmailAddressLoginResponse
		**/
		public function SetupUserForEmailAddressLogin ( $parameters ){
			return parent::SetupUserForEmailAddressLogin( $parameters );
		}

		/**
		 * @param PerformEmailAddressRegistration $parameters
		 * @return PerformEmailAddressRegistrationResponse
		**/
		public function PerformEmailAddressRegistration ( $parameters ){
			return parent::PerformEmailAddressRegistration( $parameters );
		}

		/**
		 * @param PerformEmailAddressRegistrationEx $parameters
		 * @return PerformEmailAddressRegistrationExResponse
		**/
		public function PerformEmailAddressRegistrationEx ( $parameters ){
			return parent::PerformEmailAddressRegistrationEx( $parameters );
		}

		/**
		 * @param GetArticle $parameters
		 * @return GetArticleResponse
		**/
		public function GetArticle ( $parameters ){
			return parent::GetArticle( $parameters );
		}

		/**
		 * @param GetHTML $parameters
		 * @return GetHTMLResponse
		**/
		public function GetHTML ( $parameters ){
			return parent::GetHTML( $parameters );
		}

		/**
		 * @param GetPicture $parameters
		 * @return GetPictureResponse
		**/
		public function GetPicture ( $parameters ){
			return parent::GetPicture( $parameters );
		}

		/**
		 * @param GetPDF $parameters
		 * @return GetPDFResponse
		**/
		public function GetPDF ( $parameters ){
			return parent::GetPDF( $parameters );
		}

		/**
		 * @param GetExternalURL $parameters
		 * @return GetExternalURLResponse
		**/
		public function GetExternalURL ( $parameters ){
			return parent::GetExternalURL( $parameters );
		}

		/**
		 * @param GetContent $parameters
		 * @return GetContentResponse
		**/
		public function GetContent ( $parameters ){
			return parent::GetContent( $parameters );
		}

		/**
		 * @param PerformContentSearch $parameters
		 * @return PerformContentSearchResponse
		**/
		public function PerformContentSearch ( $parameters ){
			return parent::PerformContentSearch( $parameters );
		}

		/**
		 * @param ContinueContentSearch $parameters
		 * @return ContinueContentSearchResponse
		**/
		public function ContinueContentSearch ( $parameters ){
			return parent::ContinueContentSearch( $parameters );
		}

		/**
		 * @param PerformContentSearchWithFDT $parameters
		 * @return PerformContentSearchWithFDTResponse
		**/
		public function PerformContentSearchWithFDT ( $parameters ){
			return parent::PerformContentSearchWithFDT( $parameters );
		}

		/**
		 * @param PerformContentSearchWithFDTEx $parameters
		 * @return PerformContentSearchWithFDTExResponse
		**/
		public function PerformContentSearchWithFDTEx ( $parameters ){
			return parent::PerformContentSearchWithFDTEx( $parameters );
		}

		/**
		 * @param GetMaxNavigatorElements $parameters
		 * @return GetMaxNavigatorElementsResponse
		**/
		public function GetMaxNavigatorElements ( $parameters ){
			return parent::GetMaxNavigatorElements( $parameters );
		}

		/**
		 * @param ContinueContentSearchWithFDT $parameters
		 * @return ContinueContentSearchWithFDTResponse
		**/
		public function ContinueContentSearchWithFDT ( $parameters ){
			return parent::ContinueContentSearchWithFDT( $parameters );
		}

		/**
		 * @param PerformSourceSearch $parameters
		 * @return PerformSourceSearchResponse
		**/
		public function PerformSourceSearch ( $parameters ){
			return parent::PerformSourceSearch( $parameters );
		}

		/**
		 * @param ContinueSourceSearch $parameters
		 * @return ContinueSourceSearchResponse
		**/
		public function ContinueSourceSearch ( $parameters ){
			return parent::ContinueSourceSearch( $parameters );
		}

		/**
		 * @param PerformSourceGroupSearch $parameters
		 * @return PerformSourceGroupSearchResponse
		**/
		public function PerformSourceGroupSearch ( $parameters ){
			return parent::PerformSourceGroupSearch( $parameters );
		}

		/**
		 * @param ContinueSourceGroupSearch $parameters
		 * @return ContinueSourceGroupSearchResponse
		**/
		public function ContinueSourceGroupSearch ( $parameters ){
			return parent::ContinueSourceGroupSearch( $parameters );
		}

		/**
		 * @param GetSourcesByCategory $parameters
		 * @return GetSourcesByCategoryResponse
		**/
		public function GetSourcesByCategory ( $parameters ){
			return parent::GetSourcesByCategory( $parameters );
		}

		/**
		 * @param GetSourcesByTitle $parameters
		 * @return GetSourcesByTitleResponse
		**/
		public function GetSourcesByTitle ( $parameters ){
			return parent::GetSourcesByTitle( $parameters );
		}

		/**
		 * @param GetSourcesByCode $parameters
		 * @return GetSourcesByCodeResponse
		**/
		public function GetSourcesByCode ( $parameters ){
			return parent::GetSourcesByCode( $parameters );
		}

		/**
		 * @param GetSourceGroupsByCode $parameters
		 * @return GetSourceGroupsByCodeResponse
		**/
		public function GetSourceGroupsByCode ( $parameters ){
			return parent::GetSourceGroupsByCode( $parameters );
		}

		/**
		 * @param PerformCompanySearch $parameters
		 * @return PerformCompanySearchResponse
		**/
		public function PerformCompanySearch ( $parameters ){
			return parent::PerformCompanySearch( $parameters );
		}

		/**
		 * @param PerformCompanySearchEx $parameters
		 * @return PerformCompanySearchExResponse
		**/
		public function PerformCompanySearchEx ( $parameters ){
			return parent::PerformCompanySearchEx( $parameters );
		}

		/**
		 * @param PerformCompanySearchEx2 $parameters
		 * @return PerformCompanySearchEx2Response
		**/
		public function PerformCompanySearchEx2 ( $parameters ){
			return parent::PerformCompanySearchEx2( $parameters );
		}

		/**
		 * @param ContinueCompanySearch $parameters
		 * @return ContinueCompanySearchResponse
		**/
		public function ContinueCompanySearch ( $parameters ){
			return parent::ContinueCompanySearch( $parameters );
		}

		/**
		 * @param ContinueCompanySearchEx $parameters
		 * @return ContinueCompanySearchExResponse
		**/
		public function ContinueCompanySearchEx ( $parameters ){
			return parent::ContinueCompanySearchEx( $parameters );
		}

		/**
		 * @param ContinueCompanySearchEx2 $parameters
		 * @return ContinueCompanySearchEx2Response
		**/
		public function ContinueCompanySearchEx2 ( $parameters ){
			return parent::ContinueCompanySearchEx2( $parameters );
		}

		/**
		 * @param GetCompanyByCode $parameters
		 * @return GetCompanyByCodeResponse
		**/
		public function GetCompanyByCode ( $parameters ){
			return parent::GetCompanyByCode( $parameters );
		}

		/**
		 * @param GetCompanyByCodeEx $parameters
		 * @return GetCompanyByCodeExResponse
		**/
		public function GetCompanyByCodeEx ( $parameters ){
			return parent::GetCompanyByCodeEx( $parameters );
		}

		/**
		 * @param GetCompanyByCodeEx2 $parameters
		 * @return GetCompanyByCodeEx2Response
		**/
		public function GetCompanyByCodeEx2 ( $parameters ){
			return parent::GetCompanyByCodeEx2( $parameters );
		}

		/**
		 * @param PerformInstrumentSearch $parameters
		 * @return PerformInstrumentSearchResponse
		**/
		public function PerformInstrumentSearch ( $parameters ){
			return parent::PerformInstrumentSearch( $parameters );
		}

		/**
		 * @param ContinueInstrumentSearch $parameters
		 * @return ContinueInstrumentSearchResponse
		**/
		public function ContinueInstrumentSearch ( $parameters ){
			return parent::ContinueInstrumentSearch( $parameters );
		}

		/**
		 * @param GetInstrumentByCode $parameters
		 * @return GetInstrumentByCodeResponse
		**/
		public function GetInstrumentByCode ( $parameters ){
			return parent::GetInstrumentByCode( $parameters );
		}

		/**
		 * @param PerformExchangeSearch $parameters
		 * @return PerformExchangeSearchResponse
		**/
		public function PerformExchangeSearch ( $parameters ){
			return parent::PerformExchangeSearch( $parameters );
		}

		/**
		 * @param GetExchangeByCode $parameters
		 * @return GetExchangeByCodeResponse
		**/
		public function GetExchangeByCode ( $parameters ){
			return parent::GetExchangeByCode( $parameters );
		}

		/**
		 * @param GetExchangeList $parameters
		 * @return GetExchangeListResponse
		**/
		public function GetExchangeList ( $parameters ){
			return parent::GetExchangeList( $parameters );
		}

		/**
		 * @param PerformIndustrySearch $parameters
		 * @return PerformIndustrySearchResponse
		**/
		public function PerformIndustrySearch ( $parameters ){
			return parent::PerformIndustrySearch( $parameters );
		}

		/**
		 * @param GetIndustryByCode $parameters
		 * @return GetIndustryByCodeResponse
		**/
		public function GetIndustryByCode ( $parameters ){
			return parent::GetIndustryByCode( $parameters );
		}

		/**
		 * @param GetIndustryChildren $parameters
		 * @return GetIndustryChildrenResponse
		**/
		public function GetIndustryChildren ( $parameters ){
			return parent::GetIndustryChildren( $parameters );
		}

		/**
		 * @param GetIndustryList $parameters
		 * @return GetIndustryListResponse
		**/
		public function GetIndustryList ( $parameters ){
			return parent::GetIndustryList( $parameters );
		}

		/**
		 * @param PerformRegionSearch $parameters
		 * @return PerformRegionSearchResponse
		**/
		public function PerformRegionSearch ( $parameters ){
			return parent::PerformRegionSearch( $parameters );
		}

		/**
		 * @param GetRegionByCode $parameters
		 * @return GetRegionByCodeResponse
		**/
		public function GetRegionByCode ( $parameters ){
			return parent::GetRegionByCode( $parameters );
		}

		/**
		 * @param GetRegionChildren $parameters
		 * @return GetRegionChildrenResponse
		**/
		public function GetRegionChildren ( $parameters ){
			return parent::GetRegionChildren( $parameters );
		}

		/**
		 * @param GetRegionList $parameters
		 * @return GetRegionListResponse
		**/
		public function GetRegionList ( $parameters ){
			return parent::GetRegionList( $parameters );
		}

		/**
		 * @param PerformNewsSubjectSearch $parameters
		 * @return PerformNewsSubjectSearchResponse
		**/
		public function PerformNewsSubjectSearch ( $parameters ){
			return parent::PerformNewsSubjectSearch( $parameters );
		}

		/**
		 * @param GetNewsSubjectByCode $parameters
		 * @return GetNewsSubjectByCodeResponse
		**/
		public function GetNewsSubjectByCode ( $parameters ){
			return parent::GetNewsSubjectByCode( $parameters );
		}

		/**
		 * @param GetNewsSubjectChildren $parameters
		 * @return GetNewsSubjectChildrenResponse
		**/
		public function GetNewsSubjectChildren ( $parameters ){
			return parent::GetNewsSubjectChildren( $parameters );
		}

		/**
		 * @param GetNewsSubjectList $parameters
		 * @return GetNewsSubjectListResponse
		**/
		public function GetNewsSubjectList ( $parameters ){
			return parent::GetNewsSubjectList( $parameters );
		}

		/**
		 * @param GetJobFunctionList $parameters
		 * @return GetJobFunctionListResponse
		**/
		public function GetJobFunctionList ( $parameters ){
			return parent::GetJobFunctionList( $parameters );
		}

		/**
		 * @param GetAuditorList $parameters
		 * @return GetAuditorListResponse
		**/
		public function GetAuditorList ( $parameters ){
			return parent::GetAuditorList( $parameters );
		}

		/**
		 * @param GetDegreeList $parameters
		 * @return GetDegreeListResponse
		**/
		public function GetDegreeList ( $parameters ){
			return parent::GetDegreeList( $parameters );
		}

		/**
		 * @param GetDepartmentList $parameters
		 * @return GetDepartmentListResponse
		**/
		public function GetDepartmentList ( $parameters ){
			return parent::GetDepartmentList( $parameters );
		}

		/**
		 * @param GetCurrencyList $parameters
		 * @return GetCurrencyListResponse
		**/
		public function GetCurrencyList ( $parameters ){
			return parent::GetCurrencyList( $parameters );
		}

		/**
		 * @param GetCurrencyByCode $parameters
		 * @return GetCurrencyByCodeResponse
		**/
		public function GetCurrencyByCode ( $parameters ){
			return parent::GetCurrencyByCode( $parameters );
		}

		/**
		 * @param GetIndexList $parameters
		 * @return GetIndexListResponse
		**/
		public function GetIndexList ( $parameters ){
			return parent::GetIndexList( $parameters );
		}

		/**
		 * @param GetListInfo $parameters
		 * @return GetListInfoResponse
		**/
		public function GetListInfo ( $parameters ){
			return parent::GetListInfo( $parameters );
		}

		/**
		 * @param GetFolderInfo $parameters
		 * @return GetFolderInfoResponse
		**/
		public function GetFolderInfo ( $parameters ){
			return parent::GetFolderInfo( $parameters );
		}

		/**
		 * @param GetFolderInfoByID $parameters
		 * @return GetFolderInfoByIDResponse
		**/
		public function GetFolderInfoByID ( $parameters ){
			return parent::GetFolderInfoByID( $parameters );
		}

		/**
		 * @param GetFolderHeadlines $parameters
		 * @return GetFolderHeadlinesResponse
		**/
		public function GetFolderHeadlines ( $parameters ){
			return parent::GetFolderHeadlines( $parameters );
		}

		/**
		 * @param GetFolderHeadlinesEx $parameters
		 * @return GetFolderHeadlinesExResponse
		**/
		public function GetFolderHeadlinesEx ( $parameters ){
			return parent::GetFolderHeadlinesEx( $parameters );
		}

		/**
		 * @param GetNewFolderHeadlines $parameters
		 * @return GetNewFolderHeadlinesResponse
		**/
		public function GetNewFolderHeadlines ( $parameters ){
			return parent::GetNewFolderHeadlines( $parameters );
		}

		/**
		 * @param CreateFolder $parameters
		 * @return CreateFolderResponse
		**/
		public function CreateFolder ( $parameters ){
			return parent::CreateFolder( $parameters );
		}

		/**
		 * @param ReviseFolder $parameters
		 * @return ReviseFolderResponse
		**/
		public function ReviseFolder ( $parameters ){
			return parent::ReviseFolder( $parameters );
		}

		/**
		 * @param DeleteFolder $parameters
		 * @return DeleteFolderResponse
		**/
		public function DeleteFolder ( $parameters ){
			return parent::DeleteFolder( $parameters );
		}

		/**
		 * @param GetFolder $parameters
		 * @return GetFolderResponse
		**/
		public function GetFolder ( $parameters ){
			return parent::GetFolder( $parameters );
		}

		/**
		 * @param PostContent $parameters
		 * @return PostContentResponse
		**/
		public function PostContent ( $parameters ){
			return parent::PostContent( $parameters );
		}

		/**
		 * @param UnpostContent $parameters
		 * @return UnpostContentResponse
		**/
		public function UnpostContent ( $parameters ){
			return parent::UnpostContent( $parameters );
		}

		/**
		 * @param DeleteContent $parameters
		 * @return DeleteContentResponse
		**/
		public function DeleteContent ( $parameters ){
			return parent::DeleteContent( $parameters );
		}

		/**
		 * @param AddEditorComment $parameters
		 * @return AddEditorCommentResponse
		**/
		public function AddEditorComment ( $parameters ){
			return parent::AddEditorComment( $parameters );
		}

		/**
		 * @param ReviseEditorComment $parameters
		 * @return ReviseEditorCommentResponse
		**/
		public function ReviseEditorComment ( $parameters ){
			return parent::ReviseEditorComment( $parameters );
		}

		/**
		 * @param GetEditorComment $parameters
		 * @return GetEditorCommentResponse
		**/
		public function GetEditorComment ( $parameters ){
			return parent::GetEditorComment( $parameters );
		}

		/**
		 * @param DeleteEditorComment $parameters
		 * @return DeleteEditorCommentResponse
		**/
		public function DeleteEditorComment ( $parameters ){
			return parent::DeleteEditorComment( $parameters );
		}

		/**
		 * @param AddInternalContent $parameters
		 * @return AddInternalContentResponse
		**/
		public function AddInternalContent ( $parameters ){
			return parent::AddInternalContent( $parameters );
		}

		/**
		 * @param ReviseInternalContent $parameters
		 * @return ReviseInternalContentResponse
		**/
		public function ReviseInternalContent ( $parameters ){
			return parent::ReviseInternalContent( $parameters );
		}

		/**
		 * @param GetInternalContent $parameters
		 * @return GetInternalContentResponse
		**/
		public function GetInternalContent ( $parameters ){
			return parent::GetInternalContent( $parameters );
		}

		/**
		 * @param DeleteInternalContent $parameters
		 * @return DeleteInternalContentResponse
		**/
		public function DeleteInternalContent ( $parameters ){
			return parent::DeleteInternalContent( $parameters );
		}

	}
?>